@@ -1,5 +1,5 @@
 /***************************************************************************
- *   (c) Jürgen Riegel (juergen.riegel@web.de) 2002                        *
+ *   Copyright (c) 2002 Jürgen Riegel <juergen.riegel@web.de>              *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -19,7 +19,6 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  *
  *   USA                                                                   *
  *                                                                         *
- *   Juergen Riegel 2002                                                   *
  ***************************************************************************/
 
 
@@ -51,10 +50,21 @@ using namespace Base;
 #error "Use Python2.5.x or higher"
 #endif
 
+PyException::PyException(const Py::Object &obj) {
+    _sErrMsg = obj.as_string();
+    // WARNING: we are assuming that python type object will never be
+    // destroyed, so we don't keep reference here to save book-keeping in
+    // our copy constructor and destructor
+    _exceptionType = (PyObject*)obj.ptr()->ob_type;
+    _errorType = obj.ptr()->ob_type->tp_name;
+}
 
 PyException::PyException(void)
 {
     PP_Fetch_Error_Text();    /* fetch (and clear) exception */
+
+    setPyObject(PP_PyDict_Object);
+
     std::string prefix = PP_last_error_type; /* exception name text */
 //  prefix += ": ";
     std::string error = PP_last_error_info;            /* exception data text */
@@ -70,6 +80,16 @@ PyException::PyException(void)
     _sErrMsg = error;
     _errorType = prefix;
 
+    _exceptionType = PP_last_exception_type;
+
+    if (PP_last_exception_type) {
+        // WARNING: we are assuming that python type object will never be
+        // destroyed, so we don't keep reference here to save book-keeping in
+        // our copy constructor and destructor
+        Py_DECREF(PP_last_exception_type);
+        PP_last_exception_type = 0;
+
+    }
 
     _stackTrace = PP_last_error_trace;     /* exception traceback text */
 
@@ -86,38 +106,60 @@ PyException::~PyException() throw()
 
 void PyException::ThrowException(void)
 {
-    PyException myexcp = PyException();
+    PyException myexcp;
+    myexcp.ReportException();
+    myexcp.raiseException();
+}
 
+void PyException::raiseException() {
     PyGILStateLocker locker;
+
     if (PP_PyDict_Object!=NULL) {
         // delete the Python dict upon destruction of edict
         Py::Dict edict(PP_PyDict_Object, true);
         PP_PyDict_Object = 0;
 
-        if (!edict.hasKey("sclassname"))
-            throw myexcp;
-
-        std::string exceptionname = static_cast<std::string>(Py::String(edict.getItem("sclassname")));
-        if (!Base::ExceptionFactory::Instance().CanProduce(exceptionname.c_str()))
-            throw myexcp;
-
+        std::string exceptionname;
+        if (_exceptionType == Base::BaseExceptionFreeCADAbort)
+            edict.setItem("sclassname",
+                    Py::String(typeid(Base::AbortException).name()));
+        if (_isReported)
+            edict.setItem("breported", Py::True());
         Base::ExceptionFactory::Instance().raiseException(edict.ptr());
     }
-    else
-        throw myexcp;
+
+    if (_exceptionType == Base::BaseExceptionFreeCADAbort) {
+        Base::AbortException e(_sErrMsg.c_str());
+        e.setReported(_isReported);
+        throw e;
+    }
+
+    throw *this;
 }
 
 void PyException::ReportException (void) const
 {
-    Base::Console().Error("%s%s: %s\n",
-        _stackTrace.c_str(), _errorType.c_str(), what());
+    if (!_isReported) {
+        _isReported = true;
+        Base::Console().Error("%s%s: %s\n",
+            _stackTrace.c_str(), _errorType.c_str(), what());
+    }
+}
+
+void PyException::setPyException() const
+{
+    std::stringstream str;
+    str << getStackTrace()
+        << getErrorType()
+        << ": " << what();
+    PyErr_SetString(getPyExceptionType(), str.str().c_str());
 }
 
 // ---------------------------------------------------------
 
 SystemExitException::SystemExitException()
 {
-    // Set exception message and code based upon the pthon sys.exit() code and/or message 
+    // Set exception message and code based upon the python sys.exit() code and/or message
     // based upon the following sys.exit() call semantics.
     //
     // Invocation       |  _exitCode  |  _sErrMsg
@@ -166,12 +208,6 @@ SystemExitException::SystemExitException()
     _exitCode = errCode;
 }
 
-SystemExitException::SystemExitException(const SystemExitException &inst)
-  : Exception(inst), _exitCode(inst._exitCode)
-{
-}
-
-
 // ---------------------------------------------------------
 
 // Fixes #0000831: python print causes File descriptor error on windows
@@ -257,6 +293,50 @@ std::string InterpreterSingleton::runString(const char *sCmd)
     }
 }
 
+/** runStringWithKey(psCmd, key, key_initial_value)
+ * psCmd is python script to run
+ * key is the name of a python string variable the script will have read/write
+ * access to during script execution.  It will be our return value.
+ * key_initial_value is the initial value c++ will set before calling the script
+ * If the script runs successfully it will be able to change the value of key as
+ * the return value, but if there is a runtime error key will not be changed even
+ * if the error occurs after changing it inside the script.
+ */
+
+std::string InterpreterSingleton::runStringWithKey(const char *psCmd, const char *key, const char *key_initial_value)
+{
+    PyGILStateLocker locker;
+    Py::Module module("__main__");
+    Py::Dict globalDictionary = module.getDict();
+    Py::Dict localDictionary;
+    Py::String initial_value(key_initial_value);
+    localDictionary.setItem(key, initial_value);
+
+    PyObject* presult = PyRun_String(psCmd, Py_file_input, globalDictionary.ptr(), localDictionary.ptr());
+    if (!presult) {
+        if (PyErr_ExceptionMatches(PyExc_SystemExit)) {
+            throw SystemExitException();
+        }
+        else {
+            PyException::ThrowException();
+            return std::string(); // just to quieten code analyzers
+        }
+    }
+    Py_DECREF(presult);
+
+    Py::Object key_return_value = localDictionary.getItem(key);
+    if (!key_return_value.isString())
+        key_return_value = key_return_value.str();
+
+#if PY_MAJOR_VERSION >= 3
+    Py::Bytes str = Py::String(key_return_value).encode("utf-8", "~E~");
+    std::string result = static_cast<std::string>(str);
+#else
+    std::string result = static_cast<std::string>(Py::String(key_return_value));
+#endif
+    return result;
+}
+
 Py::Object InterpreterSingleton::runStringObject(const char *sCmd)
 {
     PyObject *module, *dict, *presult;          /* "exec code in d, d" */
@@ -464,15 +544,8 @@ void InterpreterSingleton::addType(PyTypeObject* Type,PyObject* Module, const ch
 void InterpreterSingleton::addPythonPath(const char* Path)
 {
     PyGILStateLocker locker;
-    PyObject *list = PySys_GetObject("path");
-#if PY_MAJOR_VERSION >= 3
-    PyObject *path = PyUnicode_FromString(Path);
-#else
-    PyObject *path = PyString_FromString(Path);
-#endif
-    PyList_Append(list, path);
-    Py_DECREF(path);
-    PySys_SetObject("path", list);
+    Py::List list(PySys_GetObject("path"));
+    list.append(Py::String(Path));
 }
 
 const char* InterpreterSingleton::init(int argc,char *argv[])
@@ -494,7 +567,24 @@ const char* InterpreterSingleton::init(int argc,char *argv[])
         // https://bugs.python.org/issue17797#msg197474
         //
         Py_Initialize();
+        const char* virtualenv = getenv("VIRTUAL_ENV");
+        if (virtualenv) {
+            PyRun_SimpleString(
+                "# Check for virtualenv, and activate if present.\n"
+                "# See https://virtualenv.pypa.io/en/latest/userguide/#using-virtualenv-without-bin-python\n"
+                "import os\n"
+                "import sys\n"
+                "base_path = os.getenv(\"VIRTUAL_ENV\")\n"
+                "if not base_path is None:\n"
+                "    activate_this = os.path.join(base_path, \"bin\", \"activate_this.py\")\n"
+                "    exec(open(activate_this).read(), {'__file__':activate_this})\n"
+            );
+        }
+
+#if PY_VERSION_HEX < 0x03090000
         PyEval_InitThreads();
+#endif
+
 #if PY_MAJOR_VERSION >= 3
         size_t size = argc;
         wchar_t **_argv = new wchar_t*[size];
@@ -645,7 +735,11 @@ void InterpreterSingleton::runMethod(PyObject *pobject, const char *method,
         throw TypeError("InterpreterSingleton::RunMethod() wrong arguments");
     }
 
+#if PY_VERSION_HEX < 0x03090000
     presult = PyEval_CallObject(pmeth, pargs);   /* run interpreter */
+#else
+    presult = PyObject_CallObject(pmeth, pargs);   /* run interpreter */
+#endif
 
     Py_DECREF(pmeth);
     Py_DECREF(pargs);
@@ -745,7 +839,7 @@ int getSWIGVersionFromModule(const std::string& module)
             Py::String file(mod.getAttr("__file__"));
             std::string filename = (std::string)file;
             // file can have the extension .py or .pyc
-            filename = filename.substr(0, filename.rfind("."));
+            filename = filename.substr(0, filename.rfind('.'));
             filename += ".py";
             boost::regex rx("^# Version ([1-9])\\.([0-9])\\.([0-9]+)");
             boost::cmatch what;
@@ -818,6 +912,9 @@ PyObject* InterpreterSingleton::createSWIGPointerObj(const char* Module, const c
 #if (defined(HAVE_SWIG) && (HAVE_SWIG == 1))
     result = Swig_python::createSWIGPointerObj_T(TypeName, Pointer, &proxy, own);
 #else
+    (void)TypeName;
+    (void)Pointer;
+    (void)own;
     result = -1; // indicates error
 #endif
 #if PY_MAJOR_VERSION < 3
@@ -870,9 +967,13 @@ bool InterpreterSingleton::convertSWIGPointerObj(const char* Module, const char*
     (void)Module;
 #endif
 #if (defined(HAVE_SWIG) && (HAVE_SWIG == 1))
-        result = Swig_python::convertSWIGPointerObj_T(TypeName, obj, ptr, flags);
+    result = Swig_python::convertSWIGPointerObj_T(TypeName, obj, ptr, flags);
 #else
-        result = -1; // indicates error
+    (void)TypeName;
+    (void)obj;
+    (void)ptr;
+    (void)flags;
+    result = -1; // indicates error
 #endif
 #if PY_MAJOR_VERSION < 3
     }
@@ -901,6 +1002,8 @@ void InterpreterSingleton::cleanupSWIG(const char* TypeName)
     PyGILStateLocker locker;
 #if (defined(HAVE_SWIG) && (HAVE_SWIG == 1))
     Swig_python::cleanupSWIG_T(TypeName);
+#else
+    (void)TypeName;
 #endif
 #if PY_MAJOR_VERSION < 3
     Swig_1_3_25::cleanupSWIG_T(TypeName);
