@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) Jürgen Riegel          (juergen.riegel@web.de) 2002     *
+ *   Copyright (c) 2002 Jürgen Riegel <juergen.riegel@web.de>              *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -32,9 +32,12 @@
 #include "Console.h"
 #include "Interpreter.h"
 
+#define ATTR_TRACKING
+
 using namespace Base;
 
 PyObject* Base::BaseExceptionFreeCADError = 0;
+PyObject* Base::BaseExceptionFreeCADAbort = 0;
 
 // Constructor
 PyObjectBase::PyObjectBase(void* p,PyTypeObject *T)
@@ -50,7 +53,7 @@ PyObjectBase::PyObjectBase(void* p,PyTypeObject *T)
 }
 
 /// destructor
-PyObjectBase::~PyObjectBase() 
+PyObjectBase::~PyObjectBase()
 {
     PyGILStateLocker lock;
 #ifdef FC_LOGPYOBJECTS
@@ -63,8 +66,8 @@ PyObjectBase::~PyObjectBase()
  * PyObjectBase Type		-- Every class, even the abstract one should have a Type
 ------------------------------*/
 
-/** \brief 
- * To prevent subclasses of PyTypeObject to be subclassed in Python we should remove 
+/** \brief
+ * To prevent subclasses of PyTypeObject to be subclassed in Python we should remove
  * the Py_TPFLAGS_BASETYPE flag. For example, the classes App::VectorPy and App::MatrixPy
  * have removed this flag and its Python proxies App.Vector and App.Matrix cannot be subclassed.
  * In case we want to allow to derive from subclasses of PyTypeObject in Python
@@ -72,6 +75,11 @@ PyObjectBase::~PyObjectBase()
  * 0 and define tp_base as 0.
  */
 
+#if defined(__clang__)
+# pragma clang diagnostic push
+# pragma clang diagnostic ignored "-Wdeprecated-declarations"
+#endif
+
 PyTypeObject PyObjectBase::Type = {
     PyVarObject_HEAD_INIT(&PyType_Type,0)
     "PyObjectBase",                                         /*tp_name*/
@@ -130,8 +138,19 @@ PyTypeObject PyObjectBase::Type = {
 #if PY_MAJOR_VERSION >= 3
     ,0                                                      /*tp_finalize */
 #endif
+#if PY_VERSION_HEX >= 0x03090000
+    ,0                                                      /*tp_vectorcall */
+#elif PY_VERSION_HEX >= 0x03080000
+    ,0                                                      /*tp_vectorcall */
+    /* bpo-37250: kept for backwards compatibility in CPython 3.8 only */
+    ,0                                                      /*tp_print */
+#endif
 };
 
+#if defined(__clang__)
+# pragma clang diagnostic pop
+#endif
+
 /*------------------------------
  * PyObjectBase Methods 	-- Every class, even the abstract one should have a Methods
 ------------------------------*/
@@ -164,6 +183,7 @@ PyObject* PyObjectBase::__getattro(PyObject * obj, PyObject *attro)
         return NULL;
     }
 
+#ifdef ATTR_TRACKING
     // If an attribute references this as parent then reset it (bug #0002902)
     PyObject* cur = pyObj->getTrackedAttribute(attr);
     if (cur) {
@@ -173,9 +193,10 @@ PyObject* PyObjectBase::__getattro(PyObject * obj, PyObject *attro)
             pyObj->untrackAttribute(attr);
         }
     }
+#endif
 
     PyObject* value = pyObj->_getattr(attr);
-#if 1
+#ifdef ATTR_TRACKING
     if (value && PyObject_TypeCheck(value, &(PyObjectBase::Type))) {
         if (!static_cast<PyObjectBase*>(value)->isConst() &&
             !static_cast<PyObjectBase*>(value)->isNotTracking()) {
@@ -223,6 +244,7 @@ int PyObjectBase::__setattro(PyObject *obj, PyObject *attro, PyObject *value)
         return -1;
     }
 
+#ifdef ATTR_TRACKING
     // If an attribute references this as parent then reset it
     // before setting the new attribute
     PyObject* cur = static_cast<PyObjectBase*>(obj)->getTrackedAttribute(attr);
@@ -233,9 +255,10 @@ int PyObjectBase::__setattro(PyObject *obj, PyObject *attro, PyObject *value)
             static_cast<PyObjectBase*>(obj)->untrackAttribute(attr);
         }
     }
+#endif
 
     int ret = static_cast<PyObjectBase*>(obj)->_setattr(attr, value);
-#if 1
+#ifdef ATTR_TRACKING
     if (ret == 0) {
         static_cast<PyObjectBase*>(obj)->startNotify();
     }
@@ -249,8 +272,8 @@ int PyObjectBase::__setattro(PyObject *obj, PyObject *attro, PyObject *value)
 PyObject *PyObjectBase::_getattr(const char *attr)
 {
     if (streq(attr, "__class__")) {
-        // Note: We must return the type object here, 
-        // so that our own types feel as really Python objects 
+        // Note: We must return the type object here,
+        // so that our own types feel as really Python objects
         Py_INCREF(Py_TYPE(this));
         return (PyObject *)(Py_TYPE(this));
     }
