@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) Jürgen Riegel          (juergen.riegel@web.de) 2002     *
+ *   Copyright (c) 2002 Jürgen Riegel <juergen.riegel@web.de>              *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -46,7 +46,6 @@
 #undef isalnum
 #endif
 #define slots
-#include <iostream>
 #include <bitset>
 
 #include <typeinfo>
@@ -61,8 +60,8 @@
 
 
 /** Python static class macro for definition
- * sets up a static function entry in a class inheriting 
- * from PyObjectBase. Its a pure convenience macro. You can also do
+ * sets up a static function entry in a class inheriting
+ * from PyObjectBase. It's a pure convenience macro. You can also do
  * it by hand if you want. It looks like that:
  * \code
  * static PyObject* X (PyObject *self,PyObject *args,PyObject *kwd);
@@ -81,7 +80,7 @@
  * \code
  * PyObject* CLASS::SFUNC (PyObject *self,PyObject *args,PyObject *kwd)
  * \endcode
- * see PYFUNCDEF_S for details 
+ * see PYFUNCDEF_S for details
  * @param CLASS is the class in which the macro take place.
  * @param SFUNC is the object method get implemented
  * @see PYFUNCDEF_S
@@ -90,7 +89,7 @@
 #define PYFUNCIMP_S(CLASS,SFUNC) PyObject* CLASS::SFUNC (PyObject *self,PyObject *args,PyObject *kwd)
 
 
-/** Macro for initialization function of Python modules. 
+/** Macro for initialization function of Python modules.
  */
 #if PY_MAJOR_VERSION >= 3
 # define PyMOD_INIT_FUNC(name) PyMODINIT_FUNC PyInit_##name(void)
@@ -129,7 +128,7 @@ inline int streq(const char *A, const char *B)  // define "streq"
 
 inline void Assert(int expr, char *msg)         // C++ assert
 {
-    if (!expr) 
+    if (!expr)
     {
       fprintf(stderr, "%s\n", msg);
       exit(-1);
@@ -147,7 +146,11 @@ inline void Assert(int expr, char *msg)         // C++ assert
 /// return with no return value if nothing happens
 #define Py_Return return Py_INCREF(Py_None), Py_None
 /// returns an error
-#define Py_Error(E, M)   {PyErr_SetString(E, M); return NULL;}
+#define Py_Error(E, M)   _Py_Error(return(NULL),E,M)
+#define _Py_Error(R, E, M)   {PyErr_SetString(E, M); R;}
+/// returns an error
+#define Py_ErrorObj(E, O)   _Py_ErrorObj(return(NULL),E,O)
+#define _Py_ErrorObj(R, E, O)   {PyErr_SetObject(E, O); R;}
 /// checks on a condition and returns an error on failure
 #define Py_Try(F) {if (!(F)) return NULL;}
 /// assert which returns with an error on failure
@@ -171,7 +174,7 @@ namespace Base
 
 /** The PyObjectBase class, exports the class as a python type
  *  PyObjectBase is the base class for all C++ classes which
- *  need to get exported into the python namespace. This class is 
+ *  need to get exported into the python namespace. This class is
  *  very important because nearly all important classes in FreeCAD
  *  are visible in python for macro recording and automation purpose.
  *  The class App::Document is a good expample for an exported class.
@@ -188,9 +191,9 @@ namespace Base
  *  @see Py_Return
  *  @see Py_Error
  *  @see Py_Try
- *  @see Py_Assert  
+ *  @see Py_Assert
  */
-class BaseExport PyObjectBase : public PyObject 
+class BaseExport PyObjectBase : public PyObject
 {
     /** Py_Header struct from python.h.
      *  Every PyObjectBase object is also a python object. So you can use
@@ -209,7 +212,12 @@ protected:
     /// destructor
     virtual ~PyObjectBase();
 
-public:  
+    /// Overrides the pointer to the twin object
+    void setTwinPointer(void* ptr) {
+        _pcTwinPointer = ptr;
+    }
+
+public:
     /** Constructor
      *  Sets the Type of the object (for inheritance) and decrease the
      *  the reference count of the PyObject.
@@ -220,7 +228,7 @@ public:
     {  delete ((PyObjectBase *) P);  }
     /// incref method wrapper (see python extending manual)
     PyObjectBase* IncRef(void) {Py_INCREF(this);return this;}
-    /// decref method wrapper (see python extending manual)	
+    /// decref method wrapper (see python extending manual)
     PyObjectBase* DecRef(void) {Py_DECREF(this);return this;}
 
     /** GetAttribute implementation
@@ -229,7 +237,7 @@ public:
      *  this method.
      *  You have to call the method of the base class.
      *  Note: if you reimplement _gettattr() in a inheriting class you
-     *  need to call the method of the base class! Otherwise even the 
+     *  need to call the method of the base class! Otherwise even the
      *  methods of the object will disappear!
      */
     virtual PyObject *_getattr(const char *attr);
@@ -243,7 +251,7 @@ public:
      *  You have to call the method of the base class.
      */
     virtual int _setattr(const char *attro, PyObject *value);    // _setattr method
-    /// static wrapper for pythons _setattro(). // This should be the entry in Type. 
+    /// static wrapper for pythons _setattro(). // This should be the entry in Type.
     static  int __setattro(PyObject *PyObj, PyObject *attro, PyObject *value);
 
     /** _repr method
@@ -284,7 +292,7 @@ public:
         return ((PyObjectBase*) self)->PyInit(args, kwd);
     }
 
-    void setInvalid() { 
+    void setInvalid() {
         // first bit is not set, i.e. invalid
         StatusBits.reset(Valid);
         clearAttributes();
@@ -345,7 +353,7 @@ private:
 
 
 /** Python dynamic class macro for definition
- * sets up a static/dynamic function entry in a class inheriting 
+ * sets up a static/dynamic function entry in a class inheriting
  * from PyObjectBase. Its a pure convenience macro. You can also do
  * it by hand if you want. It looks like that:
  * \code
@@ -354,7 +362,7 @@ private:
  *        {return ((FCPyParametrGrp*)self)->PyGetGrp(args);};
  * \endcode
  * first the method is defined which have the functionality then the
- * static wrapper is used to provide a callback for python. The call 
+ * static wrapper is used to provide a callback for python. The call
  * is simply mapped to the method.
  * @param CLASS is the class in which the macro take place.
  * @param DFUNC is the object method get defined and called
@@ -389,7 +397,7 @@ static PyObject * s##DFUNC (PyObject *self, PyObject *args, PyObject * /*kwd*/){
  * PyMethodDef DocTypeStdPy::Methods[] = {
  * 	{"AddFeature",    (PyCFunction) sAddFeature,    Py_NEWARGS},
  * 	{"RemoveFeature", (PyCFunction) sRemoveFeature, Py_NEWARGS},
- *	{NULL, NULL}		
+ *	{NULL, NULL}
  * };
  * \endcode
  * instead of:
@@ -397,10 +405,10 @@ static PyObject * s##DFUNC (PyObject *self, PyObject *args, PyObject * /*kwd*/){
  * PyMethodDef DocTypeStdPy::Methods[] = {
  *	PYMETHODEDEF(AddFeature)
  *	PYMETHODEDEF(RemoveFeature)
- *	{NULL, NULL}		
+ *	{NULL, NULL}
  * };
  * \endcode
- * see PYFUNCDEF_D for details 
+ * see PYFUNCDEF_D for details
  * @param FUNC is the object method get defined
  * @see PYFUNCDEF_D
  * @see PyObjectBase
@@ -411,6 +419,7 @@ BaseExport extern PyObject* BaseExceptionFreeCADError;
 #define PY_FCERROR (Base::BaseExceptionFreeCADError ? \
  BaseExceptionFreeCADError : PyExc_RuntimeError)
 
+BaseExport extern PyObject* BaseExceptionFreeCADAbort;
 
 /** Exception handling for python callback functions
  * Is a convenience macro to manage the exception handling of python callback
@@ -420,9 +429,9 @@ BaseExport extern PyObject* BaseExceptionFreeCADError;
  * PYFUNCIMP_D(DocTypeStdPy,AddFeature)
  * {
  *   char *pstr;
- *   if (!PyArg_ParseTuple(args, "s", &pstr))     // convert args: Python->C 
- *      return NULL;                             // NULL triggers exception 
- * 
+ *   if (!PyArg_ParseTuple(args, "s", &pstr))     // convert args: Python->C
+ *      return NULL;                             // NULL triggers exception
+ *
  *   try {
  *     Feature *pcFtr = _pcDocTypeStd->AddFeature(pstr);
  *   }catch(...)                                                        \
@@ -436,86 +445,61 @@ BaseExport extern PyObject* BaseExceptionFreeCADError;
  * PYFUNCIMP_D(DocTypeStdPy,AddFeature)
  * {
  *   char *pstr;
- *   if (!PyArg_ParseTuple(args, "s", &pstr))     // convert args: Python->C 
- *      return NULL;                             // NULL triggers exception 
- * 
+ *   if (!PyArg_ParseTuple(args, "s", &pstr))     // convert args: Python->C
+ *      return NULL;                             // NULL triggers exception
+ *
  *  PY_TRY {
  *    Feature *pcFtr = _pcDocTypeStd->AddFeature(pstr);
  *  }PY_CATCH;
  * }
  * \endcode
- * this catch maps all of the FreeCAD standard exception to a clear output for the 
+ * this catch maps all of the FreeCAD standard exception to a clear output for the
  * Python exception.
  * @see PYMETHODEDEF
  * @see PyObjectBase
  */
-#define PY_TRY	try 
+#define PY_TRY	try
 
-#ifndef DONT_CATCH_CXX_EXCEPTIONS 
-/// see docu of PY_TRY 
-#  define PY_CATCH catch(Base::Exception &e)                        \
+#define __PY_CATCH(R)                                               \
+    catch(Base::AbortException &e)                                  \
     {                                                               \
-        std::string str;                                            \
-        str += "FreeCAD exception thrown (";                        \
-        str += e.what();                                            \
-        str += ")";                                                 \
         e.ReportException();                                        \
-        Py_Error(Base::BaseExceptionFreeCADError,str.c_str());      \
+        _Py_ErrorObj(R,Base::BaseExceptionFreeCADAbort,e.getPyObject());\
+    }                                                               \
+    catch(Base::Exception &e)                                       \
+    {                                                               \
+        e.ReportException();                                        \
+        auto pye = e.getPyExceptionType();                          \
+        if(!pye)                                                    \
+            pye = Base::BaseExceptionFreeCADError;                  \
+        _Py_ErrorObj(R,pye,e.getPyObject());                        \
     }                                                               \
     catch(std::exception &e)                                        \
     {                                                               \
-        std::string str;                                            \
-        str += "STL exception thrown (";                            \
-        str += e.what();                                            \
-        str += ")";                                                 \
-        Base::Console().Error(str.c_str());                         \
-        Py_Error(Base::BaseExceptionFreeCADError,str.c_str());      \
+        _Py_Error(R,Base::BaseExceptionFreeCADError,e.what());      \
     }                                                               \
     catch(const Py::Exception&)                                     \
     {                                                               \
-        return NULL;                                                \
-    }                                                               \
-    catch(const char *e)                                            \
-    {                                                               \
-        Py_Error(Base::BaseExceptionFreeCADError,e);                \
+        R;                                                          \
     }                                                               \
+
+#ifndef DONT_CATCH_CXX_EXCEPTIONS
+/// see docu of PY_TRY
+#  define _PY_CATCH(R)                                              \
+    __PY_CATCH(R)                                                   \
     catch(...)                                                      \
     {                                                               \
-        Py_Error(Base::BaseExceptionFreeCADError,"Unknown C++ exception"); \
+        _Py_Error(R,Base::BaseExceptionFreeCADError,"Unknown C++ exception"); \
     }
 
 #else
-/// see docu of PY_TRY 
-#  define PY_CATCH catch(Base::Exception &e)                        \
-    {                                                               \
-        std::string str;                                            \
-        str += "FreeCAD exception thrown (";                        \
-        str += e.what();                                            \
-        str += ")";                                                 \
-        e.ReportException();                                        \
-        Py_Error(Base::BaseExceptionFreeCADError,str.c_str());      \
-    }                                                               \
-    catch(std::exception &e)                                        \
-    {                                                               \
-        std::string str;                                            \
-        str += "STL exception thrown (";                            \
-        str += e.what();                                            \
-        str += ")";                                                 \
-        Base::Console().Error(str.c_str());                         \
-        Py_Error(Base::BaseExceptionFreeCADError,str.c_str());      \
-    }                                                               \
-    catch(const Py::Exception&)                                     \
-    {                                                               \
-        return NULL;                                                \
-    }                                                               \
-    catch(const char *e)                                            \
-    {                                                               \
-        Py_Error(Base::BaseExceptionFreeCADError,e);                \
-    }
-
+/// see docu of PY_TRY
+#  define _PY_CATCH(R) __PY_CATCH(R)
 #endif  // DONT_CATCH_CXX_EXCEPTIONS
 
-/** Python helper class 
+#define PY_CATCH _PY_CATCH(return(NULL))
+
+/** Python helper class
  *  This class encapsulate the Decoding of UTF8 to a python object.
  *  Including exception handling.
  */
