@@ -48,13 +48,13 @@ class BaseExport Stream
 {
 public:
     enum ByteOrder { BigEndian, LittleEndian };
-    
+
     ByteOrder byteOrder() const;
     void setByteOrder(ByteOrder);
 
 protected:
     Stream();
-    virtual ~Stream(); 
+    virtual ~Stream();
 
     bool _swap;
 };
@@ -171,9 +171,9 @@ protected:
     virtual std::streamsize showmanyc();
     virtual pos_type seekoff(std::streambuf::off_type off,
         std::ios_base::seekdir way,
-        std::ios_base::openmode which = 
+        std::ios_base::openmode which =
             std::ios::in | std::ios::out);
-    virtual pos_type seekpos(std::streambuf::pos_type pos, 
+    virtual pos_type seekpos(std::streambuf::pos_type pos,
         std::ios_base::openmode which =
             std::ios::in | std::ios::out);
 
@@ -248,8 +248,17 @@ class BaseExport PyStreambuf : public std::streambuf
     typedef std::ios::openmode       openmode;
 
 public:
+    enum Type {
+        StringIO,
+        BytesIO,
+        Unknown
+    };
+
     PyStreambuf(PyObject* o, std::size_t buf_size = 256, std::size_t put_back = 8);
     virtual ~PyStreambuf();
+    void setType(Type t) {
+        type = t;
+    }
 
 protected:
     int_type underflow();
@@ -261,9 +270,11 @@ protected:
 
 private:
     bool flushBuffer();
+    bool writeStr(const char* s, std::streamsize num);
 
 private:
     PyObject* inp;
+    Type type;
     const std::size_t put_back;
     std::vector<char> buffer;
 };
@@ -281,9 +292,9 @@ protected:
     virtual std::streamsize showmanyc();
     virtual pos_type seekoff(std::streambuf::off_type off,
         std::ios_base::seekdir way,
-        std::ios_base::openmode which = 
+        std::ios_base::openmode which =
             std::ios::in | std::ios::out);
-    virtual pos_type seekpos(std::streambuf::pos_type pos, 
+    virtual pos_type seekpos(std::streambuf::pos_type pos,
         std::ios_base::openmode which =
             std::ios::in | std::ios::out);
 
@@ -329,7 +340,7 @@ public:
 class ifstream : public std::ifstream
 {
 public:
-    ifstream(const FileInfo& fi, ios_base::openmode mode = 
+    ifstream(const FileInfo& fi, ios_base::openmode mode =
                                  std::ios::in)
 #ifdef _MSC_VER
     : std::ifstream(fi.toStdWString().c_str(), mode)
