@@ -1,3 +1,24 @@
+/***************************************************************************
+ *   Copyright (c) 2013 Jürgen Riegel <juergen.riegel@web.de>              *
+ *                                                                         *
+ *   This file is part of the FreeCAD CAx development system.              *
+ *                                                                         *
+ *   This library is free software; you can redistribute it and/or         *
+ *   modify it under the terms of the GNU Library General Public           *
+ *   License as published by the Free Software Foundation; either          *
+ *   version 2 of the License, or (at your option) any later version.      *
+ *                                                                         *
+ *   This library  is distributed in the hope that it will be useful,      *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU Library General Public License for more details.                  *
+ *                                                                         *
+ *   You should have received a copy of the GNU Library General Public     *
+ *   License along with this library; see the file COPYING.LIB. If not,    *
+ *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
+ *   Suite 330, Boston, MA  02111-1307, USA                                *
+ *                                                                         *
+ ***************************************************************************/
 
 #include "PreCompiled.h"
 
@@ -15,7 +36,7 @@ std::string UnitPy::representation(void) const
 {
     const UnitSignature &  Sig = getUnitPtr()->getSignature();
     std::stringstream ret;
-    ret << "Unit: "; 
+    ret << "Unit: ";
     ret << getUnitPtr()->getString().toUtf8().constData() << " (";
     ret << Sig.Length << ",";
     ret << Sig.Mass  << ",";
@@ -24,9 +45,9 @@ std::string UnitPy::representation(void) const
     ret << Sig.ThermodynamicTemperature << ",";
     ret << Sig.AmountOfSubstance  << ",";
     ret << Sig.LuminousIntensity  << ",";
-    ret << Sig.Angle  << ")"; 
+    ret << Sig.Angle  << ")";
     std::string type = getUnitPtr()->getTypeString().toUtf8().constData();
-    if(! type.empty())
+    if (! type.empty())
         ret << " [" << type << "]";
 
     return ret.str();
@@ -34,15 +55,48 @@ std::string UnitPy::representation(void) const
 
 PyObject *UnitPy::PyMake(struct _typeobject *, PyObject *, PyObject *)  // Python wrapper
 {
-    // create a new instance of UnitPy and the Twin object 
+    // create a new instance of UnitPy and the Twin object
     return new UnitPy(new Unit);
 }
 
 // constructor method
 int UnitPy::PyInit(PyObject* args, PyObject* /*kwd*/)
 {
+    PyObject *object;
     Unit *self = getUnitPtr();
 
+    // get quantity
+    if (PyArg_ParseTuple(args,"O!",&(Base::QuantityPy::Type), &object)) {
+        // Note: must be static_cast, not reinterpret_cast
+        *self = static_cast<Base::QuantityPy*>(object)->getQuantityPtr()->getUnit();
+        return 0;
+    }
+    PyErr_Clear(); // set by PyArg_ParseTuple()
+
+    // get unit
+    if (PyArg_ParseTuple(args,"O!",&(Base::UnitPy::Type), &object)) {
+        // Note: must be static_cast, not reinterpret_cast
+        *self = *(static_cast<Base::UnitPy*>(object)->getUnitPtr());
+        return 0;
+    }
+    PyErr_Clear(); // set by PyArg_ParseTuple()
+
+    // get string
+    char* string;
+    if (PyArg_ParseTuple(args,"et", "utf-8", &string)) {
+        QString qstr = QString::fromUtf8(string);
+        PyMem_Free(string);
+        try {
+            *self = Quantity::parse(qstr).getUnit();
+            return 0;
+        }
+        catch (const Base::Exception& e) {
+            PyErr_SetString(PyExc_RuntimeError, e.what());
+            return -1;
+        }
+    }
+    PyErr_Clear(); // set by PyArg_ParseTuple()
+
     int i1=0;
     int i2=0;
     int i3=0;
@@ -52,32 +106,14 @@ int UnitPy::PyInit(PyObject* args, PyObject* /*kwd*/)
     int i7=0;
     int i8=0;
     if (PyArg_ParseTuple(args, "|iiiiiiii", &i1,&i2,&i3,&i4,&i5,&i6,&i7,&i8)) {
-        *self = Unit(i1,i2,i3,i4,i5,i6,i7,i8);
-        return 0;
-    }
-    PyErr_Clear(); // set by PyArg_ParseTuple()
-
-    PyObject *object;
-
-    if (PyArg_ParseTuple(args,"O!",&(Base::QuantityPy::Type), &object)) {
-        // Note: must be static_cast, not reinterpret_cast
-        *self = static_cast<Base::QuantityPy*>(object)->getQuantityPtr()->getUnit();
-        return 0;
-    }
-    PyErr_Clear(); // set by PyArg_ParseTuple()
-
-    if (PyArg_ParseTuple(args,"O!",&(Base::UnitPy::Type), &object)) {
-        // Note: must be static_cast, not reinterpret_cast
-        *self = *(static_cast<Base::UnitPy*>(object)->getUnitPtr());
-        return 0;
-    }
-    PyErr_Clear(); // set by PyArg_ParseTuple()
-    char* string;
-    if (PyArg_ParseTuple(args,"et", "utf-8", &string)) {
-        QString qstr = QString::fromUtf8(string);
-        PyMem_Free(string);
-        *self = Quantity::parse(qstr).getUnit();
-        return 0;
+        try {
+            *self = Unit(i1,i2,i3,i4,i5,i6,i7,i8);
+            return 0;
+        }
+        catch (const Base::OverflowError& e) {
+            PyErr_SetString(PyExc_OverflowError, e.what());
+            return -1;
+        }
     }
 
     PyErr_SetString(PyExc_TypeError, "Either string, (float,8 ints), Unit() or Quantity()");
@@ -137,7 +173,7 @@ PyObject* UnitPy::number_multiply_handler(PyObject *self, PyObject *other)
     if (PyObject_TypeCheck(other, &(UnitPy::Type))) {
         Base::Unit *a = static_cast<UnitPy*>(self) ->getUnitPtr();
         Base::Unit *b = static_cast<UnitPy*>(other)->getUnitPtr();
-        
+
         return new UnitPy(new Unit( (*a) * (*b) ) );
     }
     else {
@@ -206,7 +242,7 @@ PyObject *UnitPy::getCustomAttributes(const char* /*attr*/) const
 
 int UnitPy::setCustomAttributes(const char* /*attr*/, PyObject* /*obj*/)
 {
-    return 0; 
+    return 0;
 }
 
 PyObject * UnitPy::number_divide_handler (PyObject* /*self*/, PyObject* /*other*/)
