@@ -38,6 +38,7 @@
 #include <xercesc/util/TranscodingException.hpp>
 #include <boost/regex.hpp>
 
+#include "Action.h"
 #include "Application.h"
 #include "BitmapFactory.h"
 #include "Command.h"
@@ -101,6 +102,12 @@ PyMethodDef Application::Methods[] = {
   {"addIcon",                 (PyCFunction) Application::sAddIcon, METH_VARARGS,
    "addIcon(string, string or list) -> None\n\n"
    "Add an icon as file name or in XPM format to the system"},
+  {"getIcon",                 (PyCFunction) Application::sGetIcon, METH_VARARGS,
+   "getIcon(string) -> QIcon\n\n"
+   "Get an icon in the system"},
+  {"isIconCached",           (PyCFunction) Application::sIsIconCached, METH_VARARGS,
+   "isIconCached(String) -> Bool\n\n"
+   "Check if an icon with the given name is cached"},
   {"getMainWindow",           (PyCFunction) Application::sGetMainWindow, METH_VARARGS,
    "getMainWindow() -> QMainWindow\n\n"
    "Return the main window instance"},
@@ -132,11 +139,10 @@ PyMethodDef Application::Methods[] = {
   {"runCommand",              (PyCFunction) Application::sRunCommand, METH_VARARGS,
    "runCommand(string) -> None\n\n"
    "Run command with name"},
-  {"listCommands",               (PyCFunction) Application::sListCommands, METH_VARARGS,
-   "listCommands() -> list of strings\n\n"
-   "Returns a list of all commands known to FreeCAD."},
   {"SendMsgToActiveView",     (PyCFunction) Application::sSendActiveView, METH_VARARGS,
    "deprecated -- use class View"},
+  {"sendMsgToFocusView",     (PyCFunction) Application::sSendFocusView, METH_VARARGS,
+   "send message to the focused view"},
   {"hide",                    (PyCFunction) Application::sHide, METH_VARARGS,
    "deprecated"},
   {"show",                    (PyCFunction) Application::sShow, METH_VARARGS,
@@ -160,11 +166,14 @@ PyMethodDef Application::Methods[] = {
    "setActiveDocument(string or App.Document) -> None\n\n"
    "Activate the specified document"},
   {"activeView", (PyCFunction)Application::sActiveView, METH_VARARGS,
-   "activeView() -> object or None\n\n"
-   "Return the active view of the active document or None if no one exists"},
+   "activeView(typename=None) -> object or None\n\n"
+   "Return the active view of the active document or None if no one exists" },
   {"activateView", (PyCFunction)Application::sActivateView, METH_VARARGS,
    "activateView(type)\n\n"
    "Activate a view of the given type of the active document"},
+  {"editDocument", (PyCFunction)Application::sEditDocument, METH_VARARGS,
+   "editDocument() -> object or None\n\n"
+   "Return the current editing document or None if no one exists" },
   {"getDocument",             (PyCFunction) Application::sGetDocument, METH_VARARGS,
    "getDocument(string) -> object\n\n"
    "Get a document by its name"},
@@ -189,7 +198,7 @@ PyMethodDef Application::Methods[] = {
 
   {"getMarkerIndex", (PyCFunction) Application::sGetMarkerIndex, METH_VARARGS,
    "Get marker index according to marker size setting"},
-   
+
     {"addDocumentObserver",  (PyCFunction) Application::sAddDocObserver, METH_VARARGS,
      "addDocumentObserver() -> None\n\n"
      "Add an observer to get notified about changes on documents."},
@@ -197,9 +206,37 @@ PyMethodDef Application::Methods[] = {
      "removeDocumentObserver() -> None\n\n"
      "Remove an added document observer."},
 
+  {"reload",                    (PyCFunction) Application::sReload, METH_VARARGS,
+   "reload(name) -> doc\n\n"
+   "Reload a partial opened document"},
+
+  {"loadFile",       (PyCFunction) Application::sLoadFile, METH_VARARGS,
+   "loadFile(string=filename,[string=module]) -> None\n\n"
+   "Loads an arbitrary file by delegating to the given Python module:\n"
+   "* If no module is given it will be determined by the file extension.\n"
+   "* If more than one module can load a file the first one will be taken.\n"
+   "* If no module exists to load the file an exception will be raised."},
+
+  {"coinRemoveAllChildren",     (PyCFunction) Application::sCoinRemoveAllChildren, METH_VARARGS,
+   "Remove all children from a group node"},
+
   {NULL, NULL, 0, NULL}		/* Sentinel */
 };
 
+PyObject* Gui::Application::sEditDocument(PyObject * /*self*/, PyObject *args)
+{
+	if (!PyArg_ParseTuple(args, ""))     // convert args: Python->C
+		return NULL;                       // NULL triggers exception
+
+	Document *pcDoc = Instance->editDocument();
+	if (pcDoc) {
+		return pcDoc->getPyObject();
+	}
+	else {
+		Py_Return;
+	}
+}
+
 PyObject* Gui::Application::sActiveDocument(PyObject * /*self*/, PyObject *args)
 {
     if (!PyArg_ParseTuple(args, ""))
@@ -216,16 +253,37 @@ PyObject* Gui::Application::sActiveDocument(PyObject * /*self*/, PyObject *args)
 
 PyObject* Gui::Application::sActiveView(PyObject * /*self*/, PyObject *args)
 {
-    if (!PyArg_ParseTuple(args, ""))
+    const char *typeName=0;
+    if (!PyArg_ParseTuple(args, "|s", &typeName))
         return NULL;
 
-    Gui::MDIView* mdiView = Instance->activeView();
-    if (mdiView) {
-        // already incremented in getPyObject().
-        return mdiView->getPyObject();
-    }
+    PY_TRY {
+        Base::Type type;
+        if(typeName) {
+            type = Base::Type::fromName(typeName);
+            if(type.isBad()) {
+                PyErr_Format(PyExc_TypeError, "Invalid type '%s'", typeName);
+                return 0;
+            }
+        }
 
-    Py_Return;
+        Gui::MDIView* mdiView = Instance->activeView();
+        if (mdiView && (type.isBad() || mdiView->isDerivedFrom(type))) {
+            auto res = Py::asObject(mdiView->getPyObject());
+            if(!res.isNone() || !type.isBad())
+                return Py::new_reference_to(res);
+        }
+
+        if(type.isBad())
+            type = Gui::View3DInventor::getClassTypeId();
+        Instance->activateView(type, true);
+        mdiView = Instance->activeView();
+        if (mdiView)
+            return mdiView->getPyObject();
+
+        Py_Return;
+
+    } PY_CATCH
 }
 
 PyObject* Gui::Application::sActivateView(PyObject * /*self*/, PyObject *args)
@@ -525,8 +583,13 @@ PyObject* Application::sExport(PyObject * /*self*/, PyObject *args)
         QFileInfo fi;
         fi.setFile(fileName);
         QString ext = fi.suffix().toLower();
-        if (ext == QLatin1String("iv") || ext == QLatin1String("wrl") ||
-            ext == QLatin1String("vrml") || ext == QLatin1String("wrz")) {
+        if (ext == QLatin1String("iv") ||
+            ext == QLatin1String("wrl") ||
+            ext == QLatin1String("vrml") ||
+            ext == QLatin1String("wrz") ||
+            ext == QLatin1String("x3d") ||
+            ext == QLatin1String("x3dz") ||
+            ext == QLatin1String("xhtml")) {
 
             // build up the graph
             SoSeparator* sep = new SoSeparator();
@@ -604,6 +667,28 @@ PyObject* Application::sSendActiveView(PyObject * /*self*/, PyObject *args)
     return Py_None;
 }
 
+PyObject* Application::sSendFocusView(PyObject * /*self*/, PyObject *args)
+{
+    char *psCommandStr;
+    PyObject *suppress=Py_False;
+    if (!PyArg_ParseTuple(args, "s|O!",&psCommandStr,&PyBool_Type,&suppress))
+        return NULL;
+
+    const char* ppReturn=0;
+    if (!Instance->sendMsgToFocusView(psCommandStr,&ppReturn)) {
+        if (!PyObject_IsTrue(suppress))
+            Base::Console().Warning("Unknown view command: %s\n",psCommandStr);
+    }
+
+    // Print the return value to the output
+    if (ppReturn) {
+        return Py_BuildValue("s",ppReturn);
+    }
+
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
 PyObject* Application::sGetMainWindow(PyObject * /*self*/, PyObject *args)
 {
     if (!PyArg_ParseTuple(args, ""))
@@ -773,7 +858,8 @@ PyObject* Application::sActivateWorkbenchHandler(PyObject * /*self*/, PyObject *
     }
 
     try {
-        Instance->activateWorkbench(psKey);
+        bool ok = Instance->activateWorkbench(psKey);
+        return Py::new_reference_to(Py::Boolean(ok));
     }
     catch (const Base::Exception& e) {
         std::stringstream err;
@@ -799,9 +885,6 @@ PyObject* Application::sActivateWorkbenchHandler(PyObject * /*self*/, PyObject *
         PyErr_SetString(Base::BaseExceptionFreeCADError, err.str().c_str());
         return 0;
     }
-
-    Py_INCREF(Py_None);
-    return Py_None;
 }
 
 PyObject* Application::sAddWorkbenchHandler(PyObject * /*self*/, PyObject *args)
@@ -816,17 +899,17 @@ PyObject* Application::sAddWorkbenchHandler(PyObject * /*self*/, PyObject *args)
         // to be base class for all workbench classes
         Py::Module module("__main__");
         Py::Object baseclass(module.getAttr(std::string("Workbench")));
-        
+
         // check whether it is an instance or class object
         Py::Object object(pcObject);
         Py::String name;
-        
+
         if (PyObject_IsSubclass(object.ptr(), baseclass.ptr()) == 1) {
             // create an instance of this class
             name = object.getAttr(std::string("__name__"));
-            Py::Tuple args;
+            Py::Tuple arg;
             Py::Callable creation(object);
-            object = creation.apply(args);
+            object = creation.apply(arg);
         }
         else if (PyObject_IsInstance(object.ptr(), baseclass.ptr()) == 1) {
             // extract the class name of the instance
@@ -845,7 +928,7 @@ PyObject* Application::sAddWorkbenchHandler(PyObject * /*self*/, PyObject *args)
         Py::Callable(object.getAttr(std::string("GetClassName")));
         item = name.as_std_string("ascii");
 
-        PyObject* wb = PyDict_GetItemString(Instance->_pcWorkbenchDictionary,item.c_str()); 
+        PyObject* wb = PyDict_GetItemString(Instance->_pcWorkbenchDictionary,item.c_str());
         if (wb) {
             PyErr_Format(PyExc_KeyError, "'%s' already exists.", item.c_str());
             return NULL;
@@ -868,7 +951,7 @@ PyObject* Application::sRemoveWorkbenchHandler(PyObject * /*self*/, PyObject *ar
     if (!PyArg_ParseTuple(args, "s", &psKey))
         return NULL;
 
-    PyObject* wb = PyDict_GetItemString(Instance->_pcWorkbenchDictionary,psKey); 
+    PyObject* wb = PyDict_GetItemString(Instance->_pcWorkbenchDictionary,psKey);
     if (!wb) {
         PyErr_Format(PyExc_KeyError, "No such workbench '%s'", psKey);
         return NULL;
@@ -887,7 +970,7 @@ PyObject* Application::sGetWorkbenchHandler(PyObject * /*self*/, PyObject *args)
     char* psKey;
     if (!PyArg_ParseTuple(args, "s", &psKey))
         return NULL;
-   
+
     // get the python workbench object from the dictionary
     PyObject* pcWorkbench = PyDict_GetItemString(Instance->_pcWorkbenchDictionary, psKey);
     if (!pcWorkbench) {
@@ -989,27 +1072,24 @@ PyObject* Application::sAddIconPath(PyObject * /*self*/, PyObject *args)
 
 PyObject* Application::sAddIcon(PyObject * /*self*/, PyObject *args)
 {
-    char *iconName;
-    char *pixmap;
-    if (!PyArg_ParseTuple(args, "ss", &iconName,&pixmap))
+    const char *iconName;
+    const char *content;
+    Py_ssize_t size = 0;
+    const char *format = "XPM";
+    if (!PyArg_ParseTuple(args, "ss#|s", &iconName,&content,&size,&format))
         return NULL;
-    
+
     QPixmap icon;
     if (BitmapFactory().findPixmapInCache(iconName, icon)) {
         PyErr_SetString(PyExc_AssertionError, "Icon with this name already registered");
         return NULL;
     }
 
-    QByteArray ary;
-    std::string content = pixmap;
-    int strlen = (int)content.size();
-    ary.resize(strlen);
-    for (int j=0; j<strlen; j++)
-        ary[j]=content[j];
-    icon.loadFromData(ary, "XPM");
+    QByteArray ary(content,size);
+    icon.loadFromData(ary, format);
 
     if (icon.isNull()){
-        QString file = QString::fromUtf8(pixmap);
+        QString file = QString::fromUtf8(content);
         icon.load(file);
     }
 
@@ -1024,6 +1104,31 @@ PyObject* Application::sAddIcon(PyObject * /*self*/, PyObject *args)
     return Py_None;
 }
 
+PyObject* Application::sGetIcon(PyObject * /*self*/, PyObject *args)
+{
+    char *iconName;
+    if (!PyArg_ParseTuple(args, "s", &iconName))
+        return NULL;
+
+    PythonWrapper wrap;
+    wrap.loadGuiModule();
+    wrap.loadWidgetsModule();
+    auto pixmap = BitmapFactory().pixmap(iconName);
+    if(!pixmap.isNull())
+        return Py::new_reference_to(wrap.fromQIcon(new QIcon(pixmap)));
+    Py_Return;
+}
+
+PyObject* Application::sIsIconCached(PyObject * /*self*/, PyObject *args)
+{
+    char *iconName;
+    if (!PyArg_ParseTuple(args, "s", &iconName))
+        return NULL;
+
+    QPixmap icon;
+    return Py::new_reference_to(Py::Boolean(BitmapFactory().findPixmapInCache(iconName, icon)));
+}
+
 PyObject* Application::sAddCommand(PyObject * /*self*/, PyObject *args)
 {
     char*       pName;
@@ -1038,13 +1143,25 @@ PyObject* Application::sAddCommand(PyObject * /*self*/, PyObject *args)
     try {
         Base::PyGILStateLocker lock;
         Py::Module mod(PyImport_ImportModule("inspect"), true);
+        if (mod.isNull()) {
+            PyErr_SetString(PyExc_ImportError, "Cannot load inspect module");
+            return 0;
+        }
         Py::Callable inspect(mod.getAttr("stack"));
-        Py::Tuple args;
-        Py::List list(inspect.apply(args));
-        args = list.getItem(0);
+        Py::List list(inspect.apply());
 
+        std::string file;
         // usually this is the file name of the calling script
-        std::string file = args.getItem(1).as_string();
+#if (PY_MAJOR_VERSION > 3 || (PY_MAJOR_VERSION==3 && PY_MINOR_VERSION>=5))
+        Py::Object info = list.getItem(0);
+        PyObject *pyfile = PyStructSequence_GET_ITEM(*info,1);
+        if(!pyfile)
+            throw Py::Exception();
+        file = Py::Object(pyfile).as_string();
+#else
+        Py::Tuple info = list.getItem(0);
+        file = info.getItem(1).as_string();
+#endif
         Base::FileInfo fi(file);
         // convert backslashes to slashes
         file = fi.filePath();
@@ -1057,7 +1174,11 @@ PyObject* Application::sAddCommand(PyObject * /*self*/, PyObject *args)
             group = what[1];
         }
         else {
-            group = module;
+            boost::regex rx("/Ext/freecad/(\\w+)/");
+            if (boost::regex_search(file, what, rx))
+                group = what[1];
+            else
+                group = module;
         }
     }
     catch (Py::Exception& e) {
@@ -1109,6 +1230,9 @@ PyObject* Application::sRunCommand(PyObject * /*self*/, PyObject *args)
     if (!PyArg_ParseTuple(args, "s|i", &pName, &item))
         return NULL;
 
+    Gui::Command::LogDisabler d1;
+    Gui::SelectionLogDisabler d2;
+
     Command* cmd = Application::Instance->commandManager().getCommandByName(pName);
     if (cmd) {
         cmd->invoke(item);
@@ -1121,31 +1245,16 @@ PyObject* Application::sRunCommand(PyObject * /*self*/, PyObject *args)
     }
 }
 
-PyObject* Application::sListCommands(PyObject * /*self*/, PyObject *args)
-{
-    if (!PyArg_ParseTuple(args, ""))
-        return NULL;
-
-    std::vector <Command*> cmds = Application::Instance->commandManager().getAllCommands();
-    PyObject* pyList = PyList_New(cmds.size());
-    int i=0;
-    for ( std::vector<Command*>::iterator it = cmds.begin(); it != cmds.end(); ++it ) {
-#if PY_MAJOR_VERSION >= 3
-        PyObject* str = PyUnicode_FromString((*it)->getName());
-#else
-        PyObject* str = PyString_FromString((*it)->getName());
-#endif
-        PyList_SetItem(pyList, i++, str);
-    }
-    return pyList;
-}
-
 PyObject* Application::sDoCommand(PyObject * /*self*/, PyObject *args)
 {
     char *sCmd=0;
     if (!PyArg_ParseTuple(args, "s", &sCmd))
         return NULL;
 
+    Gui::Command::LogDisabler d1;
+    Gui::SelectionLogDisabler d2;
+
+    Gui::Command::printPyCaller();
     Gui::Application::Instance->macroManager()->addLine(MacroManager::App, sCmd);
 
     PyObject *module, *dict;
@@ -1167,6 +1276,10 @@ PyObject* Application::sDoCommandGui(PyObject * /*self*/, PyObject *args)
     if (!PyArg_ParseTuple(args, "s", &sCmd))
         return NULL;
 
+    Gui::Command::LogDisabler d1;
+    Gui::SelectionLogDisabler d2;
+
+    Gui::Command::printPyCaller();
     Gui::Application::Instance->macroManager()->addLine(MacroManager::Gui, sCmd);
 
     PyObject *module, *dict;
@@ -1217,7 +1330,7 @@ PyObject* Application::sShowPreferences(PyObject * /*self*/, PyObject *args)
     if (!PyArg_ParseTuple(args, "|si", &pstr, &idx))
         return NULL;
     Gui::Dialog::DlgPreferencesImp cDlg(getMainWindow());
-    if (pstr) 
+    if (pstr)
         cDlg.activateGroupPage(QString::fromUtf8(pstr),idx);
     WaitCursor wc;
     wc.restoreCursor();
@@ -1267,23 +1380,86 @@ PyObject* Application::sGetMarkerIndex(PyObject * /*self*/, PyObject *args)
     PY_TRY {
         ParameterGrp::handle const hGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View");
 
-        if (strcmp(pstr, "square") == 0)
-            return Py_BuildValue("i", Gui::Inventor::MarkerBitmaps::getMarkerIndex("DIAMOND_FILLED", hGrp->GetInt("MarkerSize", defSize)));
-        else if (strcmp(pstr, "cross") == 0)
-            return Py_BuildValue("i", Gui::Inventor::MarkerBitmaps::getMarkerIndex("CROSS", hGrp->GetInt("MarkerSize", defSize)));
-        else if (strcmp(pstr, "plus") == 0)
-            return Py_BuildValue("i", Gui::Inventor::MarkerBitmaps::getMarkerIndex("PLUS", hGrp->GetInt("MarkerSize", defSize)));
-        else if (strcmp(pstr, "empty") == 0)
-            return Py_BuildValue("i", Gui::Inventor::MarkerBitmaps::getMarkerIndex("SQUARE_LINE", hGrp->GetInt("MarkerSize", defSize)));
-        else if (strcmp(pstr, "quad") == 0)
-            return Py_BuildValue("i", Gui::Inventor::MarkerBitmaps::getMarkerIndex("SQUARE_FILLED", hGrp->GetInt("MarkerSize", defSize)));
-        else if (strcmp(pstr, "circle") == 0)
-            return Py_BuildValue("i", Gui::Inventor::MarkerBitmaps::getMarkerIndex("CIRCLE_LINE", hGrp->GetInt("MarkerSize", defSize)));
-        else
-            return Py_BuildValue("i", Gui::Inventor::MarkerBitmaps::getMarkerIndex("CIRCLE_FILLED", hGrp->GetInt("MarkerSize", defSize)));
+        //find the appropriate marker style string token
+        std::string marker_arg = pstr;
+
+        std::list<std::pair<std::string, std::string> > markerList = {
+            {"square", "DIAMOND_FILLED"},
+            {"cross", "CROSS"},
+            {"plus", "PLUS"},
+            {"empty", "SQUARE_LINE"},
+            {"quad", "SQUARE_FILLED"},
+            {"circle", "CIRCLE_LINE"},
+            {"default", "CIRCLE_FILLED"}
+        };
+
+        std::list<std::pair<std::string, std::string>>::iterator markerStyle;
+
+        for (markerStyle = markerList.begin(); markerStyle != markerList.end(); ++markerStyle)
+        {
+            if (marker_arg == (*markerStyle).first || marker_arg == (*markerStyle).second)
+                break;
+        }
+
+        marker_arg = "CIRCLE_FILLED";
+
+        if (markerStyle != markerList.end())
+            marker_arg = (*markerStyle).second;
+
+        //get the marker size
+        int sizeList[]={5, 7, 9};
+
+        if (std::find(std::begin(sizeList), std::end(sizeList), defSize) == std::end(sizeList))
+            defSize = 9;
+
+        return Py_BuildValue("i", Gui::Inventor::MarkerBitmaps::getMarkerIndex(marker_arg, defSize));
     }PY_CATCH;
 }
 
+PyObject* Application::sReload(PyObject * /*self*/, PyObject *args)
+{
+    const char *name;
+    if (!PyArg_ParseTuple(args, "s", &name))
+        return NULL;
+
+    PY_TRY {
+        auto doc = Application::Instance->reopen(App::GetApplication().getDocument(name));
+        if(doc)
+            return doc->getPyObject();
+    }PY_CATCH;
+    Py_Return;
+}
+
+PyObject* Application::sLoadFile(PyObject * /*self*/, PyObject *args)
+{
+    char *path, *mod="";
+    if (!PyArg_ParseTuple(args, "s|s", &path, &mod))     // convert args: Python->C
+        return 0;                             // NULL triggers exception
+    PY_TRY {
+        Base::FileInfo fi(path);
+        if (!fi.isFile() || !fi.exists()) {
+            PyErr_Format(PyExc_IOError, "File %s doesn't exist.", path);
+            return 0;
+        }
+
+        std::string module = mod;
+        if (module.empty()) {
+            std::string ext = fi.extension();
+            std::vector<std::string> modules = App::GetApplication().getImportModules(ext.c_str());
+            if (modules.empty()) {
+                PyErr_Format(PyExc_IOError, "Filetype %s is not supported.", ext.c_str());
+                return 0;
+            }
+            else {
+                module = modules.front();
+            }
+        }
+
+        Application::Instance->open(path,module.c_str());
+
+        Py_Return;
+    } PY_CATCH
+}
 
 PyObject* Application::sAddDocObserver(PyObject * /*self*/, PyObject *args)
 {
@@ -1306,3 +1482,18 @@ PyObject* Application::sRemoveDocObserver(PyObject * /*self*/, PyObject *args)
         Py_Return;
     } PY_CATCH;
 }
+
+PyObject* Application::sCoinRemoveAllChildren(PyObject * /*self*/, PyObject *args)
+{
+    PyObject *pynode;
+    if (!PyArg_ParseTuple(args, "O", &pynode))
+        return NULL;
+
+    PY_TRY {
+        void* ptr = 0;
+        Base::Interpreter().convertSWIGPointerObj("pivy.coin","_p_SoGroup", pynode, &ptr, 0);
+        coinRemoveAllChildren(reinterpret_cast<SoGroup*>(ptr));
+        Py_Return;
+    }PY_CATCH;
+}
+
