@@ -23,6 +23,7 @@
 
 #include "PreCompiled.h"
 #ifndef _PreComp_
+# include <QString>
 # include <QApplication>
 # include <QBitmap>
 # include <QDir>
@@ -36,7 +37,6 @@
 # include <QStyleOption>
 # include <sstream>
 #endif
-
 #if defined (FC_OS_WIN32) && QT_VERSION < 0x050000
 #define QTWEBKIT
 #endif
@@ -57,7 +57,7 @@
 using namespace Gui;
 
 /* XPM */
-static const char *px[]={
+static const char *not_found[]={
 "24 24 2 1",
 "# c #000000",
 ". c #ffffff",
@@ -293,10 +293,11 @@ QPixmap BitmapFactoryInst::pixmap(const char* name) const
     }
 
     Base::Console().Warning("Cannot find icon: %s\n", name);
-    return QPixmap(px);
+    return QPixmap(not_found);
 }
 
-QPixmap BitmapFactoryInst::pixmapFromSvg(const char* name, const QSize& size) const
+QPixmap BitmapFactoryInst::pixmapFromSvg(const char* name, const QSizeF& size,
+    const std::map<unsigned long, unsigned long>& colorMapping) const
 {
     // If an absolute path is given
     QPixmap icon;
@@ -325,15 +326,26 @@ QPixmap BitmapFactoryInst::pixmapFromSvg(const char* name, const QSize& size) co
         QFile file(iconPath);
         if (file.open(QFile::ReadOnly | QFile::Text)) {
             QByteArray content = file.readAll();
-            icon = pixmapFromSvg(content, size);
+            icon = pixmapFromSvg(content, size, colorMapping);
         }
     }
 
     return icon;
 }
 
-QPixmap BitmapFactoryInst::pixmapFromSvg(const QByteArray& contents, const QSize& size) const
+QPixmap BitmapFactoryInst::pixmapFromSvg(const QByteArray& originalContents, const QSizeF& size,
+    const std::map<unsigned long, unsigned long>& colorMapping) const
 {
+    QString stringContents = QString::fromUtf8(originalContents);
+    for ( const auto &colorToColor : colorMapping ) {
+        ulong fromColor = colorToColor.first;
+        ulong toColor = colorToColor.second;
+        QString fromColorString = QString::fromLatin1(":#%1;").arg(fromColor, 6, 16,  QChar::fromLatin1('0'));
+        QString toColorString = QString::fromLatin1(":#%1;").arg(toColor, 6, 16,  QChar::fromLatin1('0'));
+        stringContents = stringContents.replace(fromColorString, toColorString);
+    }
+    QByteArray contents = stringContents.toUtf8();
+
 #ifdef QTWEBKIT
     // There is a crash when using the Webkit engine in debug mode
     // for a couple of SVG files. Thus, use the qsvg plugin.
@@ -419,14 +431,14 @@ QPixmap BitmapFactoryInst::pixmapFromSvg(const QByteArray& contents, const QSize
     return QPixmap::fromImage(image);
 #endif // QT_VERSION
 #else //QTWEBKIT
-    QImage image(size, QImage::Format_ARGB32_Premultiplied);
+    QImage image(size.toSize(), QImage::Format_ARGB32_Premultiplied);
     image.fill(0x00000000);
 
     QPainter p(&image);
     // tmp. disable the report window to suppress some bothering warnings
-    Base::Console().SetEnabledMsgType("ReportOutput", ConsoleMsgType::MsgType_Wrn, false);
+    Base::Console().SetEnabledMsgType("ReportOutput", Base::ConsoleSingleton::MsgType_Wrn, false);
     QSvgRenderer svg(contents);
-    Base::Console().SetEnabledMsgType("ReportOutput", ConsoleMsgType::MsgType_Wrn, true);
+    Base::Console().SetEnabledMsgType("ReportOutput", Base::ConsoleSingleton::MsgType_Wrn, true);
     svg.render(&p);
     p.end();
 
@@ -621,7 +633,11 @@ void BitmapFactoryInst::convert(const QImage& p, SoSFImage& img) const
     size[0] = p.width();
     size[1] = p.height();
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    int buffersize = static_cast<int>(p.sizeInBytes());
+#else
     int buffersize = p.byteCount();
+#endif
     int numcomponents = 0;
     QVector<QRgb> table = p.colorTable();
     if (!table.isEmpty()) {
@@ -650,13 +666,13 @@ void BitmapFactoryInst::convert(const QImage& p, SoSFImage& img) const
     int width  = (int)size[0];
     int height = (int)size[1];
 
-    for (int y = 0; y < height; y++) 
+    for (int y = 0; y < height; y++)
     {
         unsigned char * line = &bytes[width*numcomponents*(height-(y+1))];
-        for (int x = 0; x < width; x++) 
+        for (int x = 0; x < width; x++)
         {
             QRgb rgb = p.pixel(x,y);
-            switch (numcomponents) 
+            switch (numcomponents)
             {
             default:
                 break;
@@ -693,19 +709,21 @@ void BitmapFactoryInst::convert(const SoSFImage& p, QImage& img) const
     int numcomponents;
 
     const unsigned char * bytes = p.getValue(size, numcomponents);
+    if (!bytes)
+        return;
 
     int width  = (int)size[0];
     int height = (int)size[1];
 
     img = QImage(width, height, QImage::Format_RGB32);
     QRgb * bits = (QRgb*) img.bits();
-    
-    for (int y = 0; y < height; y++) 
+
+    for (int y = 0; y < height; y++)
     {
         const unsigned char * line = &bytes[width*numcomponents*(height-(y+1))];
-        for (int x = 0; x < width; x++) 
+        for (int x = 0; x < width; x++)
         {
-            switch (numcomponents) 
+            switch (numcomponents)
             {
             default:
             case 1:
@@ -727,3 +745,17 @@ void BitmapFactoryInst::convert(const SoSFImage& p, QImage& img) const
     }
 }
 
+QIcon BitmapFactoryInst::mergePixmap (const QIcon &base, const QPixmap &px, Gui::BitmapFactoryInst::Position position)
+{
+    QIcon overlayedIcon;
+
+    int w = QApplication::style()->pixelMetric(QStyle::PM_ListViewIconSize);
+
+    overlayedIcon.addPixmap(Gui::BitmapFactory().merge(base.pixmap(w, w, QIcon::Normal, QIcon::Off),
+                                                       px,position), QIcon::Normal, QIcon::Off);
+
+    overlayedIcon.addPixmap(Gui::BitmapFactory().merge(base.pixmap(w, w, QIcon::Normal, QIcon::On ),
+                                                       px,position), QIcon::Normal, QIcon::Off);
+
+    return overlayedIcon;
+}
