@@ -36,8 +36,6 @@
 # include <QRegExp>
 #endif
 
-#include <Inventor/sensors/SoTimerSensor.h>
-
 #include <App/Application.h>
 #include "NavigationStyle.h"
 #include "View3DInventorViewer.h"
@@ -51,7 +49,7 @@ using namespace Gui;
 
 /* TRANSLATOR Gui::BlenderNavigationStyle */
 
-TYPESYSTEM_SOURCE(Gui::BlenderNavigationStyle, Gui::UserNavigationStyle);
+TYPESYSTEM_SOURCE(Gui::BlenderNavigationStyle, Gui::UserNavigationStyle)
 
 BlenderNavigationStyle::BlenderNavigationStyle() : lockButton1(false)
 {
@@ -147,6 +145,10 @@ SbBool BlenderNavigationStyle::processSoEvent(const SoEvent * const ev)
             processed = true;
             viewer->saveHomePosition();
             break;
+        case SoKeyboardEvent::R:
+            processed = true;
+            viewer->resetToHomePosition();
+            break;
         case SoKeyboardEvent::S:
         case SoKeyboardEvent::HOME:
         case SoKeyboardEvent::LEFT_ARROW:
@@ -223,8 +225,8 @@ SbBool BlenderNavigationStyle::processSoEvent(const SoEvent * const ev)
             this->lockrecenter = true;
             if (!viewer->isEditing()) {
                 // If we are in zoom or pan mode ignore RMB events otherwise
-                // the canvas doesn't get any release events 
-                if (this->currentmode != NavigationStyle::ZOOMING && 
+                // the canvas doesn't get any release events
+                if (this->currentmode != NavigationStyle::ZOOMING &&
                     this->currentmode != NavigationStyle::PANNING &&
                     this->currentmode != NavigationStyle::DRAGGING) {
                     if (this->isPopupMenuEnabled()) {
@@ -266,14 +268,6 @@ SbBool BlenderNavigationStyle::processSoEvent(const SoEvent * const ev)
             }
             this->button3down = press;
             break;
-        case SoMouseButtonEvent::BUTTON4:
-            doZoom(viewer->getSoRenderManager()->getCamera(), true, posn);
-            processed = true;
-            break;
-        case SoMouseButtonEvent::BUTTON5:
-            doZoom(viewer->getSoRenderManager()->getCamera(), false, posn);
-            processed = true;
-            break;
         default:
             break;
         }
