@@ -36,8 +36,6 @@
 # include <QRegExp>
 #endif
 
-#include <Inventor/sensors/SoTimerSensor.h>
-
 #include <App/Application.h>
 #include "NavigationStyle.h"
 #include "View3DInventorViewer.h"
@@ -51,7 +49,7 @@ using namespace Gui;
 
 /* TRANSLATOR Gui::CADNavigationStyle */
 
-TYPESYSTEM_SOURCE(Gui::CADNavigationStyle, Gui::UserNavigationStyle);
+TYPESYSTEM_SOURCE(Gui::CADNavigationStyle, Gui::UserNavigationStyle)
 
 CADNavigationStyle::CADNavigationStyle() : lockButton1(false)
 {
@@ -310,14 +308,6 @@ SbBool CADNavigationStyle::processSoEvent(const SoEvent * const ev)
             }
             this->button3down = press;
             break;
-        case SoMouseButtonEvent::BUTTON4:
-            doZoom(viewer->getSoRenderManager()->getCamera(), true, posn);
-            processed = true;
-            break;
-        case SoMouseButtonEvent::BUTTON5:
-            doZoom(viewer->getSoRenderManager()->getCamera(), false, posn);
-            processed = true;
-            break;
         default:
             break;
         }
