@@ -32,6 +32,167 @@
 
 #include <Base/Type.h>
 
+/** @defgroup CommandMacros Helper macros for running commands through Python interpreter */
+//@{
+
+/** Runs a command for accessing document attribute or method
+ * @param _type: type of document, Gui or App
+ * @param _doc: pointer to a document
+ * @param _cmd: command string, streamable
+ *
+ * Example:
+ * @code{.cpp}
+ *      _FCMD_DOC_CMD(Gui,doc,"getObject('" << objName << "')");
+ * @endcode
+ *
+ * Translates to command (assuming doc's name is 'DocName', and
+ * and objName contains value 'ObjName'):
+ * @code{.py}
+ *       Gui.getDocument('DocName').getObject('ObjName')
+ * @endcode
+ */
+#define _FCMD_DOC_CMD(_type,_doc,_cmd) do{\
+    auto __doc = _doc;\
+    if(__doc && __doc->getName()) {\
+        std::ostringstream _str;\
+        _str << #_type ".getDocument('" << __doc->getName() << "')." << _cmd;\
+        Gui::Command::runCommand(Gui::Command::Doc,_str.str().c_str());\
+    }\
+}while(0)
+
+/** Runs a command for accessing App.Document attribute or method
+ *
+ * @param _doc: pointer to a document
+ * @param _cmd: command string, streamable
+ * @sa _FCMD_DOC_CMD()
+ */
+#define FCMD_DOC_CMD(_doc,_cmd) _FCMD_DOC_CMD(App,_doc,_cmd)
+
+/** Runs a command for accessing an object's document attribute or method
+ * @param _type: type of the document, Gui or App
+ * @param _obj: pointer to a DocumentObject
+ * @param _cmd: command string, streamable
+ */
+#define _FCMD_OBJ_DOC_CMD(_type,_obj,_cmd) do{\
+    auto __obj = _obj;\
+    if(__obj)\
+        _FCMD_DOC_CMD(_type,__obj->getDocument(),_cmd);\
+}while(0)
+
+/** Runs a command for accessing an object's App::Document attribute or method
+ * @param _obj: pointer to a DocumentObject
+ * @param _cmd: command string, streamable
+ */
+#define FCMD_OBJ_DOC_CMD(_obj,_cmd) _FCMD_OBJ_DOC_CMD(App,_obj,_cmd)
+
+/** Runs a command for accessing an object's Gui::Document attribute or method
+ * @param _obj: pointer to a DocumentObject
+ * @param _cmd: command string, streamable
+ */
+#define FCMD_VOBJ_DOC_CMD(_obj,_cmd) _FCMD_OBJ_DOC_CMD(Gui,_obj,_cmd)
+
+/** Runs a command for accessing a document/view object's attribute or method
+ * @param _type: type of the object, Gui or App
+ * @param _obj: pointer to a DocumentObject
+ * @param _cmd: command string, streamable
+ *
+ * Example:
+ * @code{.cpp}
+ *      _FCMD_OBJ_CMD(Gui,obj,"Visibility = " << (visible?"True":"False"));
+ * @endcode
+ *
+ * Translates to command (assuming obj's document name is 'DocName', obj's name
+ * is 'ObjName', and visible is true):
+ * @code{.py}
+ *       Gui.getDocument('DocName').getObject('ObjName').Visibility = True
+ * @endcode
+ */
+#define _FCMD_OBJ_CMD(_type,_cmd_type,_obj,_cmd) do{\
+    auto __obj = _obj;\
+    if(__obj && __obj->getNameInDocument()) {\
+        std::ostringstream _str;\
+        _str << #_type ".getDocument('" << __obj->getDocument()->getName() \
+             << "').getObject('" <<  __obj->getNameInDocument() << "')." << _cmd;\
+        Gui::Command::runCommand(Gui::Command::_cmd_type,_str.str().c_str());\
+    }\
+}while(0)
+
+/** Runs a command for accessing an document object's attribute or method
+ * @param _obj: pointer to a DocumentObject
+ * @param _cmd: command string, streamable
+ * @sa _FCMD_OBJ_CMD()
+ */
+#define FCMD_OBJ_CMD(_obj,_cmd) _FCMD_OBJ_CMD(App,Doc,_obj,_cmd)
+
+/** Runs a command for accessing an view object's attribute or method
+ * @param _obj: pointer to a DocumentObject
+ * @param _cmd: command string, streamable
+ * @sa _FCMD_OBJ_CMD()
+ */
+#define FCMD_VOBJ_CMD(_obj,_cmd) _FCMD_OBJ_CMD(Gui,Gui,_obj,_cmd)
+
+/** Runs a command for accessing a document object's attribute or method
+ * @param _cmd: command string, supporting printf like formatter
+ * @param _obj: pointer to a DocumentObject
+ *
+ * Example:
+ * @code{.cpp}
+ *      FCMD_OBJ_CMD2("Visibility = %s", obj, visible?"True":"False");
+ * @endcode
+ *
+ * Translates to command (assuming obj's document name is 'DocName', obj's name
+ * is 'ObjName', and visible is true):
+ * @code{.py}
+ *       App.getDocument('DocName').getObject('ObjName').Visibility = True
+ * @endcode
+ */
+#define FCMD_OBJ_CMD2(_cmd,_obj,...) do{\
+    auto __obj = _obj;\
+    if(__obj && __obj->getNameInDocument()) {\
+        Gui::Command::doCommand(Gui::Command::Doc,"App.getDocument('%s').getObject('%s')." _cmd,\
+                __obj->getDocument()->getName(),__obj->getNameInDocument(),## __VA_ARGS__);\
+    }\
+}while(0)
+
+/** Runs a command for accessing a view object's attribute or method
+ * @param _cmd: command string, supporting printf like formatter
+ * @param _obj: pointer to a DocumentObject
+ * @sa FCMD_OBJ_CMD2()
+ */
+#define FCMD_VOBJ_CMD2(_cmd,_obj,...) do{\
+    auto __obj = _obj;\
+    if(__obj && __obj->getNameInDocument()) {\
+        Gui::Command::doCommand(Gui::Command::Gui,"Gui.getDocument('%s').getObject('%s')." _cmd,\
+                __obj->getDocument()->getName(),__obj->getNameInDocument(),## __VA_ARGS__);\
+    }\
+}while(0)
+
+/** Runs a command to start editing a give object
+ * @param _obj: pointer to a DocumentObject
+ *
+ * Unlike other FCMD macros, this macro editing the object using the current
+ * active document, instead of the object's owner document. This allows
+ * in-place editing an object, which may be brought in through linking to an
+ * external group.
+ */
+#define FCMD_SET_EDIT(_obj) do{\
+    auto __obj = _obj;\
+    if(__obj && __obj->getNameInDocument()) {\
+        Gui::Command::doCommand(Gui::Command::Gui,\
+            "Gui.ActiveDocument.setEdit(App.getDocument('%s').getObject('%s'))",\
+            __obj->getDocument()->getName(), __obj->getNameInDocument());\
+    }\
+}while(0)
+
+
+/// Hides an object
+#define FCMD_OBJ_HIDE(_obj) FCMD_OBJ_CMD(_obj,"Visibility = False")
+
+/// Shows an object
+#define FCMD_OBJ_SHOW(_obj) FCMD_OBJ_CMD(_obj,"Visibility = True")
+
+//@}
+
 class QWidget;
 class QByteArray;
 
@@ -63,6 +224,7 @@ void CreateViewStdCommands(void);
 void CreateWindowStdCommands(void);
 void CreateStructureCommands(void);
 void CreateTestCommands(void);
+void CreateLinkCommands(void);
 
 
 /** The CommandBase class
@@ -90,7 +252,7 @@ protected:
     virtual Action * createAction(void);
 
 public:
-    /// Reassigns QAction stuff after the language has changed. 
+    /// Reassigns QAction stuff after the language has changed.
     virtual void languageChange() = 0;
     /// Updates the QAction with respect to the passed mode.
     virtual void updateAction(int mode) = 0;
@@ -135,6 +297,7 @@ protected:
     //@}
 protected:
     Action *_pcAction; /**< The Action item. */
+    std::string displayText;
 };
 
 /** The Command class.
@@ -162,8 +325,6 @@ protected:
     //@{
     /// Methods which gets called when activated, needs to be reimplemented!
     virtual void activated(int iMsg)=0;
-    /// Override this method if your Cmd is not always active
-    virtual bool isActive(void){return true;} 
     /// Creates the used Action
     virtual Action * createAction(void);
     /// Applies the menu text, tool and status tip to the passed action object
@@ -176,23 +337,43 @@ public:
     //@{
     /// CommandManager is a friend
     friend class CommandManager;
+    /// Override this method if your Cmd is not always active
+    virtual bool isActive(void){return true;}
     /// Get somtile called to check the state of the command
     void testActive(void);
     /// Enables or disables the command
     void setEnabled(bool);
-    /// get called by the QAction
-    void invoke (int); 
+    /// Command trigger source
+    enum TriggerSource {
+        /// No external trigger, e.g. invoked through Python
+        TriggerNone,
+        /// Command triggered by an action
+        TriggerAction,
+        /// Command triggered by a child action inside an action group
+        TriggerChildAction,
+    };
+    /// Return the current command trigger source
+    TriggerSource triggerSource() const {return _trigger;}
+    /** Called to invoke the command
+     *
+     * @param index: in case of group command, this is the index of the child
+     *               command.  For checkable command, this indicates the
+     *               checkable state.
+     * @param trigger: indicate the command triggering source, see TriggerSource.
+     */
+    void invoke (int index, TriggerSource trigger=TriggerNone);
     /// adds this command to arbitrary widgets
     void addTo(QWidget *);
     void addToGroup(ActionGroup *, bool checkable);
+    void addToGroup(ActionGroup *);
     //@}
 
 
     /** @name Helper methods to get important classes */
     //@{
     /// Get pointer to the Application Window
-    static Application*  getGuiApplication(void);   
-    /// Get a reference to the selection 
+    static Application*  getGuiApplication(void);
+    /// Get a reference to the selection
     static Gui::SelectionSingleton&  getSelection(void);
     /// Get pointer to the active gui document
     Gui::Document*  getActiveGuiDocument(void) const;
@@ -206,8 +387,19 @@ public:
     bool isViewOfType(Base::Type t) const;
     /// returns the named feature or the active one from the active document or NULL
     App::DocumentObject*  getObject(const char* Name) const;
-    /// Get unique Feature name from the active document 
-    std::string getUniqueObjectName(const char *BaseName) const;
+    /// returns a python command string to retrieve an object from a document
+    static std::string getObjectCmd(const char *Name, const App::Document *doc=0,
+            const char *prefix=0, const char *postfix=0, bool gui=false);
+    /// returns a python command string to retrieve the given object
+    static std::string getObjectCmd(const App::DocumentObject *obj,
+            const char *prefix=0, const char *postfix=0, bool gui=false);
+    /** Get unique Feature name from the active document
+     *
+     *  @param BaseName: the base name
+     *  @param obj: if not zero, then request the unique name in the document of
+     *  the given object.
+     */
+    std::string getUniqueObjectName(const char *BaseName, const App::DocumentObject *obj=0) const;
     //@}
 
     /** @name Helper methods for the Undo/Redo and Update handling */
@@ -230,6 +422,8 @@ public:
     void languageChange();
     /// Updates the QAction with respect to the passed mode.
     void updateAction(int mode);
+    /// Setup checkable actions based on current TriggerSource
+    void setupCheckable(int iMsg);
     //@}
 
     /** @name Helper methods for issuing commands to the Python interpreter */
@@ -245,25 +439,102 @@ public:
     };
     /// Blocks all command objects
     static void blockCommand(bool);
-    /// Run a App level Action 
-    static void doCommand(DoCmd_Type eType,const char* sCmd,...);
-    static void runCommand(DoCmd_Type eType,const char* sCmd);
-    static void runCommand(DoCmd_Type eType,const QByteArray& sCmd);
-    /// import an external (or own) module only once 
-    static void addModule(DoCmd_Type eType,const char* sModuleName);
-    /// assures the switch to a certain workbench, if already in the workbench, does nothing.
-    static std::string assureWorkbench(const char * sName);
+    /// Print to Python console the current Python calling source file and line number
+    static void printPyCaller();
+    /// Print to Python console the current calling source file and line number
+    static void printCaller(const char *file, int line);
 
-    static void copyVisual(const char* to, const char* attr, const char* from);
-    static void copyVisual(const char* to, const char* attr_to, const char* from, const char* attr_from);
-    /// Get Python tuple from object and sub-elements 
+    // ISO C++11 requires at least one argument for the "..." in a variadic macro
+    // https://en.wikipedia.org/wiki/Variadic_macro#Example
+    /** Convenience macro to run a command with printf like formatter
+     *
+     * @sa Command::_doCommand()
+     */
+#ifdef FC_OS_WIN32
+#define doCommand(_type,...) _doCommand(__FILE__,__LINE__,_type,##__VA_ARGS__)
+#else
+#define doCommand(...) _doCommand(__FILE__,__LINE__,__VA_ARGS__)
+#endif
+
+    /** Run a command with printf like formatter
+     *
+     * @param file: the calling file path (for debugging purpose)
+     * @param line: the calling line number (for debugging purpose)
+     * @param eType: command type, See DoCmd_Type
+     * @param sCmd: command string that supports printf like formatter
+     *
+     * You can use the convenience macro doCommand() to automate \c file and \c
+     * line arguments. You may also want to use various helper @ref CommandMacros.
+     */
+    static void _doCommand(const char *file, int line, DoCmd_Type eType,const char* sCmd,...);
+
+    /** Convenience macro to run a command
+     *
+     * @sa Command::_runCommand()
+     */
+#define runCommand(_type,_cmd) _runCommand(__FILE__,__LINE__,_type,_cmd)
+
+    /** Run a command
+     *
+     * @param file: the calling file path (for debugging purpose)
+     * @param line: the calling line number (for debugging purpose)
+     * @param eType: command type, See DoCmd_Type
+     * @param sCmd: command string
+     *
+     * @sa _doCommand()
+     */
+    static void _runCommand(const char *file, int line, DoCmd_Type eType,const char* sCmd);
+
+    /** Run a command
+     *
+     * @param file: the calling file path (for debugging purpose)
+     * @param line: the calling line number (for debugging purpose)
+     * @param eType: command type, See DoCmd_Type
+     * @param sCmd: command string
+     *
+     * @sa _doCommand()
+     */
+    static void _runCommand(const char *file, int line, DoCmd_Type eType,const QByteArray& sCmd);
+
+    /// import an external (or own) module only once
+    static void addModule(DoCmd_Type eType,const char* sModuleName);
+
+    /** Convenience macro to assure the switch to a certain workbench
+     *
+     * @sa _assureWorkbench()
+     */
+#define assureWorkbench(_name) _assureWorkbench(__FILE__,__LINE__,_name)
+
+    /** Assures the switch to a certain workbench
+     *
+     * @param file: the calling file path (for debugging purpose)
+     * @param line: the calling line number (for debugging purpose)
+     * @param sName: workbench name
+     *
+     * @return Return the current active workbench name before switching.
+     *
+     * If already in the workbench, does nothing.
+     */
+    static std::string _assureWorkbench(const char *file, int line, const char * sName);
+    //@}
+
+    /** @name Methods for copying visiual properties */
+    //@{
+    /// Convenience macro to copy visual properties
+#define copyVisual(...) _copyVisual(__FILE__,__LINE__,__VA_ARGS__)
+    static void _copyVisual(const char *file, int line, const char* to, const char* attr, const char* from);
+    static void _copyVisual(const char *file, int line, const char* to, const char* attr_to, const char* from, const char* attr_from);
+    static void _copyVisual(const char *file, int line, const App::DocumentObject *to, const char *attr, const App::DocumentObject *from);
+    static void _copyVisual(const char *file, int line, const App::DocumentObject *to, const char *attr_to, const App::DocumentObject *from, const char *attr_from);
+    //@}
+
+    /// Get Python tuple from object and sub-elements
     static std::string getPythonTuple(const std::string& name, const std::vector<std::string>& subnames);
     /// translate a string to a python string literal (needed e.g. in file names for windows...)
     const std::string strToPython(const char* Str);
     const std::string strToPython(const std::string &Str){
         return strToPython(Str.c_str());
     }
-    //@}
 
     /** @name Helper methods to generate help pages */
     //@{
@@ -294,24 +565,37 @@ public:
     const char* getGroupName() const { return sGroup; }
     void setGroupName(const char*);
     //@}
-    
-    
+
+
     /** @name arbitrary helper methods */
     //@{
     void adjustCameraPosition();
     //@}
 
+    /// Helper class to disable python console log
+    class LogDisabler {
+    public:
+        LogDisabler() {
+            ++Command::_busy;
+        }
+        ~LogDisabler() {
+            --Command::_busy;
+        }
+    };
+    friend class LogDisabler;
+
 protected:
     enum CmdType {
         AlterDoc       = 1,  /**< Command change the Document */
         Alter3DView    = 2,  /**< Command change the Gui */
         AlterSelection = 4,  /**< Command change the Selection */
-        ForEdit        = 8   /**< Command is in a special edit mode active */
+        ForEdit        = 8,  /**< Command is in a special edit mode active */
+        NoTransaction  = 16, /**< Do not setup auto transaction */
     };
 
-    /** @name Attributes 
-     *  Set by the inherited constructor to set up the most important properties 
-     *  of the command. In the Command constructor are set default values! 
+    /** @name Attributes
+     *  Set by the inherited constructor to set up the most important properties
+     *  of the command. In the Command constructor are set default values!
      *  The real values should be set in the constructor of the inhereting class.
      */
     //@{
@@ -320,16 +604,54 @@ protected:
     const char* sName;
     const char* sHelpUrl;
     int         eType;
+    /// Indicate if the command shall log to MacroManager
+    bool        bCanLog;
     //@}
 private:
+    static int _busy;
     bool bEnabled;
     static bool _blockCmd;
+    /// For storing the current command trigger source
+    TriggerSource _trigger = TriggerNone;
+};
+
+/** Class to help implement a group command
+ *
+ * To use this class, simply add children command in the constructor of your
+ * derived class by calling addCommand();
+ */
+class GuiExport GroupCommand : public Command {
+public:
+    /// Constructor
+    GroupCommand(const char *name);
+
+    /** Add child command
+     * @param cmd: child command. Pass null pointer to add a separator.
+     * @param reg: whether to register the command with CommandManager
+     * @return Return the command index.
+     */
+    int addCommand(Command *cmd = 0, bool reg=true);
+    /** Add child command
+     * @param cmd: child command name.
+     * @return Return the found command, or NULL if not found.
+     */
+    Command *addCommand(const char *cmdName);
+
+protected:
+    virtual void activated(int iMsg);
+    virtual Gui::Action * createAction(void);
+    virtual void languageChange();
+
+    void setup(Action *);
+
+protected:
+    std::vector<std::pair<Command*,size_t> > cmds;
 };
 
 /** The Python command class
- * This is a special type of command class. It's used to bind a Python command class into the 
+ * This is a special type of command class. It's used to bind a Python command class into the
  * FreeCAD command framework.
- * An object of this class gets a reference to the Python command object and manages all the 
+ * An object of this class gets a reference to the Python command object and manages all the
  * passing between the C++ and the Python world. This includes everything like setting resources such as
  * bitmaps, activation or bindings to the user interface.
  * @see CommandManager
@@ -357,7 +679,7 @@ protected:
 public:
     /** @name Methods to get the properties of the command */
     //@{
-    /// Reassigns QAction stuff after the language has changed. 
+    /// Reassigns QAction stuff after the language has changed.
     void languageChange();
     const char* className() const
     { return "PythonCommand"; }
@@ -408,7 +730,7 @@ protected:
 public:
     /** @name Methods to get the properties of the command */
     //@{
-    /// Reassigns QAction stuff after the language has changed. 
+    /// Reassigns QAction stuff after the language has changed.
     void languageChange();
     const char* className() const
     { return "PythonGroupCommand"; }
@@ -433,7 +755,7 @@ protected:
 
 
 /** The script command class
- * This is a special type of command class. Its used to bind a macro or Python script to the 
+ * This is a special type of command class. Its used to bind a macro or Python script to the
  * FreeCAD command framework.
  * An object of this class gets a string to the place where the script is in the file system.
  * Unlike the other commands the resources can be set by several methods.
@@ -459,11 +781,11 @@ protected:
 public:
     /// Returns the script name
     const char* getScriptName () const { return sScriptName; }
-    /// Ignore when language has changed. 
+    /// Ignore when language has changed.
     void languageChange() {}
     const char* className() const
     { return "Gui::MacroCommand"; }
- 
+
     /** @name Methods to set the properties of the Script Command */
     //@{
     /// Sets the script name
@@ -484,10 +806,10 @@ protected:
 };
 
 /** The CommandManager class
- *  This class manage all available commands in FreeCAD. All 
+ *  This class manage all available commands in FreeCAD. All
  *  Commands will registered here, also commands from Application
  *  modules. Also activation / deactivation, Icons Tooltips and so
- *  on are handles here. Further the Building of Toolbars and (Context) 
+ *  on are handles here. Further the Building of Toolbars and (Context)
  *  menus (connecting to a QAction) is done here.
  *  @see Command
  *  @author Jürgen Riegel
@@ -508,7 +830,7 @@ public:
     bool addTo(const char* Name, QWidget* pcWidget);
 
     /** Returns all commands of a special App Module
-     *  delivers a vector of all commands in the given application module. When no 
+     *  delivers a vector of all commands in the given application module. When no
      *  name is given the standard commands (build in ) are returned.
      *  @see Command
      */
