@@ -35,6 +35,7 @@
 
 #include "ui_DlgParameter.h"
 #include "DlgParameterImp.h"
+#include "DlgParameterFind.h"
 #include "DlgInputDialogImp.h"
 #include "BitmapFactory.h"
 #include "FileDialog.h"
@@ -52,7 +53,7 @@ using namespace Gui::Dialog;
 
 /**
  *  Constructs a DlgParameterImp which is a child of 'parent', with the
- *  name 'name' and widget flags set to 'f' 
+ *  name 'name' and widget flags set to 'f'
  *
  *  The dialog will by default be modeless, unless you set 'modal' to
  *  true to construct a modal dialog.
@@ -62,19 +63,29 @@ DlgParameterImp::DlgParameterImp( QWidget* parent,  Qt::WindowFlags fl )
   , ui(new Ui_DlgParameter)
 {
     ui->setupUi(this);
-    QStringList groupLabels; 
+    ui->checkSort->setVisible(false); // for testing
+
+    QStringList groupLabels;
     groupLabels << tr( "Group" );
     paramGroup = new ParameterGroup(ui->splitter3);
     paramGroup->setHeaderLabels(groupLabels);
     paramGroup->setRootIsDecorated(false);
+#if QT_VERSION >= 0x050000
+    paramGroup->setSortingEnabled(true);
+    paramGroup->sortByColumn(0, Qt::AscendingOrder);
+    paramGroup->header()->setProperty("showSortIndicator", QVariant(true));
+#endif
 
-    QStringList valueLabels; 
+    QStringList valueLabels;
     valueLabels << tr( "Name" ) << tr( "Type" ) << tr( "Value" );
     paramValue = new ParameterValue(ui->splitter3);
     paramValue->setHeaderLabels(valueLabels);
     paramValue->setRootIsDecorated(false);
 #if QT_VERSION >= 0x050000
     paramValue->header()->setSectionResizeMode(0, QHeaderView::Stretch);
+    paramValue->setSortingEnabled(true);
+    paramValue->sortByColumn(0, Qt::AscendingOrder);
+    paramValue->header()->setProperty("showSortIndicator", QVariant(true));
 #else
     paramValue->header()->setResizeMode(0, QHeaderView::Stretch);
 #endif
@@ -101,14 +112,28 @@ DlgParameterImp::DlgParameterImp( QWidget* parent,  Qt::WindowFlags fl )
     if (ui->parameterSet->count() < 2)
         ui->parameterSet->hide();
 
-    connect(ui->parameterSet, SIGNAL(activated(int)), 
+    connect(ui->parameterSet, SIGNAL(activated(int)),
             this, SLOT(onChangeParameterSet(int)));
-    connect(paramGroup, SIGNAL(currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)), 
+    connect(paramGroup, SIGNAL(currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)),
             this, SLOT(onGroupSelected(QTreeWidgetItem*)));
     onGroupSelected(paramGroup->currentItem());
+
+    // setup for function on_findGroup_changed:
+    // store the current font properties because
+    // we don't know what style sheet the user uses for FC
+    defaultFont = paramGroup->font();
+    boldFont = defaultFont;
+    boldFont.setBold(true);
+    defaultColor = paramGroup->topLevelItem(0)->foreground(0);
+
+    // set a placeholder text to inform the user
+    // (QLineEdit has no placeholderText property in Qt4)
+#if QT_VERSION >= 0x050200
+    ui->findGroupLE->setPlaceholderText(tr("Search Group"));
+#endif
 }
 
-/** 
+/**
  *  Destroys the object and frees any allocated resources
  */
 DlgParameterImp::~DlgParameterImp()
@@ -117,6 +142,83 @@ DlgParameterImp::~DlgParameterImp()
     delete ui;
 }
 
+void DlgParameterImp::on_buttonFind_clicked()
+{
+    if (finder.isNull())
+        finder = new DlgParameterFind(this);
+    finder->show();
+}
+
+void DlgParameterImp::on_findGroupLE_textChanged(const QString &SearchStr)
+{
+    // search for group tree items and highlight found results
+
+    QTreeWidgetItem* ExpandItem;
+
+    // at first reset all items to the default font and expand state
+    if (foundList.size() > 0) {
+        for (QTreeWidgetItem* item : foundList) {
+            item->setFont(0, defaultFont);
+            item->setForeground(0, defaultColor);
+            ExpandItem = item;
+            // a group can be nested down to several levels
+            // do not collapse if the search string is empty
+            while (!SearchStr.isEmpty()) {
+                if (!ExpandItem->parent())
+                    break;
+                else {
+                    ExpandItem->setExpanded(false);
+                    ExpandItem = ExpandItem->parent();
+                }
+            }
+        }
+    }
+    // expand the top level entries to get the initial tree state
+    for (int i = 0; i < paramGroup->topLevelItemCount(); ++i) {
+        paramGroup->topLevelItem(i)->setExpanded(true);
+    }
+
+    // don't perform a search if the string is empty
+    if (SearchStr.isEmpty())
+        return;
+
+    // search the tree widget
+    foundList = paramGroup->findItems(SearchStr, Qt::MatchContains | Qt::MatchRecursive);
+    if (foundList.size() > 0) {
+        // reset background style sheet
+        if (!ui->findGroupLE->styleSheet().isEmpty())
+            ui->findGroupLE->setStyleSheet(QString());
+        for (QTreeWidgetItem* item : foundList) {
+            item->setFont(0, boldFont);
+            item->setForeground(0, Qt::red);
+            // expand its parent to see the item
+            // a group can be nested down to several levels
+            ExpandItem = item;
+            while (true) {
+                if (!ExpandItem->parent())
+                    break;
+                else {
+                    ExpandItem->setExpanded(true);
+                    ExpandItem = ExpandItem->parent();
+                }
+            }
+            // if there is only one item found, scroll to it
+            if (foundList.size() == 1) {
+                paramGroup->scrollToItem(foundList[0], QAbstractItemView::PositionAtCenter);
+            }
+        }
+    }
+    else {
+        // Set red background to indicate no matching
+        QString styleSheet = QString::fromLatin1(
+            " QLineEdit {\n"
+            "     background-color: rgb(221,144,161);\n"
+            " }\n"
+        );
+        ui->findGroupLE->setStyleSheet(styleSheet);
+    }
+}
+
 /**
  *  Sets the strings of the subwidgets using the current
  *  language.
@@ -134,6 +236,21 @@ void DlgParameterImp::changeEvent(QEvent *e)
     }
 }
 
+void DlgParameterImp::on_checkSort_toggled(bool on)
+{
+#if QT_VERSION >= 0x050000
+    paramGroup->setSortingEnabled(on);
+    paramGroup->sortByColumn(0, Qt::AscendingOrder);
+    paramGroup->header()->setProperty("showSortIndicator", QVariant(on));
+
+    paramValue->setSortingEnabled(on);
+    paramValue->sortByColumn(0, Qt::AscendingOrder);
+    paramValue->header()->setProperty("showSortIndicator", QVariant(on));
+#else
+    Q_UNUSED(on)
+#endif
+}
+
 void DlgParameterImp::on_closeButton_clicked()
 {
     close();
@@ -199,6 +316,7 @@ void DlgParameterImp::onGroupSelected( QTreeWidgetItem * item )
 {
     if ( item && item->type() == QTreeWidgetItem::UserType + 1 )
     {
+        bool sortingEnabled = paramValue->isSortingEnabled();
         paramValue->clear();
         Base::Reference<ParameterGrp> _hcGrp = static_cast<ParameterGroupItem*>(item)->_hcGrp;
         static_cast<ParameterValue*>(paramValue)->setCurrentGroup( _hcGrp );
@@ -238,6 +356,7 @@ void DlgParameterImp::onGroupSelected( QTreeWidgetItem * item )
         {
             (void)new ParameterUInt(paramValue,QString::fromUtf8(It6->first.c_str()),It6->second, _hcGrp);
         }
+        paramValue->setSortingEnabled(sortingEnabled);
     }
 }
 
@@ -252,12 +371,13 @@ void DlgParameterImp::activateParameterSet(const char* config)
 }
 
 /** Switches the type of parameters either to user or system parameters. */
-void DlgParameterImp::onChangeParameterSet(int index)
+void DlgParameterImp::onChangeParameterSet(int itemPos)
 {
-    ParameterManager* rcParMngr = App::GetApplication().GetParameterSet(ui->parameterSet->itemData(index).toByteArray());
+    ParameterManager* rcParMngr = App::GetApplication().GetParameterSet(ui->parameterSet->itemData(itemPos).toByteArray());
     if (!rcParMngr)
         return;
 
+    rcParMngr->CheckDocument();
     ui->buttonSaveToDisk->setEnabled(rcParMngr->HasSerializer());
 
     // remove all labels
@@ -276,7 +396,11 @@ void DlgParameterImp::onChangeParameterSet(int index)
     ParameterGrp::handle hGrp = App::GetApplication().GetUserParameter().GetGroup("BaseApp")->GetGroup("Preferences");
     hGrp = hGrp->GetGroup("ParameterEditor");
     QString path = QString::fromUtf8(hGrp->GetASCII("LastParameterGroup").c_str());
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,0)
+    QStringList paths = path.split(QLatin1String("."), Qt::SkipEmptyParts);
+#else
     QStringList paths = path.split(QLatin1String("."), QString::SkipEmptyParts);
+#endif
 
     QTreeWidgetItem* parent = 0;
     for (int index=0; index < paramGroup->topLevelItemCount() && !paths.empty(); index++) {
@@ -288,7 +412,7 @@ void DlgParameterImp::onChangeParameterSet(int index)
     }
 
     while (parent && !paths.empty()) {
-        paramGroup->setItemExpanded(parent, true);
+        parent->setExpanded(true);
         QTreeWidgetItem* item = parent;
         parent = 0;
         for (int index=0; index < item->childCount(); index++) {
@@ -328,7 +452,7 @@ bool validateInput(QWidget* parent, const QString& input)
             (c < 'A' || c > 'Z') &&  // Uppercase letters
             (c < 'a' || c > 'z') &&  // Lowercase letters
             (c != ' ')) {            // Space
-            QMessageBox::warning(parent, DlgParameterImp::tr("Invalid input"), 
+            QMessageBox::warning(parent, DlgParameterImp::tr("Invalid input"),
                                          DlgParameterImp::tr("Invalid key name '%1'").arg(input));
             return false;
         }
@@ -363,13 +487,13 @@ ParameterGroup::~ParameterGroup()
 void ParameterGroup::contextMenuEvent ( QContextMenuEvent* event )
 {
     QTreeWidgetItem* item = currentItem();
-    if (isItemSelected(item))
+    if (item && item->isSelected())
     {
         expandAct->setEnabled(item->childCount() > 0);
         // do not allow to import parameters from a non-empty parameter group
         importAct->setEnabled(item->childCount() == 0);
 
-        if ( isItemExpanded(item) )
+        if (item->isExpanded())
             expandAct->setText( tr("Collapse") );
         else
         expandAct->setText( tr("Expand") );
@@ -379,7 +503,7 @@ void ParameterGroup::contextMenuEvent ( QContextMenuEvent* event )
 
 void ParameterGroup::keyPressEvent (QKeyEvent* event)
 {
-    switch ( tolower(event->key()) ) 
+    switch ( tolower(event->key()) )
     {
     case Qt::Key_Delete:
         {
@@ -393,18 +517,23 @@ void ParameterGroup::keyPressEvent (QKeyEvent* event)
 void ParameterGroup::onDeleteSelectedItem()
 {
     QTreeWidgetItem* sel = currentItem();
-    if (isItemSelected(sel) && sel->parent())
+    if (sel && sel->isSelected() && sel->parent())
     {
-        if ( QMessageBox::question(this, tr("Remove group"), tr("Do really want to remove this parameter group?"),
-                               QMessageBox::Yes, QMessageBox::No|QMessageBox::Default|QMessageBox::Escape) == 
+        if ( QMessageBox::question(this, tr("Remove group"), tr("Do you really want to remove this parameter group?"),
+                               QMessageBox::Yes, QMessageBox::No|QMessageBox::Default|QMessageBox::Escape) ==
                                QMessageBox::Yes )
         {
             QTreeWidgetItem* parent = sel->parent();
             int index = parent->indexOfChild(sel);
             parent->takeChild(index);
-            ParameterGroupItem* para = static_cast<ParameterGroupItem*>(parent);
-            para->_hcGrp->RemoveGrp(sel->text(0).toLatin1());
+
+            std::string groupName = sel->text(0).toStdString();
+            // must delete the tree item here because it and its children still
+            // hold a reference to the parameter group
             delete sel;
+
+            ParameterGroupItem* para = static_cast<ParameterGroupItem*>(parent);
+            para->_hcGrp->RemoveGrp(groupName.c_str());
         }
     }
 }
@@ -412,12 +541,12 @@ void ParameterGroup::onDeleteSelectedItem()
 void ParameterGroup::onToggleSelectedItem()
 {
     QTreeWidgetItem* sel = currentItem();
-    if (isItemSelected(sel))
+    if (sel && sel->isSelected())
     {
-        if ( isItemExpanded(sel) )
-            setItemExpanded(sel, false);
-        else if ( sel->childCount() > 0 )
-            setItemExpanded(sel, true);
+        if (sel->isExpanded())
+            sel->setExpanded(false);
+        else if (sel->childCount() > 0)
+            sel->setExpanded(true);
     }
 }
 
@@ -425,12 +554,12 @@ void ParameterGroup::onCreateSubgroup()
 {
     bool ok;
     QString name = QInputDialog::getText(this, QObject::tr("New sub-group"), QObject::tr("Enter the name:"),
-                                         QLineEdit::Normal, QString::null, &ok );
+                                         QLineEdit::Normal, QString(), &ok, Qt::MSWindowsFixedSizeDialogHint);
 
     if (ok && Gui::validateInput(this, name))
     {
         QTreeWidgetItem* item = currentItem();
-        if (isItemSelected(item))
+        if (item && item->isSelected())
         {
             ParameterGroupItem* para = static_cast<ParameterGroupItem*>(item);
             Base::Reference<ParameterGrp> hGrp = para->_hcGrp;
@@ -452,11 +581,11 @@ void ParameterGroup::onCreateSubgroup()
 void ParameterGroup::onExportToFile()
 {
     QString file = FileDialog::getSaveFileName( this, tr("Export parameter to file"),
-        QString::null, QString::fromLatin1("XML (*.FCParam)"));
+        QString(), QString::fromLatin1("XML (*.FCParam)"));
     if ( !file.isEmpty() )
     {
         QTreeWidgetItem* item = currentItem();
-        if (isItemSelected(item))
+        if (item && item->isSelected())
         {
             ParameterGroupItem* para = static_cast<ParameterGroupItem*>(item);
             Base::Reference<ParameterGrp> hGrp = para->_hcGrp;
@@ -468,11 +597,11 @@ void ParameterGroup::onExportToFile()
 void ParameterGroup::onImportFromFile()
 {
     QString file = FileDialog::getOpenFileName( this, tr("Import parameter from file"),
-        QString::null, QString::fromLatin1("XML (*.FCParam)"));
+        QString(), QString::fromLatin1("XML (*.FCParam)"));
     if ( !file.isEmpty() )
     {
         QTreeWidgetItem* item = currentItem();
-        if (isItemSelected(item))
+        if (item && item->isSelected())
         {
             ParameterGroupItem* para = static_cast<ParameterGroupItem*>(item);
             Base::Reference<ParameterGrp> hGrp = para->_hcGrp;
@@ -493,7 +622,7 @@ void ParameterGroup::onImportFromFile()
                     new ParameterGroupItem(para,*it);
                 }
 
-                setItemExpanded(para, para->childCount());
+                para->setExpanded(para->childCount());
             }
             catch( const Base::Exception& )
             {
@@ -506,7 +635,7 @@ void ParameterGroup::onImportFromFile()
 void ParameterGroup::onRenameSelectedItem()
 {
     QTreeWidgetItem* sel = currentItem();
-    if (isItemSelected(sel))
+    if (sel && sel->isSelected())
     {
         editItem(sel, 0);
     }
@@ -548,7 +677,7 @@ ParameterValue::ParameterValue( QWidget * parent )
     newUlgAct = menuNew->addAction(tr("New unsigned item"), this, SLOT(onCreateUIntItem()));
     newBlnAct = menuNew->addAction(tr("New Boolean item"), this, SLOT(onCreateBoolItem()));
 
-    connect(this, SIGNAL(itemDoubleClicked(QTreeWidgetItem*, int)), 
+    connect(this, SIGNAL(itemDoubleClicked(QTreeWidgetItem*, int)),
             this, SLOT(onChangeSelectedItem(QTreeWidgetItem*, int)));
 }
 
@@ -561,6 +690,11 @@ void ParameterValue::setCurrentGroup( const Base::Reference<ParameterGrp>& hGrp
     _hcGrp = hGrp;
 }
 
+Base::Reference<ParameterGrp> ParameterValue::currentGroup() const
+{
+    return _hcGrp;
+}
+
 bool ParameterValue::edit ( const QModelIndex & index, EditTrigger trigger, QEvent * event )
 {
     if (index.column() > 0)
@@ -571,15 +705,22 @@ bool ParameterValue::edit ( const QModelIndex & index, EditTrigger trigger, QEve
 void ParameterValue::contextMenuEvent ( QContextMenuEvent* event )
 {
     QTreeWidgetItem* item = currentItem();
-    if (isItemSelected(item))
+    if (item && item->isSelected()) {
         menuEdit->popup(event->globalPos());
-    else
-        menuNew->popup(event->globalPos());
+    }
+    else {
+        // There is a regression in Qt 5.12.9 where it isn't checked that a sub-menu (here menuNew)
+        // can be popped up without its parent menu (menuEdit) and thus causes a crash.
+        // A workaround is to simply call exec() instead.
+        //
+        //menuNew->popup(event->globalPos());
+        menuNew->exec(event->globalPos());
+    }
 }
 
 void ParameterValue::keyPressEvent (QKeyEvent* event)
 {
-    switch ( tolower(event->key()) ) 
+    switch ( tolower(event->key()) )
     {
     case Qt::Key_Delete:
         {
@@ -590,9 +731,23 @@ void ParameterValue::keyPressEvent (QKeyEvent* event)
   }
 }
 
+void ParameterValue::resizeEvent(QResizeEvent* event)
+{
+#if QT_VERSION >= 0x050000
+    QHeaderView* hv = header();
+    hv->setSectionResizeMode(QHeaderView::Stretch);
+#endif
+
+    QTreeWidget::resizeEvent(event);
+
+#if QT_VERSION >= 0x050000
+    hv->setSectionResizeMode(QHeaderView::Interactive);
+#endif
+}
+
 void ParameterValue::onChangeSelectedItem(QTreeWidgetItem* item, int col)
 {
-    if (isItemSelected(item) && col > 0)
+    if (item->isSelected() && col > 0)
     {
         static_cast<ParameterValueItem*>(item)->changeValue();
     }
@@ -606,7 +761,7 @@ void ParameterValue::onChangeSelectedItem()
 void ParameterValue::onDeleteSelectedItem()
 {
     QTreeWidgetItem* sel = currentItem();
-    if (isItemSelected(sel))
+    if (sel && sel->isSelected())
     {
         takeTopLevelItem(indexOfTopLevelItem(sel));
         static_cast<ParameterValueItem*>(sel)->removeFromGroup();
@@ -617,7 +772,7 @@ void ParameterValue::onDeleteSelectedItem()
 void ParameterValue::onRenameSelectedItem()
 {
     QTreeWidgetItem* sel = currentItem();
-    if (isItemSelected(sel))
+    if (sel && sel->isSelected())
     {
         editItem(sel, 0);
     }
@@ -626,8 +781,8 @@ void ParameterValue::onRenameSelectedItem()
 void ParameterValue::onCreateTextItem()
 {
     bool ok;
-    QString name = QInputDialog::getText(this, QObject::tr("New text item"), QObject::tr("Enter the name:"), 
-                                         QLineEdit::Normal, QString::null, &ok);
+    QString name = QInputDialog::getText(this, QObject::tr("New text item"), QObject::tr("Enter the name:"),
+                                         QLineEdit::Normal, QString(), &ok, Qt::MSWindowsFixedSizeDialogHint);
 
     if (!ok || !Gui::validateInput(this, name))
         return;
@@ -642,8 +797,8 @@ void ParameterValue::onCreateTextItem()
         }
     }
 
-    QString val = QInputDialog::getText(this, QObject::tr("New text item"), QObject::tr("Enter your text:"), 
-                                        QLineEdit::Normal, QString::null, &ok);
+    QString val = QInputDialog::getText(this, QObject::tr("New text item"), QObject::tr("Enter your text:"),
+                                        QLineEdit::Normal, QString(), &ok, Qt::MSWindowsFixedSizeDialogHint);
     if ( ok && !val.isEmpty() )
     {
         ParameterValueItem *pcItem;
@@ -655,8 +810,8 @@ void ParameterValue::onCreateTextItem()
 void ParameterValue::onCreateIntItem()
 {
     bool ok;
-    QString name = QInputDialog::getText(this, QObject::tr("New integer item"), QObject::tr("Enter the name:"), 
-                                         QLineEdit::Normal, QString::null, &ok);
+    QString name = QInputDialog::getText(this, QObject::tr("New integer item"), QObject::tr("Enter the name:"),
+                                         QLineEdit::Normal, QString(), &ok, Qt::MSWindowsFixedSizeDialogHint);
 
     if (!ok || !Gui::validateInput(this, name))
         return;
@@ -672,7 +827,7 @@ void ParameterValue::onCreateIntItem()
     }
 
     int val = QInputDialog::getInt(this, QObject::tr("New integer item"), QObject::tr("Enter your number:"),
-                                   0, -2147483647, 2147483647, 1, &ok);
+                                   0, -2147483647, 2147483647, 1, &ok, Qt::MSWindowsFixedSizeDialogHint);
 
     if ( ok )
     {
@@ -685,8 +840,8 @@ void ParameterValue::onCreateIntItem()
 void ParameterValue::onCreateUIntItem()
 {
     bool ok;
-    QString name = QInputDialog::getText(this, QObject::tr("New unsigned item"), QObject::tr("Enter the name:"), 
-                                         QLineEdit::Normal, QString::null, &ok);
+    QString name = QInputDialog::getText(this, QObject::tr("New unsigned item"), QObject::tr("Enter the name:"),
+                                         QLineEdit::Normal, QString(), &ok, Qt::MSWindowsFixedSizeDialogHint);
 
     if (!ok || !Gui::validateInput(this, name))
         return;
@@ -721,8 +876,8 @@ void ParameterValue::onCreateUIntItem()
 void ParameterValue::onCreateFloatItem()
 {
     bool ok;
-    QString name = QInputDialog::getText(this, QObject::tr("New float item"), QObject::tr("Enter the name:"), 
-                                         QLineEdit::Normal, QString::null, &ok);
+    QString name = QInputDialog::getText(this, QObject::tr("New float item"), QObject::tr("Enter the name:"),
+                                         QLineEdit::Normal, QString(), &ok, Qt::MSWindowsFixedSizeDialogHint);
 
     if (!ok || !Gui::validateInput(this, name))
         return;
@@ -736,9 +891,9 @@ void ParameterValue::onCreateFloatItem()
             return;
         }
     }
-  
-    double val = QInputDialog::getDouble(this, QObject::tr("New float item"), QObject::tr("Enter your number:"), 
-                                         0, -2147483647, 2147483647, 12, &ok);
+
+    double val = QInputDialog::getDouble(this, QObject::tr("New float item"), QObject::tr("Enter your number:"),
+                                         0, -2147483647, 2147483647, 12, &ok, Qt::MSWindowsFixedSizeDialogHint);
     if ( ok )
     {
         ParameterValueItem *pcItem;
@@ -750,8 +905,8 @@ void ParameterValue::onCreateFloatItem()
 void ParameterValue::onCreateBoolItem()
 {
     bool ok;
-    QString name = QInputDialog::getText(this, QObject::tr("New Boolean item"), QObject::tr("Enter the name:"), 
-                                         QLineEdit::Normal, QString::null, &ok);
+    QString name = QInputDialog::getText(this, QObject::tr("New Boolean item"), QObject::tr("Enter the name:"),
+                                         QLineEdit::Normal, QString(), &ok, Qt::MSWindowsFixedSizeDialogHint);
 
     if (!ok || !Gui::validateInput(this, name))
         return;
@@ -769,7 +924,7 @@ void ParameterValue::onCreateBoolItem()
     QStringList list; list << QString::fromLatin1("true")
                            << QString::fromLatin1("false");
     QString val = QInputDialog::getItem (this, QObject::tr("New boolean item"), QObject::tr("Choose an item:"),
-                                         list, 0, false, &ok);
+                                         list, 0, false, &ok, Qt::MSWindowsFixedSizeDialogHint);
     if ( ok )
     {
         ParameterValueItem *pcItem;
@@ -804,7 +959,7 @@ ParameterGroupItem::~ParameterGroupItem()
 
 void ParameterGroupItem::fillUp(void)
 {
-    // filing up groups
+    // filling up groups
     std::vector<Base::Reference<ParameterGrp> > vhcParamGrp = _hcGrp->GetGroups();
 
     setText(0,QString::fromUtf8(_hcGrp->GetGroupName()));
@@ -836,14 +991,12 @@ void ParameterGroupItem::setData ( int column, int role, const QVariant & value
             QMessageBox::critical( treeWidget(), QObject::tr("Existing group"),
                 QObject::tr("The group '%1' already exists.").arg( newName ) );
             return;
-        } 
-        else 
+        }
+        else
         {
             // rename the group by adding a new group, copy the content and remove the old group
-            Base::Reference<ParameterGrp> hOldGrp = item->_hcGrp->GetGroup( oldName.toLatin1() );
-            Base::Reference<ParameterGrp> hNewGrp = item->_hcGrp->GetGroup( newName.toLatin1() );
-            hOldGrp->copyTo( hNewGrp );
-            item->_hcGrp->RemoveGrp( oldName.toLatin1() );
+            if (!item->_hcGrp->RenameGrp(oldName.toLatin1(), newName.toLatin1()))
+                return;
         }
     }
 
@@ -855,7 +1008,7 @@ QVariant ParameterGroupItem::data ( int column, int role ) const
     if (role == Qt::DecorationRole) {
         // The root item should keep its special pixmap
         if (parent()) {
-            return treeWidget()->isItemExpanded(this) ?
+            return this->isExpanded() ?
                 QApplication::style()->standardPixmap(QStyle::SP_DirOpenIcon):
                 QApplication::style()->standardPixmap(QStyle::SP_DirClosedIcon);
         }
@@ -898,7 +1051,7 @@ void ParameterValueItem::setData ( int column, int role, const QVariant & value
 ParameterText::ParameterText ( QTreeWidget * parent, QString label, const char* value, const Base::Reference<ParameterGrp> &hcGrp)
   :ParameterValueItem( parent, hcGrp)
 {
-    setIcon(0,BitmapFactory().pixmap("Param_Text") );
+    setIcon(0, BitmapFactory().iconFromTheme("Param_Text") );
     setText(0, label);
     setText(1, QString::fromLatin1("Text"));
     setText(2, QString::fromUtf8(value));
@@ -911,8 +1064,8 @@ ParameterText::~ParameterText()
 void ParameterText::changeValue()
 {
     bool ok;
-    QString txt = QInputDialog::getText(treeWidget(), QObject::tr("Change value"), QObject::tr("Enter your text:"), 
-                                        QLineEdit::Normal, text(2), &ok);
+    QString txt = QInputDialog::getText(treeWidget(), QObject::tr("Change value"), QObject::tr("Enter your text:"),
+                                        QLineEdit::Normal, text(2), &ok, Qt::MSWindowsFixedSizeDialogHint);
     if ( ok )
     {
         setText( 2, txt );
@@ -942,7 +1095,7 @@ void ParameterText::appendToGroup()
 ParameterInt::ParameterInt ( QTreeWidget * parent, QString label, long value, const Base::Reference<ParameterGrp> &hcGrp)
   :ParameterValueItem( parent, hcGrp)
 {
-    setIcon(0,BitmapFactory().pixmap("Param_Int") );
+    setIcon(0, BitmapFactory().iconFromTheme("Param_Int") );
     setText(0, label);
     setText(1, QString::fromLatin1("Integer"));
     setText(2, QString::fromLatin1("%1").arg(value));
@@ -956,7 +1109,7 @@ void ParameterInt::changeValue()
 {
     bool ok;
     int num = QInputDialog::getInt(treeWidget(), QObject::tr("Change value"), QObject::tr("Enter your number:"),
-                                   text(2).toInt(), -2147483647, 2147483647, 1, &ok);
+                                   text(2).toInt(), -2147483647, 2147483647, 1, &ok, Qt::MSWindowsFixedSizeDialogHint);
     if ( ok )
     {
         setText(2, QString::fromLatin1("%1").arg(num));
@@ -986,7 +1139,7 @@ void ParameterInt::appendToGroup()
 ParameterUInt::ParameterUInt ( QTreeWidget * parent, QString label, unsigned long value, const Base::Reference<ParameterGrp> &hcGrp)
   :ParameterValueItem( parent, hcGrp)
 {
-    setIcon(0,BitmapFactory().pixmap("Param_UInt") );
+    setIcon(0, BitmapFactory().iconFromTheme("Param_UInt") );
     setText(0, label);
     setText(1, QString::fromLatin1("Unsigned"));
     setText(2, QString::fromLatin1("%1").arg(value));
@@ -1039,7 +1192,7 @@ void ParameterUInt::appendToGroup()
 ParameterFloat::ParameterFloat ( QTreeWidget * parent, QString label, double value, const Base::Reference<ParameterGrp> &hcGrp)
   :ParameterValueItem( parent, hcGrp)
 {
-    setIcon(0,BitmapFactory().pixmap("Param_Float") );
+    setIcon(0, BitmapFactory().iconFromTheme("Param_Float") );
     setText(0, label);
     setText(1, QString::fromLatin1("Float"));
     setText(2, QString::fromLatin1("%1").arg(value));
@@ -1052,8 +1205,8 @@ ParameterFloat::~ParameterFloat()
 void ParameterFloat::changeValue()
 {
     bool ok;
-    double num = QInputDialog::getDouble(treeWidget(), QObject::tr("Change value"), QObject::tr("Enter your number:"), 
-                                         text(2).toDouble(), -2147483647, 2147483647, 12, &ok);
+    double num = QInputDialog::getDouble(treeWidget(), QObject::tr("Change value"), QObject::tr("Enter your number:"),
+                                         text(2).toDouble(), -2147483647, 2147483647, 12, &ok, Qt::MSWindowsFixedSizeDialogHint);
     if ( ok )
     {
         setText(2, QString::fromLatin1("%1").arg(num));
@@ -1083,7 +1236,7 @@ void ParameterFloat::appendToGroup()
 ParameterBool::ParameterBool ( QTreeWidget * parent, QString label, bool value, const Base::Reference<ParameterGrp> &hcGrp)
   :ParameterValueItem( parent, hcGrp)
 {
-    setIcon(0,BitmapFactory().pixmap("Param_Bool") );
+    setIcon(0, BitmapFactory().iconFromTheme("Param_Bool") );
     setText(0, label);
     setText(1, QString::fromLatin1("Boolean"));
     setText(2, QString::fromLatin1((value ? "true" : "false")));
@@ -1096,12 +1249,12 @@ ParameterBool::~ParameterBool()
 void ParameterBool::changeValue()
 {
     bool ok;
-    QStringList list; list << QString::fromLatin1("true") 
+    QStringList list; list << QString::fromLatin1("true")
                            << QString::fromLatin1("false");
     int pos = (text(2) == list[0] ? 0 : 1);
 
     QString txt = QInputDialog::getItem (treeWidget(), QObject::tr("Change value"), QObject::tr("Choose an item:"),
-                                         list, pos, false, &ok);
+                                         list, pos, false, &ok, Qt::MSWindowsFixedSizeDialogHint);
     if ( ok )
     {
         setText( 2, txt );
