@@ -47,6 +47,7 @@
 # include <sstream>
 #endif
 
+#include <Base/Console.h>
 #include "DocumentRecovery.h"
 #include "ui_DocumentRecovery.h"
 #include "WaitCursor.h"
@@ -57,11 +58,14 @@
 #include <App/Document.h>
 
 #include <Gui/Application.h>
+#include <Gui/Command.h>
 #include <Gui/Document.h>
 
 #include <QDomDocument>
 #include <boost/interprocess/sync/file_lock.hpp>
 
+FC_LOG_LEVEL_INIT("Gui",true,true)
+
 using namespace Gui;
 using namespace Gui::Dialog;
 
@@ -80,8 +84,10 @@ std::string DocumentRecovery::doctools =
 "		self.dirname = dirname\n"
 "\n"
 "	def startElement(self, name, attributes):\n"
+"		if name == 'XLink':\n"
+"			return\n"
 "		item=attributes.get(\"file\")\n"
-"		if item != None:\n"
+"		if item:\n"
 "			self.files.append(os.path.join(self.dirname,str(item)))\n"
 "\n"
 "	def characters(self, data):\n"
@@ -172,7 +178,11 @@ DocumentRecovery::DocumentRecovery(const QList<QFileInfo>& dirs, QWidget* parent
 {
     d_ptr->ui.setupUi(this);
     d_ptr->ui.buttonBox->button(QDialogButtonBox::Ok)->setText(tr("Start Recovery"));
+#if QT_VERSION >= 0x050000
+    d_ptr->ui.treeWidget->header()->setSectionResizeMode(QHeaderView::Stretch);
+#else
     d_ptr->ui.treeWidget->header()->setResizeMode(QHeaderView::Stretch);
+#endif
 
     d_ptr->recovered = false;
 
@@ -190,6 +200,8 @@ DocumentRecovery::DocumentRecovery(const QList<QFileInfo>& dirs, QWidget* parent
             d_ptr->ui.treeWidget->addTopLevelItem(item);
         }
     }
+
+    this->adjustSize();
 }
 
 DocumentRecovery::~DocumentRecovery()
@@ -212,17 +224,16 @@ QString DocumentRecovery::createProjectFile(const QString& documentXml)
     str << doctools << "\n";
     str << "createDocument(\"" << (const char*)source.toUtf8()
         << "\", \"" << (const char*)dest.toUtf8() << "\")";
-    Application::Instance->runPythonCode(str.str().c_str());
+    Gui::Command::runCommand(Gui::Command::App, str.str().c_str());
 
     return dest;
 }
 
 void DocumentRecovery::closeEvent(QCloseEvent* e)
 {
-    Q_D(DocumentRecovery);
-
-    if (!d->recoveryInfo.isEmpty())
-        e->ignore();
+    // Do not disable the X button in the title bar
+    // #0004281: Close Document Recovery
+    e->accept();
 }
 
 void DocumentRecovery::accept()
@@ -233,32 +244,23 @@ void DocumentRecovery::accept()
 
         WaitCursor wc;
         int index = 0;
-        for (QList<DocumentRecoveryPrivate::Info>::iterator it = d->recoveryInfo.begin(); it != d->recoveryInfo.end(); ++it, index++) {
-            std::string documentName;
+        std::vector<int> indices;
+        std::vector<std::string> filenames, paths, labels, errs;
+        for (auto &info : d->recoveryInfo) {
             QString errorInfo;
             QTreeWidgetItem* item = d_ptr->ui.treeWidget->topLevelItem(index);
 
             try {
-                QString file = it->projectFile;
+                QString file = info.projectFile;
                 QFileInfo fi(file);
                 if (fi.fileName() == QLatin1String("Document.xml"))
-                    file = createProjectFile(it->projectFile);
-                App::Document* document = App::GetApplication().newDocument();
-                documentName = document->getName();
-                document->FileName.setValue(file.toUtf8().constData());
+                    file = createProjectFile(info.projectFile);
 
-                // If something goes wrong an exception will be thrown here
-                document->restore();
-
-                file = it->fileName;
-                document->FileName.setValue(file.toUtf8().constData());
-                document->Label.setValue(it->label.toUtf8().constData());
-
-                // Set the modified flag so that the user cannot close by accident
-                Gui::Document* guidoc = Gui::Application::Instance->getDocument(document);
-                if (guidoc) {
-                    guidoc->setModified(true);
-                }
+                paths.emplace_back(file.toUtf8().constData());
+                filenames.emplace_back(info.fileName.toUtf8().constData());
+                labels.emplace_back(info.label.toUtf8().constData());
+                indices.push_back(index);
+                ++index;
             }
             catch (const std::exception& e) {
                 errorInfo = QString::fromLatin1(e.what());
@@ -270,31 +272,78 @@ void DocumentRecovery::accept()
                 errorInfo = tr("Unknown problem occurred");
             }
 
-            // an error occurred so close the document again
             if (!errorInfo.isEmpty()) {
-                if (!documentName.empty())
-                    App::GetApplication().closeDocument(documentName.c_str());
-
-                it->status = DocumentRecoveryPrivate::Failure;
-
+                info.status = DocumentRecoveryPrivate::Failure;
                 if (item) {
                     item->setText(1, tr("Failed to recover"));
                     item->setToolTip(1, errorInfo);
                     item->setForeground(1, QColor(170,0,0));
                 }
+                d->writeRecoveryInfo(info);
             }
-            // everything OK
-            else {
-                it->status = DocumentRecoveryPrivate::Success;
+        }
 
+        auto docs = App::GetApplication().openDocuments(filenames,&paths,&labels,&errs);
+
+        for (size_t i = 0; i < docs.size(); ++i) {
+            auto &info = d->recoveryInfo[indices[i]];
+            QTreeWidgetItem* item = d_ptr->ui.treeWidget->topLevelItem(indices[i]);
+            if (!docs[i] || !errs[i].empty()) {
+                if (docs[i])
+                    App::GetApplication().closeDocument(docs[i]->getName());
+                info.status = DocumentRecoveryPrivate::Failure;
+
+                if (item) {
+                    item->setText(1, tr("Failed to recover"));
+                    item->setToolTip(1, QString::fromUtf8(errs[i].c_str()));
+                    item->setForeground(1, QColor(170,0,0));
+                }
+                // write back current status
+                d->writeRecoveryInfo(info);
+            }
+            else {
+                auto gdoc = Application::Instance->getDocument(docs[i]);
+                if (gdoc)
+                    gdoc->setModified(true);
+
+                info.status = DocumentRecoveryPrivate::Success;
                 if (item) {
                     item->setText(1, tr("Successfully recovered"));
                     item->setForeground(1, QColor(0,170,0));
                 }
-            }
 
-            // write back current status
-            d->writeRecoveryInfo(*it);
+                QDir transDir(QString::fromUtf8(docs[i]->TransientDir.getValue()));
+
+                QFileInfo xfi(info.xmlFile);
+                QFileInfo fi(info.projectFile);
+                bool res = false;
+
+                if (fi.fileName() == QLatin1String("fc_recovery_file.fcstd")) {
+                    transDir.remove(fi.fileName());
+                    res = transDir.rename(fi.absoluteFilePath(),fi.fileName());
+                }
+                else {
+                    transDir.rmdir(fi.dir().dirName());
+                    res = transDir.rename(fi.absolutePath(),fi.dir().dirName());
+                }
+
+                if (res) {
+                    transDir.remove(xfi.fileName());
+                    res = transDir.rename(xfi.absoluteFilePath(),xfi.fileName());
+                }
+
+                if (!res) {
+                    FC_WARN("Failed to move recovery file of document '"
+                            << docs[i]->Label.getValue() << "'");
+                }
+                else {
+                    clearDirectory(xfi.absolutePath());
+                    QDir().rmdir(xfi.absolutePath());
+                }
+
+                // DO NOT write success into recovery info, in case the program
+                // crash again before the user save the just recovered file.
+            }
         }
 
         d->ui.buttonBox->button(QDialogButtonBox::Ok)->setText(tr("Finish"));
@@ -313,28 +362,28 @@ void DocumentRecoveryPrivate::writeRecoveryInfo(const DocumentRecoveryPrivate::I
     if (file.open(QFile::WriteOnly)) {
         QTextStream str(&file);
         str.setCodec("UTF-8");
-        str << "<?xml version='1.0' encoding='utf-8'?>" << endl
-            << "<AutoRecovery SchemaVersion=\"1\">" << endl;
+        str << "<?xml version='1.0' encoding='utf-8'?>\n"
+            << "<AutoRecovery SchemaVersion=\"1\">\n";
         switch (info.status) {
         case Created:
-            str << "  <Status>Created</Status>" << endl;
+            str << "  <Status>Created</Status>\n";
             break;
         case Overage:
-            str << "  <Status>Deprecated</Status>" << endl;
+            str << "  <Status>Deprecated</Status>\n";
             break;
         case Success:
-            str << "  <Status>Success</Status>" << endl;
+            str << "  <Status>Success</Status>\n";
             break;
         case Failure:
-            str << "  <Status>Failure</Status>" << endl;
+            str << "  <Status>Failure</Status>\n";
             break;
         default:
-            str << "  <Status>Unknown</Status>" << endl;
+            str << "  <Status>Unknown</Status>\n";
             break;
         }
-        str << "  <Label>" << info.label << "</Label>" << endl;
-        str << "  <FileName>" << info.fileName << "</FileName>" << endl;
-        str << "</AutoRecovery>" << endl;
+        str << "  <Label>" << info.label << "</Label>\n";
+        str << "  <FileName>" << info.fileName << "</FileName>\n";
+        str << "</AutoRecovery>\n";
         file.close();
     }
 }
@@ -496,7 +545,7 @@ void DocumentRecovery::on_buttonCleanup_clicked()
     msgBox.setIcon(QMessageBox::Warning);
     msgBox.setWindowTitle(tr("Cleanup"));
     msgBox.setText(tr("Are you sure you want to delete all transient directories?"));
-    msgBox.setInformativeText(tr("When deleting all transient directory you won't be able to recover any files afterwards."));
+    msgBox.setInformativeText(tr("When deleting all transient directories you won't be able to recover any files afterwards."));
     msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
     msgBox.setDefaultButton(QMessageBox::No);
     int ret = msgBox.exec();
@@ -512,7 +561,6 @@ void DocumentRecovery::on_buttonCleanup_clicked()
     tmp.setNameFilters(QStringList() << QString::fromLatin1("*.lock"));
     tmp.setFilter(QDir::Files);
 
-    QList<QFileInfo> restoreDocFiles;
     QString exeName = QString::fromLatin1(App::GetApplication().getExecutableName());
     QList<QFileInfo> locks = tmp.entryInfoList();
     for (QList<QFileInfo>::iterator it = locks.begin(); it != locks.end(); ++it) {
