@@ -46,6 +46,7 @@
 #include "BitmapFactory.h"
 #include "FileDialog.h"
 #include "Macro.h"
+#include "MainWindow.h"
 #include "PythonDebugger.h"
 #include "PythonEditor.h"
 
@@ -63,6 +64,7 @@ public:
     QTimer*  activityTimer;
     uint timeStamp;
     bool lock;
+    bool aboutToClose;
     QStringList undos;
     QStringList redos;
 };
@@ -77,16 +79,23 @@ public:
  *  name 'name'.
  */
 EditorView::EditorView(QPlainTextEdit* editor, QWidget* parent)
-    : MDIView(0,parent,0), WindowParameter( "Editor" )
+    : MDIView(0,parent,Qt::WindowFlags()), WindowParameter( "Editor" )
 {
     d = new EditorViewP;
     d->lock = false;
+    d->aboutToClose = false;
     d->displayName = EditorView::FullName;
 
     // create the editor first
     d->textEdit = editor;
     d->textEdit->setLineWrapMode(QPlainTextEdit::NoWrap);
 
+    // update editor actions on request
+    Gui::MainWindow* mw = Gui::getMainWindow();
+    connect(editor, SIGNAL(undoAvailable(bool)), mw, SLOT(updateEditorActions()));
+    connect(editor, SIGNAL(redoAvailable(bool)), mw, SLOT(updateEditorActions()));
+    connect(editor, SIGNAL(copyAvailable(bool)), mw, SLOT(updateEditorActions()));
+
     // Create the layout containing the workspace and a tab bar
     QFrame* hbox = new QFrame(this);
     hbox->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
@@ -133,9 +142,31 @@ QPlainTextEdit* EditorView::getEditor() const
     return d->textEdit;
 }
 
+void EditorView::showEvent(QShowEvent* event)
+{
+    Gui::MainWindow* mw = Gui::getMainWindow();
+    mw->updateEditorActions();
+    MDIView::showEvent(event);
+}
+
+void EditorView::hideEvent(QHideEvent* event)
+{
+    MDIView::hideEvent(event);
+}
+
+void EditorView::closeEvent(QCloseEvent* event)
+{
+    MDIView::closeEvent(event);
+    if (event->isAccepted()) {
+        d->aboutToClose = true;
+        Gui::MainWindow* mw = Gui::getMainWindow();
+        mw->updateEditorActions();
+    }
+}
+
 void EditorView::OnChange(Base::Subject<const char*> &rCaller,const char* rcReason)
 {
-    Q_UNUSED(rCaller); 
+    Q_UNUSED(rCaller);
     ParameterGrp::handle hPrefGrp = getWindowParameter();
     if (strcmp(rcReason, "EnableLineNumber") == 0) {
         //bool show = hPrefGrp->GetBool( "EnableLineNumber", true );
@@ -147,7 +178,7 @@ void EditorView::checkTimestamp()
     QFileInfo fi(d->fileName);
     uint timeStamp =  fi.lastModified().toTime_t();
     if (timeStamp != d->timeStamp) {
-        switch( QMessageBox::question( this, tr("Modified file"), 
+        switch( QMessageBox::question( this, tr("Modified file"),
                 tr("%1.\n\nThis has been modified outside of the source editor. Do you want to reload it?").arg(d->fileName),
                 QMessageBox::Yes|QMessageBox::Default, QMessageBox::No|QMessageBox::Escape) )
         {
@@ -170,28 +201,39 @@ void EditorView::checkTimestamp()
  */
 bool EditorView::onMsg(const char* pMsg,const char** /*ppReturn*/)
 {
-    if (strcmp(pMsg,"Save")==0){
+    // don't allow any actions if the editor is being closed
+    if (d->aboutToClose)
+        return false;
+
+    if (strcmp(pMsg, "Save") == 0) {
         saveFile();
         return true;
-    } else if (strcmp(pMsg,"SaveAs")==0){
+    }
+    else if (strcmp(pMsg, "SaveAs") == 0) {
         saveAs();
         return true;
-    } else if (strcmp(pMsg,"Cut")==0){
+    }
+    else if (strcmp(pMsg, "Cut") == 0) {
         cut();
         return true;
-    } else if (strcmp(pMsg,"Copy")==0){
+    }
+    else if (strcmp(pMsg, "Copy") == 0) {
         copy();
         return true;
-    } else if (strcmp(pMsg,"Paste")==0){
+    }
+    else if (strcmp(pMsg, "Paste") == 0) {
         paste();
         return true;
-    } else if (strcmp(pMsg,"Undo")==0){
+    }
+    else if (strcmp(pMsg, "Undo") == 0) {
         undo();
         return true;
-    } else if (strcmp(pMsg,"Redo")==0){
+    }
+    else if (strcmp(pMsg, "Redo") == 0) {
         redo();
         return true;
-    } else if (strcmp(pMsg,"ViewFit")==0){
+    }
+    else if (strcmp(pMsg, "ViewFit") == 0) {
         // just ignore this
         return true;
     }
@@ -205,21 +247,34 @@ bool EditorView::onMsg(const char* pMsg,const char** /*ppReturn*/)
  */
 bool EditorView::onHasMsg(const char* pMsg) const
 {
-    if (strcmp(pMsg,"Run")==0)  return true;
-    if (strcmp(pMsg,"DebugStart")==0)  return true;
-    if (strcmp(pMsg,"DebugStop")==0)  return true;
-    if (strcmp(pMsg,"SaveAs")==0)  return true;
-    if (strcmp(pMsg,"Print")==0) return true;
-    if (strcmp(pMsg,"PrintPreview")==0) return true;
-    if (strcmp(pMsg,"PrintPdf")==0) return true;
-    if (strcmp(pMsg,"Save")==0) { 
+    // don't allow any actions if the editor is being closed
+    if (d->aboutToClose)
+        return false;
+    if (strcmp(pMsg, "Run") == 0)
+        return true;
+    if (strcmp(pMsg, "DebugStart") == 0)
+        return true;
+    if (strcmp(pMsg, "DebugStop") == 0)
+        return true;
+    if (strcmp(pMsg, "SaveAs") == 0)
+        return true;
+    if (strcmp(pMsg, "Print") == 0)
+        return true;
+    if (strcmp(pMsg, "PrintPreview") == 0)
+        return true;
+    if (strcmp(pMsg, "PrintPdf") == 0)
+        return true;
+    if (strcmp(pMsg, "Save") == 0) {
         return d->textEdit->document()->isModified();
-    } else if (strcmp(pMsg,"Cut")==0) {
+    }
+    else if (strcmp(pMsg, "Cut") == 0) {
         bool canWrite = !d->textEdit->isReadOnly();
         return (canWrite && (d->textEdit->textCursor().hasSelection()));
-    } else if (strcmp(pMsg,"Copy")==0) {
+    }
+    else if (strcmp(pMsg, "Copy") == 0) {
         return ( d->textEdit->textCursor().hasSelection() );
-    } else if (strcmp(pMsg,"Paste")==0) {
+    }
+    else if (strcmp(pMsg, "Paste") == 0) {
         QClipboard *cb = QApplication::clipboard();
         QString text;
 
@@ -228,9 +283,11 @@ bool EditorView::onHasMsg(const char* pMsg) const
 
         bool canWrite = !d->textEdit->isReadOnly();
         return ( !text.isEmpty() && canWrite );
-    } else if (strcmp(pMsg,"Undo")==0) {
+    }
+    else if (strcmp(pMsg, "Undo") == 0) {
         return d->textEdit->document()->isUndoAvailable ();
-    } else if (strcmp(pMsg,"Redo")==0) {
+    }
+    else if (strcmp(pMsg, "Redo") == 0) {
         return d->textEdit->document()->isRedoAvailable ();
     }
 
@@ -243,10 +300,10 @@ bool EditorView::canClose(void)
     if ( !d->textEdit->document()->isModified() )
         return true;
     this->setFocus(); // raises the view to front
-    switch( QMessageBox::question(this, tr("Unsaved document"), 
+    switch( QMessageBox::question(this, tr("Unsaved document"),
                                     tr("The document has been modified.\n"
                                        "Do you want to save your changes?"),
-                                     QMessageBox::Yes|QMessageBox::Default, QMessageBox::No, 
+                                     QMessageBox::Yes|QMessageBox::Default, QMessageBox::No,
                                      QMessageBox::Cancel|QMessageBox::Escape))
     {
         case QMessageBox::Yes:
@@ -271,7 +328,7 @@ void EditorView::setDisplayName(EditorView::DisplayName type)
 bool EditorView::saveAs(void)
 {
     QString fn = FileDialog::getSaveFileName(this, QObject::tr("Save Macro"),
-        QString::null, QString::fromLatin1("%1 (*.FCMacro);;Python (*.py)").arg(tr("FreeCAD macro")));
+        QString(), QString::fromLatin1("%1 (*.FCMacro);;Python (*.py)").arg(tr("FreeCAD macro")));
     if (fn.isEmpty())
         return false;
     setCurrentFileName(fn);
@@ -323,7 +380,7 @@ void EditorView::copy(void)
 }
 
 /**
- * Pastes the text from the clipboard into the text edit at the current cursor position. 
+ * Pastes the text from the clipboard into the text edit at the current cursor position.
  * If there is no text in the clipboard nothing happens.
  */
 void EditorView::paste(void)
@@ -474,7 +531,7 @@ void EditorView::redoAvailable(bool redo)
 
 void EditorView::contentsChange(int position, int charsRemoved, int charsAdded)
 {
-    Q_UNUSED(position); 
+    Q_UNUSED(position);
     if (d->lock)
         return;
     if (charsRemoved > 0 && charsAdded > 0)
