@@ -32,7 +32,7 @@
 
 using namespace Gui;
 
-TYPESYSTEM_SOURCE_ABSTRACT(Gui::GLGraphicsItem, Base::BaseClass);
+TYPESYSTEM_SOURCE_ABSTRACT(Gui::GLGraphicsItem, Base::BaseClass)
 
 GLPainter::GLPainter()
   : viewer(0)
@@ -390,7 +390,7 @@ void Polyline::setCloseStippled(bool c)
 
 void Polyline::setLineWidth(float l)
 {
-    line = l; 
+    line = l;
 }
 
 void Polyline::addNode(const QPoint& p)
