@@ -26,7 +26,7 @@
 
 #include "MDIView.h"
 #include <boost/shared_ptr.hpp>
-#include <boost/signals2.hpp>
+#include <boost_signals2.hpp>
 
 
 class QGraphicsScene;
@@ -35,7 +35,7 @@ class QSvgRenderer;
 class QGraphicsSvgItem;
 class GraphicsViewZoom;
 
-namespace Gui 
+namespace Gui
 {
 
 class GraphvizWorker;
