@@ -30,31 +30,25 @@
 namespace Gui {
 
 /** The console window class
- *  This class opens a console window when instantiated 
- *  and redirects the stdio streams to it as long it exists. 
+ *  This class opens a console window when instantiated
+ *  and redirects the stdio streams to it as long it exists.
  *  This is for Windows only!
  *  After instantiation it automatically registers itself at
  *  the FCConsole class and gets all the FCConsoleObserver
- *  messages. The class must not used directly! Only the 
+ *  messages. The class must not used directly! Only the
  *  FCConsole class is allowed!
  *  @see FCConsole
  *  \author Jürgen Riegel
  */
-class GuiExport GUIConsole :public Base::ConsoleObserver
+class GuiExport GUIConsole :public Base::ILogger
 {
 public:
   /// Constructor
   GUIConsole(void);
   /// Destructor
   virtual ~GUIConsole(void);
-  //@{
-    /** Observer implementation */
-  virtual void Warning(const char *sWarn);
-  virtual void Message(const char *sMsg);
-  virtual void Error  (const char *sErr);
-  virtual void Log    (const char *sErr);
-  const char* Name(void){return "GUIConsole";}
-  //@}
+  void SendLog(const std::string& msg, Base::LogStyle level) override;
+  const char* Name(void) override {return "GUIConsole";}
 
 protected:
   static const unsigned int s_nMaxLines;
