@@ -67,7 +67,7 @@ public:
     }
 };
 
-/** 
+/**
  * The MainWindow class provides a main window with menu bar, toolbars, dockable windows,
  * a status bar and mainly a workspace for the MDI windows.
  * @author Werner Mayer
@@ -75,7 +75,7 @@ public:
 class GuiExport MainWindow : public QMainWindow
 {
     Q_OBJECT
- 
+
 public:
     /**
      * Constructs an empty main window. For default \a parent is 0, as there usually is
@@ -97,7 +97,7 @@ public:
      * Removes an MDI window from the main window's workspace and its associated tab without
      * deleting the widget. If the main windows does not have such a window nothing happens.
      */
-    void removeWindow(MDIView* view);
+    void removeWindow(MDIView* view, bool close=true);
     /**
      * Returns a list of all MDI windows in the worpspace.
      */
@@ -118,6 +118,10 @@ public:
      * MRU: Appends \a file to the list of recent files.
      */
     void appendRecentFile(const QString& filename);
+    /**
+     * MRU: Appends \a macro to the list of recent macros.
+     */
+    void appendRecentMacro(const QString& filename);
     /**
      * Returns true that the context menu contains the 'Customize...' menu item.
      */
@@ -137,7 +141,7 @@ public:
     void showDocumentation(const QString& help);
     //@}
 
-    /** @name Layout Methods 
+    /** @name Layout Methods
      */
     //@{
     /// Loads the main window settings.
@@ -178,7 +182,17 @@ public:
     void unsetUrlHandler(const QString &scheme);
     //@}
 
+    void updateActions(bool delay = false);
+
+    enum StatusType {None, Err, Wrn, Pane, Msg, Log, Tmp};
+    void showStatus(int type, const QString & message);
+
+
 public Q_SLOTS:
+    /**
+     * Updates the standard actions of a text editor such as Cut, Copy, Paste, Undo and Redo.
+     */
+    void updateEditorActions();
     /**
      * Sets text to the pane in the status bar.
      */
@@ -200,11 +214,12 @@ public Q_SLOTS:
      */
     void closeActiveWindow ();
     /**
-     * Closes all child windows. 
-     * The windows are closed in random order. The operation stops
-     * if a window does not accept the close event.
+     * Closes all document window.
      */
-    void closeAllWindows ();
+    bool closeAllDocuments (bool close=true);
+    /** Pop up a message box asking for saving document
+     */
+    int confirmSave(const char *docName, QWidget *parent=0, bool addCheckBox=false);
     /**
      * Activates the next window in the child window chain.
      */
@@ -223,6 +238,9 @@ public Q_SLOTS:
     void whatsThis();
     void switchToTopLevelMode();
     void switchToDockedMode();
+
+    void statusMessageChanged();
+
     void showMessage (const QString & message, int timeout = 0);
 
 protected:
@@ -275,10 +293,10 @@ private Q_SLOTS:
      * Fills up the menu with the current dock windows.
      */
     void onDockWindowMenuAboutToShow();
-    /** 
+    /**
      * This method gets frequently activated and test the commands if they are still active.
      */
-    void updateActions();
+    void _updateActions();
     /**
      * \internal
      */
@@ -291,6 +309,10 @@ private Q_SLOTS:
      * \internal
      */
     void processMessages(const QList<QByteArray> &);
+    /**
+     * \internal
+     */
+    void clearStatus();
 
 Q_SIGNALS:
     void timeEvent();
@@ -316,29 +338,24 @@ inline MainWindow* getMainWindow()
  * error messages are in red. Log messages are completely ignored.
  * The class is implemented to be thread-safe.
  * @see Console
- * @see ConsoleObserver
+ * @see ILogger
  * @author Werner Mayer
  */
-class StatusBarObserver: public WindowParameter, public Base::ConsoleObserver
+class StatusBarObserver: public WindowParameter, public Base::ILogger
 {
 public:
     StatusBarObserver();
     virtual ~StatusBarObserver();
 
     /** Observes its parameter group. */
-    void OnChange(Base::Subject<const char*> &rCaller, const char * sReason);
+    void OnChange(Base::Subject<const char*> &rCaller, const char * sReason) override;
+
+    void SendLog(const std::string& msg, Base::LogStyle level) override;
 
-    /// get called when a Warning is issued
-    void Warning(const char *m);
-    /// get called when a Message is issued
-    void Message(const char * m);
-    /// get called when a Error is issued
-    void Error  (const char *m);
-    /// get called when a Log Message is issued
-    void Log    (const char *);
     /// name of the observer
-    const char *Name(void){return "StatusBar";}
+    const char *Name(void) override {return "StatusBar";}
 
+    friend class MainWindow;
 private:
     QString msg, wrn, err;
 };
