@@ -70,8 +70,6 @@
 # include <QRegExp>
 #endif
 
-#include <Inventor/sensors/SoTimerSensor.h>
-
 #include <App/Application.h>
 #include <Base/Console.h>
 #include "NavigationStyle.h"
@@ -87,7 +85,7 @@ using namespace Gui;
 
 /* TRANSLATOR Gui::MayaGestureNavigationStyle */
 
-TYPESYSTEM_SOURCE(Gui::MayaGestureNavigationStyle, Gui::UserNavigationStyle);
+TYPESYSTEM_SOURCE(Gui::MayaGestureNavigationStyle, Gui::UserNavigationStyle)
 
 MayaGestureNavigationStyle::MayaGestureNavigationStyle()
 {
@@ -345,13 +343,13 @@ SbBool MayaGestureNavigationStyle::processSoEvent(const SoEvent * const ev)
                 break;
             case SoKeyboardEvent::PAGE_UP:
                 if(press){
-                    doZoom(viewer->getSoRenderManager()->getCamera(), true, posn);
+                    doZoom(viewer->getSoRenderManager()->getCamera(), getDelta(), posn);
                 }
                 processed = true;
                 break;
             case SoKeyboardEvent::PAGE_DOWN:
                 if(press){
-                    doZoom(viewer->getSoRenderManager()->getCamera(), false, posn);
+                    doZoom(viewer->getSoRenderManager()->getCamera(), -getDelta(), posn);
                 }
                 processed = true;
                 break;
@@ -423,14 +421,6 @@ SbBool MayaGestureNavigationStyle::processSoEvent(const SoEvent * const ev)
                 }
                 processed = true;
                 break;
-            case SoMouseButtonEvent::BUTTON4: //(wheel?)
-                doZoom(viewer->getSoRenderManager()->getCamera(), true, posn);
-                processed = true;
-                break;
-            case SoMouseButtonEvent::BUTTON5: //(wheel?)
-                doZoom(viewer->getSoRenderManager()->getCamera(), false, posn);
-                processed = true;
-                break;
             }
         }
 
@@ -507,7 +497,7 @@ SbBool MayaGestureNavigationStyle::processSoEvent(const SoEvent * const ev)
                         //end of dragging/panning/whatever
                         setViewingMode(NavigationStyle::SELECTION);
                         processed = true;
-                    } //else of if (some bottons down)
+                    } //end of else (some buttons down)
                 break;
             } //switch(button)
         } //if(evIsButton)
