@@ -24,7 +24,7 @@
 #ifndef GUI_MERGEDOCUMENTS_H
 #define GUI_MERGEDOCUMENTS_H
 
-#include <boost/signals2.hpp>
+#include <boost_signals2.hpp>
 #include <Base/Persistence.h>
 
 namespace zipios {
