@@ -99,10 +99,17 @@ public:
         Trackball
     };
 
+#if QT_VERSION < 0x050000
     enum RotationCenterMode {
-        ScenePointAtCursor,     /**< Find the point in the scene at the cursor position. If there is no point then the focal plane is used */
-        FocalPointAtCursor      /**< Find the point on the focal plane at the cursor position. */
+#else
+    enum class RotationCenterMode {
+#endif
+        WindowCenter       = 0, /**< The center of the window */
+        ScenePointAtCursor = 1, /**< Find the point in the scene at the cursor position. If there is no point then the focal plane is used */
+        FocalPointAtCursor = 2, /**< Find the point on the focal plane at the cursor position. */
+        BoundingBoxCenter  = 4  /**< Find the center point of the bounding box of the scene. */
     };
+    Q_DECLARE_FLAGS(RotationCenterModes, RotationCenterMode)
 
 public:
     NavigationStyle();
@@ -131,10 +138,8 @@ public:
     SbBool isZoomAtCursor() const;
     void zoomIn();
     void zoomOut();
-    void setDragAtCursor(SbBool);
-    SbBool isDragAtCursor() const;
-    void setRotationCenterMode(RotationCenterMode);
-    RotationCenterMode getRotationCenterMode() const;
+    void setRotationCenterMode(RotationCenterModes);
+    RotationCenterModes getRotationCenterMode() const;
     void setRotationCenter(const SbVec3f& cnt);
     SbVec3f getFocalPoint() const;
 
@@ -188,9 +193,10 @@ protected:
                    const SbVec2f & current);
     void pan(SoCamera* camera);
     void panToCenter(const SbPlane & pplane, const SbVec2f & currpos);
+    int getDelta() const;
     void zoom(SoCamera * camera, float diffvalue);
     void zoomByCursor(const SbVec2f & thispos, const SbVec2f & prevpos);
-    void doZoom(SoCamera * camera, SbBool forward, const SbVec2f& pos);
+    void doZoom(SoCamera * camera, int wheeldelta, const SbVec2f& pos);
     void doZoom(SoCamera * camera, float logzoomfactor, const SbVec2f& pos);
     void doRotate(SoCamera * camera, float angle, const SbVec2f& pos);
     void spin(const SbVec2f & pointerpos);
@@ -263,7 +269,7 @@ private:
  * in the above dialog.
  * This mechanism is useful to implement special navigation styles which are
  * only needed for certain purposes. Thus, it should not be possible to be
- * choosable by the user 
+ * choosable by the user
  * @author Werner Mayer
  */
 class GuiExport UserNavigationStyle : public NavigationStyle {
@@ -390,32 +396,6 @@ private:
     SoMouseButtonEvent mouseDownConsumedEvent;
 };
 
-class GuiExport GestureNavigationStyle : public UserNavigationStyle {
-    typedef UserNavigationStyle inherited;
-
-    TYPESYSTEM_HEADER();
-
-public:
-    GestureNavigationStyle();
-    ~GestureNavigationStyle();
-    const char* mouseButtons(ViewerMode);
-
-protected:
-    SbBool processSoEvent(const SoEvent * const ev);
-    bool isDraggerUnderCursor(SbVec2s pos);
-
-    SbVec2s mousedownPos;//the position where some mouse button was pressed (local pixel coordinates).
-    short mouseMoveThreshold;//setting. Minimum move required to consider it a move (in pixels).
-    bool mouseMoveThresholdBroken;//a flag that the move threshold was surpassed since last mousedown.
-    int mousedownConsumedCount;//a flag for remembering that a mousedown of button1/button2 was consumed.
-    SoMouseButtonEvent mousedownConsumedEvent[5];//the event that was consumed and is to be refired. 2 should be enough, but just for a case of the maximum 5 buttons...
-    bool testMoveThreshold(const SbVec2s currentPos) const;
-
-    bool thisClickIsComplex;//a flag that becomes set when a complex clicking pattern is detected (i.e., two or more mouse buttons were down at the same time).
-    bool inGesture; //a flag that is used to filter out mouse events during gestures.
-    bool enableGestureTilt = false; //fetched from settings
-};
-
 class GuiExport OpenCascadeNavigationStyle : public UserNavigationStyle {
     typedef UserNavigationStyle inherited;
 
@@ -435,4 +415,6 @@ private:
 
 } // namespace Gui
 
-#endif // GUI_NAVIGATIONSTYLE_H 
+Q_DECLARE_OPERATORS_FOR_FLAGS(Gui::NavigationStyle::RotationCenterModes)
+
+#endif // GUI_NAVIGATIONSTYLE_H
