@@ -22,10 +22,14 @@
 
 
 #include "PreCompiled.h"
+#ifndef _PreComp_
 #include <QSignalMapper>
 #include <QDockWidget>
 #include <QMessageBox>
 #include <QClipboard>
+#include <QMetaObject>
+#include <boost_bind_bind.hpp>
+#endif
 
 #include "Placement.h"
 #include "ui_Placement.h"
@@ -44,6 +48,7 @@
 #include <Base/UnitsApi.h>
 
 using namespace Gui::Dialog;
+namespace bp = boost::placeholders;
 
 namespace Gui { namespace Dialog {
 class find_placement
@@ -82,11 +87,13 @@ public:
 
 Placement::Placement(QWidget* parent, Qt::WindowFlags fl)
   : Gui::LocationDialog(parent, fl)
+  , changeProperty(false)
 {
     selectionObjects = Gui::Selection().getSelectionEx();
 
     propertyName = "Placement"; // default name
     ui = new Ui_PlacementComp(this);
+    ui->gridLayout->removeItem(ui->vSpacer);
 
     ui->xPos->setUnit(Base::Unit::Length);
     ui->yPos->setUnit(Base::Unit::Length);
@@ -115,7 +122,7 @@ Placement::Placement(QWidget* parent, Qt::WindowFlags fl)
     connect(signalMapper, SIGNAL(mapped(int)),
             this, SLOT(onPlacementChanged(int)));
     connectAct = Application::Instance->signalActiveDocument.connect
-        (boost::bind(&Placement::slotActiveDocument, this, _1));
+        (boost::bind(&Placement::slotActiveDocument, this, bp::_1));
     App::Document* activeDoc = App::GetApplication().getActiveDocument();
     if (activeDoc) documents.insert(activeDoc->getName());
 
@@ -136,11 +143,37 @@ void Placement::showDefaultButtons(bool ok)
     ui->oKButton->setVisible(ok);
     ui->closeButton->setVisible(ok);
     ui->applyButton->setVisible(ok);
+    ui->buttonBoxLayout->invalidate();
+    if (ok) {
+        ui->buttonBoxLayout->insertSpacerItem(0, ui->buttonBoxSpacer);
+    }
+    else {
+        ui->buttonBoxLayout->removeItem(ui->buttonBoxSpacer);
+    }
+}
+
+void Placement::open()
+{
+    if (propertyName != "Placement") {
+        changeProperty = true;
+        openTransaction();
+    }
 }
 
 void Placement::slotActiveDocument(const Gui::Document& doc)
 {
     documents.insert(doc.getDocument()->getName());
+
+    if (changeProperty) {
+        QMetaObject::invokeMethod(this, "openTransaction", Qt::QueuedConnection);
+    }
+}
+
+void Placement::openTransaction()
+{
+    App::Document* activeDoc = App::GetApplication().getActiveDocument();
+    if (activeDoc)
+        activeDoc->openTransaction("Placement");
 }
 
 QWidget* Placement::getInvalidInput() const
@@ -159,22 +192,28 @@ void Placement::revertTransformation()
         Gui::Document* document = Application::Instance->getDocument(it->c_str());
         if (!document) continue;
 
-        std::vector<App::DocumentObject*> obj = document->getDocument()->
-            getObjectsOfType(App::DocumentObject::getClassTypeId());
-        if (!obj.empty()) {
-            for (std::vector<App::DocumentObject*>::iterator it=obj.begin();it!=obj.end();++it) {
-                std::map<std::string,App::Property*> props;
-                (*it)->getPropertyMap(props);
-                // search for the placement property
-                std::map<std::string,App::Property*>::iterator jt;
-                jt = std::find_if(props.begin(), props.end(), find_placement(this->propertyName));
-                if (jt != props.end()) {
-                    Base::Placement cur = static_cast<App::PropertyPlacement*>(jt->second)->getValue();
-                    Gui::ViewProvider* vp = document->getViewProvider(*it);
-                    if (vp) vp->setTransformation(cur.toMatrix());
+        if (!changeProperty) {
+            std::vector<App::DocumentObject*> obj = document->getDocument()->
+                getObjectsOfType(App::DocumentObject::getClassTypeId());
+            if (!obj.empty()) {
+                for (std::vector<App::DocumentObject*>::iterator it=obj.begin();it!=obj.end();++it) {
+                    std::map<std::string,App::Property*> props;
+                    (*it)->getPropertyMap(props);
+                    // search for the placement property
+                    std::map<std::string,App::Property*>::iterator jt;
+                    jt = std::find_if(props.begin(), props.end(), find_placement(this->propertyName));
+                    if (jt != props.end()) {
+                        App::PropertyPlacement* property = static_cast<App::PropertyPlacement*>(jt->second);
+                        Base::Placement cur = property->getValue();
+                        Gui::ViewProvider* vp = document->getViewProvider(*it);
+                        if (vp) vp->setTransformation(cur.toMatrix());
+                    }
                 }
             }
         }
+        else {
+            document->abortCommand();
+        }
     }
 }
 
@@ -194,14 +233,20 @@ void Placement::applyPlacement(const Base::Placement& p, bool incremental)
             std::map<std::string,App::Property*>::iterator jt;
             jt = std::find_if(props.begin(), props.end(), find_placement(this->propertyName));
             if (jt != props.end()) {
-                Base::Placement cur = static_cast<App::PropertyPlacement*>(jt->second)->getValue();
+                App::PropertyPlacement* property = static_cast<App::PropertyPlacement*>(jt->second);
+                Base::Placement cur = property->getValue();
                 if (incremental)
                     cur = p * cur;
                 else
                     cur = p;
 
-                Gui::ViewProvider* vp = document->getViewProvider(*it);
-                if (vp) vp->setTransformation(cur.toMatrix());
+                if (!changeProperty) {
+                    Gui::ViewProvider* vp = document->getViewProvider(*it);
+                    if (vp) vp->setTransformation(cur.toMatrix());
+                }
+                else {
+                    property->setValue(cur);
+                }
             }
         }
     }
@@ -215,47 +260,60 @@ void Placement::applyPlacement(const QString& data, bool incremental)
     Gui::Document* document = Application::Instance->activeDocument();
     if (!document) return;
 
-    std::vector<App::DocumentObject*> sel = Gui::Selection().getObjectsOfType
-        (App::DocumentObject::getClassTypeId(), document->getDocument()->getName());
-    if (!sel.empty()) {
-        document->openCommand("Placement");
-        for (std::vector<App::DocumentObject*>::iterator it=sel.begin();it!=sel.end();++it) {
-            std::map<std::string,App::Property*> props;
-            (*it)->getPropertyMap(props);
-            // search for the placement property
-            std::map<std::string,App::Property*>::iterator jt;
-            jt = std::find_if(props.begin(), props.end(), find_placement(this->propertyName));
-            if (jt != props.end()) {
-                QString cmd;
-                if (incremental)
-                    cmd = QString::fromLatin1(
-                        "App.getDocument(\"%1\").%2.%3=%4.multiply(App.getDocument(\"%1\").%2.%3)")
-                        .arg(QLatin1String((*it)->getDocument()->getName()))
-                        .arg(QLatin1String((*it)->getNameInDocument()))
-                        .arg(QLatin1String(this->propertyName.c_str()))
-                        .arg(data);
-                else {
-                    cmd = QString::fromLatin1(
-                        "App.getDocument(\"%1\").%2.%3=%4")
-                        .arg(QLatin1String((*it)->getDocument()->getName()))
-                        .arg(QLatin1String((*it)->getNameInDocument()))
-                        .arg(QLatin1String(this->propertyName.c_str()))
-                        .arg(data);
-                }
-
-                Gui::Command::runCommand(Gui::Command::App, cmd.toLatin1());
-            }
-        }
-
+    // When directly changing the property we now only have to commit the transaction,
+    // do a recompute and open a new transaction
+    if (changeProperty) {
         document->commitCommand();
         try {
             document->getDocument()->recompute();
         }
         catch (...) {
         }
+        document->openCommand(QT_TRANSLATE_NOOP("Command", "Placement"));
     }
     else {
-        Base::Console().Warning("No object selected.\n");
+        std::vector<App::DocumentObject*> sel = Gui::Selection().getObjectsOfType
+            (App::DocumentObject::getClassTypeId(), document->getDocument()->getName());
+        if (!sel.empty()) {
+            document->openCommand(QT_TRANSLATE_NOOP("Command", "Placement"));
+            for (std::vector<App::DocumentObject*>::iterator it=sel.begin();it!=sel.end();++it) {
+                std::map<std::string,App::Property*> props;
+                (*it)->getPropertyMap(props);
+                // search for the placement property
+                std::map<std::string,App::Property*>::iterator jt;
+                jt = std::find_if(props.begin(), props.end(), find_placement(this->propertyName));
+                if (jt != props.end()) {
+                    QString cmd;
+                    if (incremental)
+                        cmd = QString::fromLatin1(
+                            "App.getDocument(\"%1\").%2.%3=%4.multiply(App.getDocument(\"%1\").%2.%3)")
+                            .arg(QLatin1String((*it)->getDocument()->getName()))
+                            .arg(QLatin1String((*it)->getNameInDocument()))
+                            .arg(QLatin1String(this->propertyName.c_str()))
+                            .arg(data);
+                    else {
+                        cmd = QString::fromLatin1(
+                            "App.getDocument(\"%1\").%2.%3=%4")
+                            .arg(QLatin1String((*it)->getDocument()->getName()))
+                            .arg(QLatin1String((*it)->getNameInDocument()))
+                            .arg(QLatin1String(this->propertyName.c_str()))
+                            .arg(data);
+                    }
+
+                    Gui::Command::runCommand(Gui::Command::App, cmd.toLatin1());
+                }
+            }
+
+            document->commitCommand();
+            try {
+                document->getDocument()->recompute();
+            }
+            catch (...) {
+            }
+        }
+        else {
+            Base::Console().Warning("No object selected.\n");
+        }
     }
 }
 
@@ -353,7 +411,8 @@ void Placement::on_selectedVertex_clicked()
         Base::Vector3d axis;
         if (firstSelected==picked[0]){
             axis = Base::Vector3d(picked[1]-picked[0]);
-        } else {
+        }
+        else {
             axis = Base::Vector3d(picked[0]-picked[1]);
         }
         double length = axis.Length();
@@ -361,7 +420,8 @@ void Placement::on_selectedVertex_clicked()
         if (QApplication::keyboardModifiers() == Qt::ShiftModifier){ //copy to clipboard on Shift+click
             QLocale loc;
             QApplication::clipboard()->setText(loc.toString(length,'g',8));
-        }else {
+        }
+        else {
             Base::Console().Message("(Shift + click Selected points button to copy distance to clipboard)\n");
         }
         axis.Normalize();
@@ -371,7 +431,8 @@ void Placement::on_selectedVertex_clicked()
         ui->rotationInput->setCurrentIndex(0); //use rotation with axis instead of euler
         ui->stackedWidget->setCurrentIndex(0);
         success=true;
-    } else if (picked.size() == 3){
+    }
+    else if (picked.size() == 3){
         /* User selected 3 points, so we find the plane defined by those
          * and use the normal vector that contains the first point picked
          * as the axis of rotation.
@@ -381,10 +442,12 @@ void Placement::on_selectedVertex_clicked()
         if (picked[0] == firstSelected){
             a = picked[1];
             c = picked[2];
-        } else if (picked[1]==firstSelected){
+        }
+        else if (picked[1]==firstSelected){
             a = picked[0];
             c = picked[2];
-        } else if (picked[2] == firstSelected){
+        }
+        else if (picked[2] == firstSelected){
             a = picked[0];
             c = picked[1];
         }
@@ -416,7 +479,8 @@ void Placement::on_selectedVertex_clicked()
             QLocale loc;
             QApplication::clipboard()->setText(loc.toString(targetAngle,'g',8));
             Base::Console().Message("(Angle copied to clipboard, but you might need to use a negative (-) angle sometimes.)\n");
-        } else {
+        }
+        else {
             Base::Console().Message("(Shift + click Selected points button to copy angle to clipboard)\n");
         }
         rot.setValue(norm, angle);
@@ -459,7 +523,8 @@ void Placement::on_applyAxial_clicked()
     Qt::KeyboardModifiers km = QApplication::keyboardModifiers();
     if (km == Qt::ShiftModifier){ //go opposite direction on Shift+click
         newPos = Base::Vector3d(curPos.x-(axis.x*axPos),curPos.y-(axis.y*axPos),curPos.z-(axis.z*axPos));
-    } else {
+    }
+    else {
         newPos = Base::Vector3d(curPos.x+(axis.x*axPos),curPos.y+(axis.y*axPos),curPos.z+(axis.z*axPos));
     }
     ui->xPos->setValue(Base::Quantity(newPos.x,Base::Unit::Length));
@@ -499,6 +564,13 @@ void Placement::reject()
     /*emit*/ placementChanged(data, true, false);
 
     revertTransformation();
+
+    // One of the quantity spin boxes still can emit a signal when it has the focus
+    // but its content is not fully updated.
+    // In order to override again the placement the signalMapper is blocked
+    // See related forum thread:
+    // https://forum.freecadweb.org/viewtopic.php?f=3&t=44341#p378659
+    QSignalBlocker block(signalMapper);
     QDialog::reject();
 }
 
@@ -567,6 +639,21 @@ void Placement::on_resetButton_clicked()
     onPlacementChanged(0);
 }
 
+void Placement::bindObject()
+{
+    if (!selectionObjects.empty()) {
+        App::DocumentObject* obj = selectionObjects.front().getObject();
+
+        ui->xPos->bind(App::ObjectIdentifier::parse(obj, propertyName + std::string(".Base.x")));
+        ui->yPos->bind(App::ObjectIdentifier::parse(obj, propertyName + std::string(".Base.y")));
+        ui->zPos->bind(App::ObjectIdentifier::parse(obj, propertyName + std::string(".Base.z")));
+
+        ui->yawAngle  ->bind(App::ObjectIdentifier::parse(obj, propertyName + std::string(".Rotation.Yaw")));
+        ui->pitchAngle->bind(App::ObjectIdentifier::parse(obj, propertyName + std::string(".Rotation.Pitch")));
+        ui->rollAngle ->bind(App::ObjectIdentifier::parse(obj, propertyName + std::string(".Rotation.Roll")));
+    }
+}
+
 void Placement::directionActivated(int index)
 {
     if (ui->directionActivated(this, index)) {
@@ -772,13 +859,23 @@ TaskPlacement::~TaskPlacement()
     // automatically deleted in the sub-class
 }
 
+void TaskPlacement::bindObject()
+{
+    widget->bindObject();
+}
+
+void TaskPlacement::open()
+{
+    widget->open();
+}
+
 void TaskPlacement::setPropertyName(const QString& name)
 {
     widget->propertyName = (const char*)name.toLatin1();
 }
 
 QDialogButtonBox::StandardButtons TaskPlacement::getStandardButtons() const
-{ 
+{
     return QDialogButtonBox::Ok|
            QDialogButtonBox::Cancel|
            QDialogButtonBox::Apply;
