@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) 2012 Juergen Riegel <juergen.riegel@web.de>             *
+ *   Copyright (c) 2012 Jürgen Riegel <juergen.riegel@web.de>              *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -31,7 +31,8 @@
 
 #include <Gui/DockWindow.h>
 #include <Gui/Selection.h>
-class QDirModel;
+
+class QFileSystemModel;
 
 namespace Gui {
 
@@ -48,8 +49,8 @@ public:
     ~ProjectWidget();
 
 private:
-    QDirModel *fileModel;
- 
+    QFileSystemModel *fileModel;
+
 };
 
 
