@@ -29,6 +29,9 @@
 # include <QContextMenuEvent>
 # include <QTextCursor>
 # include <QTextStream>
+# include <QTime>
+# include <QDockWidget>
+# include <QPointer>
 #endif
 
 #include <Base/Interpreter.h>
@@ -37,6 +40,9 @@
 #include "PythonConsole.h"
 #include "PythonConsolePy.h"
 #include "BitmapFactory.h"
+#include "MainWindow.h"
+#include "Application.h"
+#include "Tools.h"
 
 using namespace Gui;
 using namespace Gui::DockWnd;
@@ -44,8 +50,8 @@ using namespace Gui::DockWnd;
 /* TRANSLATOR Gui::DockWnd::ReportView */
 
 /**
- *  Constructs a ReportView which is a child of 'parent', with the 
- *  name 'name' and widget flags set to 'f' 
+ *  Constructs a ReportView which is a child of 'parent', with the
+ *  name 'name' and widget flags set to 'f'
  */
 ReportView::ReportView( QWidget* parent )
   : QWidget(parent)
@@ -66,7 +72,7 @@ ReportView::ReportView( QWidget* parent )
 
     // create the output window
     tabOutput = new ReportOutput();
-    tabOutput->setWindowTitle(trUtf8("Output"));
+    tabOutput->setWindowTitle(tr("Output"));
     tabOutput->setWindowIcon(BitmapFactory().pixmap("MacroEditor"));
     int output = tabWidget->addTab(tabOutput, tabOutput->windowTitle());
     tabWidget->setTabIcon(output, tabOutput->windowIcon());
@@ -74,7 +80,7 @@ ReportView::ReportView( QWidget* parent )
     // create the python console
     tabPython = new PythonConsole();
     tabPython->setWordWrapMode(QTextOption::NoWrap);
-    tabPython->setWindowTitle(trUtf8("Python console"));
+    tabPython->setWindowTitle(tr("Python console"));
     tabPython->setWindowIcon(BitmapFactory().iconFromTheme("applications-python"));
     int python = tabWidget->addTab(tabPython, tabPython->windowTitle());
     tabWidget->setTabIcon(python, tabPython->windowIcon());
@@ -98,8 +104,8 @@ void ReportView::changeEvent(QEvent *e)
 {
     QWidget::changeEvent(e);
     if (e->type() == QEvent::LanguageChange) {
-        tabOutput->setWindowTitle(trUtf8("Output"));
-        tabPython->setWindowTitle(trUtf8("Python console"));
+        tabOutput->setWindowTitle(tr("Output"));
+        tabPython->setWindowTitle(tr("Python console"));
         for (int i=0; i<tabWidget->count();i++)
             tabWidget->setTabText(i, tabWidget->widget(i)->windowTitle());
     }
@@ -200,7 +206,7 @@ void ReportHighlighter::setErrorColor( const QColor& col )
 // ----------------------------------------------------------
 
 /**
- * The CustomReportEvent class is used to send report events in the methods Log(), 
+ * The CustomReportEvent class is used to send report events in the methods Log(),
  * Error(), Warning() and Message() of the ReportOutput class to itself instead of
  * printing the messages directly in its text view.
  *
@@ -211,7 +217,7 @@ class CustomReportEvent : public QEvent
 {
 public:
     CustomReportEvent(ReportHighlighter::Paragraph p, const QString& s)
-    : QEvent(QEvent::Type(QEvent::User)) 
+    : QEvent(QEvent::Type(QEvent::User))
     { par = p; msg = s;}
     ~CustomReportEvent()
     { }
@@ -226,6 +232,69 @@ private:
 
 // ----------------------------------------------------------
 
+/**
+ * The ReportOutputObserver class is used to check if messages sent to the
+ * report view are warnings or errors, and if so and if the user has not
+ * disabled this in preferences, the report view is toggled on so the
+ * user always gets the warnings/errors
+ */
+
+ReportOutputObserver::ReportOutputObserver(ReportOutput *report)
+{
+    this->reportView = report;
+}
+
+void ReportOutputObserver::showReportView(){
+    // get the QDockWidget parent of the report view
+    QDockWidget* dw = nullptr;
+    QWidget* par = reportView->parentWidget();
+    while (par) {
+        dw = qobject_cast<QDockWidget*>(par);
+        if (dw)
+            break;
+        par = par->parentWidget();
+    }
+
+    if (dw && !dw->toggleViewAction()->isChecked()) {
+        dw->toggleViewAction()->activate(QAction::Trigger);
+    }
+}
+
+bool ReportOutputObserver::eventFilter(QObject *obj, QEvent *event)
+{
+    if (event->type() == QEvent::User && obj == reportView.data()) {
+        CustomReportEvent* cr = dynamic_cast<CustomReportEvent*>(event);
+        if (cr) {
+            ParameterGrp::handle group = App::GetApplication().GetUserParameter().
+                    GetGroup("BaseApp")->GetGroup("Preferences")->GetGroup("OutputWindow");
+            ReportHighlighter::Paragraph msgType = cr->messageType();
+            if (msgType == ReportHighlighter::Warning){
+                if (group->GetBool("checkShowReportViewOnWarning", true)) {
+                    showReportView();
+                }
+            } else if (msgType == ReportHighlighter::Error){
+                if (group->GetBool("checkShowReportViewOnError", true)) {
+                    showReportView();
+                }
+            } else if (msgType == ReportHighlighter::Message){
+                if (group->GetBool("checkShowReportViewOnNormalMessage", false)) {
+                    showReportView();
+                }
+            } else if (msgType == ReportHighlighter::LogText){
+                if (group->GetBool("checkShowReportViewOnLogMessage", false)) {
+                    showReportView();
+                }
+            }
+        }
+        return false;  //true would prevent the messages reaching the report view
+    }
+
+    // standard event processing
+    return QObject::eventFilter(obj, event);
+}
+
+// ----------------------------------------------------------
+
 class ReportOutput::Data
 {
 public:
@@ -279,11 +348,15 @@ PyObject* ReportOutput::Data::replace_stderr = 0;
 /* TRANSLATOR Gui::DockWnd::ReportOutput */
 
 /**
- *  Constructs a ReportOutput which is a child of 'parent', with the 
- *  name 'name' and widget flags set to 'f' 
+ *  Constructs a ReportOutput which is a child of 'parent', with the
+ *  name 'name' and widget flags set to 'f'
  */
 ReportOutput::ReportOutput(QWidget* parent)
-  : QTextEdit(parent), WindowParameter("OutputWindow"), d(new Data), gotoEnd(false)
+  : QTextEdit(parent)
+  , WindowParameter("OutputWindow")
+  , d(new Data)
+  , gotoEnd(false)
+  , blockStart(true)
 {
     bLog = false;
     reportHl = new ReportHighlighter(this);
@@ -301,6 +374,12 @@ ReportOutput::ReportOutput(QWidget* parent)
     _prefs->Attach(this);
     _prefs->Notify("FontSize");
 
+#ifdef FC_DEBUG
+    messageSize = _prefs->GetInt("LogMessageSize",0);
+#else
+    messageSize = _prefs->GetInt("LogMessageSize",2048);
+#endif
+
     // scroll to bottom at startup to make sure that last appended text is visible
     ensureCursorVisible();
 }
@@ -323,35 +402,37 @@ void ReportOutput::restoreFont()
     setFont(serifFont);
 }
 
-void ReportOutput::Warning(const char * s)
+void ReportOutput::SendLog(const std::string& msg, Base::LogStyle level)
 {
-    // Send the event to itself to allow thread-safety. Qt will delete it when done.
-    CustomReportEvent* ev = new CustomReportEvent(ReportHighlighter::Warning, QString::fromUtf8(s));
-    QApplication::postEvent(this, ev);
-}
-
-void ReportOutput::Message(const char * s)
-{
-    // Send the event to itself to allow thread-safety. Qt will delete it when done.
-    CustomReportEvent* ev = new CustomReportEvent(ReportHighlighter::Message, QString::fromUtf8(s));
-    QApplication::postEvent(this, ev);
-}
-
-void ReportOutput::Error  (const char * s)
-{
-    // Send the event to itself to allow thread-safety. Qt will delete it when done.
-    CustomReportEvent* ev = new CustomReportEvent(ReportHighlighter::Error, QString::fromUtf8(s));
-    QApplication::postEvent(this, ev);
-}
-
-void ReportOutput::Log (const char * s)
-{
-    QString msg = QString::fromUtf8(s);
-    if (msg.length() < 1000){
-        // Send the event to itself to allow thread-safety. Qt will delete it when done.
-        CustomReportEvent* ev = new CustomReportEvent(ReportHighlighter::LogText, msg);
-        QApplication::postEvent(this, ev);
+    ReportHighlighter::Paragraph style = ReportHighlighter::LogText;
+    switch (level) {
+        case Base::LogStyle::Warning:
+            style = ReportHighlighter::Warning;
+            break;
+        case Base::LogStyle::Message:
+            style = ReportHighlighter::Message;
+            break;
+        case Base::LogStyle::Error:
+            style = ReportHighlighter::Error;
+            break;
+        case Base::LogStyle::Log:
+            style = ReportHighlighter::LogText;
+            break;
     }
+
+    QString qMsg = QString::fromUtf8(msg.c_str());
+
+    // This truncates log messages that are too long
+    if (style == ReportHighlighter::LogText) {
+        if (messageSize > 0 && qMsg.size()>messageSize) {
+            qMsg.truncate(messageSize);
+            qMsg += QString::fromLatin1("...\n");
+        }
+    }
+
+    // Send the event to itself to allow thread-safety. Qt will delete it when done.
+    CustomReportEvent* ev = new CustomReportEvent(style, qMsg);
+    QApplication::postEvent(this, ev);
 }
 
 void ReportOutput::customEvent ( QEvent* ev )
@@ -361,11 +442,22 @@ void ReportOutput::customEvent ( QEvent* ev )
         CustomReportEvent* ce = (CustomReportEvent*)ev;
         reportHl->setParagraphType(ce->messageType());
 
+        bool showTimecode = getWindowParameter()->GetBool("checkShowReportTimecode", true);
+        QString text = ce->message();
+
+        // The time code can only be set when the cursor is at the block start
+        if (showTimecode && blockStart) {
+            QTime time = QTime::currentTime();
+            text.prepend(time.toString(QLatin1String("hh:mm:ss  ")));
+        }
+
         QTextCursor cursor(this->document());
         cursor.beginEditBlock();
         cursor.movePosition(QTextCursor::End);
-        cursor.insertText(ce->message());
+        cursor.insertText(text);
         cursor.endEditBlock();
+
+        blockStart = cursor.atBlockStart();
         if (gotoEnd) {
             setTextCursor(cursor);
         }
@@ -389,41 +481,74 @@ void ReportOutput::changeEvent(QEvent *ev)
 
 void ReportOutput::contextMenuEvent ( QContextMenuEvent * e )
 {
+    ParameterGrp::handle hGrp = WindowParameter::getDefaultParameter()->GetGroup("OutputWindow");
+    bool bShowOnLog = hGrp->GetBool("checkShowReportViewOnLogMessage",false);
+    bool bShowOnNormal = hGrp->GetBool("checkShowReportViewOnNormalMessage",false);
+    bool bShowOnWarn = hGrp->GetBool("checkShowReportViewOnWarning",true);
+    bool bShowOnError = hGrp->GetBool("checkShowReportViewOnError",true);
+
     QMenu* menu = createStandardContextMenu();
     QAction* first = menu->actions().front();
+    QMenu* optionMenu = new QMenu( menu );
+    optionMenu->setTitle(tr("Options"));
+    menu->insertMenu(first, optionMenu);
+    menu->insertSeparator(first);
 
-    QMenu* submenu = new QMenu( menu );
-    QAction* logAct = submenu->addAction(tr("Logging"), this, SLOT(onToggleLogging()));
+    QMenu* displayMenu = new QMenu(optionMenu);
+    displayMenu->setTitle(tr("Display message types"));
+    optionMenu->addMenu(displayMenu);
+
+    QAction* logMsg = displayMenu->addAction(tr("Normal messages"), this, SLOT(onToggleNormalMessage()));
+    logMsg->setCheckable(true);
+    logMsg->setChecked(bMsg);
+
+    QAction* logAct = displayMenu->addAction(tr("Log messages"), this, SLOT(onToggleLogMessage()));
     logAct->setCheckable(true);
     logAct->setChecked(bLog);
 
-    QAction* wrnAct = submenu->addAction(tr("Warning"), this, SLOT(onToggleWarning()));
+    QAction* wrnAct = displayMenu->addAction(tr("Warnings"), this, SLOT(onToggleWarning()));
     wrnAct->setCheckable(true);
     wrnAct->setChecked(bWrn);
 
-    QAction* errAct = submenu->addAction(tr("Error"), this, SLOT(onToggleError()));
+    QAction* errAct = displayMenu->addAction(tr("Errors"), this, SLOT(onToggleError()));
     errAct->setCheckable(true);
     errAct->setChecked(bErr);
 
-    submenu->addSeparator();
+    QMenu* showOnMenu = new QMenu (optionMenu);
+    showOnMenu->setTitle(tr("Show report view on"));
+    optionMenu->addMenu(showOnMenu);
 
-    QAction* stdoutAct = submenu->addAction(tr("Redirect Python output"), this, SLOT(onToggleRedirectPythonStdout()));
+    QAction* showNormAct = showOnMenu->addAction(tr("Normal messages"), this, SLOT(onToggleShowReportViewOnNormalMessage()));
+    showNormAct->setCheckable(true);
+    showNormAct->setChecked(bShowOnNormal);
+
+    QAction* showLogAct = showOnMenu->addAction(tr("Log messages"), this, SLOT(onToggleShowReportViewOnLogMessage()));
+    showLogAct->setCheckable(true);
+    showLogAct->setChecked(bShowOnLog);
+
+    QAction* showWrnAct = showOnMenu->addAction(tr("Warnings"), this, SLOT(onToggleShowReportViewOnWarning()));
+    showWrnAct->setCheckable(true);
+    showWrnAct->setChecked(bShowOnWarn);
+
+    QAction* showErrAct = showOnMenu->addAction(tr("Errors"), this, SLOT(onToggleShowReportViewOnError()));
+    showErrAct->setCheckable(true);
+    showErrAct->setChecked(bShowOnError);
+
+    optionMenu->addSeparator();
+
+    QAction* stdoutAct = optionMenu->addAction(tr("Redirect Python output"), this, SLOT(onToggleRedirectPythonStdout()));
     stdoutAct->setCheckable(true);
     stdoutAct->setChecked(d->redirected_stdout);
 
-    QAction* stderrAct = submenu->addAction(tr("Redirect Python errors"), this, SLOT(onToggleRedirectPythonStderr()));
+    QAction* stderrAct = optionMenu->addAction(tr("Redirect Python errors"), this, SLOT(onToggleRedirectPythonStderr()));
     stderrAct->setCheckable(true);
     stderrAct->setChecked(d->redirected_stderr);
 
-    submenu->addSeparator();
-    QAction* botAct = submenu->addAction(tr("Go to end"), this, SLOT(onToggleGoToEnd()));
+    optionMenu->addSeparator();
+    QAction* botAct = optionMenu->addAction(tr("Go to end"), this, SLOT(onToggleGoToEnd()));
     botAct->setCheckable(true);
     botAct->setChecked(gotoEnd);
 
-    submenu->setTitle(tr("Options"));
-    menu->insertMenu(first, submenu);
-    menu->insertSeparator(first);
-
     menu->addAction(tr("Clear"), this, SLOT(clear()));
     menu->addSeparator();
     menu->addAction(tr("Save As..."), this, SLOT(onSaveAs()));
@@ -459,11 +584,16 @@ bool ReportOutput::isWarning() const
     return bWrn;
 }
 
-bool ReportOutput::isLogging() const
+bool ReportOutput::isLogMessage() const
 {
     return bLog;
 }
 
+bool ReportOutput::isNormalMessage() const
+{
+    return bMsg;
+}
+
 void ReportOutput::onToggleError()
 {
     bErr = bErr ? false : true;
@@ -476,12 +606,42 @@ void ReportOutput::onToggleWarning()
     getWindowParameter()->SetBool( "checkWarning", bWrn );
 }
 
-void ReportOutput::onToggleLogging()
+void ReportOutput::onToggleLogMessage()
 {
     bLog = bLog ? false : true;
     getWindowParameter()->SetBool( "checkLogging", bLog );
 }
 
+void ReportOutput::onToggleNormalMessage()
+{
+    bMsg = bMsg ? false : true;
+    getWindowParameter()->SetBool( "checkMessage", bMsg );
+}
+
+void ReportOutput::onToggleShowReportViewOnWarning()
+{
+    bool show = getWindowParameter()->GetBool("checkShowReportViewOnWarning", true);
+    getWindowParameter()->SetBool("checkShowReportViewOnWarning", !show);
+}
+
+void ReportOutput::onToggleShowReportViewOnError()
+{
+    bool show = getWindowParameter()->GetBool("checkShowReportViewOnError", true);
+    getWindowParameter()->SetBool("checkShowReportViewOnError", !show);
+}
+
+void ReportOutput::onToggleShowReportViewOnNormalMessage()
+{
+    bool show = getWindowParameter()->GetBool("checkShowReportViewOnNormalMessage", false);
+    getWindowParameter()->SetBool("checkShowReportViewOnNormalMessage", !show);
+}
+
+void ReportOutput::onToggleShowReportViewOnLogMessage()
+{
+    bool show = getWindowParameter()->GetBool("checkShowReportViewOnLogMessage", false);
+    getWindowParameter()->SetBool("checkShowReportViewOnLogMessage", !show);
+}
+
 void ReportOutput::onToggleRedirectPythonStdout()
 {
     if (d->redirected_stdout) {
@@ -554,12 +714,16 @@ void ReportOutput::OnChange(Base::Subject<const char*> &rCaller, const char * sR
     else if (strcmp(sReason, "FontSize") == 0 || strcmp(sReason, "Font") == 0) {
         int fontSize = rclGrp.GetInt("FontSize", 10);
         QString fontFamily = QString::fromLatin1(rclGrp.GetASCII("Font", "Courier").c_str());
-        
+
         QFont font(fontFamily, fontSize);
         setFont(font);
         QFontMetrics metric(font);
-        int width = metric.width(QLatin1String("0000"));
+        int width = QtTools::horizontalAdvance(metric, QLatin1String("0000"));
+#if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
         setTabStopWidth(width);
+#else
+        setTabStopDistance(width);
+#endif
     }
     else if (strcmp(sReason, "RedirectPythonOutput") == 0) {
         bool checked = rclGrp.GetBool(sReason, true);
@@ -570,6 +734,12 @@ void ReportOutput::OnChange(Base::Subject<const char*> &rCaller, const char * sR
         bool checked = rclGrp.GetBool(sReason, true);
         if (checked != d->redirected_stderr)
             onToggleRedirectPythonStderr();
+    }else if(strcmp(sReason, "LogMessageSize") == 0) {
+#ifdef FC_DEBUG
+        messageSize = rclGrp.GetInt(sReason,0);
+#else
+        messageSize = rclGrp.GetInt(sReason,2048);
+#endif
     }
 }
 
