@@ -24,11 +24,15 @@
 #ifndef GUI_SOFCDB_H
 #define GUI_SOFCDB_H
 
+#include <map>
 #include <string>
+#include <iosfwd>
 #include <Inventor/SbBasic.h>
 
 class SoNode;
 class SoGroup;
+class SoVRMLGroup;
+
 namespace Gui {
 /**
  * The FreeCAD database class to initialize all our own Inventor nodes.
@@ -40,15 +44,27 @@ public:
     static SbBool isInitialized(void);
     static void init();
     static void finish();
+    static SoNode* replaceSwitches(SoNode* node);
     /// helper to apply a SoWriteAction to a node and write it to a string
     static const std::string& writeNodesToString(SoNode * root);
     static bool writeToVRML(SoNode* node, const char* filename, bool binary);
-    // Write to VRML or Inventor file
+    static void writeToVRML(SoNode* node, std::string& buffer);
+    static bool writeToX3D(SoNode* node, const char* filename, bool binary);
+    static bool writeToX3D(SoNode* node, bool exportViewpoints, std::string& buffer);
+    static bool writeToX3DOM(SoNode* node, std::string& buffer);
+    // Write to Inventor, VRML, X3D or XHTML (based on X3DOM) file
     static bool writeToFile(SoNode* node, const char* filename, bool binary);
     /*! container for app lifetime storage. See SoFCCSysDragger for details
      * on why this is needed.
-     */ 
+     */
     static SoGroup* getStorage();
+
+private:
+    static void writeX3D(SoVRMLGroup* node, bool exportViewpoints, std::ostream& out);
+    static void writeX3DChild(SoNode* node, std::map<SoNode*, std::string>& nodeMap,
+                              int& numDEF, int spaces, std::ostream& out);
+    static void writeX3DFields(SoNode* node, std::map<SoNode*, std::string>& nodeMap,
+                               bool isRoot, int& numDEF, int spaces, std::ostream& out);
 };
 
 } // namespace Gui
