@@ -27,6 +27,9 @@
 # include <qstring.h>
 # include <Inventor/details/SoFaceDetail.h>
 # include <Inventor/details/SoLineDetail.h>
+# include <Inventor/nodes/SoCube.h>
+# include <Inventor/actions/SoGetBoundingBoxAction.h>
+# include <Inventor/nodes/SoCube.h>
 #endif
 
 #include <Inventor/elements/SoOverrideElement.h>
@@ -54,22 +57,33 @@
 #include "Selection.h"
 #include "SoFCSelectionAction.h"
 #include "SoFCInteractiveElement.h"
+#include "SoFCUnifiedSelection.h"
+#include "ViewParams.h"
 
 // For 64-bit system the method using the front buffer doesn't work at all for lines.
 // Thus, use the method which forces a redraw every time. This is a bit slower but at
 // least it works.
-#if defined(_OCC64) // is set by configure or cmake
+//
+// Disable front buffer in all cases, in order to spare the repeating logic of
+// handling selection contextn. SoFCSelection is not really used that much
+// anyway.
+//
+// #if defined(_OCC64) // is set by configure or cmake
 # define NO_FRONTBUFFER
-#endif
+// #endif
 
 using namespace Gui;
 
+namespace Gui {
+std::array<std::pair<double, std::string>,3 > schemaTranslatePoint(double x, double y, double z, double precision);
+}
+
 SoFullPath * Gui::SoFCSelection::currenthighlight = NULL;
 
 
 // *************************************************************************
 
-SO_NODE_SOURCE(SoFCSelection);
+SO_NODE_SOURCE(SoFCSelection)
 
 /*!
   Constructor.
@@ -87,6 +101,7 @@ SoFCSelection::SoFCSelection()
     SO_NODE_ADD_FIELD(documentName,   (""));
     SO_NODE_ADD_FIELD(objectName,     (""));
     SO_NODE_ADD_FIELD(subElementName, (""));
+    SO_NODE_ADD_FIELD(useNewSelection, (true));
 
     SO_NODE_DEFINE_ENUM_VALUE(Styles, EMISSIVE);
     SO_NODE_DEFINE_ENUM_VALUE(Styles, EMISSIVE_DIFFUSE);
@@ -111,6 +126,10 @@ SoFCSelection::SoFCSelection()
     bCtrl       = false;
 
     selected = NOTSELECTED;
+
+    useNewSelection = ViewParams::instance()->getUseNewSelection();
+    selContext = std::make_shared<SelContext>();
+    selContext2 = std::make_shared<SelContext>();
 }
 
 /*!
@@ -151,6 +170,46 @@ SoFCSelection::turnOffCurrentHighlight(SoGLRenderAction * action)
 
 void SoFCSelection::doAction(SoAction *action)
 {
+    if(useNewSelection.getValue() && action->getCurPathCode()!=SoAction::OFF_PATH) {
+        if (action->getTypeId() == Gui::SoHighlightElementAction::getClassTypeId()) {
+            Gui::SoHighlightElementAction* hlaction = static_cast<Gui::SoHighlightElementAction*>(action);
+            if(!hlaction->isHighlighted()) {
+                auto ctx = Gui::SoFCSelectionRoot::getActionContext(action,this,selContext,false);
+                if(ctx->isHighlighted()) {
+                    ctx->highlightIndex = -1;
+                    touch();
+                }
+            }else{
+                auto ctx = Gui::SoFCSelectionRoot::getActionContext(action,this,selContext);
+                ctx->highlightColor = hlaction->getColor();
+                if(!ctx->isHighlighted()) {
+                    ctx->highlightIndex = 0;
+                    touch();
+                }
+            }
+            return;
+        } else if (action->getTypeId() == Gui::SoSelectionElementAction::getClassTypeId()) {
+            Gui::SoSelectionElementAction* selaction = static_cast<Gui::SoSelectionElementAction*>(action);
+            if (selaction->getType() == Gui::SoSelectionElementAction::All ||
+                selaction->getType() == Gui::SoSelectionElementAction::Append) {
+                SelContextPtr ctx = Gui::SoFCSelectionRoot::getActionContext(action,this,selContext);
+                ctx->selectionColor = selaction->getColor();
+                if(!ctx->isSelectAll()) {
+                    ctx->selectAll();
+                    this->touch();
+                }
+            } else if (selaction->getType() == Gui::SoSelectionElementAction::None ||
+                       selaction->getType() == Gui::SoSelectionElementAction::Remove) {
+                SelContextPtr ctx = Gui::SoFCSelectionRoot::getActionContext(action,this,selContext,false);
+                if(ctx && ctx->isSelected()) {
+                    ctx->selectionIndex.clear();
+                    this->touch();
+                }
+            }
+            return;
+        }
+    }
+
     if (action->getTypeId() == SoFCDocumentAction::getClassTypeId()) {
         SoFCDocumentAction *docaction = (SoFCDocumentAction*)action;
         this->documentName = docaction->documentName;
@@ -164,84 +223,87 @@ void SoFCSelection::doAction(SoAction *action)
         objaction->setHandled();
     }
 
-    if (action->getTypeId() == SoFCEnableHighlightAction::getClassTypeId()) {
-        SoFCEnableHighlightAction *preaction = (SoFCEnableHighlightAction*)action;
-        if (preaction->highlight) {
-            this->highlightMode = SoFCSelection::AUTO;
-        }
-        else {
-            this->highlightMode = SoFCSelection::OFF;
-        }
-    }
+    if(!useNewSelection.getValue()) {
 
-    if (action->getTypeId() == SoFCEnableSelectionAction::getClassTypeId()) {
-        SoFCEnableSelectionAction *selaction = (SoFCEnableSelectionAction*)action;
-        if (selaction->selection) {
-            this->selectionMode = SoFCSelection::SEL_ON;
-        }
-        else {
-            this->selectionMode = SoFCSelection::SEL_OFF;
-            if (selected.getValue() == SELECTED) {
-                this->selected = NOTSELECTED;
+        if (action->getTypeId() == SoFCEnableHighlightAction::getClassTypeId()) {
+            SoFCEnableHighlightAction *preaction = (SoFCEnableHighlightAction*)action;
+            if (preaction->highlight) {
+                this->highlightMode = SoFCSelection::AUTO;
+            }
+            else {
+                this->highlightMode = SoFCSelection::OFF;
             }
         }
-    }
 
-    if (action->getTypeId() == SoFCSelectionColorAction::getClassTypeId()) {
-        SoFCSelectionColorAction *colaction = (SoFCSelectionColorAction*)action;
-        this->colorSelection = colaction->selectionColor;
-    }
+        if (action->getTypeId() == SoFCEnableSelectionAction::getClassTypeId()) {
+            SoFCEnableSelectionAction *selaction = (SoFCEnableSelectionAction*)action;
+            if (selaction->selection) {
+                this->selectionMode = SoFCSelection::SEL_ON;
+            }
+            else {
+                this->selectionMode = SoFCSelection::SEL_OFF;
+                if (selected.getValue() == SELECTED) {
+                    this->selected = NOTSELECTED;
+                }
+            }
+        }
 
-    if (action->getTypeId() == SoFCHighlightColorAction::getClassTypeId()) {
-        SoFCHighlightColorAction *colaction = (SoFCHighlightColorAction*)action;
-        this->colorHighlight = colaction->highlightColor;
-    }
+        if (action->getTypeId() == SoFCSelectionColorAction::getClassTypeId()) {
+            SoFCSelectionColorAction *colaction = (SoFCSelectionColorAction*)action;
+            this->colorSelection = colaction->selectionColor;
+        }
 
-    if (selectionMode.getValue() == SEL_ON && action->getTypeId() == SoFCSelectionAction::getClassTypeId()) {
-        SoFCSelectionAction *selaction = static_cast<SoFCSelectionAction*>(action);
+        if (action->getTypeId() == SoFCHighlightColorAction::getClassTypeId()) {
+            SoFCHighlightColorAction *colaction = (SoFCHighlightColorAction*)action;
+            this->colorHighlight = colaction->highlightColor;
+        }
 
-        if (selaction->SelChange.Type == SelectionChanges::AddSelection || 
-            selaction->SelChange.Type == SelectionChanges::RmvSelection) {
-            if (documentName.getValue() == selaction->SelChange.pDocName &&
-                objectName.getValue() == selaction->SelChange.pObjectName &&
-                (subElementName.getValue() == selaction->SelChange.pSubName || 
-                *(selaction->SelChange.pSubName) == '\0') ) {
-                if (selaction->SelChange.Type == SelectionChanges::AddSelection) {
-                    if(selected.getValue() == NOTSELECTED){
+        if (selectionMode.getValue() == SEL_ON && action->getTypeId() == SoFCSelectionAction::getClassTypeId()) {
+            SoFCSelectionAction *selaction = static_cast<SoFCSelectionAction*>(action);
+
+            if (selaction->SelChange.Type == SelectionChanges::AddSelection ||
+                selaction->SelChange.Type == SelectionChanges::RmvSelection) {
+                if (documentName.getValue() == selaction->SelChange.pDocName &&
+                    objectName.getValue() == selaction->SelChange.pObjectName &&
+                    (subElementName.getValue() == selaction->SelChange.pSubName ||
+                    *(selaction->SelChange.pSubName) == '\0') ) {
+                    if (selaction->SelChange.Type == SelectionChanges::AddSelection) {
+                        if(selected.getValue() == NOTSELECTED){
+                            selected = SELECTED;
+                        }
+                    }
+                    else {
+                        if(selected.getValue() == SELECTED){
+                            selected = NOTSELECTED;
+                        }
+                    }
+                    return;
+                }
+            }
+            else if (selaction->SelChange.Type == SelectionChanges::ClrSelection) {
+                if (documentName.getValue() == selaction->SelChange.pDocName ||
+                    strcmp(selaction->SelChange.pDocName,"") == 0){
+                    if(selected.getValue() == SELECTED){
+                        selected = NOTSELECTED;
+                    }
+
+                }
+            }
+            else if (selaction->SelChange.Type == SelectionChanges::SetSelection) {
+                bool sel = Selection().isSelected(
+                        documentName.getValue().getString(),
+                        objectName.getValue().getString()/*,
+                        subElementName.getValue().getString()*/);
+                if (sel) {
+                    if (selected.getValue() == NOTSELECTED) {
                         selected = SELECTED;
                     }
                 }
                 else {
-                    if(selected.getValue() == SELECTED){
+                    if (selected.getValue() == SELECTED) {
                         selected = NOTSELECTED;
                     }
                 }
-                return;
-            }
-        }
-        else if (selaction->SelChange.Type == SelectionChanges::ClrSelection) {
-            if (documentName.getValue() == selaction->SelChange.pDocName ||
-                strcmp(selaction->SelChange.pDocName,"") == 0){
-                if(selected.getValue() == SELECTED){
-                    selected = NOTSELECTED;
-                }
-               
-            }
-        }
-        else if (selaction->SelChange.Type == SelectionChanges::SetSelection) {
-            bool sel = Selection().isSelected(
-                    documentName.getValue().getString(),
-                    objectName.getValue().getString()/*,
-                    subElementName.getValue().getString()*/);
-            if (sel) {
-                if (selected.getValue() == NOTSELECTED) {
-                    selected = SELECTED;
-                }
-            }
-            else {
-                if (selected.getValue() == SELECTED) {
-                    selected = NOTSELECTED;
-                }
             }
         }
     }
@@ -262,7 +324,7 @@ int SoFCSelection::getPriority(const SoPickedPoint* p)
 const SoPickedPoint*
 SoFCSelection::getPickedPoint(SoHandleEventAction* action) const
 {
-    // To identify the picking of lines in a concave area we have to 
+    // To identify the picking of lines in a concave area we have to
     // get all intersection points. If we have two or more intersection
     // points where the first is of a face and the second of a line with
     // almost similar coordinates we use the second point, instead.
@@ -284,13 +346,13 @@ SoFCSelection::getPickedPoint(SoHandleEventAction* action) const
     //}
 
     //return pp0;
-    
+
     const SoPickedPoint* picked = points[0];
 
     int picked_prio = getPriority(picked);
     const SbVec3f& picked_pt = picked->getPoint();
 
-   
+
     for(int i=1; i<points.getLength();i++) {
         const SoPickedPoint* cur = points[i];
         int cur_prio = getPriority(cur);
@@ -309,6 +371,11 @@ SoFCSelection::getPickedPoint(SoHandleEventAction* action) const
 void
 SoFCSelection::handleEvent(SoHandleEventAction * action)
 {
+    if(useNewSelection.getValue()) {
+       inherited::handleEvent( action );
+       return;
+    }
+
     static char buf[513];
     HighlightModes mymode = (HighlightModes) this->highlightMode.getValue();
     const SoEvent * event = action->getEvent();
@@ -336,15 +403,19 @@ SoFCSelection::handleEvent(SoHandleEventAction * action)
                         this->redrawHighlighted(action, true);
                     }
                 }
-                
-                snprintf(buf,512,"Preselected: %s.%s.%s (%f,%f,%f)",documentName.getValue().getString()
-                                           ,objectName.getValue().getString()
-                                           ,subElementName.getValue().getString()
-                                           ,pp->getPoint()[0]
-                                           ,pp->getPoint()[1]
-                                           ,pp->getPoint()[2]);
 
-                getMainWindow()->showMessage(QString::fromLatin1(buf));
+                const auto &pt = pp->getPoint();
+
+                auto pts = schemaTranslatePoint(pt[0], pt[1], pt[2], 1e-7);
+                snprintf(buf,512,"Preselected: %s.%s.%s (%f %s, %f %s, %f %s)"
+                                ,documentName.getValue().getString()
+                                ,objectName.getValue().getString()
+                                ,subElementName.getValue().getString()
+                                ,pts[0].first, pts[0].second.c_str()
+                                ,pts[1].first, pts[1].second.c_str()
+                                ,pts[2].first, pts[2].second.c_str());
+
+                getMainWindow()->showMessage(QString::fromUtf8(buf));
             }
             else { // picked point
                 if (highlighted) {
@@ -380,6 +451,7 @@ SoFCSelection::handleEvent(SoHandleEventAction * action)
             //       Otherwise the tree signals that an object is preselected even though it is hidden. (Werner)
             const SoPickedPoint * pp = this->getPickedPoint(action);
             if (pp && pp->getPath()->containsPath(action->getCurPath())) {
+                const auto &pt = pp->getPoint();
                 if (bCtrl) {
                     if (Gui::Selection().isSelected(documentName.getValue().getString()
                                          ,objectName.getValue().getString()
@@ -391,17 +463,15 @@ SoFCSelection::handleEvent(SoHandleEventAction * action)
                         Gui::Selection().addSelection(documentName.getValue().getString()
                                           ,objectName.getValue().getString()
                                           ,subElementName.getValue().getString()
-                                          ,pp->getPoint()[0]
-                                          ,pp->getPoint()[1]
-                                          ,pp->getPoint()[2]);
+                                          ,pt[0] ,pt[1] ,pt[2]);
 
                         if (mymode == OFF) {
-                            snprintf(buf,512,"Selected: %s.%s.%s (%f,%f,%f)",documentName.getValue().getString()
+                            snprintf(buf,512,"Selected: %s.%s.%s (%g, %g, %g)",documentName.getValue().getString()
                                                        ,objectName.getValue().getString()
                                                        ,subElementName.getValue().getString()
-                                                       ,pp->getPoint()[0]
-                                                       ,pp->getPoint()[1]
-                                                       ,pp->getPoint()[2]);
+                                                       ,fabs(pt[0])>1e-7?pt[0]:0.0
+                                                       ,fabs(pt[1])>1e-7?pt[1]:0.0
+                                                       ,fabs(pt[2])>1e-7?pt[2]:0.0);
 
                             getMainWindow()->showMessage(QString::fromLatin1(buf));
                         }
@@ -415,33 +485,28 @@ SoFCSelection::handleEvent(SoHandleEventAction * action)
                         Gui::Selection().addSelection(documentName.getValue().getString()
                                               ,objectName.getValue().getString()
                                               ,subElementName.getValue().getString()
-                                              ,pp->getPoint()[0]
-                                              ,pp->getPoint()[1]
-                                              ,pp->getPoint()[2]);
+                                              ,pt[0] ,pt[1] ,pt[2]);
                     }
                     else {
                         Gui::Selection().clearSelection(documentName.getValue().getString());
                         Gui::Selection().addSelection(documentName.getValue().getString()
                                               ,objectName.getValue().getString()
-                                              ,0
-                                              ,pp->getPoint()[0]
-                                              ,pp->getPoint()[1]
-                                              ,pp->getPoint()[2]);
+                                              ,0 ,pt[0] ,pt[1] ,pt[2]);
                     }
 
                     if (mymode == OFF) {
-                        snprintf(buf,512,"Selected: %s.%s.%s (%f,%f,%f)",documentName.getValue().getString()
+                        snprintf(buf,512,"Selected: %s.%s.%s (%g, %g, %g)",documentName.getValue().getString()
                                                    ,objectName.getValue().getString()
                                                    ,subElementName.getValue().getString()
-                                                   ,pp->getPoint()[0]
-                                                   ,pp->getPoint()[1]
-                                                   ,pp->getPoint()[2]);
+                                                   ,fabs(pt[0])>1e-7?pt[0]:0.0
+                                                   ,fabs(pt[1])>1e-7?pt[1]:0.0
+                                                   ,fabs(pt[2])>1e-7?pt[2]:0.0);
 
                         getMainWindow()->showMessage(QString::fromLatin1(buf));
                     }
                 }
 
-                action->setHandled(); 
+                action->setHandled();
             } // picked point
         } // mouse release
     }
@@ -458,7 +523,7 @@ SoFCSelection::handleEvent(SoHandleEventAction * action)
     //    return;
     //}
 
-    
+
     //
     // If this is a mouseMotion event, then check for locate highlighting
     //
@@ -536,7 +601,7 @@ SoFCSelection::handleEvent(SoHandleEventAction * action)
             bCtrl = false;
     }
     // mouse press events for (de)selection (only if selection is enabled on this node)
-    else if (event->isOfType(SoMouseButtonEvent::getClassTypeId()) && 
+    else if (event->isOfType(SoMouseButtonEvent::getClassTypeId()) &&
              selectionMode.getValue() == SoFCSelection::SEL_ON) {
         SoMouseButtonEvent * const e = (SoMouseButtonEvent *) event;
         if (SoMouseButtonEvent::isButtonReleaseEvent(e,SoMouseButtonEvent::BUTTON1)) {
@@ -544,6 +609,7 @@ SoFCSelection::handleEvent(SoHandleEventAction * action)
             //       Otherwise the tree signals that an object is preselected even though it is hidden. (Werner)
             const SoPickedPoint * pp = this->getPickedPoint(action);
             if (pp && pp->getPath()->containsPath(action->getCurPath())) {
+                const auto &pt = pp->getPoint();
                 if (bCtrl) {
                     if (Gui::Selection().isSelected(documentName.getValue().getString()
                                          ,objectName.getValue().getString()
@@ -556,17 +622,15 @@ SoFCSelection::handleEvent(SoHandleEventAction * action)
                         Gui::Selection().addSelection(documentName.getValue().getString()
                                           ,objectName.getValue().getString()
                                           ,subElementName.getValue().getString()
-                                          ,pp->getPoint()[0]
-                                          ,pp->getPoint()[1]
-                                          ,pp->getPoint()[2]);
+                                          ,pt[0] ,pt[1] ,pt[2]);
 
                         if (mymode == OFF) {
-                            snprintf(buf,512,"Selected: %s.%s.%s (%f,%f,%f)",documentName.getValue().getString()
+                            snprintf(buf,512,"Selected: %s.%s.%s (%g, %g, %g)",documentName.getValue().getString()
                                                        ,objectName.getValue().getString()
                                                        ,subElementName.getValue().getString()
-                                                       ,pp->getPoint()[0]
-                                                       ,pp->getPoint()[1]
-                                                       ,pp->getPoint()[2]);
+                                                       ,fabs(pt[0])>1e-7?pt[0]:0.0
+                                                       ,fabs(pt[1])>1e-7?pt[1]:0.0
+                                                       ,fabs(pt[2])>1e-7?pt[2]:0.0);
 
                             getMainWindow()->showMessage(QString::fromLatin1(buf));
                         }
@@ -580,33 +644,28 @@ SoFCSelection::handleEvent(SoHandleEventAction * action)
                         Gui::Selection().addSelection(documentName.getValue().getString()
                                               ,objectName.getValue().getString()
                                               ,subElementName.getValue().getString()
-                                              ,pp->getPoint()[0]
-                                              ,pp->getPoint()[1]
-                                              ,pp->getPoint()[2]);
+                                              ,pt[0] ,pt[1] ,pt[2]);
                     }
                     else {
                         Gui::Selection().clearSelection(documentName.getValue().getString());
                         Gui::Selection().addSelection(documentName.getValue().getString()
                                               ,objectName.getValue().getString()
-                                              ,0
-                                              ,pp->getPoint()[0]
-                                              ,pp->getPoint()[1]
-                                              ,pp->getPoint()[2]);
+                                              ,0 ,pt[0] ,pt[1] ,pt[2]);
                     }
- 
+
                     if (mymode == OFF) {
-                        snprintf(buf,512,"Selected: %s.%s.%s (%f,%f,%f)",documentName.getValue().getString()
+                        snprintf(buf,512,"Selected: %s.%s.%s (%g, %g, %g)",documentName.getValue().getString()
                                                    ,objectName.getValue().getString()
                                                    ,subElementName.getValue().getString()
-                                                   ,pp->getPoint()[0]
-                                                   ,pp->getPoint()[1]
-                                                   ,pp->getPoint()[2]);
+                                                   ,fabs(pt[0])>1e-7?pt[0]:0.0
+                                                   ,fabs(pt[1])>1e-7?pt[1]:0.0
+                                                   ,fabs(pt[2])>1e-7?pt[2]:0.0);
 
                         getMainWindow()->showMessage(QString::fromLatin1(buf));
                     }
                 }
 
-                action->setHandled(); 
+                action->setHandled();
             } // picked point
         } // mouse release
     }
@@ -621,17 +680,27 @@ SoFCSelection::handleEvent(SoHandleEventAction * action)
 void
 SoFCSelection::GLRenderBelowPath(SoGLRenderAction * action)
 {
+    SoState * state = action->getState();
+    SelContextPtr ctx = Gui::SoFCSelectionRoot::getRenderContext<SelContext>(this,selContext);
+    if(selContext2->checkGlobal(ctx))
+        ctx = selContext2;
+    if(!useNewSelection.getValue() && selContext == ctx) {
+        ctx->selectionColor = this->colorSelection.getValue();
+        ctx->highlightColor = this->colorHighlight.getValue();
+        if(this->selected.getValue()==SELECTED)
+            ctx->selectAll();
+        else
+            ctx->selectionIndex.clear();
+        ctx->highlightIndex = this->highlighted?0:-1;
+    }
+
 #ifdef NO_FRONTBUFFER
     // check if preselection is active
-    HighlightModes mymode = (HighlightModes) this->highlightMode.getValue();
-    bool preselected = highlighted && mymode == AUTO;
-    SoState * state = action->getState();
-    state->push();
-    if (preselected || this->highlightMode.getValue() == ON || this->selected.getValue() == SELECTED) {
-        this->setOverride(action);
-    }
-    inherited::GLRenderBelowPath(action);
-    state->pop();
+    if(this->setOverride(action,ctx)) {
+        inherited::GLRenderBelowPath(action);
+        state->pop();
+    } else
+        inherited::GLRenderBelowPath(action);
 #else
     // Set up state for locate highlighting (if necessary)
     GLint oldDepthFunc;
@@ -652,24 +721,69 @@ SoFCSelection::GLRenderBelowPath(SoGLRenderAction * action)
 
 void SoFCSelection::GLRender(SoGLRenderAction * action)
 {
+    SoState * state = action->getState();
+    SelContextPtr ctx = Gui::SoFCSelectionRoot::getRenderContext<SelContext>(this,selContext);
+    if(selContext2->checkGlobal(ctx))
+        ctx = selContext2;
+    if(!useNewSelection.getValue() && selContext == ctx) {
+        ctx->selectionColor = this->colorSelection.getValue();
+        ctx->highlightColor = this->colorHighlight.getValue();
+        if(this->selected.getValue()==SELECTED)
+            ctx->selectAll();
+        else
+            ctx->selectionIndex.clear();
+        ctx->highlightIndex = this->highlighted?0:-1;
+    }
+
+#ifdef NO_FRONTBUFFER
+    // check if preselection is active
+    if(this->setOverride(action,ctx)) {
+        inherited::GLRender(action);
+        state->pop();
+    } else
+        inherited::GLRender(action);
+#else
+    // Set up state for locate highlighting (if necessary)
+    GLint oldDepthFunc;
+    SbBool drawHighlighted = preRender(action, oldDepthFunc);
+
+    // now invoke the parent method
     inherited::GLRender(action);
+
+    // Restore old depth buffer model if needed
+    if (drawHighlighted || highlighted)
+        glDepthFunc((GLenum)oldDepthFunc);
+
+    // Clean up state if needed
+    if (drawHighlighted)
+        action->getState()->pop();
+#endif
 }
 
 // doc from parent
 void
 SoFCSelection::GLRenderInPath(SoGLRenderAction * action)
 {
+    SelContextPtr ctx = Gui::SoFCSelectionRoot::getRenderContext<SelContext>(this,selContext);
+    if(selContext2->checkGlobal(ctx))
+        ctx = selContext2;
+    if(!useNewSelection.getValue() && selContext == ctx) {
+        ctx->selectionColor = this->colorSelection.getValue();
+        ctx->highlightColor = this->colorHighlight.getValue();
+        if(this->selected.getValue()==SELECTED)
+            ctx->selectAll();
+        else
+            ctx->selectionIndex.clear();
+        ctx->highlightIndex = this->highlighted?0:-1;
+    }
 #ifdef NO_FRONTBUFFER
     // check if preselection is active
-    HighlightModes mymode = (HighlightModes) this->highlightMode.getValue();
-    bool preselected = highlighted && mymode == AUTO;
     SoState * state = action->getState();
-    state->push();
-    if (preselected || this->highlightMode.getValue() == ON || this->selected.getValue() == SELECTED) {
-        this->setOverride(action);
-    }
-    inherited::GLRenderInPath(action);
-    state->pop();
+    if(this->setOverride(action,ctx)) {
+        inherited::GLRenderInPath(action);
+        state->pop();
+    } else
+        inherited::GLRenderInPath(action);
 #else
     // Set up state for locate highlighting (if necessary)
     GLint oldDepthFunc;
@@ -747,8 +861,8 @@ SoFCSelection::preRender(SoGLRenderAction *action, GLint &oldDepthFunc)
 void
 SoFCSelection::redrawHighlighted(SoAction *  action , SbBool  doHighlight )
 {
-    Q_UNUSED(action); 
-    Q_UNUSED(doHighlight); 
+    Q_UNUSED(action);
+    Q_UNUSED(doHighlight);
     //Base::Console().Log("SoFCSelection::redrawHighlighted() (%p) doHigh=%d \n",this,doHighlight?1:0);
 
 #ifdef NO_FRONTBUFFER
@@ -837,7 +951,7 @@ SoFCSelection::redrawHighlighted(SoAction *  action , SbBool  doHighlight )
 #endif
 }
 
-SbBool 
+SbBool
 SoFCSelection::readInstance  (  SoInput *  in, unsigned short  flags )
 {
     // Note: The read in document name can be false, so the caller must ensure pointing to the correct document
@@ -847,25 +961,55 @@ SoFCSelection::readInstance  (  SoInput *  in, unsigned short  flags )
 //
 // update override state before rendering
 //
-void
-SoFCSelection::setOverride(SoGLRenderAction * action)
+bool
+SoFCSelection::setOverride(SoGLRenderAction * action, SelContextPtr ctx)
 {
-    //Base::Console().Log("SoFCSelection::setOverride() (%p)\n",this);
-    SoState * state = action->getState();
-    if(this->selected.getValue() == SELECTED)
-        SoLazyElement::setEmissive(state, &this->colorSelection.getValue());
-    else
-        SoLazyElement::setEmissive(state, &this->colorHighlight.getValue());
-    SoOverrideElement::setEmissiveColorOverride(state, this, true);
+    HighlightModes mymode = (HighlightModes) this->highlightMode.getValue();
+    bool preselected = ctx && ctx->isHighlighted() && (useNewSelection.getValue()||mymode == AUTO);
+    if (!preselected && mymode!=ON && (!ctx || !ctx->isSelected()))
+        return false;
+
+    // uniqueId is returned by SoNode::getNodeId(). It is used to notify change
+    // and for render cache update. In order to update cache on selection state
+    // change, We manually change the id here by using a combined hash of the
+    // original id and context pointer.
+    auto oldId = this->uniqueId;
+    this->uniqueId ^= std::hash<void*>()(ctx.get()) + 0x9e3779b9 + (oldId << 6) + (oldId >> 2);
 
     Styles mystyle = (Styles) this->style.getValue();
-    if (mystyle == SoFCSelection::EMISSIVE_DIFFUSE) {
-        if(this->selected.getValue() == SELECTED)
-            SoLazyElement::setDiffuse(state, this,1, &this->colorSelection.getValue(),&colorpacker);
+
+    if(mystyle == SoFCSelection::BOX) {
+        SoFCSelectionRoot::renderBBox(
+                action,this,preselected?ctx->highlightColor:ctx->selectionColor);
+        this->uniqueId = oldId;
+        return false;
+    }
+
+    //Base::Console().Log("SoFCSelection::setOverride() (%p)\n",this);
+    SoState * state = action->getState();
+    state->push();
+
+    SoMaterialBindingElement::set(state,SoMaterialBindingElement::OVERALL);
+    SoOverrideElement::setMaterialBindingOverride(state,this,true);
+
+    if(!preselected)
+        SoLazyElement::setEmissive(state, &ctx->selectionColor);
+    else
+        SoLazyElement::setEmissive(state, &ctx->highlightColor);
+    SoOverrideElement::setEmissiveColorOverride(state, this, true);
+
+    if(SoLazyElement::getLightModel(state)==SoLazyElement::BASE_COLOR
+            || mystyle == SoFCSelection::EMISSIVE_DIFFUSE)
+    {
+        if(!preselected)
+            SoLazyElement::setDiffuse(state, this,1, &ctx->selectionColor,&colorpacker);
         else
-            SoLazyElement::setDiffuse(state, this,1, &this->colorHighlight.getValue(),&colorpacker);
+            SoLazyElement::setDiffuse(state, this,1, &ctx->highlightColor,&colorpacker);
         SoOverrideElement::setDiffuseColorOverride(state, this, true);
     }
+
+    this->uniqueId = oldId;
+    return true;
 }
 
 // private convenience method
