@@ -1,5 +1,4 @@
 /***************************************************************************
- * 
  *   Copyright (c) 2005 Jürgen Riegel <juergen.riegel@web.de>              *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
@@ -95,7 +94,7 @@
 using namespace Gui;
 
 
-SO_ACTION_SOURCE(SoFCHighlightAction);
+SO_ACTION_SOURCE(SoFCHighlightAction)
 
 /**
  * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base
@@ -181,14 +180,14 @@ void SoFCHighlightAction::callDoAction(SoAction *action,SoNode *node)
 
 // ---------------------------------------------------------------
 
-SO_ACTION_SOURCE(SoFCSelectionAction);
+SO_ACTION_SOURCE(SoFCSelectionAction)
 
 /**
- * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base 
- * classes and afterwards subclasses of them must be listed, otherwise the registered methods 
- * of subclasses will be overridden. For more details see the thread in the Coin3d forum 
+ * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base
+ * classes and afterwards subclasses of them must be listed, otherwise the registered methods
+ * of subclasses will be overridden. For more details see the thread in the Coin3d forum
  * https://www.coin3d.org/pipermail/coin-discuss/2004-May/004346.html.
- * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after 
+ * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after
  * \c SoSeparator because both classes inherits the others.
  */
 void SoFCSelectionAction::initClass()
@@ -254,7 +253,7 @@ SoFCSelectionAction::~SoFCSelectionAction()
 {
 }
 
- 
+
 void SoFCSelectionAction::beginTraversal(SoNode *node)
 {
   traverse(node);
@@ -267,14 +266,14 @@ void SoFCSelectionAction::callDoAction(SoAction *action,SoNode *node)
 
 // ---------------------------------------------------------------
 
-SO_ACTION_SOURCE(SoFCEnableSelectionAction);
+SO_ACTION_SOURCE(SoFCEnableSelectionAction)
 
 /**
- * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base 
- * classes and afterwards subclasses of them must be listed, otherwise the registered methods 
- * of subclasses will be overridden. For more details see the thread in the Coin3d forum 
+ * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base
+ * classes and afterwards subclasses of them must be listed, otherwise the registered methods
+ * of subclasses will be overridden. For more details see the thread in the Coin3d forum
  * https://www.coin3d.org/pipermail/coin-discuss/2004-May/004346.html.
- * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after 
+ * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after
  * \c SoSeparator because both classes inherits the others.
  */
 void SoFCEnableSelectionAction::initClass()
@@ -336,7 +335,7 @@ SoFCEnableSelectionAction::~SoFCEnableSelectionAction()
 {
 }
 
- 
+
 void SoFCEnableSelectionAction::beginTraversal(SoNode *node)
 {
   traverse(node);
@@ -349,14 +348,14 @@ void SoFCEnableSelectionAction::callDoAction(SoAction *action,SoNode *node)
 
 // ---------------------------------------------------------------
 
-SO_ACTION_SOURCE(SoFCEnableHighlightAction);
+SO_ACTION_SOURCE(SoFCEnableHighlightAction)
 
 /**
- * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base 
- * classes and afterwards subclasses of them must be listed, otherwise the registered methods 
- * of subclasses will be overridden. For more details see the thread in the Coin3d forum 
+ * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base
+ * classes and afterwards subclasses of them must be listed, otherwise the registered methods
+ * of subclasses will be overridden. For more details see the thread in the Coin3d forum
  * https://www.coin3d.org/pipermail/coin-discuss/2004-May/004346.html.
- * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after 
+ * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after
  * \c SoSeparator because both classes inherits the others.
  */
 void SoFCEnableHighlightAction::initClass()
@@ -418,7 +417,7 @@ SoFCEnableHighlightAction::~SoFCEnableHighlightAction()
 {
 }
 
- 
+
 void SoFCEnableHighlightAction::beginTraversal(SoNode *node)
 {
   traverse(node);
@@ -431,14 +430,14 @@ void SoFCEnableHighlightAction::callDoAction(SoAction *action,SoNode *node)
 
 // ---------------------------------------------------------------
 
-SO_ACTION_SOURCE(SoFCSelectionColorAction);
+SO_ACTION_SOURCE(SoFCSelectionColorAction)
 
 /**
- * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base 
- * classes and afterwards subclasses of them must be listed, otherwise the registered methods 
- * of subclasses will be overridden. For more details see the thread in the Coin3d forum 
+ * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base
+ * classes and afterwards subclasses of them must be listed, otherwise the registered methods
+ * of subclasses will be overridden. For more details see the thread in the Coin3d forum
  * https://www.coin3d.org/pipermail/coin-discuss/2004-May/004346.html.
- * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after 
+ * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after
  * \c SoSeparator because both classes inherits the others.
  */
 void SoFCSelectionColorAction::initClass()
@@ -500,7 +499,7 @@ SoFCSelectionColorAction::~SoFCSelectionColorAction()
 {
 }
 
- 
+
 void SoFCSelectionColorAction::beginTraversal(SoNode *node)
 {
   traverse(node);
@@ -513,14 +512,14 @@ void SoFCSelectionColorAction::callDoAction(SoAction *action,SoNode *node)
 
 // ---------------------------------------------------------------
 
-SO_ACTION_SOURCE(SoFCHighlightColorAction);
+SO_ACTION_SOURCE(SoFCHighlightColorAction)
 
 /**
- * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base 
- * classes and afterwards subclasses of them must be listed, otherwise the registered methods 
- * of subclasses will be overridden. For more details see the thread in the Coin3d forum 
+ * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base
+ * classes and afterwards subclasses of them must be listed, otherwise the registered methods
+ * of subclasses will be overridden. For more details see the thread in the Coin3d forum
  * https://www.coin3d.org/pipermail/coin-discuss/2004-May/004346.html.
- * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after 
+ * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after
  * \c SoSeparator because both classes inherits the others.
  */
 void SoFCHighlightColorAction::initClass()
@@ -582,7 +581,7 @@ SoFCHighlightColorAction::~SoFCHighlightColorAction()
 {
 }
 
- 
+
 void SoFCHighlightColorAction::beginTraversal(SoNode *node)
 {
   traverse(node);
@@ -595,14 +594,14 @@ void SoFCHighlightColorAction::callDoAction(SoAction *action,SoNode *node)
 
 // ---------------------------------------------------------------
 
-SO_ACTION_SOURCE(SoFCDocumentAction);
+SO_ACTION_SOURCE(SoFCDocumentAction)
 
 /**
- * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base 
- * classes and afterwards subclasses of them must be listed, otherwise the registered methods 
- * of subclasses will be overridden. For more details see the thread in the Coin3d forum 
+ * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base
+ * classes and afterwards subclasses of them must be listed, otherwise the registered methods
+ * of subclasses will be overridden. For more details see the thread in the Coin3d forum
  * https://www.coin3d.org/pipermail/coin-discuss/2004-May/004346.html.
- * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after 
+ * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after
  * \c SoSeparator because both classes inherits the others.
  */
 void SoFCDocumentAction::initClass()
@@ -664,7 +663,7 @@ SoFCDocumentAction::~SoFCDocumentAction()
 {
 }
 
- 
+
 void SoFCDocumentAction::beginTraversal(SoNode *node)
 {
   traverse(node);
@@ -678,14 +677,14 @@ void SoFCDocumentAction::callDoAction(SoAction *action,SoNode *node)
 
 // ---------------------------------------------------------------
 
-SO_ACTION_SOURCE(SoFCDocumentObjectAction);
+SO_ACTION_SOURCE(SoFCDocumentObjectAction)
 
 /**
- * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base 
- * classes and afterwards subclasses of them must be listed, otherwise the registered methods 
- * of subclasses will be overridden. For more details see the thread in the Coin3d forum 
+ * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base
+ * classes and afterwards subclasses of them must be listed, otherwise the registered methods
+ * of subclasses will be overridden. For more details see the thread in the Coin3d forum
  * https://www.coin3d.org/pipermail/coin-discuss/2004-May/004346.html.
- * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after 
+ * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after
  * \c SoSeparator because both classes inherits the others.
  */
 void SoFCDocumentObjectAction::initClass()
@@ -763,14 +762,14 @@ SbBool SoFCDocumentObjectAction::isHandled() const
 
 // ---------------------------------------------------------------
 
-SO_ACTION_SOURCE(SoGLSelectAction);
+SO_ACTION_SOURCE(SoGLSelectAction)
 
 /**
- * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base 
- * classes and afterwards subclasses of them must be listed, otherwise the registered methods 
- * of subclasses will be overridden. For more details see the thread in the Coin3d forum 
+ * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base
+ * classes and afterwards subclasses of them must be listed, otherwise the registered methods
+ * of subclasses will be overridden. For more details see the thread in the Coin3d forum
  * https://www.coin3d.org/pipermail/coin-discuss/2004-May/004346.html.
- * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after 
+ * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after
  * \c SoSeparator because both classes inherits the others.
  */
 void SoGLSelectAction::initClass()
@@ -839,14 +838,14 @@ SbBool SoGLSelectAction::isHandled() const
 
 // ---------------------------------------------------------------
 
-SO_ACTION_SOURCE(SoVisibleFaceAction);
+SO_ACTION_SOURCE(SoVisibleFaceAction)
 
 /**
- * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base 
- * classes and afterwards subclasses of them must be listed, otherwise the registered methods 
- * of subclasses will be overridden. For more details see the thread in the Coin3d forum 
+ * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base
+ * classes and afterwards subclasses of them must be listed, otherwise the registered methods
+ * of subclasses will be overridden. For more details see the thread in the Coin3d forum
  * https://www.coin3d.org/pipermail/coin-discuss/2004-May/004346.html.
- * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after 
+ * This means that \c SoSwitch must be listed after \c SoGroup and \c SoFCSelection after
  * \c SoSeparator because both classes inherits the others.
  */
 void SoVisibleFaceAction::initClass()
@@ -909,7 +908,7 @@ SbBool SoVisibleFaceAction::isHandled() const
 // ---------------------------------------------------------------
 
 
-SO_ACTION_SOURCE(SoUpdateVBOAction);
+SO_ACTION_SOURCE(SoUpdateVBOAction)
 
 /**
  * The order of the defined SO_ACTION_ADD_METHOD statements is very important. First the base
@@ -976,7 +975,7 @@ void SoUpdateVBOAction::callDoAction(SoAction *action,SoNode *node)
 namespace Gui {
 class SoBoxSelectionRenderActionP {
 public:
-    SoBoxSelectionRenderActionP(SoBoxSelectionRenderAction * master) 
+    SoBoxSelectionRenderActionP(SoBoxSelectionRenderAction * master)
       : master(master)
       , searchaction(0)
       , selectsearch(0)
@@ -1020,7 +1019,7 @@ public:
 
 // used to initialize the internal storage class with variables
 void
-SoBoxSelectionRenderActionP::initBoxGraph() 
+SoBoxSelectionRenderActionP::initBoxGraph()
 {
     this->localRoot = new SoSeparator;
     this->localRoot->ref();
@@ -1052,8 +1051,8 @@ SoBoxSelectionRenderActionP::initBoxGraph()
 }
 
 
-// used to render shape and non-shape nodes (usually SoGroup or SoSeparator). 
-void 
+// used to render shape and non-shape nodes (usually SoGroup or SoSeparator).
+void
 SoBoxSelectionRenderActionP::updateBbox(const SoPath * path)
 {
     if (this->camerasearch == NULL) {
@@ -1065,22 +1064,22 @@ SoBoxSelectionRenderActionP::updateBbox(const SoPath * path)
     this->camerasearch->setInterest(SoSearchAction::LAST);
     this->camerasearch->setType(SoCamera::getClassTypeId());
     this->camerasearch->apply((SoPath*) path);
-  
+
     if (!this->camerasearch->getPath()) {
         // if there is no camera there is no point rendering the bbox
         return;
     }
     this->localRoot->insertChild(this->camerasearch->getPath()->getTail(), 0);
     this->camerasearch->reset();
-  
+
     if (this->bboxaction == NULL) {
         this->bboxaction = new SoGetBoundingBoxAction(SbViewportRegion(100, 100));
     }
     this->bboxaction->setViewportRegion(PUBLIC(this)->getViewportRegion());
     this->bboxaction->apply((SoPath*) path);
-  
+
     SbXfBox3f & box = this->bboxaction->getXfBoundingBox();
-  
+
     if (!box.isEmpty()) {
         // set cube size
         float x, y, z;
@@ -1088,27 +1087,27 @@ SoBoxSelectionRenderActionP::updateBbox(const SoPath * path)
         this->cube->width  = x;
         this->cube->height  = y;
         this->cube->depth = z;
-    
+
         SbMatrix transform = box.getTransform();
-    
+
         // get center (in the local bbox coordinate system)
         SbVec3f center = box.SbBox3f::getCenter();
-    
+
         // if center != (0,0,0), move the cube
         if (center != SbVec3f(0.0f, 0.0f, 0.0f)) {
             SbMatrix t;
             t.setTranslate(center);
             transform.multLeft(t);
         }
-        this->xform->matrix = transform; 
-    
+        this->xform->matrix = transform;
+
         PUBLIC(this)->SoGLRenderAction::apply(this->localRoot);
     }
     // remove camera
     this->localRoot->removeChild(0);
 }
 
-SO_ACTION_SOURCE(SoBoxSelectionRenderAction);
+SO_ACTION_SOURCE(SoBoxSelectionRenderAction)
 
 // Overridden from parent class.
 void
@@ -1142,7 +1141,8 @@ SoBoxSelectionRenderAction::constructorCommon(void)
     // Initialize local variables
     PRIVATE(this)->initBoxGraph();
 
-    this->hlVisible = true;
+    // this->hlVisible = true;
+    this->hlVisible = false;
 
     PRIVATE(this)->basecolor->rgb.setValue(1.0f, 0.0f, 0.0f);
     PRIVATE(this)->drawstyle->linePattern = 0xffff;
@@ -1236,20 +1236,6 @@ SoBoxSelectionRenderAction::apply(SoNode * node)
             }
         }
         PRIVATE(this)->searchaction->reset();
-
-        // Search for selections of SoFCUnifiedSelection
-        PRIVATE(this)->searchaction->setType(SoFCUnifiedSelection::getClassTypeId());
-        PRIVATE(this)->searchaction->setInterest(SoSearchAction::FIRST);
-        PRIVATE(this)->searchaction->apply(node);
-        SoFullPath * path = static_cast<SoFullPath *>(PRIVATE(this)->searchaction->getPath());
-        if (path) {
-            SoFCUnifiedSelection * selection = static_cast<SoFCUnifiedSelection *>(path->getTail());
-            if (selection->getNumSelected()) {
-                PRIVATE(this)->basecolor->rgb.setValue(selection->colorSelection.getValue());
-                this->drawBoxes(path, selection->getList());
-            }
-        }
-        PRIVATE(this)->searchaction->reset();
     }
 }
 
@@ -1348,7 +1334,7 @@ SoBoxSelectionRenderAction::drawBoxes(SoPath * pathtothis, const SoPathList * pa
     int thispos = ((SoFullPath *)pathtothis)->getLength()-1;
     assert(thispos >= 0);
     PRIVATE(this)->postprocpath->truncate(0); // reset
-  
+
     for (i = 0; i < thispos; i++)
         PRIVATE(this)->postprocpath->append(pathtothis->getNode(i));
 
