@@ -37,16 +37,18 @@
 #include "Document.h"
 #include "Application.h"
 #include "NavigationStyle.h"
+#include "View3DPy.h"
 
 
 using namespace Gui;
 
-TYPESYSTEM_SOURCE_ABSTRACT(Gui::AbstractSplitView,Gui::MDIView);
+TYPESYSTEM_SOURCE_ABSTRACT(Gui::AbstractSplitView,Gui::MDIView)
 
 AbstractSplitView::AbstractSplitView(Gui::Document* pcDocument, QWidget* parent, Qt::WindowFlags wflags)
   : MDIView(pcDocument,parent, wflags)
 {
-    // important for highlighting 
+    _viewerPy = 0;
+    // important for highlighting
     setMouseTracking(true);
 }
 
@@ -56,6 +58,10 @@ AbstractSplitView::~AbstractSplitView()
     for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it) {
         delete *it;
     }
+    if (_viewerPy) {
+        static_cast<AbstractSplitViewPy*>(_viewerPy)->_view = 0;
+        Py_DECREF(_viewerPy);
+    }
 }
 
 void AbstractSplitView::deleteSelf()
@@ -66,6 +72,16 @@ void AbstractSplitView::deleteSelf()
     MDIView::deleteSelf();
 }
 
+bool AbstractSplitView::containsViewProvider(const ViewProvider* vp) const
+{
+    for (auto it = _viewer.begin(); it != _viewer.end(); ++it) {
+        if ((*it)->containsViewProvider(vp))
+            return true;
+    }
+
+    return false;
+}
+
 void AbstractSplitView::setupSettings()
 {
     // attach Parameter Observer
@@ -82,8 +98,8 @@ void AbstractSplitView::setupSettings()
     OnChange(*hGrp,"BackgroundColor3");
     OnChange(*hGrp,"BackgroundColor4");
     OnChange(*hGrp,"UseBackgroundColorMid");
-    OnChange(*hGrp,"UseAntialiasing");
     OnChange(*hGrp,"ShowFPS");
+    OnChange(*hGrp,"UseVBO");
     OnChange(*hGrp,"Orthographic");
     OnChange(*hGrp,"HeadlightColor");
     OnChange(*hGrp,"HeadlightDirection");
@@ -93,6 +109,10 @@ void AbstractSplitView::setupSettings()
     OnChange(*hGrp,"BacklightDirection");
     OnChange(*hGrp,"BacklightIntensity");
     OnChange(*hGrp,"NavigationStyle");
+    OnChange(*hGrp,"OrbitStyle");
+    OnChange(*hGrp,"Sensitivity");
+    OnChange(*hGrp,"ResetCursorPosition");
+    OnChange(*hGrp,"PickRadius");
 }
 
 View3DInventorViewer* AbstractSplitView::getViewer(unsigned int n) const
@@ -198,6 +218,21 @@ void AbstractSplitView::OnChange(ParameterGrp::SubjectType &rCaller,ParameterGrp
         //for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it)
         //    (*it)->setNavigationType(type);
     }
+    else if (strcmp(Reason,"OrbitStyle") == 0) {
+        int style = rGrp.GetInt("OrbitStyle",1);
+        for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it)
+            (*it)->navigationStyle()->setOrbitStyle(NavigationStyle::OrbitStyle(style));
+    }
+    else if (strcmp(Reason,"Sensitivity") == 0) {
+        float val = rGrp.GetFloat("Sensitivity",2.0f);
+        for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it)
+            (*it)->navigationStyle()->setSensitivity(val);
+    }
+    else if (strcmp(Reason,"ResetCursorPosition") == 0) {
+        bool on = rGrp.GetBool("ResetCursorPosition",false);
+        for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it)
+            (*it)->navigationStyle()->setResetCursorPosition(on);
+    }
     else if (strcmp(Reason,"EyeDistance") == 0) {
         for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it)
             (*it)->getSoRenderManager()->setStereoOffset(rGrp.GetFloat("EyeDistance",5.0));
@@ -208,20 +243,22 @@ void AbstractSplitView::OnChange(ParameterGrp::SubjectType &rCaller,ParameterGrp
     }
     else if (strcmp(Reason,"UseAutoRotation") == 0) {
         for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it)
-            (*it)->setAnimationEnabled(rGrp.GetBool("UseAutoRotation",true));
+            (*it)->setAnimationEnabled(rGrp.GetBool("UseAutoRotation",false));
     }
     else if (strcmp(Reason,"Gradient") == 0) {
         for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it)
             (*it)->setGradientBackground((rGrp.GetBool("Gradient",true)));
     }
-    else if (strcmp(Reason,"UseAntialiasing") == 0) {
-        for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it)
-            (*it)->getSoRenderManager()->getGLRenderAction()->setSmoothing(rGrp.GetBool("UseAntialiasing",false));
-    }
     else if (strcmp(Reason,"ShowFPS") == 0) {
         for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it)
             (*it)->setEnabledFPSCounter(rGrp.GetBool("ShowFPS",false));
     }
+    else if (strcmp(Reason,"UseVBO") == 0) {
+        // Disable VBO for split screen as this leads to random crashes
+        //for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it)
+        //    (*it)->setEnabledVBO(rGrp.GetBool("UseVBO",false));
+    }
+
     else if (strcmp(Reason,"Orthographic") == 0) {
         // check whether a perspective or orthogrphic camera should be set
         if (rGrp.GetBool("Orthographic", true)) {
@@ -233,6 +270,10 @@ void AbstractSplitView::OnChange(ParameterGrp::SubjectType &rCaller,ParameterGrp
                 (*it)->setCameraType(SoPerspectiveCamera::getClassTypeId());
         }
     }
+    else if (strcmp(Reason, "PickRadius") == 0) {
+        for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it)
+            (*it)->setPickRadius(rGrp.GetFloat("PickRadius", 5.0f));
+    }
     else {
         unsigned long col1 = rGrp.GetUnsigned("BackgroundColor",3940932863UL);
         unsigned long col2 = rGrp.GetUnsigned("BackgroundColor2",859006463UL); // default color (dark blue)
@@ -255,7 +296,7 @@ void AbstractSplitView::OnChange(ParameterGrp::SubjectType &rCaller,ParameterGrp
 
 void AbstractSplitView::onUpdate(void)
 {
-    update();  
+    update();
 }
 
 const char *AbstractSplitView::getName(void) const
@@ -263,7 +304,7 @@ const char *AbstractSplitView::getName(void) const
     return "SplitView3DInventor";
 }
 
-bool AbstractSplitView::onMsg(const char* pMsg, const char** ppReturn)
+bool AbstractSplitView::onMsg(const char* pMsg, const char**)
 {
     if (strcmp("ViewFit",pMsg) == 0 ) {
         for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it)
@@ -271,60 +312,64 @@ bool AbstractSplitView::onMsg(const char* pMsg, const char** ppReturn)
         return true;
     }
     else if (strcmp("ViewBottom",pMsg) == 0) {
+        SbRotation rot(Camera::rotation(Camera::Bottom));
         for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it) {
             SoCamera* cam = (*it)->getSoRenderManager()->getCamera();
-            cam->orientation.setValue(-1, 0, 0, 0);
+            cam->orientation.setValue(rot);
             (*it)->viewAll();
         }
         return true;
     }
     else if (strcmp("ViewFront",pMsg) == 0) {
-        float root = (float)(sqrt(2.0)/2.0);
+        SbRotation rot(Camera::rotation(Camera::Front));
         for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it) {
             SoCamera* cam = (*it)->getSoRenderManager()->getCamera();
-            cam->orientation.setValue(-root, 0, 0, -root);
+            cam->orientation.setValue(rot);
             (*it)->viewAll();
         }
         return true;
     }
     else if (strcmp("ViewLeft",pMsg) == 0) {
+        SbRotation rot(Camera::rotation(Camera::Left));
         for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it) {
             SoCamera* cam = (*it)->getSoRenderManager()->getCamera();
-            cam->orientation.setValue(-0.5, 0.5, 0.5, -0.5);
+            cam->orientation.setValue(rot);
             (*it)->viewAll();
         }
         return true;
     }
     else if (strcmp("ViewRear",pMsg) == 0) {
-        float root = (float)(sqrt(2.0)/2.0);
+        SbRotation rot(Camera::rotation(Camera::Rear));
         for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it) {
             SoCamera* cam = (*it)->getSoRenderManager()->getCamera();
-            cam->orientation.setValue(0, root, root, 0);
+            cam->orientation.setValue(rot);
             (*it)->viewAll();
         }
         return true;
     }
     else if (strcmp("ViewRight",pMsg) == 0) {
+        SbRotation rot(Camera::rotation(Camera::Right));
         for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it) {
             SoCamera* cam = (*it)->getSoRenderManager()->getCamera();
-            cam->orientation.setValue(0.5, 0.5, 0.5, 0.5);
+            cam->orientation.setValue(rot);
             (*it)->viewAll();
         }
         return true;
     }
     else if (strcmp("ViewTop",pMsg) == 0) {
+        SbRotation rot(Camera::rotation(Camera::Top));
         for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it) {
             SoCamera* cam = (*it)->getSoRenderManager()->getCamera();
-            cam->orientation.setValue(0, 0, 0, 1);
+            cam->orientation.setValue(rot);
             (*it)->viewAll();
         }
         return true;
     }
     else if (strcmp("ViewAxo",pMsg) == 0) {
-        float root = (float)(sqrt(3.0)/4.0);
+        SbRotation rot(Camera::rotation(Camera::Isometric));
         for (std::vector<View3DInventorViewer*>::iterator it = _viewer.begin(); it != _viewer.end(); ++it) {
             SoCamera* cam = (*it)->getSoRenderManager()->getCamera();
-            cam->orientation.setValue(-0.333333f, -0.166666f, -0.333333f, -root);
+            cam->orientation.setValue(rot);
             (*it)->viewAll();
         }
         return true;
@@ -364,18 +409,16 @@ bool AbstractSplitView::onHasMsg(const char* pMsg) const
 
 void AbstractSplitView::setOverrideCursor(const QCursor& aCursor)
 {
+    Q_UNUSED(aCursor);
     //_viewer->getWidget()->setCursor(aCursor);
 }
 
 PyObject *AbstractSplitView::getPyObject(void)
 {
-    static bool init = false;
-    if (!init) {
-        init = true;
-        AbstractSplitViewPy::init_type();
-    }
-
-    return new AbstractSplitViewPy(this);
+    if (!_viewerPy)
+        _viewerPy = new AbstractSplitViewPy(this);
+    Py_INCREF(_viewerPy);
+    return _viewerPy;
 }
 
 void AbstractSplitView::setPyObject(PyObject *)
@@ -383,6 +426,11 @@ void AbstractSplitView::setPyObject(PyObject *)
     throw Base::AttributeError("Attribute is read-only");
 }
 
+int AbstractSplitView::getSize()
+{
+    return static_cast<int>(_viewer.size());
+}
+
 // ------------------------------------------------------
 
 void AbstractSplitViewPy::init_type()
@@ -391,6 +439,7 @@ void AbstractSplitViewPy::init_type()
     behaviors().doc("Python binding class for the Inventor viewer class");
     // you must have overwritten the virtual functions
     behaviors().supportRepr();
+    behaviors().supportSequenceType();
 
     add_varargs_method("fitAll",&AbstractSplitViewPy::fitAll,"fitAll()");
     add_varargs_method("viewBottom",&AbstractSplitViewPy::viewBottom,"viewBottom()");
@@ -399,7 +448,10 @@ void AbstractSplitViewPy::init_type()
     add_varargs_method("viewRear",&AbstractSplitViewPy::viewRear,"viewRear()");
     add_varargs_method("viewRight",&AbstractSplitViewPy::viewRight,"viewRight()");
     add_varargs_method("viewTop",&AbstractSplitViewPy::viewTop,"viewTop()");
-    add_varargs_method("viewAxometric",&AbstractSplitViewPy::viewAxometric,"viewAxometric()");
+    add_varargs_method("viewAxometric",&AbstractSplitViewPy::viewIsometric,"viewAxometric()");
+    add_varargs_method("viewIsometric",&AbstractSplitViewPy::viewIsometric,"viewIsometric()");
+    add_varargs_method("getViewer",&AbstractSplitViewPy::getViewer,"getViewer(index)");
+    add_varargs_method("close",&AbstractSplitViewPy::close,"close()");
 }
 
 AbstractSplitViewPy::AbstractSplitViewPy(AbstractSplitView *vi)
@@ -411,6 +463,12 @@ AbstractSplitViewPy::~AbstractSplitViewPy()
 {
 }
 
+void AbstractSplitViewPy::testExistence()
+{
+    if (!(_view && _view->getViewer(0)))
+        throw Py::RuntimeError("Object already deleted");
+}
+
 Py::Object AbstractSplitViewPy::repr()
 {
     std::string s;
@@ -425,18 +483,19 @@ Py::Object AbstractSplitViewPy::fitAll(const Py::Tuple& args)
 {
     if (!PyArg_ParseTuple(args.ptr(), ""))
         throw Py::Exception();
+    testExistence();
 
     try {
         _view->onMsg("ViewFit", 0);
     }
     catch (const Base::Exception& e) {
-        throw Py::Exception(e.what());
+        throw Py::RuntimeError(e.what());
     }
     catch (const std::exception& e) {
-        throw Py::Exception(e.what());
+        throw Py::RuntimeError(e.what());
     }
     catch(...) {
-        throw Py::Exception("Unknown C++ exception");
+        throw Py::RuntimeError("Unknown C++ exception");
     }
     return Py::None();
 }
@@ -445,18 +504,19 @@ Py::Object AbstractSplitViewPy::viewBottom(const Py::Tuple& args)
 {
     if (!PyArg_ParseTuple(args.ptr(), ""))
         throw Py::Exception();
+    testExistence();
 
     try {
         _view->onMsg("ViewBottom", 0);
     }
     catch (const Base::Exception& e) {
-        throw Py::Exception(e.what());
+        throw Py::RuntimeError(e.what());
     }
     catch (const std::exception& e) {
-        throw Py::Exception(e.what());
+        throw Py::RuntimeError(e.what());
     }
     catch(...) {
-        throw Py::Exception("Unknown C++ exception");
+        throw Py::RuntimeError("Unknown C++ exception");
     }
 
     return Py::None();
@@ -466,18 +526,19 @@ Py::Object AbstractSplitViewPy::viewFront(const Py::Tuple& args)
 {
     if (!PyArg_ParseTuple(args.ptr(), ""))
         throw Py::Exception();
+    testExistence();
 
     try {
         _view->onMsg("ViewFront", 0);
     }
     catch (const Base::Exception& e) {
-        throw Py::Exception(e.what());
+        throw Py::RuntimeError(e.what());
     }
     catch (const std::exception& e) {
-        throw Py::Exception(e.what());
+        throw Py::RuntimeError(e.what());
     }
     catch(...) {
-        throw Py::Exception("Unknown C++ exception");
+        throw Py::RuntimeError("Unknown C++ exception");
     }
 
     return Py::None();
@@ -487,18 +548,19 @@ Py::Object AbstractSplitViewPy::viewLeft(const Py::Tuple& args)
 {
     if (!PyArg_ParseTuple(args.ptr(), ""))
         throw Py::Exception();
+    testExistence();
 
     try {
         _view->onMsg("ViewLeft", 0);
     }
     catch (const Base::Exception& e) {
-        throw Py::Exception(e.what());
+        throw Py::RuntimeError(e.what());
     }
     catch (const std::exception& e) {
-        throw Py::Exception(e.what());
+        throw Py::RuntimeError(e.what());
     }
     catch(...) {
-        throw Py::Exception("Unknown C++ exception");
+        throw Py::RuntimeError("Unknown C++ exception");
     }
 
     return Py::None();
@@ -508,18 +570,19 @@ Py::Object AbstractSplitViewPy::viewRear(const Py::Tuple& args)
 {
     if (!PyArg_ParseTuple(args.ptr(), ""))
         throw Py::Exception();
+    testExistence();
 
     try {
         _view->onMsg("ViewRear", 0);
     }
     catch (const Base::Exception& e) {
-        throw Py::Exception(e.what());
+        throw Py::RuntimeError(e.what());
     }
     catch (const std::exception& e) {
-        throw Py::Exception(e.what());
+        throw Py::RuntimeError(e.what());
     }
     catch(...) {
-        throw Py::Exception("Unknown C++ exception");
+        throw Py::RuntimeError("Unknown C++ exception");
     }
 
     return Py::None();
@@ -529,18 +592,19 @@ Py::Object AbstractSplitViewPy::viewRight(const Py::Tuple& args)
 {
     if (!PyArg_ParseTuple(args.ptr(), ""))
         throw Py::Exception();
+    testExistence();
 
     try {
         _view->onMsg("ViewRight", 0);
     }
     catch (const Base::Exception& e) {
-        throw Py::Exception(e.what());
+        throw Py::RuntimeError(e.what());
     }
     catch (const std::exception& e) {
-        throw Py::Exception(e.what());
+        throw Py::RuntimeError(e.what());
     }
     catch(...) {
-        throw Py::Exception("Unknown C++ exception");
+        throw Py::RuntimeError("Unknown C++ exception");
     }
 
     return Py::None();
@@ -550,70 +614,171 @@ Py::Object AbstractSplitViewPy::viewTop(const Py::Tuple& args)
 {
     if (!PyArg_ParseTuple(args.ptr(), ""))
         throw Py::Exception();
+    testExistence();
 
     try {
         _view->onMsg("ViewTop", 0);
     }
     catch (const Base::Exception& e) {
-        throw Py::Exception(e.what());
+        throw Py::RuntimeError(e.what());
     }
     catch (const std::exception& e) {
-        throw Py::Exception(e.what());
+        throw Py::RuntimeError(e.what());
     }
     catch(...) {
-        throw Py::Exception("Unknown C++ exception");
+        throw Py::RuntimeError("Unknown C++ exception");
     }
 
     return Py::None();
 }
 
-Py::Object AbstractSplitViewPy::viewAxometric(const Py::Tuple& args)
+Py::Object AbstractSplitViewPy::viewIsometric(const Py::Tuple& args)
 {
     if (!PyArg_ParseTuple(args.ptr(), ""))
         throw Py::Exception();
+    testExistence();
 
     try {
         _view->onMsg("ViewAxo", 0);
     }
     catch (const Base::Exception& e) {
-        throw Py::Exception(e.what());
+        throw Py::RuntimeError(e.what());
     }
     catch (const std::exception& e) {
-        throw Py::Exception(e.what());
+        throw Py::RuntimeError(e.what());
     }
     catch(...) {
-        throw Py::Exception("Unknown C++ exception");
+        throw Py::RuntimeError("Unknown C++ exception");
     }
 
     return Py::None();
 }
 
+Py::Object AbstractSplitViewPy::getViewer(const Py::Tuple& args)
+{
+    int viewIndex;
+    if (!PyArg_ParseTuple(args.ptr(), "i", &viewIndex))
+        throw Py::Exception();
+    testExistence();
+
+    try {
+        Gui::View3DInventorViewer* view = _view->getViewer(viewIndex);
+        if (!view)
+            throw Py::IndexError("Index out of range");
+        return Py::asObject(view->getPyObject());
+    }
+    catch (const Base::Exception& e) {
+        throw Py::RuntimeError(e.what());
+    }
+    catch (const std::exception& e) {
+        throw Py::RuntimeError(e.what());
+    }
+    catch(...) {
+        throw Py::RuntimeError("Unknown C++ exception");
+    }
+}
+
+Py::Object AbstractSplitViewPy::sequence_item(ssize_t viewIndex)
+{
+    testExistence();
+    if (viewIndex >= _view->getSize() || viewIndex < 0)
+        throw Py::IndexError("Index out of range");
+    PyObject* viewer = _view->getViewer(viewIndex)->getPyObject();
+    return Py::asObject(viewer);
+}
+
+int AbstractSplitViewPy::sequence_length()
+{
+    testExistence();
+    return _view->getSize();
+}
+
+Py::Object AbstractSplitViewPy::close(const Py::Tuple& args)
+{
+    if (!PyArg_ParseTuple(args.ptr(), ""))
+        throw Py::Exception();
+    testExistence();
+
+    _view->close();
+    if (_view->parentWidget())
+        _view->parentWidget()->deleteLater();
+    _view = 0;
+
+    return Py::None();
+}
+
 // ------------------------------------------------------
 
-TYPESYSTEM_SOURCE_ABSTRACT(Gui::SplitView3DInventor, Gui::AbstractSplitView);
+TYPESYSTEM_SOURCE_ABSTRACT(Gui::SplitView3DInventor, Gui::AbstractSplitView)
 
 SplitView3DInventor::SplitView3DInventor(int views, Gui::Document* pcDocument, QWidget* parent, Qt::WindowFlags wflags)
   : AbstractSplitView(pcDocument,parent, wflags)
 {
-    QSplitter* mainSplitter=0;
+    // attach parameter Observer
+    hGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View");
+    hGrp->Attach(this);
 
+    //anti-aliasing settings
+    bool smoothing = false;
+    bool glformat = false;
+    int samples = View3DInventorViewer::getNumSamples();
+    QtGLFormat f;
+
+    if (samples > 1) {
+        glformat = true;
+#if !defined(HAVE_QT5_OPENGL)
+        f.setSampleBuffers(true);
+#endif
+        f.setSamples(samples);
+    }
+    else if (samples > 0) {
+        smoothing = true;
+    }
+
+    // minimal 2 views
+    while (views < 2)
+        views ++;
+
+    QSplitter* mainSplitter = 0;
+
+    // if views < 3 show them as a row
     if (views <= 3) {
         mainSplitter = new QSplitter(Qt::Horizontal, this);
-        _viewer.push_back(new View3DInventorViewer(mainSplitter));
-        _viewer.push_back(new View3DInventorViewer(mainSplitter));
-        if (views==3)
-            _viewer.push_back(new View3DInventorViewer(mainSplitter));
+        for (int i=0; i < views; i++) {
+            if (glformat)
+                _viewer.push_back(new View3DInventorViewer(f, mainSplitter));
+            else
+                _viewer.push_back(new View3DInventorViewer(mainSplitter));
+        }
     }
     else {
         mainSplitter = new QSplitter(Qt::Vertical, this);
         QSplitter *topSplitter = new QSplitter(Qt::Horizontal, mainSplitter);
         QSplitter *botSplitter = new QSplitter(Qt::Horizontal, mainSplitter);
-        _viewer.push_back(new View3DInventorViewer(topSplitter));
-        _viewer.push_back(new View3DInventorViewer(topSplitter));
-        for (int i=2;i<views;i++)
-            _viewer.push_back(new View3DInventorViewer(botSplitter));
-        topSplitter->setOpaqueResize( true );
-        botSplitter->setOpaqueResize( true );
+
+        if (glformat) {
+            _viewer.push_back(new View3DInventorViewer(f, topSplitter));
+            _viewer.push_back(new View3DInventorViewer(f, topSplitter));
+        }
+        else {
+            _viewer.push_back(new View3DInventorViewer(topSplitter));
+            _viewer.push_back(new View3DInventorViewer(topSplitter));
+        }
+
+        for (int i=2;i<views;i++) {
+            if (glformat)
+                _viewer.push_back(new View3DInventorViewer(f, botSplitter));
+            else
+                _viewer.push_back(new View3DInventorViewer(botSplitter));
+        }
+
+        topSplitter->setOpaqueResize(true);
+        botSplitter->setOpaqueResize(true);
+    }
+
+    if (smoothing) {
+        for (std::vector<int>::size_type i = 0; i != _viewer.size(); i++)
+            _viewer[i]->getSoRenderManager()->getGLRenderAction()->setSmoothing(true);
     }
 
     mainSplitter->show();
