@@ -29,6 +29,7 @@
 # include <QByteArray>
 # include <QDateTime>
 # include <QImage>
+# include <QThread>
 #endif
 
 #include <QtOpenGL.h>
@@ -78,7 +79,7 @@ void Thumbnail::Save (Base::Writer &writer) const
 
 void Thumbnail::Restore(Base::XMLReader &reader)
 {
-    Q_UNUSED(reader); 
+    Q_UNUSED(reader);
     //reader.addFile("Thumbnail.png",this);
 }
 
@@ -88,17 +89,28 @@ void Thumbnail::SaveDocFile (Base::Writer &writer) const
         return;
     QImage img;
     if (this->viewer->isActiveWindow()) {
+        if (this->viewer->thread() != QThread::currentThread()) {
+            qWarning("Cannot create a thumbnail from non-GUI thread");
+            return;
+        }
+
         QColor invalid;
         this->viewer->imageFromFramebuffer(this->size, this->size, 0, invalid, img);
     }
 
-    QPixmap px = Gui::BitmapFactory().pixmap(App::Application::Config()["AppIcon"].c_str());
+    // Get app icon and resize to half size to insert in topbottom position over the current view snapshot
+    QPixmap appIcon = Gui::BitmapFactory().pixmap(App::Application::Config()["AppIcon"].c_str());
+    QPixmap px =  appIcon;
     if (!img.isNull()) {
         if (App::GetApplication().GetParameterGroupByPath
-            ("User parameter:BaseApp/Preferences/Document")->GetBool("AddThumbnailLogo",true))
-            px = BitmapFactory().merge(QPixmap::fromImage(img),px,BitmapFactoryInst::BottomRight);
-        else
+            ("User parameter:BaseApp/Preferences/Document")->GetBool("AddThumbnailLogo",true)) {
+            // only scale app icon if an offscreen image could be created
+            appIcon =  appIcon.scaled(this->size / 4, this->size /4);
+            px = BitmapFactory().merge(QPixmap::fromImage(img), appIcon, BitmapFactoryInst::BottomRight);
+        }
+        else {
             px = QPixmap::fromImage(img);
+        }
     }
 
     if (!px.isNull()) {
@@ -120,5 +132,5 @@ void Thumbnail::SaveDocFile (Base::Writer &writer) const
 
 void Thumbnail::RestoreDocFile(Base::Reader &reader)
 {
-    Q_UNUSED(reader); 
+    Q_UNUSED(reader);
 }
