@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) 2004 Juergen Riegel <juergen.riegel@web.de>             *
+ *   Copyright (c) 2004 Jürgen Riegel <juergen.riegel@web.de>              *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -30,6 +30,7 @@
 #include <vector>
 
 #include <Base/Type.h>
+#include <Base/Placement.h>
 #include <Inventor/nodes/SoEventCallback.h>
 #include <Inventor/nodes/SoSwitch.h>
 #include <Inventor/SbRotation.h>
@@ -38,11 +39,11 @@
 #include <QImage>
 
 #include <Gui/Selection.h>
+#include <Gui/Namespace.h>
 
 class SoTranslation;
 class SoTransform;
 class SoText2;
-namespace Quarter = SIM::Coin3D::Quarter;
 
 class SoSeparator;
 class SoShapeHints;
@@ -52,9 +53,13 @@ class SbSphereSheetProjector;
 class SoEventCallback;
 class SbBox2s;
 class SoVectorizeAction;
-class QGLFramebufferObject;
 class QImage;
 class SoGroup;
+class SoPickStyle;
+class NaviCube;
+class SoClipPlane;
+
+namespace Quarter = SIM::Coin3D::Quarter;
 
 namespace Gui {
 
@@ -63,7 +68,6 @@ class SoFCBackgroundGradient;
 class NavigationStyle;
 class SoFCUnifiedSelection;
 class Document;
-class SoFCUnifiedSelection;
 class GLGraphicsItem;
 class SoShapeScale;
 class ViewerEventFilter;
@@ -71,10 +75,10 @@ class ViewerEventFilter;
 /** GUI view into a 3D scene provided by View3DInventor
  *
  */
-class GuiExport View3DInventorViewer : public Quarter::SoQTQuarterAdaptor, public Gui::SelectionSingleton::ObserverType
+class GuiExport View3DInventorViewer : public Quarter::SoQTQuarterAdaptor, public SelectionObserver
 {
     typedef Quarter::SoQTQuarterAdaptor inherited;
-    
+
 public:
     /// Pick modes for picking points in the scene
     enum SelectionMode {
@@ -85,24 +89,24 @@ public:
         Clip        = 4,  /**< Clip objects using a lasso. */
     };
     /** @name Modus handling of the viewer
-      * Here the you can switch on/off several features
-      * and modies of the Viewer
+      * Here you can switch several features on/off
+      * and modes of the Viewer
       */
     //@{
     enum ViewerMod {
         ShowCoord=1,       /**< Enables the Coordinate system in the corner. */
         ShowFPS  =2,       /**< Enables the Frams per Second counter. */
         SimpleBackground=4,/**< switch to a simple background. */
-        DisallowRotation=8,/**< switch of the rotation. */
-        DisallowPanning=16,/**< switch of the panning. */
-        DisallowZooming=32,/**< switch of the zooming. */
+        DisallowRotation=8,/**< switch off the rotation. */
+        DisallowPanning=16,/**< switch off the panning. */
+        DisallowZooming=32,/**< switch off the zooming. */
     };
     //@}
-    
+
     /** @name Anti-Aliasing modes of the rendered 3D scene
       * Specifies Anti-Aliasing (AA) method
-      * - Smoothing enables OpenGL line and vertex smoothing (basicly depreciated)
-      * - MSAA is hardware multi sampling (with 2, 4 or 8 passes), a quite commom and efficient AA technique
+      * - Smoothing enables OpenGL line and vertex smoothing (basically deprecated)
+      * - MSAA is hardware multi sampling (with 2, 4 or 8 passes), a quite common and efficient AA technique
       */
     //@{
     enum AntiAliasing {
@@ -124,20 +128,22 @@ public:
     };
     //@}
 
-    View3DInventorViewer (QWidget *parent, const QGLWidget* sharewidget = 0);
-    View3DInventorViewer (const QGLFormat& format, QWidget *parent, const QGLWidget* sharewidget = 0);
+    View3DInventorViewer (QWidget *parent, const QtGLWidget* sharewidget = 0);
+    View3DInventorViewer (const QtGLFormat& format, QWidget *parent, const QtGLWidget* sharewidget = 0);
     virtual ~View3DInventorViewer();
-    
+
     void init();
 
     /// Observer message from the Selection
-    virtual void OnChange(Gui::SelectionSingleton::SubjectType &rCaller,
-                          Gui::SelectionSingleton::MessageType Reason);
+    virtual void onSelectionChanged(const SelectionChanges &Reason);
+    void checkGroupOnTop(const SelectionChanges &Reason);
+    void clearGroupOnTop();
 
     SoDirectionalLight* getBacklight(void) const;
     void setBacklight(SbBool on);
     SbBool isBacklight(void) const;
     void setSceneGraph (SoNode *root);
+    SbBool searchNode(SoNode*) const;
 
     void setAnimationEnabled(const SbBool enable);
     SbBool isAnimationEnabled(void) const;
@@ -155,8 +161,14 @@ public:
     void setFeedbackSize(const int size);
     int getFeedbackSize(void) const;
 
+    /// Get the preferred samples from the user settings
+    static int getNumSamples();
     void setRenderType(const RenderType type);
-    void renderToFramebuffer(QGLFramebufferObject*);
+    RenderType getRenderType() const;
+    void renderToFramebuffer(QtGLFramebufferObject*);
+    QImage grabFramebuffer();
+    void imageFromFramebuffer(int width, int height, int samples,
+                              const QColor& bgcolor, QImage& img);
 
     virtual void setViewing(SbBool enable);
     virtual void setCursorEnabled(SbBool enable);
@@ -169,7 +181,12 @@ public:
 
     /** @name Handling of view providers */
     //@{
+    /// Checks if the view provider is a top-level object of the scene
     SbBool hasViewProvider(ViewProvider*) const;
+    /// Checks if the view provider is part of the scene.
+    /// In contrast to hasViewProvider() this method also checks if the view
+    /// provider is a child of another view provider
+    SbBool containsViewProvider(const ViewProvider*) const;
     /// adds an ViewProvider to the view, e.g. from a feature
     void addViewProvider(ViewProvider*);
     /// remove a ViewProvider
@@ -180,28 +197,39 @@ public:
     /// get all view providers of given type
     std::vector<ViewProvider*> getViewProvidersOfType(const Base::Type& typeId) const;
     /// set the ViewProvider in special edit mode
-    SbBool setEditingViewProvider(Gui::ViewProvider* p, int ModNum=0);
+    void setEditingViewProvider(Gui::ViewProvider* p, int ModNum);
     /// return whether a view provider is edited
     SbBool isEditingViewProvider() const;
     /// reset from edit mode
     void resetEditingViewProvider();
+    void setupEditingRoot(SoNode *node=0, const Base::Matrix4D *mat=0);
+    void resetEditingRoot(bool updateLinks=true);
+    void setEditingTransform(const Base::Matrix4D &mat);
+    /** Helper method to get picked entities while editing.
+     * It's in the responsibility of the caller to delete the returned instance.
+     */
+    SoPickedPoint* getPointOnRay(const SbVec2s& pos, ViewProvider* vp) const;
+    /** Helper method to get picked entities while editing.
+     * It's in the responsibility of the caller to delete the returned instance.
+     */
+    SoPickedPoint* getPointOnRay(const SbVec3f& pos, const SbVec3f& dir, ViewProvider* vp) const;
     /// display override mode
     void setOverrideMode(const std::string &mode);
     void updateOverrideMode(const std::string &mode);
-    std::string getOverrideMode() {return overrideMode;}
+    std::string getOverrideMode() const {return overrideMode;}
     //@}
 
     /** @name Making pictures */
     //@{
     /**
      * Creates an image with width \a w and height \a h of the current scene graph
-     * and exports the rendered scenegraph to an image.
+     * using a multi-sampling of \a s and exports the rendered scenegraph to an image.
      */
-    void savePicture(int w, int h, const QColor&, QImage&) const;
+    void savePicture(int w, int h, int s, const QColor&, QImage&) const;
     void saveGraphic(int pagesize, const QColor&, SoVectorizeAction* va) const;
     //@}
     /**
-     * Writes the current scenegraph to an Inventor file, either in ascii or binary. 
+     * Writes the current scenegraph to an Inventor file, either in ascii or binary.
      */
     bool dumpToFile(SoNode* node, const char* filename, bool binary) const;
 
@@ -210,11 +238,13 @@ public:
     void startSelection(SelectionMode = Lasso);
     void stopSelection();
     bool isSelecting() const;
-    std::vector<SbVec2f> getGLPolygon(SbBool* clip_inner=0) const;
+    std::vector<SbVec2f> getGLPolygon(SelectionRole* role=0) const;
     std::vector<SbVec2f> getGLPolygon(const std::vector<SbVec2s>&) const;
-    const std::vector<SbVec2s>& getPolygon(SbBool* clip_inner=0) const;
+    const std::vector<SbVec2s>& getPolygon(SelectionRole* role=0) const;
+    void setSelectionEnabled(const SbBool enable);
+    SbBool isSelectionEnabled(void) const;
     //@}
-    
+
     /// Returns the screen coordinates of the origin of the path's tail object
     /*! Return value is in floating-point pixels, origin at bottom-left. */
     SbVec2f screenCoordsOfPath(SoPath *path) const;
@@ -242,8 +272,8 @@ public:
     //@}
 
     /**
-     * Set up a callback function \a cb which will be invoked for the given eventtype. 
-     * \a userdata will be given as the first argument to the callback function. 
+     * Set up a callback function \a cb which will be invoked for the given eventtype.
+     * \a userdata will be given as the first argument to the callback function.
      */
     void addEventCallback(SoType eventtype, SoEventCallbackCB * cb, void* userdata = 0);
     /**
@@ -262,7 +292,7 @@ public:
     /** Returns the up direction */
     SbVec3f getUpDirection() const;
     /** Returns the orientation of the camera. */
-    SbRotation getCameraOrientation() const; 
+    SbRotation getCameraOrientation() const;
     /** Returns the 3d point on the focal plane to the given 2d point. */
     SbVec3f getPointOnScreen(const SbVec2s&) const;
     /** Returns the near plane represented by its normal and base point. */
@@ -270,7 +300,8 @@ public:
     /** Returns the far plane represented by its normal and base point. */
     void getFarPlane(SbVec3f& rcPt, SbVec3f& rcNormal) const;
     /** Adds or remove a manipulator to/from the scenegraph. */
-    void toggleClippingPlane();
+    void toggleClippingPlane(int toggle=-1, bool beforeEditing=false,
+            bool noManip=false, const Base::Placement &pla = Base::Placement());
     /** Checks whether a clipping plane is set or not. */
     bool hasClippingPlane() const;
     /** Project the given normalized 2d point onto the near plane */
@@ -278,7 +309,7 @@ public:
     /** Project the given normalized 2d point onto the far plane */
     SbVec3f projectOnFarPlane(const SbVec2f&) const;
     //@}
-    
+
     /** @name Dimension controls
      * the "turn*" functions are wired up to parameter groups through view3dinventor.
      * don't call them directly. instead set the parameter groups.
@@ -304,8 +335,8 @@ public:
     void setCameraOrientation(const SbRotation& rot, SbBool moveTocenter=false);
     void setCameraType(SoType t);
     void moveCameraTo(const SbRotation& rot, const SbVec3f& pos, int steps, int ms);
-    /** 
-     * Zooms the viewport to the size of the bounding box. 
+    /**
+     * Zooms the viewport to the size of the bounding box.
      */
     void boxZoom(const SbBox2s&);
     /**
@@ -318,7 +349,7 @@ public:
     void viewVR(void);
 
     /**
-     * Reposition the current camera so we can see all selected objects 
+     * Reposition the current camera so we can see all selected objects
      * of the scene. Therefore we search for all SOFCSelection nodes, if
      * none of them is selected nothing happens.
      */
@@ -335,16 +366,25 @@ public:
 
     void setAxisCross(bool b);
     bool hasAxisCross(void);
-    
+
     void setEnabledFPSCounter(bool b);
+    void setEnabledNaviCube(bool b);
+    bool isEnabledNaviCube(void) const;
+    void setNaviCubeCorner(int);
+    NaviCube* getNavigationCube() const;
+    void setEnabledVBO(bool b);
+    bool isEnabledVBO() const;
+    void setRenderCache(int);
 
     NavigationStyle* navigationStyle() const;
 
     void setDocument(Gui::Document *pcDocument);
-    
+    Gui::Document* getDocument();
+
     virtual PyObject *getPyObject(void);
 
 protected:
+    GLenum getInternalTextureFormat() const;
     void renderScene();
     void renderFramebuffer();
     void renderGLImage();
@@ -353,13 +393,17 @@ protected:
     virtual void setSeekMode(SbBool enable);
     virtual void afterRealizeHook(void);
     virtual bool processSoEvent(const SoEvent * ev);
+    void dropEvent (QDropEvent * e);
+    void dragEnterEvent (QDragEnterEvent * e);
+    void dragMoveEvent(QDragMoveEvent *e);
+    void dragLeaveEvent(QDragLeaveEvent *e);
     SbBool processSoEventBase(const SoEvent * const ev);
     void printDimension();
     void selectAll();
 
     enum eWinGestureTuneState{
         ewgtsDisabled, //suppress tuning/re-tuning after errors
-        ewgtsNeedTuning, //gestures are to be retuned upon next event
+        ewgtsNeedTuning, //gestures are to be re-tuned upon next event
         ewgtsTuned
     };
     eWinGestureTuneState winGestureTuneState;//See ViewerEventFilter::eventFilter function for explanation
@@ -381,9 +425,11 @@ private:
     void drawAxisCross(void);
     static void drawArrow(void);
     void setCursorRepresentation(int mode);
-
+    void aboutToDestroyGLContext();
+    void createStandardCursors(double);
 
 private:
+    NaviCube* naviCube;
     std::set<ViewProvider*> _ViewProviderSet;
     std::map<SoSeparator*,ViewProvider*> _ViewProviderMap;
     std::list<GLGraphicsItem*> graphicsItems;
@@ -394,13 +440,26 @@ private:
     SoDirectionalLight* backlight;
 
     SoSeparator * pcViewProviderRoot;
+
+    SoGroup * pcGroupOnTop;
+    SoGroup * pcGroupOnTopSel;
+    SoGroup * pcGroupOnTopPreSel;
+    std::map<std::string,SoNode*> objectsOnTop;
+    std::map<std::string,SoNode*> objectsOnTopPreSel;
+
+    SoSeparator * pcEditingRoot;
+    SoTransform * pcEditingTransform;
+    bool restoreEditingRoot;
     SoEventCallback* pEventCallback;
     NavigationStyle* navigation;
     SoFCUnifiedSelection* selectionRoot;
 
+    SoClipPlane *pcClipPlane;
+
     RenderType renderType;
-    QGLFramebufferObject* framebuffer;
+    QtGLFramebufferObject* framebuffer;
     QImage glImage;
+    SbBool shading;
     SoSwitch *dimensionRoot;
 
     // small axis cross in the corner
@@ -409,10 +468,11 @@ private:
     // big one in the middle
     SoShapeScale* axisCross;
     SoGroup* axisGroup;
-    
+
     //stuff needed to draw the fps counter
     bool fpsEnabled;
-    SoSeparator* fpsRoot;
+    bool vboEnabled;
+    SbBool naviCubeEnabled;
 
     SbBool editing;
     QCursor editCursor, zoomCursor, panCursor, spinCursor;
@@ -420,9 +480,10 @@ private:
     SbBool allowredir;
 
     std::string overrideMode;
-    
+    Gui::Document* guiDocument = nullptr;
+
     ViewerEventFilter* viewerEventFilter;
-    
+
     PyObject *_viewerPy;
 
     // friends
@@ -434,4 +495,3 @@ private:
 } // namespace Gui
 
 #endif  // GUI_VIEW3DINVENTORVIEWER_H
-
