@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) Jürgen Riegel          (juergen.riegel@web.de) 2002     *
+ *   Copyright (c) 2002 Jürgen Riegel <juergen.riegel@web.de>              *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -41,6 +41,7 @@
 #include "Application.h"
 #include "Document.h"
 #include "NavigationStyle.h"
+#include "SoMouseWheelEvent.h"
 #include "SoFCSelectionAction.h"
 #include "SoFCOffscreenRenderer.h"
 #include "SoFCVectorizeSVGAction.h"
@@ -50,6 +51,7 @@
 #include "View3DInventorViewer.h"
 #include "View3DViewerPy.h"
 #include "ActiveObjectList.h"
+#include "WidgetFactory.h"
 
 
 #include <Base/Console.h>
@@ -64,6 +66,7 @@
 #include <App/Document.h>
 #include <App/DocumentObject.h>
 #include <App/DocumentObjectPy.h>
+#include <App/GeoFeature.h>
 #include <CXX/Objects.hxx>
 
 using namespace Gui;
@@ -93,7 +96,16 @@ void View3DInventorPy::init_type()
     add_varargs_method("viewIsometric",&View3DInventorPy::viewIsometric,"viewIsometric()");
     add_varargs_method("viewDimetric",&View3DInventorPy::viewDimetric,"viewDimetric()");
     add_varargs_method("viewTrimetric",&View3DInventorPy::viewTrimetric,"viewTrimetric()");
-    add_varargs_method("viewDefaultOrientation",&View3DInventorPy::viewDefaultOrientation,"viewDefaultOrientation()");
+    add_varargs_method("viewDefaultOrientation",&View3DInventorPy::viewDefaultOrientation,
+                       "viewDefaultOrientation(ori_str = '', scale = -1.0): sets camera rotation to a predefined one, \n"
+                       "and camera position and zoom to show certain amount of model space. \n"
+                       "ori_string can be 'Top', 'Bottom', 'Front', 'Rear', 'Left', 'Right', \n"
+                       "'Isometric', 'Dimetric', 'Trimetric', 'Custom'. If empty, the value is \n"
+                       "fetched from Parameters.\n"
+                       "scale sets distance from camera to origin, and height of the screen in \n"
+                       "model space, so that a sphere of diameter <scale> fits the height of the\n"
+                       "viewport. If zero, scaling is not done. If negative, the value is \n"
+                       "fetched from Parameters.");
     add_varargs_method("viewRotateLeft",&View3DInventorPy::viewRotateLeft,"viewRotateLeft()");
     add_varargs_method("viewRotateRight",&View3DInventorPy::viewRotateRight,"viewRotateRight()");
     add_varargs_method("zoomIn",&View3DInventorPy::zoomIn,"zoomIn()");
@@ -103,7 +115,7 @@ void View3DInventorPy::init_type()
     add_varargs_method("stopAnimating",&View3DInventorPy::stopAnimating,"stopAnimating()");
     add_varargs_method("setAnimationEnabled",&View3DInventorPy::setAnimationEnabled,"setAnimationEnabled()");
     add_varargs_method("isAnimationEnabled",&View3DInventorPy::isAnimationEnabled,"isAnimationEnabled()");
-    add_varargs_method("dump",&View3DInventorPy::dump,"dump()");
+    add_varargs_method("dump",&View3DInventorPy::dump,"dump(filename, [onlyVisible=False])");
     add_varargs_method("dumpNode",&View3DInventorPy::dumpNode,"dumpNode(node)");
     add_varargs_method("setStereoType",&View3DInventorPy::setStereoType,"setStereoType()");
     add_varargs_method("getStereoType",&View3DInventorPy::getStereoType,"getStereoType()");
@@ -178,11 +190,22 @@ void View3DInventorPy::init_type()
         "Remove the DraggerCalback function from the coin node\n"
         "Possibles types :\n"
         "'addFinishCallback','addStartCallback','addMotionCallback','addValueChangedCallback'\n");
-    add_varargs_method("setActiveObject", &View3DInventorPy::setActiveObject, "setActiveObject(name,object)\nadd or set a new active object");
-    add_varargs_method("getActiveObject", &View3DInventorPy::getActiveObject, "getActiveObject(name)\nreturns the active object for the given type");
+    add_varargs_method("setActiveObject", &View3DInventorPy::setActiveObject, "setActiveObject(name,object,subname=None)\nadd or set a new active object");
+    add_varargs_method("getActiveObject", &View3DInventorPy::getActiveObject, "getActiveObject(name,resolve=True)\nreturns the active object for the given type");
     add_varargs_method("getViewProvidersOfType", &View3DInventorPy::getViewProvidersOfType, "getViewProvidersOfType(name)\nreturns a list of view providers for the given type");
     add_varargs_method("redraw", &View3DInventorPy::redraw, "redraw(): renders the scene on screen (useful for animations)");
-
+    add_varargs_method("setName",&View3DInventorPy::setName,"setName(str): sets a name to this viewer\nThe name sets the widget's windowTitle and appears on the viewer tab");
+    add_keyword_method("toggleClippingPlane", &View3DInventorPy::toggleClippingPlane,
+        "toggleClippingPlane(toggle=-1, beforeEditing=False, noManip=True, pla=App.Placement()\n"
+        "Toggle a global clipping plane\n\n"
+        "toggle: -1 toggle, 1 show, 0 hide\n"
+        "beforeEditing: whether to insert the clipping node before or after editing root node\n"
+        "noManip: whether to create a manipulator\n"
+        "pla: clipping plane placement");
+    add_varargs_method("hasClippingPlane",&View3DInventorPy::hasClippingPlane,
+        "hasClippingPlane(): check whether this clipping plane is active");
+    add_varargs_method("graphicsView",&View3DInventorPy::graphicsView,
+        "graphicsView(): Access this view as QGraphicsView");
 }
 
 View3DInventorPy::View3DInventorPy(View3DInventor *vi)
@@ -272,7 +295,7 @@ Py::Object View3DInventorPy::message(const Py::Tuple& args)
 {
     const char **ppReturn = 0;
     char *psMsgStr;
-    if (!PyArg_ParseTuple(args.ptr(), "s;Message string needed (string)",&psMsgStr))     // convert args: Python->C 
+    if (!PyArg_ParseTuple(args.ptr(), "s;Message string needed (string)",&psMsgStr))     // convert args: Python->C
         throw Py::Exception();
 
     try {
@@ -394,7 +417,7 @@ SbRotation Camera::rotation(Camera::Orientation view)
     case Top:
         return SbRotation(0, 0, 0, 1);
     case Bottom:
-        return SbRotation(0, 1, 0, 0);
+        return SbRotation(1, 0, 0, 0);
     case Front: {
         float root = (float)(sqrt(2.0)/2.0);
         return SbRotation(root, 0, 0, root);
@@ -629,7 +652,8 @@ Py::Object View3DInventorPy::viewTrimetric(const Py::Tuple& args)
 Py::Object View3DInventorPy::viewDefaultOrientation(const Py::Tuple& args)
 {
     char* view = nullptr;
-    if (!PyArg_ParseTuple(args.ptr(), "|s", &view))
+    double scale = -1.0;
+    if (!PyArg_ParseTuple(args.ptr(), "|sd", &view, &scale))
         throw Py::Exception();
 
     try {
@@ -640,7 +664,7 @@ Py::Object View3DInventorPy::viewDefaultOrientation(const Py::Tuple& args)
         }
         else {
             ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View");
-            newDocView = hGrp->GetASCII("NewDocumentCameraOrientation", "Top");
+            newDocView = hGrp->GetASCII("NewDocumentCameraOrientation", "Trimetric");
         }
 
         if (newDocView == "Top") {
@@ -679,7 +703,29 @@ Py::Object View3DInventorPy::viewDefaultOrientation(const Py::Tuple& args)
             rot.setValue(q0, q1, q2, q3);
         }
 
-        _view->getViewer()->setCameraOrientation(rot);
+        SoCamera* cam = _view->getViewer()->getCamera();
+        cam->orientation = rot;
+
+        if (scale < 0.0){
+            ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View");
+            scale = hGrp->GetFloat("NewDocumentCameraScale",100.0);
+        }
+        if (scale > 1e-7) {
+            double f = 0.0; //focal dist
+            if (cam->isOfType(SoOrthographicCamera::getClassTypeId())){
+                static_cast<SoOrthographicCamera*>(cam)->height = scale;
+                f = scale;
+            } else if (cam->isOfType(SoPerspectiveCamera::getClassTypeId())){
+                //nothing to do
+                double ang = static_cast<SoPerspectiveCamera*>(cam)->heightAngle.getValue();
+                f = 0.5 * scale / sin(ang * 0.5);
+            }
+            SbVec3f lookDir;
+            rot.multVec(SbVec3f(0,0,-1), lookDir);
+            SbVec3f pos = lookDir * -f;
+            cam->focalDistance = f;
+            cam->position = pos;
+        }
     }
     catch (const Base::Exception& e) {
         throw Py::RuntimeError(e.what());
@@ -911,8 +957,9 @@ Py::Object View3DInventorPy::saveImage(const Py::Tuple& args)
 {
     char *cFileName,*cColor="Current",*cComment="$MIBA";
     int w=-1,h=-1;
+    int s=View3DInventorViewer::getNumSamples();
 
-    if (!PyArg_ParseTuple(args.ptr(), "et|iiss","utf-8",&cFileName,&w,&h,&cColor,&cComment))
+    if (!PyArg_ParseTuple(args.ptr(), "et|iissi","utf-8",&cFileName,&w,&h,&cColor,&cComment,&s))
         throw Py::Exception();
 
     std::string encodedName = std::string(cFileName);
@@ -930,7 +977,7 @@ Py::Object View3DInventorPy::saveImage(const Py::Tuple& args)
         bg.setNamedColor(colname);
 
     QImage img;
-    _view->getViewer()->savePicture(w, h, 8, bg, img);
+    _view->getViewer()->savePicture(w, h, s, bg, img);
 
     SoFCOffscreenRenderer& renderer = SoFCOffscreenRenderer::instance();
     SoCamera* cam = _view->getViewer()->getSoRenderManager()->getCamera();
@@ -1053,8 +1100,8 @@ Py::Object View3DInventorPy::getViewDirection(const Py::Tuple& args)
 Py::Object View3DInventorPy::setViewDirection(const Py::Tuple& args)
 {
     PyObject* object;
-    if (!PyArg_ParseTuple(args.ptr(), "O", &object)) 
-        throw Py::Exception(); 
+    if (!PyArg_ParseTuple(args.ptr(), "O", &object))
+        throw Py::Exception();
 
     try {
         if (PyTuple_Check(object)) {
@@ -1135,7 +1182,7 @@ Py::Object View3DInventorPy::getCameraType(const Py::Tuple& args)
 Py::Object View3DInventorPy::setCameraType(const Py::Tuple& args)
 {
     int cameratype=-1;
-    if (!PyArg_ParseTuple(args.ptr(), "i", &cameratype)) {    // convert args: Python->C 
+    if (!PyArg_ParseTuple(args.ptr(), "i", &cameratype)) {    // convert args: Python->C
         char* modename;
         PyErr_Clear();
         if (!PyArg_ParseTuple(args.ptr(), "s", &modename))
@@ -1190,11 +1237,12 @@ Py::Object View3DInventorPy::listCameraTypes(const Py::Tuple& args)
 Py::Object View3DInventorPy::dump(const Py::Tuple& args)
 {
     char* filename;
-    if (!PyArg_ParseTuple(args.ptr(), "s", &filename))
+    PyObject *onlyVisible = Py_False;
+    if (!PyArg_ParseTuple(args.ptr(), "s|O", &filename, &onlyVisible))
         throw Py::Exception();
 
     try {
-        _view->dump(filename);
+        _view->dump(filename, PyObject_IsTrue(onlyVisible));
         return Py::None();
     }
     catch (const Base::Exception& e) {
@@ -1211,7 +1259,7 @@ Py::Object View3DInventorPy::dump(const Py::Tuple& args)
 Py::Object View3DInventorPy::dumpNode(const Py::Tuple& args)
 {
     PyObject* object;
-    if (!PyArg_ParseTuple(args.ptr(), "O", &object))     // convert args: Python->C 
+    if (!PyArg_ParseTuple(args.ptr(), "O", &object))     // convert args: Python->C
         throw Py::Exception();
 
     void* ptr = 0;
@@ -1339,7 +1387,7 @@ Py::Object View3DInventorPy::getObjectInfo(const Py::Tuple& args)
     try {
         //Note: For gcc (4.2) we need the 'const' keyword to avoid the compiler error:
         //conversion from 'Py::seqref<Py::Object>' to non-scalar type 'Py::Int' requested
-        //We should report this problem to the PyCXX project as in the documentation an 
+        //We should report this problem to the PyCXX project as in the documentation an
         //example without the 'const' keyword is used.
         //Or we can also write Py::Int x(tuple[0]);
         const Py::Tuple tuple(object);
@@ -1365,19 +1413,41 @@ Py::Object View3DInventorPy::getObjectInfo(const Py::Tuple& args)
             dict.setItem("z", Py::Float(pt[2]));
 
             Gui::Document* doc = _view->getViewer()->getDocument();
-            ViewProvider *vp = doc ? doc->getViewProviderByPathFromTail(Point->getPath())
-                    : _view->getViewer()->getViewProviderByPathFromTail(Point->getPath());
-            if (vp && vp->isDerivedFrom(ViewProviderDocumentObject::getClassTypeId())) {
+            ViewProvider *vp = doc ? doc->getViewProviderByPathFromHead(Point->getPath())
+                    : _view->getViewer()->getViewProviderByPath(Point->getPath());
+            if(vp && vp->isDerivedFrom(ViewProviderDocumentObject::getClassTypeId())) {
+                if(!vp->isSelectable())
+                    return ret;
                 ViewProviderDocumentObject* vpd = static_cast<ViewProviderDocumentObject*>(vp);
-                dict.setItem("Document",
-                    Py::String(vpd->getObject()->getDocument()->getName()));
-                dict.setItem("Object",
-                    Py::String(vpd->getObject()->getNameInDocument()));
-                if (vp->useNewSelectionModel()) {
-                    dict.setItem("Component",
-                        Py::String(vpd->getElement(Point->getDetail())));
-                }
-                else {
+                if(vp->useNewSelectionModel()) {
+                    std::string subname;
+                    if(!vp->getElementPicked(Point,subname))
+                        return ret;
+                    auto obj = vpd->getObject();
+                    if(!obj)
+                        return ret;
+                    if(subname.size()) {
+                        std::pair<std::string,std::string> elementName;
+                        auto sobj = App::GeoFeature::resolveElement(obj,subname.c_str(),elementName);
+                        if(!sobj)
+                            return ret;
+                        if(sobj!=obj) {
+                            dict.setItem("ParentObject",Py::Object(obj->getPyObject(),true));
+                            dict.setItem("SubName",Py::String(subname));
+                            obj = sobj;
+                        }
+                        subname = elementName.second.size()?elementName.second:elementName.first;
+                    }
+                    dict.setItem("Document",
+                        Py::String(obj->getDocument()->getName()));
+                    dict.setItem("Object",
+                        Py::String(obj->getNameInDocument()));
+                    dict.setItem("Component",Py::String(subname));
+                } else {
+                    dict.setItem("Document",
+                        Py::String(vpd->getObject()->getDocument()->getName()));
+                    dict.setItem("Object",
+                        Py::String(vpd->getObject()->getNameInDocument()));
                     // search for a SoFCSelection node
                     SoFCDocumentObjectAction objaction;
                     objaction.apply(Point->getPath());
@@ -1424,7 +1494,7 @@ Py::Object View3DInventorPy::getObjectsInfo(const Py::Tuple& args)
     try {
         //Note: For gcc (4.2) we need the 'const' keyword to avoid the compiler error:
         //conversion from 'Py::seqref<Py::Object>' to non-scalar type 'Py::Int' requested
-        //We should report this problem to the PyCXX project as in the documentation an 
+        //We should report this problem to the PyCXX project as in the documentation an
         //example without the 'const' keyword is used.
         //Or we can also write Py::Int x(tuple[0]);
         const Py::Tuple tuple(object);
@@ -1454,19 +1524,41 @@ Py::Object View3DInventorPy::getObjectsInfo(const Py::Tuple& args)
                 dict.setItem("y", Py::Float(pt[1]));
                 dict.setItem("z", Py::Float(pt[2]));
 
-                ViewProvider *vp = doc ? doc->getViewProviderByPathFromTail(point->getPath())
-                        : _view->getViewer()->getViewProviderByPathFromTail(point->getPath());
-                if (vp && vp->isDerivedFrom(ViewProviderDocumentObject::getClassTypeId())) {
+                ViewProvider *vp = doc ? doc->getViewProviderByPathFromHead(point->getPath())
+                        : _view->getViewer()->getViewProviderByPath(point->getPath());
+                if(vp && vp->isDerivedFrom(ViewProviderDocumentObject::getClassTypeId())) {
+                    if(!vp->isSelectable())
+                        continue;
                     ViewProviderDocumentObject* vpd = static_cast<ViewProviderDocumentObject*>(vp);
-                    dict.setItem("Document",
-                        Py::String(vpd->getObject()->getDocument()->getName()));
-                    dict.setItem("Object",
-                        Py::String(vpd->getObject()->getNameInDocument()));
-                    if (vp->useNewSelectionModel()) {
-                        dict.setItem("Component",
-                            Py::String(vpd->getElement(point->getDetail())));
-                    }
-                    else {
+                    if(vp->useNewSelectionModel()) {
+                        std::string subname;
+                        if(!vp->getElementPicked(point,subname))
+                            continue;
+                        auto obj = vpd->getObject();
+                        if(!obj)
+                            continue;
+                        if(subname.size()) {
+                            std::pair<std::string,std::string> elementName;
+                            auto sobj = App::GeoFeature::resolveElement(obj,subname.c_str(),elementName);
+                            if(!sobj)
+                                continue;
+                            if(sobj!=obj) {
+                                dict.setItem("ParentObject",Py::Object(obj->getPyObject(),true));
+                                dict.setItem("SubName",Py::String(subname));
+                                obj = sobj;
+                            }
+                            subname = elementName.second.size()?elementName.second:elementName.first;
+                        }
+                        dict.setItem("Document",
+                            Py::String(obj->getDocument()->getName()));
+                        dict.setItem("Object",
+                            Py::String(obj->getNameInDocument()));
+                        dict.setItem("Component",Py::String(subname));
+                    } else {
+                        dict.setItem("Document",
+                            Py::String(vpd->getObject()->getDocument()->getName()));
+                        dict.setItem("Object",
+                            Py::String(vpd->getObject()->getNameInDocument()));
                         // search for a SoFCSelection node
                         SoFCDocumentObjectAction objaction;
                         objaction.apply(point->getPath());
@@ -1904,6 +1996,10 @@ void View3DInventorPy::eventCallback(void * ud, SoEventCallback * n)
 
             dict.setItem("Button", Py::String(button));
         }
+        if (e->isOfType(SoMouseWheelEvent::getClassTypeId())){
+            const SoMouseWheelEvent* mwe = static_cast<const SoMouseWheelEvent*>(e);
+            dict.setItem("Delta", Py::Long(mwe->getDelta()));
+        }
         if (e->isOfType(SoSpaceballButtonEvent::getClassTypeId())) {
             const SoSpaceballButtonEvent* sbe = static_cast<const SoSpaceballButtonEvent*>(e);
             std::string button;
@@ -2191,7 +2287,7 @@ Py::Object View3DInventorPy::addEventCallbackPivy(const Py::Tuple& args)
             throw Py::TypeError("object is not callable");
         }
 
-        SoEventCallbackCB* callback = (ex == 1 ? 
+        SoEventCallbackCB* callback = (ex == 1 ?
             View3DInventorPy::eventCallbackPivyEx :
             View3DInventorPy::eventCallbackPivy);
         _view->getViewer()->addEventCallback(*eventId, callback, method);
@@ -2233,7 +2329,7 @@ Py::Object View3DInventorPy::removeEventCallbackPivy(const Py::Tuple& args)
             throw Py::TypeError("object is not callable");
         }
 
-        SoEventCallbackCB* callback = (ex == 1 ? 
+        SoEventCallbackCB* callback = (ex == 1 ?
             View3DInventorPy::eventCallbackPivyEx :
             View3DInventorPy::eventCallbackPivy);
         _view->getViewer()->removeEventCallback(*eventId, callback, method);
@@ -2396,37 +2492,43 @@ Py::Object View3DInventorPy::removeDraggerCallback(const Py::Tuple& args)
 
 Py::Object View3DInventorPy::setActiveObject(const Py::Tuple& args)
 {
-    PyObject* docObject = 0;
-    char* name;
+	PyObject* docObject = Py_None;
+	char* name;
+    char *subname = 0;
+    if (!PyArg_ParseTuple(args.ptr(), "s|Os", &name, &docObject, &subname))
+		throw Py::Exception();
 
-    //allow reset of active object by setting "None"
-    if (args.length() == 2 && args.back() == Py::None()) {
-        PyArg_Parse(args.front().ptr(), "s", &name);
-        _view->setActiveObject(NULL, name);
-        return Py::None();
-    }
-
-    if (!PyArg_ParseTuple(args.ptr(), "sO!", &name, &App::DocumentObjectPy::Type, &docObject))
-        throw Py::Exception();
-
-    if (docObject){
-        App::DocumentObject* obj = static_cast<App::DocumentObjectPy*>(docObject)->getDocumentObjectPtr();
-        _view->setActiveObject(obj, name);
-    }
-    return Py::None();
+	if (docObject == Py_None)
+		_view->setActiveObject(0, name);
+    else{
+        if(!PyObject_TypeCheck(docObject, &App::DocumentObjectPy::Type))
+            throw Py::TypeError("Expect the second argument to be a document object or None");
+		App::DocumentObject* obj = static_cast<App::DocumentObjectPy*>(docObject)->getDocumentObjectPtr();
+		_view->setActiveObject(obj, name, subname);
+	}
+	return Py::None();
 }
 
 Py::Object View3DInventorPy::getActiveObject(const Py::Tuple& args)
 {
     char* name;
-    if (!PyArg_ParseTuple(args.ptr(), "s", &name))
-        throw Py::Exception();
+    PyObject *resolve = Py_True;
+    if (!PyArg_ParseTuple(args.ptr(), "s|O", &name,&resolve))
+                throw Py::Exception();
 
-    App::DocumentObject* obj = _view->getActiveObject<App::DocumentObject*>(name);
+    App::DocumentObject *parent = 0;
+    std::string subname;
+    App::DocumentObject* obj = _view->getActiveObject<App::DocumentObject*>(name,&parent,&subname);
     if(!obj)
         return Py::None();
 
-    return Py::Object(obj->getPyObject());
+    if(PyObject_IsTrue(resolve))
+        return Py::asObject(obj->getPyObject());
+
+    return Py::TupleN(
+            Py::asObject(obj->getPyObject()),
+            Py::asObject(parent->getPyObject()),
+            Py::String(subname.c_str()));
 }
 
 Py::Object View3DInventorPy::getViewProvidersOfType(const Py::Tuple& args)
@@ -2451,3 +2553,60 @@ Py::Object View3DInventorPy::redraw(const Py::Tuple& args)
     _view->getViewer()->redraw();
     return Py::None();
 }
+
+Py::Object View3DInventorPy::setName(const Py::Tuple& args)
+{
+    char* buffer;
+    if (!PyArg_ParseTuple(args.ptr(), "s", &buffer))
+        throw Py::Exception();
+
+    try {
+        _view->setWindowTitle(QString::fromUtf8(buffer));
+        return Py::None();
+    }
+    catch (const Base::Exception& e) {
+        throw Py::RuntimeError(e.what());
+    }
+    catch (const std::exception& e) {
+        throw Py::RuntimeError(e.what());
+    }
+    catch(...) {
+        throw Py::RuntimeError("Unknown C++ exception");
+    }
+}
+
+Py::Object View3DInventorPy::toggleClippingPlane(const Py::Tuple& args, const Py::Dict& kwds)
+{
+    static char* keywords[] = {"toggle", "beforeEditing", "noManip", "pla", NULL};
+    int toggle = -1;
+    PyObject *beforeEditing = Py_False;
+    PyObject *noManip = Py_True;
+    PyObject *pyPla = Py_None;
+    if (!PyArg_ParseTupleAndKeywords(args.ptr(), kwds.ptr(), "|iOOO!", keywords,
+                    &toggle, &beforeEditing, &noManip, &Base::PlacementPy::Type,&pyPla))
+        throw Py::Exception();
+
+    Base::Placement pla;
+    if(pyPla!=Py_None)
+        pla = *static_cast<Base::PlacementPy*>(pyPla)->getPlacementPtr();
+    _view->getViewer()->toggleClippingPlane(toggle,PyObject_IsTrue(beforeEditing),
+            PyObject_IsTrue(noManip),pla);
+    return Py::None();
+}
+
+Py::Object View3DInventorPy::hasClippingPlane(const Py::Tuple& args)
+{
+    if (!PyArg_ParseTuple(args.ptr(), ""))
+        throw Py::Exception();
+    return Py::Boolean(_view->getViewer()->hasClippingPlane());
+}
+
+Py::Object View3DInventorPy::graphicsView(const Py::Tuple& args)
+{
+    if (!PyArg_ParseTuple(args.ptr(), ""))
+        throw Py::Exception();
+
+    PythonWrapper wrap;
+    wrap.loadWidgetsModule();
+    return wrap.fromQWidget(_view->getViewer(), "QGraphicsView");
+}
