@@ -45,6 +45,7 @@
 #include "Application.h"
 #include "Document.h"
 #include "View3DInventorViewer.h"
+#include "ViewParams.h"
 
 #include <App/PropertyGeo.h>
 #include <App/PropertyStandard.h>
@@ -58,7 +59,7 @@ using namespace Gui;
 PROPERTY_SOURCE(Gui::ViewProviderMeasureDistance, Gui::ViewProviderDocumentObject)
 
 
-ViewProviderMeasureDistance::ViewProviderMeasureDistance() 
+ViewProviderMeasureDistance::ViewProviderMeasureDistance()
 {
     ADD_PROPERTY(TextColor,(1.0f,1.0f,1.0f));
     ADD_PROPERTY(LineColor,(1.0f,1.0f,1.0f));
@@ -170,7 +171,8 @@ void ViewProviderMeasureDistance::attach(App::DocumentObject* pcObject)
     lineSep->addChild(pCoords);
     lineSep->addChild(pLines);
     SoMarkerSet* points = new SoMarkerSet();
-    points->markerIndex = Gui::Inventor::MarkerBitmaps::getMarkerIndex("CROSS", App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View")->GetInt("MarkerSize", 9));
+    points->markerIndex = Gui::Inventor::MarkerBitmaps::getMarkerIndex("CROSS",
+            ViewParams::instance()->getMarkerSize());
     points->numPoints=2;
     lineSep->addChild(points);
 
@@ -263,7 +265,7 @@ int PointMarker::countPoints() const
 void PointMarker::customEvent(QEvent*)
 {
     Gui::Document* doc = Gui::Application::Instance->activeDocument();
-    doc->openCommand("Measure distance");
+    doc->openCommand(QT_TRANSLATE_NOOP("Command", "Measure distance"));
     App::DocumentObject* obj = doc->getDocument()->addObject
         (App::MeasureDistance::getClassTypeId().getName(),"Distance");
 
@@ -289,7 +291,8 @@ ViewProviderPointMarker::ViewProviderPointMarker()
     pCoords->ref();
     pCoords->point.setNum(0);
     pMarker = new SoMarkerSet();
-    pMarker->markerIndex = Gui::Inventor::MarkerBitmaps::getMarkerIndex("CROSS", App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View")->GetInt("MarkerSize", 9));
+    pMarker->markerIndex = Gui::Inventor::MarkerBitmaps::getMarkerIndex("CROSS",
+            ViewParams::instance()->getMarkerSize());
     pMarker->numPoints=0;
     pMarker->ref();
 
