@@ -51,9 +51,13 @@
 # pragma clang diagnostic push
 # pragma clang diagnostic ignored "-Wmismatched-tags"
 # pragma clang diagnostic ignored "-Wunused-parameter"
+# if __clang_major__ > 3
+# pragma clang diagnostic ignored "-Wkeyword-macro"
+# endif
 #elif defined (__GNUC__)
 # pragma GCC diagnostic push
 # pragma GCC diagnostic ignored "-Wunused-parameter"
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 #endif
 
 #ifdef HAVE_SHIBOKEN
@@ -67,8 +71,8 @@
 # ifdef HAVE_PYSIDE
 # include <pyside_qtcore_python.h>
 # include <pyside_qtgui_python.h>
-PyTypeObject** SbkPySide_QtCoreTypes=NULL;
-PyTypeObject** SbkPySide_QtGuiTypes=NULL;
+PyTypeObject** SbkPySide_QtCoreTypes=nullptr;
+PyTypeObject** SbkPySide_QtGuiTypes=nullptr;
 # endif
 #endif
 
@@ -82,15 +86,28 @@ PyTypeObject** SbkPySide_QtGuiTypes=NULL;
 # include <shiboken.h>
 # ifdef HAVE_PYSIDE2
 # define HAVE_PYSIDE
+
+// Since version 5.12 shiboken offers a method to get wrapper by class name (typeForTypeName)
+// This helps to avoid to include the PySide2 headers since MSVC has a compiler bug when
+// compiling together with std::bitset (https://bugreports.qt.io/browse/QTBUG-72073)
+
+// Do not use SHIBOKEN_MICRO_VERSION; it might contain a dot
+# define SHIBOKEN_FULL_VERSION QT_VERSION_CHECK(SHIBOKEN_MAJOR_VERSION, SHIBOKEN_MINOR_VERSION, 0)
+# if (SHIBOKEN_FULL_VERSION >= QT_VERSION_CHECK(5, 12, 0))
+# define HAVE_SHIBOKEN_TYPE_FOR_TYPENAME
+# endif
+
+# ifndef HAVE_SHIBOKEN_TYPE_FOR_TYPENAME
 # include <pyside2_qtcore_python.h>
 # include <pyside2_qtgui_python.h>
 # include <pyside2_qtwidgets_python.h>
-# include <signalmanager.h>
-PyTypeObject** SbkPySide2_QtCoreTypes=NULL;
-PyTypeObject** SbkPySide2_QtGuiTypes=NULL;
-PyTypeObject** SbkPySide2_QtWidgetsTypes=NULL;
 # endif
-#endif
+# include <signalmanager.h>
+PyTypeObject** SbkPySide2_QtCoreTypes=nullptr;
+PyTypeObject** SbkPySide2_QtGuiTypes=nullptr;
+PyTypeObject** SbkPySide2_QtWidgetsTypes=nullptr;
+# endif // HAVE_PYSIDE2
+#endif // HAVE_SHIBOKEN2
 
 #if defined(__clang__)
 # pragma clang diagnostic pop
@@ -274,6 +291,22 @@ void* qt_getCppPointer(const Py::Object& pyobject, const char* shiboken, const c
     void* ptr = PyLong_AsVoidPtr(result[0].ptr());
     return ptr;
 }
+
+
+template<typename qttype>
+PyTypeObject *getPyTypeObjectForTypeName()
+{
+#if defined (HAVE_SHIBOKEN) && defined(HAVE_PYSIDE)
+#if defined (HAVE_SHIBOKEN_TYPE_FOR_TYPENAME)
+    SbkObjectType* sbkType = Shiboken::ObjectType::typeForTypeName(typeid(qttype).name());
+    if (sbkType)
+        return &(sbkType->type);
+#else
+    return Shiboken::SbkType<qttype>();
+#endif
+#endif
+    return nullptr;
+}
 }
 
 // --------------------------------------------------------
@@ -326,7 +359,7 @@ QObject* PythonWrapper::toQObject(const Py::Object& pyobject)
 {
     // http://pastebin.com/JByDAF5Z
 #if defined (HAVE_SHIBOKEN) && defined(HAVE_PYSIDE)
-    PyTypeObject * type = Shiboken::SbkType<QObject>();
+    PyTypeObject * type = getPyTypeObjectForTypeName<QObject>();
     if (type) {
         if (Shiboken::Object::checkType(pyobject.ptr())) {
             SbkObject* sbkobject = reinterpret_cast<SbkObject *>(pyobject.ptr());
@@ -354,11 +387,36 @@ QObject* PythonWrapper::toQObject(const Py::Object& pyobject)
     return 0;
 }
 
+QGraphicsItem* PythonWrapper::toQGraphicsItem(PyObject* pyPtr)
+{
+#if defined (HAVE_SHIBOKEN) && defined(HAVE_PYSIDE)
+    PyTypeObject* type = getPyTypeObjectForTypeName<QObject>();
+    if (type) {
+        if (Shiboken::Object::checkType(pyPtr)) {
+            SbkObject* sbkobject = reinterpret_cast<SbkObject*>(pyPtr);
+            void* cppobject = Shiboken::Object::cppPointer(sbkobject, type);
+            return reinterpret_cast<QGraphicsItem*>(cppobject);
+        }
+    }
+#elif QT_VERSION >= 0x050000
+    // Access shiboken2/PySide2 via Python
+    //
+    void* ptr = qt_getCppPointer(Py::asObject(pyPtr), "shiboken2", "getCppPointer");
+    return reinterpret_cast<QGraphicsItem*>(ptr);
+#else
+    // Access shiboken/PySide via Python
+    //
+    void* ptr = qt_getCppPointer(Py::asObject(pyPtr), "shiboken", "getCppPointer");
+    return reinterpret_cast<QGraphicsItem*>(ptr);
+#endif
+    return nullptr;
+}
+
 Py::Object PythonWrapper::fromQIcon(const QIcon* icon)
 {
 #if defined (HAVE_SHIBOKEN) && defined(HAVE_PYSIDE)
     const char* typeName = typeid(*const_cast<QIcon*>(icon)).name();
-    PyObject* pyobj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QIcon>()),
+    PyObject* pyobj = Shiboken::Object::newObject(reinterpret_cast<SbkObjectType*>(getPyTypeObjectForTypeName<QIcon>()),
                               const_cast<QIcon*>(icon), true, false, typeName);
     if (pyobj)
         return Py::asObject(pyobj);
@@ -374,12 +432,67 @@ Py::Object PythonWrapper::fromQIcon(const QIcon* icon)
     throw Py::RuntimeError("Failed to wrap icon");
 }
 
+QIcon *PythonWrapper::toQIcon(PyObject *pyobj)
+{
+#if defined (HAVE_SHIBOKEN) && defined(HAVE_PYSIDE)
+    PyTypeObject * type = getPyTypeObjectForTypeName<QIcon>();
+    if(type) {
+        if (Shiboken::Object::checkType(pyobj)) {
+            SbkObject* sbkobject = reinterpret_cast<SbkObject *>(pyobj);
+            void* cppobject = Shiboken::Object::cppPointer(sbkobject, type);
+            return reinterpret_cast<QIcon*>(cppobject);
+        }
+    }
+#else
+    Q_UNUSED(pyobj);
+#endif
+    return 0;
+}
+
+Py::Object PythonWrapper::fromQObject(QObject* object, const char* className)
+{
+#if defined (HAVE_SHIBOKEN) && defined(HAVE_PYSIDE)
+    // Access shiboken/PySide via C++
+    //
+    PyTypeObject * type = getPyTypeObjectForTypeName<QObject>();
+    if (type) {
+        SbkObjectType* sbk_type = reinterpret_cast<SbkObjectType*>(type);
+        std::string typeName;
+        if (className)
+            typeName = className;
+        else
+            typeName = object->metaObject()->className();
+        PyObject* pyobj = Shiboken::Object::newObject(sbk_type, object, false, false, typeName.c_str());
+        return Py::asObject(pyobj);
+    }
+    throw Py::RuntimeError("Failed to wrap object");
+
+#elif QT_VERSION >= 0x050000
+    // Access shiboken2/PySide2 via Python
+    //
+    return qt_wrapInstance<QObject*>(object, className, "shiboken2", "PySide2.QtCore", "wrapInstance");
+#else
+    // Access shiboken/PySide via Python
+    //
+    return qt_wrapInstance<QObject*>(object, className, "shiboken", "PySide.QtCore", "wrapInstance");
+#endif
+
+#if 0 // Unwrapping using sip/PyQt
+    Q_UNUSED(className);
+#if QT_VERSION >= 0x050000
+    return qt_wrapInstance<QObject*>(object, "QObject", "sip", "PyQt5.QtCore", "wrapinstance");
+#else
+    return qt_wrapInstance<QObject*>(object, "QObject", "sip", "PyQt4.Qt", "wrapinstance");
+#endif
+#endif
+}
+
 Py::Object PythonWrapper::fromQWidget(QWidget* widget, const char* className)
 {
 #if defined (HAVE_SHIBOKEN) && defined(HAVE_PYSIDE)
     // Access shiboken/PySide via C++
     //
-    PyTypeObject * type = Shiboken::SbkType<QWidget>();
+    PyTypeObject * type = getPyTypeObjectForTypeName<QWidget>();
     if (type) {
         SbkObjectType* sbk_type = reinterpret_cast<SbkObjectType*>(type);
         std::string typeName;
@@ -504,7 +617,7 @@ void PythonWrapper::createChildrenNameAttributes(PyObject* root, QObject* object
             bool hasAttr = PyObject_HasAttrString(root, name.constData());
             if (!hasAttr) {
 #if defined (HAVE_SHIBOKEN) && defined(HAVE_PYSIDE)
-                Shiboken::AutoDecRef pyChild(Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject>()), child));
+                Shiboken::AutoDecRef pyChild(Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType*>(getPyTypeObjectForTypeName<QObject>()), child));
                 PyObject_SetAttrString(root, name.constData(), pyChild);
 #elif QT_VERSION >= 0x050000
                 const char* className = qt_identifyType(child, "PySide2.QtWidgets");
@@ -540,7 +653,7 @@ void PythonWrapper::setParent(PyObject* pyWdg, QObject* parent)
 {
 #if defined (HAVE_SHIBOKEN) && defined(HAVE_PYSIDE)
     if (parent) {
-        Shiboken::AutoDecRef pyParent(Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QWidget>()), parent));
+        Shiboken::AutoDecRef pyParent(Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType*>(getPyTypeObjectForTypeName<QWidget>()), parent));
         Shiboken::Object::setParent(pyParent, pyWdg);
     }
 #else
@@ -569,7 +682,7 @@ void WidgetFactoryInst::destruct ()
 
 /**
  * Creates a widget with the name \a sName which is a child of \a parent.
- * To create an instance of this widget once it must has been registered. 
+ * To create an instance of this widget once it must has been registered.
  * If there is no appropriate widget registered 0 is returned.
  */
 QWidget* WidgetFactoryInst::createWidget (const char* sName, QWidget* parent) const
@@ -611,7 +724,7 @@ QWidget* WidgetFactoryInst::createWidget (const char* sName, QWidget* parent) co
 
 /**
  * Creates a widget with the name \a sName which is a child of \a parent.
- * To create an instance of this widget once it must has been registered. 
+ * To create an instance of this widget once it must has been registered.
  * If there is no appropriate widget registered 0 is returned.
  */
 Gui::Dialog::PreferencePage* WidgetFactoryInst::createPreferencePage (const char* sName, QWidget* parent) const
@@ -649,9 +762,9 @@ Gui::Dialog::PreferencePage* WidgetFactoryInst::createPreferencePage (const char
 }
 
 /**
- * Creates a preference widget with the name \a sName and the preference name \a sPref 
+ * Creates a preference widget with the name \a sName and the preference name \a sPref
  * which is a child of \a parent.
- * To create an instance of this widget once it must has been registered. 
+ * To create an instance of this widget once it must has been registered.
  * If there is no appropriate widget registered 0 is returned.
  * After creation of this widget its recent preferences are restored automatically.
  */
@@ -709,13 +822,13 @@ Py::Object PySideUicModule::loadUiType(const Py::Tuple& args)
     QString cmd;
     QTextStream str(&cmd);
     // https://github.com/albop/dolo/blob/master/bin/load_ui.py
-#if defined(HAVE_PYSIDE2)
+#if QT_VERSION >= 0x050000
     str << "import pyside2uic\n"
         << "from PySide2 import QtCore, QtGui, QtWidgets\n"
         << "import xml.etree.ElementTree as xml\n"
         << "try:\n"
         << "    from cStringIO import StringIO\n"
-        << "except:\n"
+        << "except Exception:\n"
         << "    from io import StringIO\n"
         << "\n"
         << "uiFile = \"" << file.c_str() << "\"\n"
@@ -737,7 +850,7 @@ Py::Object PySideUicModule::loadUiType(const Py::Tuple& args)
         << "import xml.etree.ElementTree as xml\n"
         << "try:\n"
         << "    from cStringIO import StringIO\n"
-        << "except:\n"
+        << "except Exception:\n"
         << "    from io import StringIO\n"
         << "\n"
         << "uiFile = \"" << file.c_str() << "\"\n"
@@ -811,7 +924,7 @@ Py::Object PySideUicModule::loadUi(const Py::Tuple& args)
         << "loader = UiLoader(globals()[\"base_\"])\n"
         << "widget = loader.load(globals()[\"uiFile_\"])\n"
         << "\n";
-#elif defined(HAVE_PYSIDE2)
+#elif QT_VERSION >= 0x050000
     str << "from PySide2 import QtCore, QtGui, QtWidgets\n"
         << "import FreeCADGui"
         << "\n"
@@ -1321,7 +1434,7 @@ void PyResource::load(const char* name)
 /**
  * Makes a connection between the sender widget \a sender and its signal \a signal
  * of the created resource and Python callback function \a cb.
- * If the sender widget does not exist or no resource has been loaded this method returns false, 
+ * If the sender widget does not exist or no resource has been loaded this method returns false,
  * otherwise it returns true.
  */
 bool PyResource::connect(const char* sender, const char* signal, PyObject* cb)
@@ -1602,7 +1715,11 @@ void SignalConnect::onExecute()
 
     /* Time to call the callback */
     arglist = Py_BuildValue("(O)", myResource);
+#if PY_VERSION_HEX < 0x03090000
     result = PyEval_CallObject(myCallback, arglist);
+#else
+    result = PyObject_CallObject(myCallback, arglist);
+#endif
     Py_XDECREF(result);
     Py_DECREF(arglist);
 }
