@@ -32,8 +32,10 @@
 #include <QPushButton>
 #include <QPlainTextEdit>
 #include <QBasicTimer>
-#include <QTime>
+#include <QElapsedTimer>
 #include <QToolButton>
+#include <QModelIndex>
+#include "ExpressionBinding.h"
 
 namespace Gui {
 class PrefCheckBox;
@@ -177,7 +179,7 @@ class GuiExport CheckListDialog : public QDialog
   Q_OBJECT
 
 public:
-  CheckListDialog( QWidget* parent = 0, Qt::WindowFlags fl = 0 );
+  CheckListDialog( QWidget* parent = 0, Qt::WindowFlags fl = Qt::WindowFlags() );
   ~CheckListDialog();
 
   void setCheckableItems( const QStringList& items );
@@ -246,7 +248,7 @@ private:
 
 /**
  * A text label where a url can specified. When the user clicks on the text label the system browser
- * gets opened with the specified url. 
+ * gets opened with the specified url.
  *
  * This can be used for e.g. in the about dialog where the url of the maintainer of an application
  * can be specified.
@@ -258,7 +260,7 @@ class GuiExport UrlLabel : public QLabel
   Q_PROPERTY( QString  url    READ url   WRITE setUrl)
 
 public:
-  UrlLabel ( QWidget * parent = 0, Qt::WindowFlags f = 0 );
+  UrlLabel ( QWidget * parent = 0, Qt::WindowFlags f = Qt::WindowFlags() );
   virtual ~UrlLabel();
 
   QString url() const;
@@ -349,12 +351,12 @@ private:
     QPoint pos;
     QPointer<QWidget> w; // need guard in case widget gets destroyed
     QBasicTimer tooltipTimer;
-    QTime displayTime;
+    QElapsedTimer displayTime;
 };
 
 // ----------------------------------------------------------------------
 
-class GuiExport StatusWidget : public QWidget
+class GuiExport StatusWidget : public QDialog
 {
     Q_OBJECT
 
@@ -368,7 +370,6 @@ public:
 protected:
     void showEvent(QShowEvent*);
     void hideEvent(QHideEvent*);
-    void adjustPosition(QWidget* w);
 
 private:
     QLabel* label;
@@ -413,7 +414,7 @@ public:
     LabelEditor (QWidget * parent = 0);
     virtual ~LabelEditor();
 
-    /** 
+    /**
     * Returns the text.
     */
     QString text() const;
@@ -449,6 +450,33 @@ private:
     QPushButton *button;
 };
 
+/**
+ * The ExpLineEdit class provides a lineedit that support expressing binding.
+ * \author realthunder
+ */
+class GuiExport ExpLineEdit : public QLineEdit, public ExpressionBinding
+{
+    Q_OBJECT
+
+public:
+    ExpLineEdit ( QWidget * parent=0, bool expressionOnly=false );
+
+    void setExpression(boost::shared_ptr<App::Expression> expr);
+    void bind(const App::ObjectIdentifier &_path);
+    bool apply(const std::string &propName);
+
+    void keyPressEvent(QKeyEvent *event);
+    void resizeEvent(QResizeEvent *event);
+
+private Q_SLOTS:
+    void finishFormulaDialog();
+    void openFormulaDialog();
+    virtual void onChange();
+
+private:
+    bool autoClose;
+};
+
 } // namespace Gui
 
 #endif // GUI_WIDGETS_H
