@@ -1,7 +1,5 @@
 #***************************************************************************
-#*                                                                         *
-#*   Copyright (c) 2011                                                    *
-#*   Yorik van Havre <yorik@uncreated.net>                                 *
+#*   Copyright (c) 2011 Yorik van Havre <yorik@uncreated.net>              *
 #*                                                                         *
 #*   This program is free software; you can redistribute it and/or modify  *
 #*   it under the terms of the GNU Lesser General Public License (LGPL)    *
@@ -21,7 +19,9 @@
 #*                                                                         *
 #***************************************************************************
 
-import FreeCAD,Draft,math,DraftVecUtils,ArchCommands,sys
+import six
+
+import FreeCAD,Draft,math,DraftVecUtils,ArchCommands
 from FreeCAD import Vector
 if FreeCAD.GuiUp:
     import FreeCADGui
@@ -37,9 +37,9 @@ else:
         return txt
     # \endcond
 
-__title__="FreeCAD Axis System"
+__title__  = "FreeCAD Axis System"
 __author__ = "Yorik van Havre"
-__url__ = "http://www.freecadweb.org"
+__url__    = "https://www.freecadweb.org"
 
 ## @package ArchAxis
 #  \ingroup ARCH
@@ -246,10 +246,10 @@ class _Axis:
             obj.Shape = sh
             obj.Placement = pl
 
-    #def onChanged(self,obj,prop):
+    def onChanged(self,obj,prop):
 
-    #    if prop in ["Angles","Distances","Placement"]:
-    #        self.execute(obj)
+        if prop in ["Angles","Distances","Placement"]:
+            obj.touch()
 
     def __getstate__(self):
 
@@ -461,7 +461,7 @@ class _ViewProviderAxis:
                                     cin = coin.SoInput()
                                     cin.setBuffer(buf)
                                     cob = coin.SoDB.readAll(cin)
-                                except:
+                                except Exception:
                                     import re
                                     # workaround for pivy SoInput.setBuffer() bug
                                     buf = buf.replace("\n","")
@@ -492,7 +492,7 @@ class _ViewProviderAxis:
                                     if vobj.FontName:
                                         try:
                                             fn = str(vobj.FontName)
-                                        except:
+                                        except Exception:
                                             pass
                                 fo.name = fn
                                 fo.size = fs
@@ -544,7 +544,7 @@ class _ViewProviderAxis:
                                 tx = coin.SoAsciiText()
                                 tx.justification = coin.SoText2.LEFT
                                 t = vobj.Object.Labels[i]
-                                if sys.version_info.major < 3 and isinstance(t,unicode):
+                                if six.PY2 and isinstance(t,six.text_type):
                                     t = t.encode("utf8")
                                 tx.string.setValue(t)
                                 if hasattr(vobj,"FontSize"):
@@ -560,7 +560,7 @@ class _ViewProviderAxis:
                                     if vobj.FontName:
                                         try:
                                             fn = str(vobj.FontName)
-                                        except:
+                                        except Exception:
                                             pass
                                 fo.name = fn
                                 fo.size = fs
@@ -577,7 +577,7 @@ class _ViewProviderAxis:
                ('C',100),('XC',90),('L',50),('XL',40),
                ('X',10),('IX',9),('V',5),('IV',4),('I',1))
         if hasattr(vobj.Object,"CustomNumber") and vobj.Object.CustomNumber:
-            if sys.version_info.major < 3:
+            if six.PY2:
                 return vobj.Object.CustomNumber.encode("utf8")
             else:
                 return vobj.Object.CustomNumber
@@ -754,7 +754,7 @@ class _AxisTaskPanel:
         l = []
         for i in range(self.tree.topLevelItemCount()):
             it = self.tree.findItems(str(i+1),QtCore.Qt.MatchExactly,0)[0]
-            if (remove == None) or (remove != i):
+            if (remove is None) or (remove != i):
                 if it.text(1):
                     d.append(float(it.text(1)))
                 else:
@@ -1001,8 +1001,9 @@ class AxisSystemTaskPanel:
             return QtGui.QIcon(":/icons/Sketcher_Sketch.svg")
         elif obj.isDerivedFrom("App::DocumentObjectGroup"):
             return QtGui.QApplication.style().standardIcon(QtGui.QStyle.SP_DirIcon)
-        else:
-            return QtGui.QIcon(":/icons/Tree_Part.svg")
+        elif hasattr(obj.ViewObject, "Icon"):
+            return QtGui.QIcon(obj.ViewObject.Icon)
+        return QtGui.QIcon(":/icons/Part_3D_object.svg")
 
     def update(self):
 
