@@ -1,9 +1,6 @@
 # -*- coding: utf8 -*-
-
 #***************************************************************************
-#*                                                                         *
-#*   Copyright (c) 2011                                                    *
-#*   Yorik van Havre <yorik@uncreated.net>                                 *
+#*   Copyright (c) 2011 Yorik van Havre <yorik@uncreated.net>              *
 #*                                                                         *
 #*   This program is free software; you can redistribute it and/or modify  *
 #*   it under the terms of the GNU Lesser General Public License (LGPL)    *
@@ -29,20 +26,21 @@ from FreeCAD import Vector
 if FreeCAD.GuiUp:
     import FreeCADGui
     from PySide import QtGui,QtCore
-    from DraftTools import translate, utf8_decode
+    from draftutils.translate import translate
+    from draftutils.utils import utf8_decode
 else:
     # \cond
     def translate(ctxt,txt):
         return txt
     # \endcond
 
-__title__="FreeCAD Arch Commands"
+__title__  = "FreeCAD Arch Commands"
 __author__ = "Yorik van Havre"
-__url__ = "http://www.freecadweb.org"
+__url__    = "https://www.freecadweb.org"
 
 ## @package ArchCommands
 #  \ingroup ARCH
-#  \brief Utility functions for theArch Workbench
+#  \brief Utility functions for the Arch Workbench
 #
 #  This module provides general functions used by Arch tools
 #  and utility commands
@@ -65,7 +63,7 @@ def string_replace(text, pattern, replacement):
     if sys.version_info.major < 3:
         text = text.encode("utf8")
     return text.replace(pattern, replacement)
-    
+
 
 def getStringList(objects):
     '''getStringList(objects): returns a string defining a list
@@ -94,6 +92,8 @@ def getDefaultColor(objectType):
         c = p.GetUnsigned("RebarColor",3111475967)
     elif objectType == "Panel":
         c = p.GetUnsigned("PanelColor",3416289279)
+    elif objectType == "Space":
+        c = p.GetUnsigned("defaultSpaceColor",4278190080)
     elif objectType == "Helpers":
         c = p.GetUnsigned("ColorHelpers",674321151)
     elif objectType == "Construction":
@@ -114,7 +114,7 @@ def addComponents(objectsList,host):
     if not isinstance(objectsList,list):
         objectsList = [objectsList]
     hostType = Draft.getType(host)
-    if hostType in ["Floor","Building","Site","BuildingPart"]:
+    if hostType in ["Floor","Building","Site","Project","BuildingPart"]:
         for o in objectsList:
             host.addObject(o)
     elif hostType in ["Wall","Structure","Window","Roof","Stairs","StructuralSystem","Panel","Component"]:
@@ -123,7 +123,7 @@ def addComponents(objectsList,host):
         if hasattr(host,"Axes"):
             x = host.Axes
         for o in objectsList:
-            if o.isDerivedFrom("Part::Feature"):
+            if hasattr(o,'Shape'):
                 if Draft.getType(o) == "Window":
                     if hasattr(o,"Hosts"):
                         if not host in o.Hosts:
@@ -235,7 +235,7 @@ def makeComponent(baseobj=None,name="Component",delete=False):
         ArchComponent.ViewProviderComponent(obj.ViewObject)
     if baseobj:
         import Part
-        if baseobj.isDerivedFrom("Part::Feature"):
+        if hasattr(baseobj,'Shape'):
             obj.Shape = baseobj.Shape
             obj.Placement = baseobj.Placement
             if delete:
@@ -273,6 +273,8 @@ def setAsSubcomponent(obj):
             color = getDefaultColor("Construction")
             if hasattr(obj.ViewObject,"LineColor"):
                 obj.ViewObject.LineColor = color
+            if hasattr(obj.ViewObject, "PointColor"):
+                obj.ViewObject.PointColor = color
             if hasattr(obj.ViewObject,"ShapeColor"):
                 obj.ViewObject.ShapeColor = color
             if hasattr(obj.ViewObject,"Transparency"):
@@ -396,9 +398,10 @@ def closeHole(shape):
     else:
         return solid
 
-def getCutVolume(cutplane,shapes):
-    """getCutVolume(cutplane,shapes): returns a cut face and a cut volume
-    from the given shapes and the given cutting plane"""
+def getCutVolume(cutplane,shapes,clip=False):
+    """getCutVolume(cutplane,shapes,[clip]): returns a cut face and a cut volume
+    from the given shapes and the given cutting plane. If clip is True, the cutvolume will
+    also cut off everything outside the cutplane projection"""
     if not shapes:
         return None,None,None
     if not cutplane.Faces:
@@ -460,6 +463,13 @@ def getCutVolume(cutplane,shapes):
         cutvolume = cutface.extrude(cutnormal)
         cutnormal = cutnormal.negative()
         invcutvolume = cutface.extrude(cutnormal)
+        if clip:
+            extrudedplane = p.extrude(cutnormal)
+            bordervolume = invcutvolume.cut(extrudedplane)
+            cutvolume = cutvolume.fuse(bordervolume)
+            cutvolume = cutvolume.removeSplitter()
+            invcutvolume = extrudedplane
+            cutface = p
         return cutface,cutvolume,invcutvolume
 
 def getShapeFromMesh(mesh,fast=True,tolerance=0.001,flat=False,cut=True):
@@ -474,7 +484,7 @@ def getShapeFromMesh(mesh,fast=True,tolerance=0.001,flat=False,cut=True):
                 pts.append(FreeCAD.Vector(pp[0],pp[1],pp[2]))
             try:
                 f = Part.Face(Part.makePolygon(pts))
-            except:
+            except Exception:
                 print("getShapeFromMesh: error building face from polygon")
                 #pass
             else:
@@ -508,7 +518,7 @@ def getShapeFromMesh(mesh,fast=True,tolerance=0.001,flat=False,cut=True):
                     wires = nwires
                 try:
                     faces.append(makeFace(wires,method=int(cut)+1))
-                except:
+                except Exception:
                     return None
     try:
         se = Part.makeShell(faces)
@@ -674,19 +684,19 @@ def download(url,force=False):
         f = open(filepath,'wb')
         f.write(s)
         f.close()
-    except:
+    except Exception:
         return None
     else:
         return filepath
 
 def check(objectslist,includehidden=False):
     """check(objectslist,includehidden=False): checks if the given objects contain only solids"""
-    objs = Draft.getGroupContents(objectslist)
+    objs = Draft.get_group_contents(objectslist)
     if not includehidden:
         objs = Draft.removeHidden(objs)
     bad = []
     for o in objs:
-        if not o.isDerivedFrom("Part::Feature"):
+        if not hasattr(o,'Shape'):
             bad.append([o,"is not a Part-based object"])
         else:
             s = o.Shape
@@ -734,10 +744,16 @@ def pruneIncluded(objectslist,strict=False):
         if obj.isDerivedFrom("Part::Feature"):
             if not (Draft.getType(obj) in ["Window","Clone","Pipe","Rebar"]):
                 for parent in obj.InList:
-                    if parent.isDerivedFrom("Part::Feature") and not (Draft.getType(parent) in ["Facebinder","Window","Roof"]):
+                    if parent.isDerivedFrom("Part::Feature") and not (Draft.getType(parent) in ["Space","Facebinder","Window","Roof","Clone","Site","Project"]):
                         if not parent.isDerivedFrom("Part::Part2DObject"):
                             # don't consider 2D objects based on arch elements
-                            if hasattr(parent,"CloneOf"):
+                            if hasattr(parent,"Host") and (parent.Host == obj):
+                                pass
+                            elif hasattr(parent,"Hosts") and (obj in parent.Hosts):
+                                pass
+                            elif hasattr(parent,"TypeId") and (parent.TypeId == "Part::Mirroring"):
+                                pass
+                            elif hasattr(parent,"CloneOf"):
                                 if parent.CloneOf:
                                     if parent.CloneOf.Name != obj.Name:
                                         toplevel = False
@@ -750,6 +766,8 @@ def pruneIncluded(objectslist,strict=False):
                             toplevel = True
         if toplevel:
             newlist.append(obj)
+        else:
+            FreeCAD.Console.PrintLog("pruning "+obj.Label+"\n")
     return newlist
 
 def getAllChildren(objectlist):
@@ -822,7 +840,7 @@ def survey(callback=False):
                         newsels.append(o)
                 if newsels:
                     for o in newsels:
-                        if o.Object.isDerivedFrom("Part::Feature"):
+                        if hasattr(o.Object, 'Shape'):
                             n = o.Object.Label
                             showUnit = FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Mod/Arch").GetBool("surveyUnits",True)
                             t = ""
@@ -1170,35 +1188,37 @@ def cleanArchSplitter(objects=None):
     if not isinstance(objects,list):
         objects = [objects]
     for obj in objects:
-        if obj.isDerivedFrom("Part::Feature"):
+        if hasattr(obj,'Shape'):
             if hasattr(obj,"Base"):
                 if obj.Base:
                     print("Attempting to clean splitters from ", obj.Label)
-                    if obj.Base.isDerivedFrom("Part::Feature"):
-                        if not obj.Base.Shape.isNull():
-                            obj.Base.Shape = obj.Base.Shape.removeSplitter()
+                    base = obj.Base.getLinkedObject()
+                    if base.isDerivedFrom("Part::Feature"):
+                        if not base.Shape.isNull():
+                            base.Shape = base.Shape.removeSplitter()
     FreeCAD.ActiveDocument.recompute()
 
 
 def rebuildArchShape(objects=None):
-    """rebuildArchShape([objects]): takes the faces from the base shape of the given (or selected 
+    """rebuildArchShape([objects]): takes the faces from the base shape of the given (or selected
     if objects is None) Arch objects, and tries to rebuild a valid solid from them."""
-    import FreeCAD,FreeCADGui,Part
-    if not objects:
+    import FreeCAD,Part
+    if not objects and FreeCAD.GuiUp:
         objects = FreeCADGui.Selection.getSelection()
     if not isinstance(objects,list):
         objects = [objects]
     for obj in objects:
         success = False
-        if obj.isDerivedFrom("Part::Feature"):
+        if hasattr(obj,'Shape'):
             if hasattr(obj,"Base"):
                 if obj.Base:
                     try:
                         print("Attempting to rebuild ", obj.Label)
-                        if obj.Base.isDerivedFrom("Part::Feature"):
-                            if not obj.Base.Shape.isNull():
+                        base = obj.Base.getLinkedObject()
+                        if base.isDerivedFrom("Part::Feature"):
+                            if not base.Shape.isNull():
                                 faces = []
-                                for f in obj.Base.Shape.Faces:
+                                for f in base.Shape.Faces:
                                     f2 = Part.Face(f.Wires)
                                     #print("rebuilt face: isValid is ", f2.isValid())
                                     faces.append(f2)
@@ -1213,9 +1233,9 @@ def rebuildArchShape(objects=None):
                                                 solid = Part.Solid(solid)
                                             #print("rebuilt solid: isValid is ",solid.isValid())
                                             if solid.isValid():
-                                                obj.Base.Shape = solid
+                                                base.Shape = solid
                                                 success = True
-                    except:
+                    except Exception:
                         pass
         if not success:
             print ("Failed to rebuild a valid solid for object ",obj.Name)
@@ -1223,9 +1243,38 @@ def rebuildArchShape(objects=None):
 
 
 def getExtrusionData(shape,sortmethod="area"):
-    """getExtrusionData(shape,sortmethod): returns a base face and an extrusion vector
-    if this shape can be described as a perpendicular extrusion, or None if not.
-    sortmethod can be "area" (default) or "z"."""
+    """If a shape has been extruded, returns the base face, and extrusion vector.
+
+    Determines if a shape appears to have been extruded from some base face, and
+    extruded at the normal from that base face. IE: it looks like a cuboid.
+    https://en.wikipedia.org/wiki/Cuboid#Rectangular_cuboid
+
+    If this is the case, returns what appears to be the base face, and the vector
+    used to make that extrusion.
+
+    The base face is determined based on the sortmethod parameter, which can either
+    be:
+
+    "area" = Of the faces with the smallest area, the one with the lowest z coordinate.
+    "z" = The face with the lowest z coordinate.
+    a 3D vector = the face which center is closest to the given 3D point
+
+    Parameters
+    ----------
+    shape: <Part.Shape>
+        Shape to examine.
+    sortmethod: {"area", "z"}
+        Which sorting algorithm to use to determine the base face.
+
+    Returns
+    -------
+    Extrusion data: list
+        Two item list containing the base face, and the vector used to create the
+        extrusion. In that order.
+    Failure: None
+        Returns None if the object does not appear to be an extrusion.
+    """
+
     if shape.isNull():
         return None
     if not shape.Solids:
@@ -1267,9 +1316,11 @@ def getExtrusionData(shape,sortmethod="area"):
     if valids:
         if sortmethod == "z":
             valids.sort(key=lambda v: v[0].CenterOfMass.z)
-        else:
+        elif sortmethod == "area":
             # sort by smallest area
             valids.sort(key=lambda v: v[0].Area)
+        else:
+            valids.sort(key=lambda v: (v[0].CenterOfMass.sub(sortmethod)).Length)
         return valids[0]
     return None
 
@@ -1500,20 +1551,6 @@ class _CommandCheck:
                 FreeCADGui.Selection.addSelection(i[0])
 
 
-class _CommandIfcExplorer:
-    "the Arch Ifc Explorer command definition"
-    def GetResources(self):
-        return {'Pixmap'  : 'IFC',
-                'MenuText': QtCore.QT_TRANSLATE_NOOP("Arch_IfcExplorer","Ifc Explorer"),
-                'ToolTip': QtCore.QT_TRANSLATE_NOOP("Arch_Check","Explore the contents of an IFC file")}
-
-    def Activated(self):
-        if hasattr(self,"dialog"):
-            del self.dialog
-        import importIFC
-        self.dialog = importIFC.explore()
-
-
 class _CommandSurvey:
     "the Arch Survey command definition"
     def GetResources(self):
@@ -1661,7 +1698,7 @@ class _ToggleSubs:
             if hasattr(obj, "Subtractions"):
                 for sub in obj.Subtractions:
                     if not (Draft.getType(sub) in ["Window","Roof"]):
-                        if mode == None:
+                        if mode is None:
                             # take the first sub as base
                             mode = sub.ViewObject.isVisible()
                         if mode == True:
@@ -1679,7 +1716,6 @@ if FreeCAD.GuiUp:
     FreeCADGui.addCommand('Arch_RemoveShape',_CommandRemoveShape())
     FreeCADGui.addCommand('Arch_CloseHoles',_CommandCloseHoles())
     FreeCADGui.addCommand('Arch_Check',_CommandCheck())
-    FreeCADGui.addCommand('Arch_IfcExplorer',_CommandIfcExplorer())
     FreeCADGui.addCommand('Arch_Survey',_CommandSurvey())
     FreeCADGui.addCommand('Arch_ToggleIfcBrepFlag',_ToggleIfcBrepFlag())
     FreeCADGui.addCommand('Arch_Component',_CommandComponent())
