@@ -1,7 +1,5 @@
 #***************************************************************************
-#*                                                                         *
-#*   Copyright (c) 2011                                                    *
-#*   Yorik van Havre <yorik@uncreated.net>                                 *
+#*   Copyright (c) 2011 Yorik van Havre <yorik@uncreated.net>              *
 #*                                                                         *
 #*   This program is free software; you can redistribute it and/or modify  *
 #*   it under the terms of the GNU Lesser General Public License (LGPL)    *
@@ -31,6 +29,8 @@ if FreeCAD.GuiUp:
     from PySide import QtCore, QtGui
     from DraftTools import translate
     from PySide.QtCore import QT_TRANSLATE_NOOP
+    import ArchPrecast
+    import draftguitools.gui_trackers as DraftTrackers
 else:
     # \cond
     def translate(ctxt,txt):
@@ -48,9 +48,9 @@ else:
 #  elements that have a structural function, that is, that
 #  support other parts of the building.
 
-__title__="FreeCAD Structure"
+__title__= "FreeCAD Structure"
 __author__ = "Yorik van Havre"
-__url__ = "http://www.freecadweb.org"
+__url__ = "https://www.freecadweb.org"
 
 
 #Reads preset profiles and categorizes them
@@ -73,7 +73,7 @@ def makeStructure(baseobj=None,length=None,width=None,height=None,name="Structur
         return
     p = FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Mod/Arch")
     obj = FreeCAD.ActiveDocument.addObject("Part::FeaturePython","Structure")
-    obj.Label = translate("Arch",name)
+    obj.Label = translate("Arch","Structure")
     _Structure(obj)
     if FreeCAD.GuiUp:
         _ViewProviderStructure(obj.ViewObject)
@@ -88,7 +88,8 @@ def makeStructure(baseobj=None,length=None,width=None,height=None,name="Structur
     if height:
         obj.Height = height
     else:
-        obj.Height = p.GetFloat("StructureHeight",1000)
+        if not length:
+            obj.Height = p.GetFloat("StructureHeight",1000)
     if length:
         obj.Length = length
     else:
@@ -96,10 +97,34 @@ def makeStructure(baseobj=None,length=None,width=None,height=None,name="Structur
             # don't set the length if we have a base object, otherwise the length X height calc
             # gets wrong
             obj.Length = p.GetFloat("StructureLength",100)
+    if baseobj:
+        w = 0
+        h = 0
+        if hasattr(baseobj,"Width") and hasattr(baseobj,"Height"):
+            w = baseobj.Width.Value
+            h = baseobj.Height.Value
+        elif hasattr(baseobj,"Length") and hasattr(baseobj,"Width"):
+            w = baseobj.Length.Value
+            h = baseobj.Width.Value
+        elif hasattr(baseobj,"Length") and hasattr(baseobj,"Height"):
+            w = baseobj.Length.Value
+            h = baseobj.Height.Value
+        if w and h:
+            if length and not height:
+                obj.Width = w
+                obj.Height = h
+            elif height and not length:
+                obj.Width = w
+                obj.Length = h
+
     if not height and not length:
-        obj.IfcRole = "Undefined"
+        obj.IfcType = "Undefined"
+    elif obj.Length > obj.Height:
+        obj.IfcType = "Beam"
+        obj.Label = translate("Arch","Beam")
     elif obj.Height > obj.Length:
-        obj.IfcRole = "Column"
+        obj.IfcType = "Column"
+        obj.Label = translate("Arch","Column")
     return obj
 
 def makeStructuralSystem(objects=[],axes=[],name="StructuralSystem"):
@@ -138,10 +163,36 @@ def makeStructuralSystem(objects=[],axes=[],name="StructuralSystem"):
     else:
         return result
 
+def placeAlongEdge(p1,p2,horizontal=False):
+
+    """placeAlongEdge(p1,p2,[horizontal]): returns a Placement positioned at p1, with Z axis oriented towards p2.
+    If horizontal is True, then the X axis is oriented towards p2, not the Z axis"""
+
+    pl = FreeCAD.Placement()
+    pl.Base = p1
+    up = FreeCAD.Vector(0,0,1)
+    if hasattr(FreeCAD,"DraftWorkingPlane"):
+        up = FreeCAD.DraftWorkingPlane.axis
+    zaxis = p2.sub(p1)
+    yaxis = up.cross(zaxis)
+    if yaxis.Length > 0:
+        xaxis = zaxis.cross(yaxis)
+        if horizontal:
+            pl.Rotation = FreeCAD.Rotation(zaxis,yaxis,xaxis,"ZXY")
+        else:
+            pl.Rotation = FreeCAD.Rotation(xaxis,yaxis,zaxis,"ZXY")
+            pl.Rotation = FreeCAD.Rotation(pl.Rotation.multVec(FreeCAD.Vector(0,0,1)),90).multiply(pl.Rotation)
+    return pl
+
+
 class _CommandStructure:
 
     "the Arch Structure command definition"
 
+    def __init__(self):
+
+        self.beammode = False
+
     def GetResources(self):
 
         return {'Pixmap'  : 'Arch_Structure',
@@ -156,13 +207,18 @@ class _CommandStructure:
     def Activated(self):
 
         p = FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Mod/Arch")
-        self.Length = p.GetFloat("StructureLength",100)
         self.Width = p.GetFloat("StructureWidth",100)
-        self.Height = p.GetFloat("StructureHeight",1000)
+        if self.beammode:
+            self.Height = p.GetFloat("StructureLength",100)
+            self.Length = p.GetFloat("StructureHeight",1000)
+        else:
+            self.Length = p.GetFloat("StructureLength",100)
+            self.Height = p.GetFloat("StructureHeight",1000)
         self.Profile = None
         self.continueCmd = False
         self.bpoint = None
         self.bmode = False
+        self.precastvalues = None
         sel = FreeCADGui.Selection.getSelection()
         if sel:
             st = Draft.getObjectsOfType(sel,"Structure")
@@ -193,43 +249,63 @@ class _CommandStructure:
         # interactive mode
         if hasattr(FreeCAD,"DraftWorkingPlane"):
             FreeCAD.DraftWorkingPlane.setup()
-        import DraftTrackers,ArchPrecast
+
         self.points = []
         self.tracker = DraftTrackers.boxTracker()
         self.tracker.width(self.Width)
         self.tracker.height(self.Height)
         self.tracker.length(self.Length)
+        self.tracker.setRotation(FreeCAD.DraftWorkingPlane.getRotation().Rotation)
         self.tracker.on()
         self.precast = ArchPrecast._PrecastTaskPanel()
         self.dents = ArchPrecast._DentsTaskPanel()
         self.precast.Dents = self.dents
-        FreeCADGui.Snapper.getPoint(callback=self.getPoint,movecallback=self.update,extradlg=[self.taskbox(),self.precast.form,self.dents.form])
+        if self.beammode:
+            title=translate("Arch","First point of the beam")+":"
+        else:
+            title=translate("Arch","Base point of column")+":"
+        FreeCADGui.Snapper.getPoint(callback=self.getPoint,movecallback=self.update,extradlg=[self.taskbox(),self.precast.form,self.dents.form],title=title)
 
     def getPoint(self,point=None,obj=None):
 
         "this function is called by the snapper when it has a 3D point"
 
-        if self.modeb.isChecked() and (self.bpoint == None):
+        self.bmode = self.modeb.isChecked()
+        if point is None:
+            self.tracker.finalize()
+            return
+        if self.bmode and (self.bpoint is None):
             self.bpoint = point
-            FreeCADGui.Snapper.getPoint(callback=self.getPoint,movecallback=self.update,extradlg=[self.taskbox(),self.precast.form,self.dents.form])
+            FreeCADGui.Snapper.getPoint(last=point,callback=self.getPoint,movecallback=self.update,extradlg=[self.taskbox(),self.precast.form,self.dents.form],title=translate("Arch","Next point")+":",mode="line")
             return
         self.tracker.finalize()
-        if point == None:
-            return
+        horiz = True # determines the type of rotation to apply to the final object
         FreeCAD.ActiveDocument.openTransaction(translate("Arch","Create Structure"))
         FreeCADGui.addModule("Arch")
         if self.Profile is not None:
-            if "Precast" in self.Profile:
+            try: # try to update latest precast values - fails if dialog has been destroyed already
+                self.precastvalues = self.precast.getValues()
+            except Exception:
+                pass
+            if ("Precast" in self.Profile) and self.precastvalues:
                 # precast concrete
-                args = self.precast.getValues()
-                args["PrecastType"] = self.Profile.split("_")[1]
-                args["Length"] = self.Length
-                args["Width"] = self.Width
-                args["Height"] = self.Height
+                self.precastvalues["PrecastType"] = self.Profile.split("_")[1]
+                self.precastvalues["Length"] = self.Length
+                self.precastvalues["Width"] = self.Width
+                self.precastvalues["Height"] = self.Height
                 argstring = ""
                 # fix for precast placement, since their (0,0) point is the lower left corner
-                point = FreeCAD.Vector(point.x-self.Length/2,point.y-self.Width/2,point.z)
-                for pair in args.items():
+                if self.bmode:
+                    delta = FreeCAD.Vector(0,0-self.Width/2,0)
+                else:
+                    delta = FreeCAD.Vector(-self.Length/2,-self.Width/2,0)
+                if hasattr(FreeCAD,"DraftWorkingPlane"):
+                    delta = FreeCAD.DraftWorkingPlane.getRotation().multVec(delta)
+                point = point.add(delta)
+                if self.bpoint:
+                    self.bpoint = self.bpoint.add(delta)
+                # build the string definition
+                for pair in self.precastvalues.items():
                     argstring += pair[0].lower() + "="
                     if isinstance(pair[1],str):
                         argstring += '"' + pair[1] + '",'
@@ -240,26 +316,26 @@ class _CommandStructure:
             else:
                 # metal profile
                 FreeCADGui.doCommand('p = Arch.makeProfile('+str(self.Profile)+')')
-                if abs(self.Length - self.Profile[4]) < 0.1: # forgive rounding errors
+                if (abs(self.Length - self.Profile[4]) >= 0.1) or self.bmode: # forgive rounding errors
+                    # horizontal
+                    FreeCADGui.doCommand('s = Arch.makeStructure(p,length='+str(self.Length)+')')
+                    horiz = False
+                else:
                     # vertical
                     FreeCADGui.doCommand('s = Arch.makeStructure(p,height='+str(self.Height)+')')
-                else:
-                    # horizontal
-                    FreeCADGui.doCommand('s = Arch.makeStructure(p,height='+str(self.Length)+')')
-                    if not self.bmode:
-                        FreeCADGui.doCommand('s.Placement.Rotation = FreeCAD.Rotation(-0.5,0.5,-0.5,0.5)')
+                    #if not self.bmode:
+                    #    FreeCADGui.doCommand('s.Placement.Rotation = FreeCAD.Rotation(-0.5,0.5,-0.5,0.5)')
                 FreeCADGui.doCommand('s.Profile = "'+self.Profile[2]+'"')
         else :
             FreeCADGui.doCommand('s = Arch.makeStructure(length='+str(self.Length)+',width='+str(self.Width)+',height='+str(self.Height)+')')
+
+        # calculate rotation
         if self.bmode and self.bpoint:
-            FreeCADGui.doCommand('s.Placement.Base = '+DraftVecUtils.toString(self.bpoint))
+            FreeCADGui.doCommand('s.Placement = Arch.placeAlongEdge('+DraftVecUtils.toString(self.bpoint)+","+DraftVecUtils.toString(point)+","+str(horiz)+")")
         else:
             FreeCADGui.doCommand('s.Placement.Base = '+DraftVecUtils.toString(point))
-        if self.bmode and self.bpoint:
-            rot = FreeCAD.Rotation(Vector(1,0,0),(point.sub(self.bpoint)).normalize())
-            FreeCADGui.doCommand('s.Placement.Rotation=FreeCAD.Rotation'+str(rot.Q))
-        else:
-            FreeCADGui.doCommand('s.Placement.Rotation=s.Placement.Rotation.multiply(FreeCAD.DraftWorkingPlane.getRotation().Rotation)')
+            FreeCADGui.doCommand('s.Placement.Rotation = s.Placement.Rotation.multiply(FreeCAD.DraftWorkingPlane.getRotation().Rotation)')
+
         FreeCADGui.addModule("Draft")
         FreeCADGui.doCommand("Draft.autogroup(s)")
         FreeCAD.ActiveDocument.commitTransaction()
@@ -269,6 +345,8 @@ class _CommandStructure:
 
     def _createItemlist(self, baselist):
 
+        "create nice labels for presets in the task panel"
+
         ilist=[]
         for p in baselist:
             f = FreeCAD.Units.Quantity(p[4],FreeCAD.Units.Length).getUserPreferred()
@@ -285,14 +363,14 @@ class _CommandStructure:
 
         w = QtGui.QWidget()
         ui = FreeCADGui.UiLoader()
-        w.setWindowTitle(translate("Arch","Structure options", utf8_decode=True))
+        w.setWindowTitle(translate("Arch","Structure options"))
         grid = QtGui.QGridLayout(w)
 
         # mode box
-        labelmode = QtGui.QLabel(translate("Arch","Drawing mode:", utf8_decode=True))
-        self.modeb = QtGui.QRadioButton(translate("Arch","Beam", utf8_decode=True))
-        self.modec = QtGui.QRadioButton(translate("Arch","Column", utf8_decode=True))
-        if self.bpoint:
+        labelmode = QtGui.QLabel(translate("Arch","Drawing mode")+":")
+        self.modeb = QtGui.QRadioButton(translate("Arch","Beam"))
+        self.modec = QtGui.QRadioButton(translate("Arch","Column"))
+        if self.bpoint or self.beammode:
             self.modeb.setChecked(True)
         else:
             self.modec.setChecked(True)
@@ -301,14 +379,14 @@ class _CommandStructure:
         grid.addWidget(self.modec,1,1,1,1)
 
         # categories box
-        labelc = QtGui.QLabel(translate("Arch","Category", utf8_decode=True))
-        valuec = QtGui.QComboBox()
-        valuec.addItems([" ","Precast concrete"]+Categories)
+        labelc = QtGui.QLabel(translate("Arch","Category"))
+        self.valuec = QtGui.QComboBox()
+        self.valuec.addItems([" ","Precast concrete"]+Categories)
         grid.addWidget(labelc,2,0,1,1)
-        grid.addWidget(valuec,2,1,1,1)
+        grid.addWidget(self.valuec,2,1,1,1)
 
         # presets box
-        labelp = QtGui.QLabel(translate("Arch","Preset", utf8_decode=True))
+        labelp = QtGui.QLabel(translate("Arch","Preset"))
         self.vPresets = QtGui.QComboBox()
         self.pSelect = [None]
         fpresets = [" "]
@@ -317,34 +395,40 @@ class _CommandStructure:
         grid.addWidget(self.vPresets,3,1,1,1)
 
         # length
-        label1 = QtGui.QLabel(translate("Arch","Length", utf8_decode=True))
+        label1 = QtGui.QLabel(translate("Arch","Length"))
         self.vLength = ui.createWidget("Gui::InputField")
-        self.vLength.setText(FreeCAD.Units.Quantity(self.Length,FreeCAD.Units.Length).UserString)
+        if self.modeb.isChecked():
+            self.vLength.setText(FreeCAD.Units.Quantity(self.Height,FreeCAD.Units.Length).UserString)
+        else:
+            self.vLength.setText(FreeCAD.Units.Quantity(self.Length,FreeCAD.Units.Length).UserString)
         grid.addWidget(label1,4,0,1,1)
         grid.addWidget(self.vLength,4,1,1,1)
 
         # width
-        label2 = QtGui.QLabel(translate("Arch","Width", utf8_decode=True))
+        label2 = QtGui.QLabel(translate("Arch","Width"))
         self.vWidth = ui.createWidget("Gui::InputField")
         self.vWidth.setText(FreeCAD.Units.Quantity(self.Width,FreeCAD.Units.Length).UserString)
         grid.addWidget(label2,5,0,1,1)
         grid.addWidget(self.vWidth,5,1,1,1)
 
         # height
-        label3 = QtGui.QLabel(translate("Arch","Height", utf8_decode=True))
+        label3 = QtGui.QLabel(translate("Arch","Height"))
         self.vHeight = ui.createWidget("Gui::InputField")
-        self.vHeight.setText(FreeCAD.Units.Quantity(self.Height,FreeCAD.Units.Length).UserString)
+        if self.modeb.isChecked():
+            self.vHeight.setText(FreeCAD.Units.Quantity(self.Length,FreeCAD.Units.Length).UserString)
+        else:
+            self.vHeight.setText(FreeCAD.Units.Quantity(self.Height,FreeCAD.Units.Length).UserString)
         grid.addWidget(label3,6,0,1,1)
         grid.addWidget(self.vHeight,6,1,1,1)
 
         # horizontal button
-        value5 = QtGui.QPushButton(translate("Arch","Switch L/H", utf8_decode=True))
+        value5 = QtGui.QPushButton(translate("Arch","Switch L/H"))
         grid.addWidget(value5,7,0,1,1)
-        value6 = QtGui.QPushButton(translate("Arch","Switch L/W", utf8_decode=True))
+        value6 = QtGui.QPushButton(translate("Arch","Switch L/W"))
         grid.addWidget(value6,7,1,1,1)
 
         # continue button
-        label4 = QtGui.QLabel(translate("Arch","Con&tinue", utf8_decode=True))
+        label4 = QtGui.QLabel(translate("Arch","Con&tinue"))
         value4 = QtGui.QCheckBox()
         value4.setObjectName("ContinueCmd")
         value4.setLayoutDirection(QtCore.Qt.RightToLeft)
@@ -355,7 +439,8 @@ class _CommandStructure:
         grid.addWidget(label4,8,0,1,1)
         grid.addWidget(value4,8,1,1,1)
 
-        QtCore.QObject.connect(valuec,QtCore.SIGNAL("currentIndexChanged(int)"),self.setCategory)
+        # connect slots
+        QtCore.QObject.connect(self.valuec,QtCore.SIGNAL("currentIndexChanged(int)"),self.setCategory)
         QtCore.QObject.connect(self.vPresets,QtCore.SIGNAL("currentIndexChanged(int)"),self.setPreset)
         QtCore.QObject.connect(self.vLength,QtCore.SIGNAL("valueChanged(double)"),self.setLength)
         QtCore.QObject.connect(self.vWidth,QtCore.SIGNAL("valueChanged(double)"),self.setWidth)
@@ -364,6 +449,23 @@ class _CommandStructure:
         QtCore.QObject.connect(value5,QtCore.SIGNAL("pressed()"),self.rotateLH)
         QtCore.QObject.connect(value6,QtCore.SIGNAL("pressed()"),self.rotateLW)
         QtCore.QObject.connect(self.modeb,QtCore.SIGNAL("toggled(bool)"),self.switchLH)
+
+        # restore preset
+        stored = FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Mod/Arch").GetString("StructurePreset","")
+        if stored:
+            if stored.lower().startswith("precast_"):
+                self.valuec.setCurrentIndex(1)
+                tp = stored.split("_")[1]
+                if tp and (tp in self.precast.PrecastTypes):
+                    self.vPresets.setCurrentIndex(self.precast.PrecastTypes.index(tp))
+            elif ";" in stored:
+                stored = stored.split(";")
+                if len(stored) >= 3:
+                    if stored[1] in Categories:
+                        self.valuec.setCurrentIndex(2+Categories.index(stored[1]))
+                        ps = [p[2] for p in self.pSelect]
+                        if stored[2] in ps:
+                            self.vPresets.setCurrentIndex(ps.index(stored[2]))
         return w
 
     def update(self,point,info):
@@ -371,16 +473,24 @@ class _CommandStructure:
         "this function is called by the Snapper when the mouse is moved"
 
         if FreeCADGui.Control.activeDialog():
+            try: # try to update latest precast values - fails if dialog has been destroyed already
+                self.precastvalues = self.precast.getValues()
+            except Exception:
+                pass
             if self.Height >= self.Length:
                 delta = Vector(0,0,self.Height/2)
             else:
                 delta = Vector(self.Length/2,0,0)
+            if hasattr(FreeCAD,"DraftWorkingPlane"):
+                delta = FreeCAD.DraftWorkingPlane.getRotation().multVec(delta)
             if self.modec.isChecked():
                 self.tracker.pos(point.add(delta))
                 self.tracker.on()
             else:
                 if self.bpoint:
                     delta = Vector(0,0,-self.Height/2)
+                    if hasattr(FreeCAD,"DraftWorkingPlane"):
+                        delta = FreeCAD.DraftWorkingPlane.getRotation().multVec(delta)
                     self.tracker.update([self.bpoint.add(delta),point.add(delta)])
                     self.tracker.on()
                     l = (point.sub(self.bpoint)).Length
@@ -392,16 +502,25 @@ class _CommandStructure:
 
         self.Width = d
         self.tracker.width(d)
+        FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Mod/Arch").SetFloat("StructureWidth",d)
 
     def setHeight(self,d):
 
         self.Height = d
         self.tracker.height(d)
+        if self.modeb.isChecked():
+            FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Mod/Arch").SetFloat("StructureLength",d)
+        else:
+            FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Mod/Arch").SetFloat("StructureHeight",d)
 
     def setLength(self,d):
 
         self.Length = d
         self.tracker.length(d)
+        if self.modeb.isChecked():
+            FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Mod/Arch").SetFloat("StructureHeight",d)
+        else:
+            FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Mod/Arch").SetFloat("StructureLength",d)
 
     def setContinue(self,i):
 
@@ -429,6 +548,7 @@ class _CommandStructure:
             self.pSelect = [None]
             fpresets = [" "]
             self.vPresets.addItems(fpresets)
+            FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Mod/Arch").SetString("StructurePreset","")
 
     def setPreset(self,i):
 
@@ -442,11 +562,13 @@ class _CommandStructure:
                     self.dents.form.show()
                 else:
                     self.dents.form.hide()
+                FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Mod/Arch").SetString("StructurePreset",self.Profile)
             else:
                 p=elt[0]-1 # Presets indexes are 1-based
                 self.vLength.setText(FreeCAD.Units.Quantity(float(Presets[p][4]),FreeCAD.Units.Length).UserString)
                 self.vWidth.setText(FreeCAD.Units.Quantity(float(Presets[p][5]),FreeCAD.Units.Length).UserString)
                 self.Profile = Presets[p]
+                FreeCAD.ParamGet("User parameter:BaseApp/Preferences/Mod/Arch").SetString("StructurePreset",";".join([str(i) for i in self.Profile]))
 
     def switchLH(self,bmode):
 
@@ -483,7 +605,7 @@ class _Structure(ArchComponent.Component):
 
         ArchComponent.Component.__init__(self,obj)
         self.setProperties(obj)
-        obj.IfcRole = "Beam"
+        obj.IfcType = "Beam"
 
     def setProperties(self,obj):
 
@@ -549,14 +671,14 @@ class _Structure(ArchComponent.Component):
                 else:
                     pli = pla[-1].copy()
                 shi.Placement = pli.multiply(shi.Placement)
-                extv = pla[0].Rotation.multVec(evi)
-                if obj.Tool:
+                if not isinstance(evi, FreeCAD.Vector):
                     try:
-                        shi = obj.Tool.Shape.copy().makePipe(obj.Base.Shape.copy())
+                        shi = evi.makePipe(shi)
                     except Part.OCCError:
                         FreeCAD.Console.PrintError(translate("Arch","Error: The base shape couldn't be extruded along this tool object")+"\n")
                         return
                 else:
+                    extv = pla[0].Rotation.multVec(evi)
                     shi = shi.extrude(extv)
                 base.append(shi)
             if len(base) == 1:
@@ -564,7 +686,7 @@ class _Structure(ArchComponent.Component):
             else:
                 base = Part.makeCompound(base)
         if obj.Base:
-            if obj.Base.isDerivedFrom("Part::Feature"):
+            if hasattr(obj.Base,'Shape'):
                 if obj.Base.Shape.isNull():
                     return
                 if not obj.Base.Shape.isValid():
@@ -593,10 +715,10 @@ class _Structure(ArchComponent.Component):
 
         """returns (shape,extrusion vector,placement) or None"""
 
-        if hasattr(obj,"IfcRole"):
-            role = obj.IfcRole
+        if hasattr(obj,"IfcType"):
+            IfcType = obj.IfcType
         else:
-            role = obj.Role
+            IfcType = None
         import Part,DraftGeomUtils
         data = ArchComponent.Component.getExtrusionData(self,obj)
         if data:
@@ -608,19 +730,16 @@ class _Structure(ArchComponent.Component):
         height = obj.Height.Value
         normal = None
         if not height:
-            for p in obj.InList:
-                if Draft.getType(p) in ["Floor","BuildingPart"]:
-                    if p.Height.Value:
-                        height = p.Height.Value
+            height = self.getParentHeight(obj)
         base = None
         placement = None
         if obj.Base:
-            if obj.Base.isDerivedFrom("Part::Feature"):
+            if hasattr(obj.Base,'Shape'):
                 if obj.Base.Shape:
                     if obj.Base.Shape.Solids:
                         return None
                     elif obj.Base.Shape.Faces:
-                        if not DraftGeomUtils.isCoplanar(obj.Base.Shape.Faces,tolerance=0.01):
+                        if not DraftGeomUtils.isCoplanar(obj.Base.Shape.Faces,tol=0.01):
                             return None
                         else:
                             base,placement = self.rebase(obj.Base.Shape)
@@ -643,7 +762,7 @@ class _Structure(ArchComponent.Component):
                             if obj.FaceMaker != "None":
                                 try:
                                     baseface = Part.makeFace(obj.Base.Shape.Wires,"Part::FaceMaker"+str(obj.FaceMaker))
-                                except:
+                                except Exception:
                                     FreeCAD.Console.PrintError(translate("Arch","Facemaker returned an error")+"\n")
                                     return None
                                 if len(baseface.Faces) > 1:
@@ -655,7 +774,7 @@ class _Structure(ArchComponent.Component):
                                     p0 = w.OrderedVertexes[0].Point
                                     p1 = w.OrderedVertexes[-1].Point
                                     if p0 != p1:
-                                        e = Part.Line(p0,p1).toShape()
+                                        e = Part.LineSegment(p0,p1).toShape()
                                         w.add(e)
                                 w.fix(0.1,0,1) # fixes self-intersecting wires
                                 f = Part.Face(w)
@@ -672,7 +791,7 @@ class _Structure(ArchComponent.Component):
                         baseface = Part.Face(w)
                         base,placement = self.rebase(baseface)
         elif length and width and height:
-            if (length > height) and (role != "Slab"):
+            if (length > height) and (IfcType != "Slab"):
                 h2 = height/2 or 0.5
                 w2 = width/2 or 0.5
                 v1 = Vector(0,-w2,-h2)
@@ -690,34 +809,40 @@ class _Structure(ArchComponent.Component):
             baseface = Part.Face(Part.makePolygon([v1,v2,v3,v4,v1]))
             base,placement = self.rebase(baseface)
         if base and placement:
-            if obj.Normal.Length:
-                normal = Vector(obj.Normal)
-                if isinstance(placement,list):
-                    normal = placement[0].inverse().Rotation.multVec(normal)
-                else:
-                    normal = placement.inverse().Rotation.multVec(normal)
-            if not normal:
-                normal = Vector(0,0,1)
-            if not normal.Length:
-                normal = Vector(0,0,1)
-            extrusion = normal
-            if (length > height) and (role != "Slab"):
-                if length:
-                    extrusion = normal.multiply(length)
+            if obj.Tool:
+                if obj.Tool.Shape:
+                    edges = obj.Tool.Shape.Edges
+                    if len(edges) == 1 and DraftGeomUtils.geomType(edges[0]) == "Line":
+                        extrusion = DraftGeomUtils.vec(edges[0])
+                    else:
+                        extrusion = obj.Tool.Shape.copy()
             else:
-                if height:
-                    extrusion = normal.multiply(height)
+                if obj.Normal.Length:
+                    normal = Vector(obj.Normal).normalize()
+                    if isinstance(placement,list):
+                        normal = placement[0].inverse().Rotation.multVec(normal)
+                    else:
+                        normal = placement.inverse().Rotation.multVec(normal)
+                if not normal:
+                    normal = Vector(0,0,1)
+                if not normal.Length:
+                    normal = Vector(0,0,1)
+                extrusion = normal
+                if (length > height) and (IfcType != "Slab"):
+                    if length:
+                        extrusion = normal.multiply(length)
+                else:
+                    if height:
+                        extrusion = normal.multiply(height)
             return (base,extrusion,placement)
         return None
 
     def onChanged(self,obj,prop):
 
-        if hasattr(obj,"IfcRole"):
-            role = obj.IfcRole
-        elif hasattr(obj,"Role"):
-            role = obj.Role
+        if hasattr(obj,"IfcType"):
+            IfcType = obj.IfcType
         else:
-            role = None
+            IfcType = None
         self.hideSubobjects(obj,prop)
         if prop in ["Shape","ResetNodes","NodesOffset"]:
             # ResetNodes is not a property but it allows us to use this function to force reset the nodes
@@ -725,14 +850,15 @@ class _Structure(ArchComponent.Component):
             extdata = self.getExtrusionData(obj)
             if extdata and not isinstance(extdata[0],list):
                 nodes = extdata[0]
+                ev = extdata[2].Rotation.multVec(extdata[1])
                 nodes.Placement = nodes.Placement.multiply(extdata[2])
-                if role not in ["Slab"]:
+                if IfcType not in ["Slab"]:
                     if obj.Tool:
                         nodes = obj.Tool.Shape
                     elif extdata[1].Length > 0:
                         if hasattr(nodes,"CenterOfMass"):
                             import Part
-                            nodes = Part.LineSegment(nodes.CenterOfMass,nodes.CenterOfMass.add(extdata[1])).toShape()
+                            nodes = Part.LineSegment(nodes.CenterOfMass,nodes.CenterOfMass.add(ev)).toShape()
             offset = FreeCAD.Vector()
             if hasattr(obj,"NodesOffset"):
                 offset = FreeCAD.Vector(0,0,obj.NodesOffset.Value)
@@ -776,6 +902,11 @@ class _ViewProviderStructure(ArchComponent.ViewProviderComponent):
     def __init__(self,vobj):
 
         ArchComponent.ViewProviderComponent.__init__(self,vobj)
+
+        # setProperties of ArchComponent will be overwritten
+        # thus setProperties from ArchComponent will be explicit called to get the properties
+        ArchComponent.ViewProviderComponent.setProperties(self, vobj)
+
         self.setProperties(vobj)
         vobj.ShapeColor = ArchCommands.getDefaultColor("Structure")
 
@@ -822,20 +953,20 @@ class _ViewProviderStructure(ArchComponent.ViewProviderComponent):
                         p.append([n.x,n.y,n.z])
                     self.coords.point.setValues(0,len(p),p)
                     self.pointset.numPoints.setValue(len(p))
-                    self.lineset.coordIndex.setValues(0,len(p)+1,range(len(p))+[-1])
+                    self.lineset.coordIndex.setValues(0,len(p)+1,list(range(len(p)))+[-1])
                     if hasattr(obj.ViewObject,"NodeType"):
                         if (obj.ViewObject.NodeType == "Area") and (len(p) > 2):
                             self.coords.point.set1Value(len(p),p[0][0],p[0][1],p[0][2])
-                            self.lineset.coordIndex.setValues(0,len(p)+2,range(len(p)+1)+[-1])
-                            self.faceset.coordIndex.setValues(0,len(p)+1,range(len(p))+[-1])
+                            self.lineset.coordIndex.setValues(0,len(p)+2,list(range(len(p)+1))+[-1])
+                            self.faceset.coordIndex.setValues(0,len(p)+1,list(range(len(p)))+[-1])
 
-        elif prop in ["Role","IfcRole"]:
+        elif prop in ["IfcType"]:
             if hasattr(obj.ViewObject,"NodeType"):
-                if hasattr(obj,"IfcRole"):
-                    role = obj.IfcRole
+                if hasattr(obj,"IfcType"):
+                    IfcType = obj.IfcType
                 else:
-                    role = obj.Role
-                if role == "Slab":
+                    IfcType = None
+                if IfcType == "Slab":
                     obj.ViewObject.NodeType = "Area"
                 else:
                     obj.ViewObject.NodeType = "Linear"
@@ -1093,7 +1224,7 @@ class _StructuralSystem(ArchComponent.Component): # OBSOLETE - All Arch objects
         # creating base shape
         pl = obj.Placement
         if obj.Base:
-            if obj.Base.isDerivedFrom("Part::Feature"):
+            if hasattr(obj.Base,'Shape'):
                 if obj.Base.Shape.isNull():
                     return
                 if not obj.Base.Shape.Solids:
