@@ -1,10 +1,10 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0">
+<TS version="2.1">
 <context>
     <name>AssemblyGui::TaskAssemblyConstraints</name>
     <message>
-        <location filename="../../TaskAssemblyConstraints.cpp" line="53"/>
+        <location filename="../../TaskAssemblyConstraints.cpp" line="52"/>
         <source>Constraints</source>
         <translation type="unfinished"></translation>
     </message>
@@ -304,7 +304,7 @@
     </message>
     <message>
         <location filename="../../TaskAssemblyConstraints.ui" line="195"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Fixes the first geometry in its rotation and translation. Note that fix only works its the direct parent assembly. If you stack assemblys, the parent assembly will not be fixed inside the other ones.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Fixes the first geometry in its rotation and translation. Note that fix only works its the direct parent assembly. If you stack assemblies, the parent assembly will not be fixed inside the other ones.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
