@@ -164,12 +164,15 @@ void CDxfWrite::WriteEllipse(const double* c, double major_radius, double minor_
 CDxfRead::CDxfRead(const char* filepath)
 {
     // start the file
+    memset( m_str, '\0', sizeof(m_str) );
     memset( m_unused_line, '\0', sizeof(m_unused_line) );
     m_fail = false;
     m_aci = 0;
     m_eUnits = eMillimeters;
     m_measurement_inch = false;
     strcpy(m_layer_name, "0");  // Default layer name
+    memset( m_section_name, '\0', sizeof(m_section_name) );
+    memset( m_block_name, '\0', sizeof(m_block_name) );
     m_ignore_errors = true;
 
     m_ifs = new ifstream(filepath);
@@ -191,7 +194,7 @@ double CDxfRead::mm( double value ) const
 {
     if(m_measurement_inch)
     {
-        value *= 0.0393700787401575;
+        value *= 25.4;
     }
 
     switch(m_eUnits)
@@ -406,7 +409,7 @@ bool CDxfRead::ReadArc()
     double start_angle = 0.0;// in degrees
     double end_angle = 0.0;
     double radius = 0.0;
-    double c[3]; // centre
+    double c[3] = {0,0,0}; // centre
     double z_extrusion_dir = 1.0;
     bool hidden = false;
     
@@ -687,7 +690,7 @@ bool CDxfRead::ReadSpline()
 bool CDxfRead::ReadCircle()
 {
     double radius = 0.0;
-    double c[3]; // centre
+    double c[3] = {0,0,0}; // centre
     bool hidden = false;
 
     while(!((*m_ifs).eof()))
@@ -845,8 +848,8 @@ bool CDxfRead::ReadText()
 
 bool CDxfRead::ReadEllipse()
 {
-    double c[3]; // centre
-    double m[3]; //major axis point
+    double c[3] = {0,0,0}; // centre
+    double m[3] = {0,0,0}; //major axis point
     double ratio=0; //ratio of major to minor axis
     double start=0; //start of arc
     double end=0;  // end of arc
@@ -946,7 +949,7 @@ static bool poly_prev_found = false;
 static double poly_prev_x;
 static double poly_prev_y;
 static double poly_prev_z;
-static double poly_prev_bulge_found;
+static bool poly_prev_bulge_found = false;
 static double poly_prev_bulge;
 static bool poly_first_found = false;
 static double poly_first_x;
@@ -1050,7 +1053,6 @@ bool CDxfRead::ReadLwPolyLine()
                 get_line();
                 strcpy(m_layer_name, m_str);
                 break;
-
             case 10:
                 // x
                 get_line();
@@ -1070,6 +1072,11 @@ bool CDxfRead::ReadLwPolyLine()
                 ss.str(m_str); ss >> y; y = mm(y); if(ss.fail()) return false;
                 y_found = true;
                 break;
+            case 38: 
+                // elevation
+                get_line();
+                ss.str(m_str); ss >> z; z = mm(z); if(ss.fail()) return false;
+                break;
             case 42:
                 // bulge
                 get_line();
@@ -1193,7 +1200,7 @@ bool CDxfRead::ReadPolyLine()
     bool closed = false;
     int flags;
     bool first_vertex_section_found = false;
-    double first_vertex[3];
+    double first_vertex[3] = {0,0,0};
     bool bulge_found;
     double bulge;
 
@@ -1314,13 +1321,10 @@ void CDxfRead::OnReadEllipse(const double* c, const double* m, double ratio, dou
 
 bool CDxfRead::ReadInsert()
 {
-    double c[3]; // coordinate
-    double s[3]; // scale
+    double c[3] = {0,0,0}; // coordinate
+    double s[3] = {1,1,1}; // scale
     double rot = 0.0; // rotation
-    char name[1024];
-    s[0] = 1.0;
-    s[1] = 1.0;
-    s[2] = 1.0;
+    char name[1024] = {0};
 
     while(!((*m_ifs).eof()))
     {
@@ -1409,9 +1413,9 @@ bool CDxfRead::ReadInsert()
 
 bool CDxfRead::ReadDimension()
 {
-    double s[3]; // startpoint
-    double e[3]; // endpoint
-    double p[3]; // dimpoint
+    double s[3] = {0,0,0}; // startpoint
+    double e[3] = {0,0,0}; // endpoint
+    double p[3] = {0,0,0}; // dimpoint
     double rot = -1.0; // rotation
 
     while(!((*m_ifs).eof()))
@@ -1509,6 +1513,40 @@ bool CDxfRead::ReadDimension()
 }
 
 
+bool CDxfRead::ReadBlockInfo()
+{
+    while(!((*m_ifs).eof()))
+    {
+        get_line();
+        int n;
+        if(sscanf(m_str, "%d", &n) != 1)
+        {
+            printf("CDxfRead::ReadBlockInfo() Failed to read integer from '%s'\n", m_str);
+            return false;
+        }
+        std::istringstream ss;
+        ss.imbue(std::locale("C"));
+        switch(n){
+            case 2:
+                // block name
+                get_line();
+                strcpy(m_block_name, m_str);
+                return true;
+            case 3:
+                // block name too???
+                get_line();
+                strcpy(m_block_name, m_str);
+                return true;
+            default:
+                // skip the next line
+                get_line();
+                break;
+        }
+    }
+    return false;
+}
+
+
 void CDxfRead::get_line()
 {
     if (m_unused_line[0] != '\0')
@@ -1537,9 +1575,20 @@ void CDxfRead::get_line()
     strcpy(m_str, str);
 }
 
+void dxf_strncpy(char* dst, const char* src, size_t size)
+{
+    size_t ret = strlen(src);
+
+    if (size) {
+        size_t len = (ret >= size) ? size - 1 : ret;
+        memcpy(dst, src, len);
+        dst[len] = '\0';
+    }
+}
+
 void CDxfRead::put_line(const char *value)
 {
-    strcpy( m_unused_line, value );
+    dxf_strncpy( m_unused_line, value, sizeof(m_unused_line) );
 }
 
 
@@ -1563,7 +1612,7 @@ bool CDxfRead::ReadUnits()
 
 bool CDxfRead::ReadLayer()
 {
-        std::string layername;
+    std::string layername;
     int aci = -1;
 
     while(!((*m_ifs).eof()))
@@ -1642,23 +1691,15 @@ void CDxfRead::DoRead(const bool ignore_errors /* = false */ )
             }
             continue;
         } // End if - then
-
-        else if (!strcmp( m_str, "AcDbBlockBegin" )){
-            get_line();
-
-            if (! strcmp(m_str,"2"))
-            {
-                get_line();
-                strcpy(m_block_name, m_str);
-            }
-        } // End if - then
+        
         else if(!strcmp(m_str, "0"))
         {
             get_line();
             if (!strcmp( m_str, "SECTION" )){
               get_line();
               get_line();
-              strcpy(m_section_name, m_str);
+              if (strcmp( m_str, "ENTITIES" ))
+                strcpy(m_section_name, m_str);
               strcpy(m_block_name, "");
 
         } // End if - then
@@ -1675,7 +1716,17 @@ void CDxfRead::DoRead(const bool ignore_errors /* = false */ )
                   printf("CDxfRead::DoRead() Failed to read layer\n");
                   //return; Some objects or tables can have "LAYER" as name...
                 }
-              continue;     }
+              continue;     
+        }
+        
+        else if (!strcmp( m_str, "BLOCK" )) {
+            if(!ReadBlockInfo())
+            {
+                printf("CDxfRead::DoRead() Failed to read block info\n");
+                return;
+            }
+            continue;
+        } // End if - then
 
         else if (!strcmp( m_str, "ENDSEC" )){
                     strcpy(m_section_name, "");
@@ -1801,17 +1852,17 @@ std::string CDxfRead::LayerName() const
     if (strlen(m_section_name) > 0)
     {
         result.append(m_section_name);
+        result.append(" ");
     }
 
     if (strlen(m_block_name) > 0)
     {
-        result.append(" ");
         result.append(m_block_name);
+        result.append(" ");
     }
 
     if (strlen(m_layer_name) > 0)
     {
-        result.append(" ");
         result.append(m_layer_name);
     }
 
