@@ -50,8 +50,6 @@ using namespace std;
 
 PROPERTY_SOURCE(Drawing::FeaturePage, App::DocumentObjectGroup)
 
-const char *group = "Drawing view";
-
 FeaturePage::FeaturePage(void) : numChildren(0)
 {
     static const char *group = "Drawing view";
@@ -155,9 +153,8 @@ App::DocumentObjectExecReturn *FeaturePage::execute(void)
     ostringstream ofile;
     string tempendl = "--endOfLine--";
 
-    while (!file.eof())
+    while (getline (file,line))
     {
-        getline (file,line);
         // check if the marker in the template is found
         if(line.find("<!-- DrawingContent -->") == string::npos)
             // if not -  write through
@@ -259,8 +256,7 @@ std::vector<std::string> FeaturePage::getEditableTextsFromTemplate(void) const {
         }
         string tline, tfrag;
         ifstream tfile (tfi.filePath().c_str());
-        while (!tfile.eof()) {
-            getline (tfile,tline);
+        while (getline (tfile,tline)) {
             tfrag += tline;
             tfrag += "--endOfLine--";
         }
