@@ -1,21 +1,21 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="sk" sourcelanguage="en">
+<TS version="2.1" language="sk" sourcelanguage="en">
   <context>
     <name>CmdDrawingAnnotation</name>
     <message>
-      <location filename="../../Command.cpp" line="478"/>
+      <location filename="../../Command.cpp" line="481"/>
       <source>Drawing</source>
-      <translation>Kreslenie</translation>
+      <translation>Výkres</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="479"/>
-      <source>&amp;Annotation</source>
-      <translation type="unfinished">&amp;Annotation</translation>
-    </message>
-    <message>
-      <location filename="../../Command.cpp" line="480"/>
       <location filename="../../Command.cpp" line="482"/>
+      <source>&amp;Annotation</source>
+      <translation>&amp;Poznámky</translation>
+    </message>
+    <message>
+      <location filename="../../Command.cpp" line="483"/>
+      <location filename="../../Command.cpp" line="485"/>
       <source>Inserts an Annotation view in the active drawing</source>
       <translation type="unfinished">Inserts an Annotation view in the active drawing</translation>
     </message>
@@ -23,18 +23,18 @@
   <context>
     <name>CmdDrawingClip</name>
     <message>
-      <location filename="../../Command.cpp" line="526"/>
+      <location filename="../../Command.cpp" line="529"/>
       <source>Drawing</source>
-      <translation>Kreslenie</translation>
+      <translation>Výkres</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="527"/>
+      <location filename="../../Command.cpp" line="530"/>
       <source>&amp;Clip</source>
       <translation type="unfinished">&amp;Clip</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="528"/>
-      <location filename="../../Command.cpp" line="530"/>
+      <location filename="../../Command.cpp" line="531"/>
+      <location filename="../../Command.cpp" line="533"/>
       <source>Inserts a clip group in the active drawing</source>
       <translation type="unfinished">Inserts a clip group in the active drawing</translation>
     </message>
@@ -42,18 +42,18 @@
   <context>
     <name>CmdDrawingDraftView</name>
     <message>
-      <location filename="../../Command.cpp" line="723"/>
+      <location filename="../../Command.cpp" line="728"/>
       <source>Drawing</source>
-      <translation>Kreslenie</translation>
+      <translation>Výkres</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="724"/>
+      <location filename="../../Command.cpp" line="729"/>
       <source>&amp;Draft View</source>
       <translation type="unfinished">&amp;Draft View</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="725"/>
-      <location filename="../../Command.cpp" line="727"/>
+      <location filename="../../Command.cpp" line="730"/>
+      <location filename="../../Command.cpp" line="732"/>
       <source>Inserts a Draft view of the selected object(s) in the active drawing</source>
       <translation type="unfinished">Inserts a Draft view of the selected object(s) in the active drawing</translation>
     </message>
@@ -61,18 +61,18 @@
   <context>
     <name>CmdDrawingExportPage</name>
     <message>
-      <location filename="../../Command.cpp" line="631"/>
+      <location filename="../../Command.cpp" line="635"/>
       <source>File</source>
       <translation>Súbor</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="632"/>
+      <location filename="../../Command.cpp" line="636"/>
       <source>&amp;Export page...</source>
-      <translation>&amp;Export stránky...</translation>
+      <translation>&amp;Exportovať stránku...</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="633"/>
-      <location filename="../../Command.cpp" line="635"/>
+      <location filename="../../Command.cpp" line="637"/>
+      <location filename="../../Command.cpp" line="639"/>
       <source>Export a page to an SVG file</source>
       <translation>Exportovať stranu do SVG súboru</translation>
     </message>
@@ -80,13 +80,13 @@
   <context>
     <name>CmdDrawingNewA3Landscape</name>
     <message>
-      <location filename="../../Command.cpp" line="272"/>
+      <location filename="../../Command.cpp" line="275"/>
       <source>Drawing</source>
-      <translation>Kreslenie</translation>
+      <translation>Výkres</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="273"/>
-      <location filename="../../Command.cpp" line="274"/>
+      <location filename="../../Command.cpp" line="276"/>
+      <location filename="../../Command.cpp" line="277"/>
       <source>Insert new A3 landscape drawing</source>
       <translation>Vložiť nový výkres A3 na šírku</translation>
     </message>
@@ -94,86 +94,86 @@
   <context>
     <name>CmdDrawingNewPage</name>
     <message>
-      <location filename="../../Command.cpp" line="95"/>
+      <location filename="../../Command.cpp" line="97"/>
       <source>Drawing</source>
-      <translation>Kreslenie</translation>
+      <translation>Výkres</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="96"/>
-      <location filename="../../Command.cpp" line="97"/>
+      <location filename="../../Command.cpp" line="98"/>
+      <location filename="../../Command.cpp" line="99"/>
       <source>Insert new drawing</source>
-      <translation>Vložiť nové Kreslenie</translation>
+      <translation>Vložiť nový výkres</translation>
     </message>
   </context>
   <context>
     <name>CmdDrawingNewView</name>
     <message>
-      <location filename="../../Command.cpp" line="311"/>
+      <location filename="../../Command.cpp" line="314"/>
       <source>Drawing</source>
-      <translation>Kreslenie</translation>
+      <translation>Výkres</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="312"/>
+      <location filename="../../Command.cpp" line="315"/>
       <source>Insert view in drawing</source>
-      <translation>Vložiť zobrazenie v kresbe</translation>
+      <translation>Vložiť zobrazenie do výkresu</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="313"/>
+      <location filename="../../Command.cpp" line="316"/>
       <source>Insert a new View of a Part in the active drawing</source>
-      <translation>Vložiť nový pohľad na úlohu v aktívnom výkrese</translation>
+      <translation>Vloží nové zobrazenie časti do aktívneho výkresu</translation>
     </message>
   </context>
   <context>
     <name>CmdDrawingOpen</name>
     <message>
-      <location filename="../../Command.cpp" line="59"/>
+      <location filename="../../Command.cpp" line="60"/>
       <source>Drawing</source>
-      <translation>Kreslenie</translation>
+      <translation>Výkres</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="60"/>
+      <location filename="../../Command.cpp" line="61"/>
       <source>Open SVG...</source>
       <translation>Otvoriť SVG...</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="61"/>
+      <location filename="../../Command.cpp" line="62"/>
       <source>Open a scalable vector graphic</source>
-      <translation>Otvorte škálovateľnú vektorovú grafiku</translation>
+      <translation>Otvorí vektorovú grafiku s možnosťou zmeny mierky (SVG)</translation>
     </message>
   </context>
   <context>
     <name>CmdDrawingOpenBrowserView</name>
     <message>
-      <location filename="../../Command.cpp" line="440"/>
+      <location filename="../../Command.cpp" line="443"/>
       <source>Drawing</source>
-      <translation>Kreslenie</translation>
+      <translation>Výkres</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="441"/>
-      <source>Open &amp;browser view</source>
-      <translation type="unfinished">Open &amp;browser view</translation>
-    </message>
-    <message>
-      <location filename="../../Command.cpp" line="442"/>
       <location filename="../../Command.cpp" line="444"/>
+      <source>Open &amp;browser view</source>
+      <translation>Otvoriť zobrazenie &amp;prehliadača</translation>
+    </message>
+    <message>
+      <location filename="../../Command.cpp" line="445"/>
+      <location filename="../../Command.cpp" line="447"/>
       <source>Opens the selected page in a browser view</source>
-      <translation type="unfinished">Opens the selected page in a browser view</translation>
+      <translation>Otvorí vybranú stránku v zobrazení prehliadača</translation>
     </message>
   </context>
   <context>
     <name>CmdDrawingOrthoViews</name>
     <message>
-      <location filename="../../Command.cpp" line="390"/>
+      <location filename="../../Command.cpp" line="393"/>
       <source>Drawing</source>
-      <translation>Kreslenie</translation>
+      <translation>Výkres</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="391"/>
+      <location filename="../../Command.cpp" line="394"/>
       <source>Insert orthographic views</source>
       <translation type="unfinished">Insert orthographic views</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="392"/>
+      <location filename="../../Command.cpp" line="395"/>
       <source>Insert an orthographic projection of a part in the active drawing</source>
       <translation type="unfinished">Insert an orthographic projection of a part in the active drawing</translation>
     </message>
@@ -181,37 +181,37 @@
   <context>
     <name>CmdDrawingProjectShape</name>
     <message>
-      <location filename="../../Command.cpp" line="687"/>
+      <location filename="../../Command.cpp" line="692"/>
       <source>Drawing</source>
-      <translation>Kreslenie</translation>
+      <translation>Výkres</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="688"/>
+      <location filename="../../Command.cpp" line="693"/>
       <source>Project shape...</source>
       <translation>Tvary projektu...</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="689"/>
-      <location filename="../../Command.cpp" line="690"/>
+      <location filename="../../Command.cpp" line="694"/>
+      <location filename="../../Command.cpp" line="695"/>
       <source>Project shape onto a user-defined plane</source>
-      <translation>Tvary projektu na užívateľom definovanú rovinu</translation>
+      <translation>Tvar projektu na používateľom určenej rovine</translation>
     </message>
   </context>
   <context>
     <name>CmdDrawingSpreadsheetView</name>
     <message>
-      <location filename="../../Command.cpp" line="754"/>
+      <location filename="../../Command.cpp" line="759"/>
       <source>Drawing</source>
-      <translation>Kreslenie</translation>
+      <translation>Výkres</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="755"/>
+      <location filename="../../Command.cpp" line="760"/>
       <source>&amp;Spreadsheet View</source>
-      <translation type="unfinished">&amp;Spreadsheet View</translation>
+      <translation>&amp;Tabuľkové zobrazenie</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="756"/>
-      <location filename="../../Command.cpp" line="758"/>
+      <location filename="../../Command.cpp" line="761"/>
+      <location filename="../../Command.cpp" line="763"/>
       <source>Inserts a view of a selected spreadsheet in the active drawing</source>
       <translation type="unfinished">Inserts a view of a selected spreadsheet in the active drawing</translation>
     </message>
@@ -219,18 +219,18 @@
   <context>
     <name>CmdDrawingSymbol</name>
     <message>
-      <location filename="../../Command.cpp" line="571"/>
+      <location filename="../../Command.cpp" line="574"/>
       <source>Drawing</source>
-      <translation>Kreslenie</translation>
+      <translation>Výkres</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="572"/>
-      <source>&amp;Symbol</source>
-      <translation type="unfinished">&amp;Symbol</translation>
-    </message>
-    <message>
-      <location filename="../../Command.cpp" line="573"/>
       <location filename="../../Command.cpp" line="575"/>
+      <source>&amp;Symbol</source>
+      <translation>&amp;Symbol</translation>
+    </message>
+    <message>
+      <location filename="../../Command.cpp" line="576"/>
+      <location filename="../../Command.cpp" line="578"/>
       <source>Inserts a symbol from a svg file in the active drawing</source>
       <translation type="unfinished">Inserts a symbol from a svg file in the active drawing</translation>
     </message>
@@ -238,130 +238,136 @@
   <context>
     <name>DrawingGui::DrawingView</name>
     <message>
-      <location filename="../../DrawingView.cpp" line="215"/>
+      <location filename="../../DrawingView.cpp" line="219"/>
       <source>&amp;Background</source>
       <translation>&amp;Pozadie</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="221"/>
+      <location filename="../../DrawingView.cpp" line="225"/>
       <source>&amp;Outline</source>
-      <translation>&amp;Náčrt</translation>
+      <translation>&amp;Obrys</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="227"/>
+      <location filename="../../DrawingView.cpp" line="231"/>
       <source>&amp;Native</source>
       <translation>Prirodze&amp;ne</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="231"/>
+      <location filename="../../DrawingView.cpp" line="235"/>
       <source>&amp;OpenGL</source>
       <translation>&amp;OpenGL</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="234"/>
+      <location filename="../../DrawingView.cpp" line="238"/>
       <source>&amp;Image</source>
       <translation>Obrázok</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="238"/>
+      <location filename="../../DrawingView.cpp" line="242"/>
       <source>&amp;High Quality Antialiasing</source>
-      <translation>&amp;Vysoká kvalita vy&amp;hladzovania</translation>
+      <translation>Vyhladzovanie vo v&amp;ysokej kvalite</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="276"/>
+      <location filename="../../DrawingView.cpp" line="284"/>
       <source>Open SVG File</source>
       <translation>Otvoriť súbor SVG</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="277"/>
+      <location filename="../../DrawingView.cpp" line="285"/>
       <source>Could not open file '%1'.</source>
-      <translation>Nepodarilo sa otvoriť súbor '%1'.</translation>
+      <translation>Nepodarilo sa otvoriť súbor „%1“.</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="364"/>
+      <location filename="../../DrawingView.cpp" line="408"/>
       <source>&amp;Renderer</source>
-      <translation>&amp;Renderer</translation>
+      <translation>V&amp;ykresľovač</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="469"/>
+      <location filename="../../DrawingView.cpp" line="513"/>
       <source>Export PDF</source>
-      <translation>Export do PDF</translation>
+      <translation>Exportovať PDF</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="470"/>
+      <location filename="../../DrawingView.cpp" line="514"/>
       <source>PDF file</source>
-      <translation type="unfinished">PDF file</translation>
+      <translation>Súbor PDF</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="486"/>
+      <location filename="../../DrawingView.cpp" line="530"/>
       <source>Page sizes</source>
       <translation>Veľkosti stránok</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="487"/>
+      <location filename="../../DrawingView.cpp" line="532"/>
+      <location filename="../../DrawingView.cpp" line="545"/>
       <source>A0</source>
       <translation>A0</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="489"/>
+      <location filename="../../DrawingView.cpp" line="534"/>
+      <location filename="../../DrawingView.cpp" line="547"/>
       <source>A1</source>
       <translation>A1</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="491"/>
+      <location filename="../../DrawingView.cpp" line="536"/>
+      <location filename="../../DrawingView.cpp" line="549"/>
       <source>A2</source>
       <translation>A2</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="493"/>
+      <location filename="../../DrawingView.cpp" line="538"/>
+      <location filename="../../DrawingView.cpp" line="551"/>
       <source>A3</source>
       <translation>A3</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="495"/>
+      <location filename="../../DrawingView.cpp" line="540"/>
+      <location filename="../../DrawingView.cpp" line="553"/>
       <source>A4</source>
       <translation>A4</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="497"/>
+      <location filename="../../DrawingView.cpp" line="542"/>
+      <location filename="../../DrawingView.cpp" line="555"/>
       <source>A5</source>
       <translation>A5</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="578"/>
+      <location filename="../../DrawingView.cpp" line="666"/>
       <source>Different orientation</source>
-      <translation type="unfinished">Different orientation</translation>
+      <translation>Odlišná orientácia</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="579"/>
+      <location filename="../../DrawingView.cpp" line="667"/>
       <source>The printer uses a different orientation than the drawing.
 Do you want to continue?</source>
-      <translation type="unfinished">The printer uses a different orientation than the drawing.
-Do you want to continue?</translation>
+      <translation>Tlačiareň používa odlišnú orientáciu ako nákres.
+Chcete pokračovať?</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="586"/>
-      <location filename="../../DrawingView.cpp" line="594"/>
+      <location filename="../../DrawingView.cpp" line="674"/>
+      <location filename="../../DrawingView.cpp" line="682"/>
       <source>Different paper size</source>
-      <translation type="unfinished">Different paper size</translation>
+      <translation>Odlišná veľkosť papiera</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="587"/>
-      <location filename="../../DrawingView.cpp" line="595"/>
+      <location filename="../../DrawingView.cpp" line="675"/>
+      <location filename="../../DrawingView.cpp" line="683"/>
       <source>The printer uses a different paper size than the drawing.
 Do you want to continue?</source>
-      <translation type="unfinished">The printer uses a different paper size than the drawing.
-Do you want to continue?</translation>
+      <translation>Tlačiareň používa odlišnú veľkosť papiera ako nákres.
+Chcete pokračovať?</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="606"/>
+      <location filename="../../DrawingView.cpp" line="694"/>
       <source>Opening file failed</source>
-      <translation type="unfinished">Opening file failed</translation>
+      <translation>Otvorenie zlyhalo</translation>
     </message>
     <message>
-      <location filename="../../DrawingView.cpp" line="607"/>
+      <location filename="../../DrawingView.cpp" line="695"/>
       <source>Can't open file '%1' for writing.</source>
-      <translation type="unfinished">Can't open file '%1' for writing.</translation>
+      <translation>Nedá sa otvoriť súbor „%1“ na zápis.</translation>
     </message>
   </context>
   <context>
@@ -390,12 +396,12 @@ Do you want to continue?</translation>
     <message>
       <location filename="../../TaskOrthoViews.ui" line="324"/>
       <source>Primary view</source>
-      <translation type="unfinished">Primary view</translation>
+      <translation>Hlavné zobrazenie</translation>
     </message>
     <message>
       <location filename="../../TaskOrthoViews.ui" line="340"/>
       <source>Secondary Views</source>
-      <translation type="unfinished">Secondary Views</translation>
+      <translation>Sekundárny teletext</translation>
     </message>
     <message>
       <location filename="../../TaskOrthoViews.ui" line="412"/>
@@ -405,7 +411,7 @@ Do you want to continue?</translation>
     <message>
       <location filename="../../TaskOrthoViews.ui" line="421"/>
       <source>Auto scale / position</source>
-      <translation type="unfinished">Auto scale / position</translation>
+      <translation>Automatická mierka / pozícia</translation>
     </message>
     <message>
       <location filename="../../TaskOrthoViews.ui" line="436"/>
@@ -425,12 +431,12 @@ Do you want to continue?</translation>
     <message>
       <location filename="../../TaskOrthoViews.ui" line="561"/>
       <source>Show hidden lines</source>
-      <translation type="unfinished">Show hidden lines</translation>
+      <translation>Zobraziť skryté súbory</translation>
     </message>
     <message>
       <location filename="../../TaskOrthoViews.ui" line="568"/>
       <source>Show smooth lines</source>
-      <translation type="unfinished">Show smooth lines</translation>
+      <translation>Zobraziť iba riadky</translation>
     </message>
     <message>
       <location filename="../../TaskOrthoViews.ui" line="579"/>
@@ -505,12 +511,12 @@ Do you want to continue?</translation>
     <message>
       <location filename="../../TaskOrthoViews.ui" line="660"/>
       <source> Scale</source>
-      <translation type="unfinished"> Scale</translation>
+      <translation> Mierka</translation>
     </message>
     <message>
       <location filename="../../TaskOrthoViews.ui" line="667"/>
       <source>View projection</source>
-      <translation type="unfinished">View projection</translation>
+      <translation>Prehľad projektov</translation>
     </message>
     <message>
       <location filename="../../TaskOrthoViews.ui" line="674"/>
@@ -521,7 +527,7 @@ Do you want to continue?</translation>
       <location filename="../../TaskOrthoViews.ui" line="715"/>
       <location filename="../../TaskOrthoViews.ui" line="738"/>
       <source>Flip</source>
-      <translation type="unfinished">Flip</translation>
+      <translation>Otočiť</translation>
     </message>
     <message>
       <location filename="../../TaskOrthoViews.ui" line="728"/>
@@ -531,17 +537,17 @@ Do you want to continue?</translation>
     <message>
       <location filename="../../TaskOrthoViews.ui" line="756"/>
       <source>Projection</source>
-      <translation type="unfinished">Projection</translation>
+      <translation>Projekcia</translation>
     </message>
     <message>
       <location filename="../../TaskOrthoViews.ui" line="767"/>
       <source>Third Angle</source>
-      <translation type="unfinished">Third Angle</translation>
+      <translation>Tretí uhol</translation>
     </message>
     <message>
       <location filename="../../TaskOrthoViews.ui" line="772"/>
       <source>First Angle</source>
-      <translation type="unfinished">First Angle</translation>
+      <translation>Prvý uhol</translation>
     </message>
     <message>
       <location filename="../../TaskOrthoViews.ui" line="791"/>
@@ -564,7 +570,7 @@ Do you want to continue?</translation>
     <message>
       <location filename="../../TaskDialog.cpp" line="52"/>
       <source>Visible smooth edges</source>
-      <translation>Viditeľné vyhladzovanie hrán</translation>
+      <translation>Viditeľné vyhladené hrany</translation>
     </message>
     <message>
       <location filename="../../TaskDialog.cpp" line="53"/>
@@ -589,7 +595,7 @@ Do you want to continue?</translation>
     <message>
       <location filename="../../TaskDialog.cpp" line="57"/>
       <source>Hidden smooth edges</source>
-      <translation>Skryté vyhladzovanie hrán</translation>
+      <translation>Skryté vyhladené hrany</translation>
     </message>
     <message>
       <location filename="../../TaskDialog.cpp" line="58"/>
@@ -619,12 +625,12 @@ Do you want to continue?</translation>
     <message>
       <location filename="../../TaskDialog.cpp" line="92"/>
       <source>There is currently no active document to complete the operation</source>
-      <translation type="unfinished">There is currently no active document to complete the operation</translation>
+      <translation>Momentálne nie je aktívny žiadny dokument na dokončenie operácie</translation>
     </message>
     <message>
       <location filename="../../TaskDialog.cpp" line="97"/>
       <source>No active view</source>
-      <translation type="unfinished">No active view</translation>
+      <translation>Žiadne aktívne zobrazenie</translation>
     </message>
     <message>
       <location filename="../../TaskDialog.cpp" line="98"/>
@@ -635,133 +641,133 @@ Do you want to continue?</translation>
   <context>
     <name>Drawing_NewPage</name>
     <message>
-      <location filename="../../Command.cpp" line="220"/>
+      <location filename="../../Command.cpp" line="223"/>
       <source>Landscape</source>
-      <translation type="unfinished">Landscape</translation>
+      <translation>Na šírku</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="222"/>
+      <location filename="../../Command.cpp" line="225"/>
       <source>Portrait</source>
-      <translation type="unfinished">Portrait</translation>
+      <translation>Na výšku</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="226"/>
+      <location filename="../../Command.cpp" line="229"/>
       <source>%1%2 %3</source>
-      <translation type="unfinished">%1%2 %3</translation>
+      <translation>%1%2 %3</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="231"/>
+      <location filename="../../Command.cpp" line="234"/>
       <source>Insert new %1%2 %3 drawing</source>
       <translation type="unfinished">Insert new %1%2 %3 drawing</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="238"/>
+      <location filename="../../Command.cpp" line="241"/>
       <source>%1%2 %3 (%4)</source>
-      <translation type="unfinished">%1%2 %3 (%4)</translation>
+      <translation>%1%2 %3 (%4)</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="244"/>
+      <location filename="../../Command.cpp" line="247"/>
       <source>Insert new %1%2 %3 (%4) drawing</source>
-      <translation type="unfinished">Insert new %1%2 %3 (%4) drawing</translation>
+      <translation>Vloží výkres vo formáte %1%2 %3 (%4)</translation>
     </message>
   </context>
   <context>
     <name>QObject</name>
     <message>
-      <location filename="../../Command.cpp" line="71"/>
-      <location filename="../../Command.cpp" line="592"/>
+      <location filename="../../Command.cpp" line="72"/>
+      <location filename="../../Command.cpp" line="595"/>
       <source>Choose an SVG file to open</source>
       <translation>Vyberte súbor SVG k otvoreniu</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="72"/>
-      <location filename="../../Command.cpp" line="593"/>
-      <location filename="../../Command.cpp" line="650"/>
+      <location filename="../../Command.cpp" line="73"/>
+      <location filename="../../Command.cpp" line="596"/>
+      <location filename="../../Command.cpp" line="654"/>
       <source>Scalable Vector Graphic</source>
-      <translation type="unfinished">Scalable Vector Graphic</translation>
+      <translation>SVG</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="324"/>
-      <location filename="../../Command.cpp" line="403"/>
-      <location filename="../../Command.cpp" line="453"/>
-      <location filename="../../Command.cpp" line="644"/>
-      <location filename="../../Command.cpp" line="767"/>
+      <location filename="../../Command.cpp" line="327"/>
+      <location filename="../../Command.cpp" line="406"/>
+      <location filename="../../Command.cpp" line="456"/>
+      <location filename="../../Command.cpp" line="648"/>
+      <location filename="../../Command.cpp" line="772"/>
       <source>Wrong selection</source>
-      <translation>Chybný výber</translation>
+      <translation>Nesprávny výber</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="325"/>
+      <location filename="../../Command.cpp" line="328"/>
       <source>Select a Part object.</source>
       <translation>Vyberte časť objektu.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="333"/>
-      <location filename="../../Command.cpp" line="412"/>
-      <location filename="../../Command.cpp" line="493"/>
-      <location filename="../../Command.cpp" line="541"/>
-      <location filename="../../Command.cpp" line="586"/>
-      <location filename="../../Command.cpp" line="773"/>
+      <location filename="../../Command.cpp" line="336"/>
+      <location filename="../../Command.cpp" line="415"/>
+      <location filename="../../Command.cpp" line="496"/>
+      <location filename="../../Command.cpp" line="544"/>
+      <location filename="../../Command.cpp" line="589"/>
+      <location filename="../../Command.cpp" line="778"/>
       <source>No page found</source>
-      <translation type="unfinished">No page found</translation>
+      <translation>Nenašla sa žiadna stránka</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="334"/>
-      <location filename="../../Command.cpp" line="413"/>
-      <location filename="../../Command.cpp" line="494"/>
-      <location filename="../../Command.cpp" line="542"/>
-      <location filename="../../Command.cpp" line="587"/>
-      <location filename="../../Command.cpp" line="774"/>
+      <location filename="../../Command.cpp" line="337"/>
+      <location filename="../../Command.cpp" line="416"/>
+      <location filename="../../Command.cpp" line="497"/>
+      <location filename="../../Command.cpp" line="545"/>
+      <location filename="../../Command.cpp" line="590"/>
+      <location filename="../../Command.cpp" line="779"/>
       <source>Create a page first.</source>
-      <translation type="unfinished">Create a page first.</translation>
+      <translation>Najskôr vytvorte stránku.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="404"/>
+      <location filename="../../Command.cpp" line="407"/>
       <source>Select exactly one Part object.</source>
       <translation type="unfinished">Select exactly one Part object.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="454"/>
-      <location filename="../../Command.cpp" line="645"/>
+      <location filename="../../Command.cpp" line="457"/>
+      <location filename="../../Command.cpp" line="649"/>
       <source>Select one Page object.</source>
-      <translation>Vyberte jednostranný objekt.</translation>
+      <translation>Vyberte objekt na jednu stranu.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="651"/>
+      <location filename="../../Command.cpp" line="655"/>
       <source>All Files</source>
-      <translation type="unfinished">All Files</translation>
+      <translation>Všetky súbory</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="653"/>
+      <location filename="../../Command.cpp" line="657"/>
       <source>Export page</source>
       <translation>Export stránky</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="768"/>
+      <location filename="../../Command.cpp" line="773"/>
       <source>Select exactly one Spreadsheet object.</source>
       <translation type="unfinished">Select exactly one Spreadsheet object.</translation>
     </message>
     <message>
-      <location filename="../../TaskOrthoViews.cpp" line="51"/>
-      <location filename="../../TaskOrthoViews.cpp" line="981"/>
+      <location filename="../../TaskOrthoViews.cpp" line="54"/>
+      <location filename="../../TaskOrthoViews.cpp" line="982"/>
       <source>Make axonometric...</source>
       <translation type="unfinished">Make axonometric...</translation>
     </message>
     <message>
-      <location filename="../../TaskOrthoViews.cpp" line="52"/>
-      <location filename="../../TaskOrthoViews.cpp" line="982"/>
+      <location filename="../../TaskOrthoViews.cpp" line="55"/>
+      <location filename="../../TaskOrthoViews.cpp" line="983"/>
       <source>Edit axonometric settings...</source>
       <translation type="unfinished">Edit axonometric settings...</translation>
     </message>
     <message>
-      <location filename="../../TaskOrthoViews.cpp" line="53"/>
-      <location filename="../../TaskOrthoViews.cpp" line="983"/>
+      <location filename="../../TaskOrthoViews.cpp" line="56"/>
+      <location filename="../../TaskOrthoViews.cpp" line="984"/>
       <source>Make orthographic</source>
       <translation type="unfinished">Make orthographic</translation>
     </message>
     <message>
       <location filename="../../ViewProviderPage.cpp" line="152"/>
       <source>Show drawing</source>
-      <translation>Zobraziť nákres</translation>
+      <translation>Zobraziť výkres</translation>
     </message>
   </context>
   <context>
@@ -769,7 +775,7 @@ Do you want to continue?</translation>
     <message>
       <location filename="../../Workbench.cpp" line="37"/>
       <source>Drawing</source>
-      <translation>Kreslenie</translation>
+      <translation>Výkres</translation>
     </message>
   </context>
 </TS>
