@@ -1,5 +1,6 @@
 /***************************************************************************
- *   Copyright (c) 2013 Jan Rheinländer <jrheinlaender[at]users.sourceforge.net>     *
+ *   Copyright (c) 2013 Jan Rheinländer                                    *
+ *                                   <jrheinlaender@users.sourceforge.net> *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -24,6 +25,7 @@
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
+# include <math.h> //OvG: Required for log10
 # include <TopoDS.hxx>
 # include <BRepGProp_Face.hxx>
 # include <gp_Vec.hxx>
@@ -54,25 +56,33 @@
 #include "FemConstraint.h"
 #include "FemTools.h"
 
+#include <App/DocumentObjectPy.h>
+#include <App/FeaturePythonPyImp.h>
+#include <App/OriginFeature.h>
+
 #include <Mod/Part/App/PartFeature.h>
 #include <Base/Console.h>
 #include <Base/Exception.h>
-#include <math.h> //OvG: Required for log10
+
 
 using namespace Fem;
 
 // maybe in the c++ standard later, older compiler don't have round()
+#if _MSC_VER <= 1700
 double round(double r) {
     return (r > 0.0) ? floor(r + 0.5) : ceil(r - 0.5);
 }
+#endif
 
-PROPERTY_SOURCE(Fem::Constraint, App::DocumentObject);
+PROPERTY_SOURCE(Fem::Constraint, App::DocumentObject)
 
 Constraint::Constraint()
 {
     ADD_PROPERTY_TYPE(References,(0,0),"Constraint",(App::PropertyType)(App::Prop_None),"Elements where the constraint is applied");
     ADD_PROPERTY_TYPE(NormalDirection,(Base::Vector3d(0,0,1)),"Constraint",App::PropertyType(App::Prop_ReadOnly|App::Prop_Output),"Normal direction pointing outside of solid");
     ADD_PROPERTY_TYPE(Scale,(1),"Base",App::PropertyType(App::Prop_Output),"Scale used for drawing constraints"); //OvG: Add scale parameter inherited by all derived constraints
+
+    References.setScope(App::LinkScope::Global);
 }
 
 Constraint::~Constraint()
@@ -81,9 +91,14 @@ Constraint::~Constraint()
 
 App::DocumentObjectExecReturn *Constraint::execute(void)
 {
-    References.touch();
-    Scale.touch();
-    return StdReturn;
+    try {
+        References.touch();
+        Scale.touch();
+        return StdReturn;
+    }
+    catch (const Standard_Failure& e) {
+        return new App::DocumentObjectExecReturn(e.GetMessageString(), this);
+    }
 }
 
 //OvG: Provide the ability to determine how big to draw constraint arrows etc.
@@ -114,14 +129,15 @@ void Constraint::onChanged(const App::Property* prop)
         // Extract geometry from References
         TopoDS_Shape sh;
 
+        bool execute = this->isRecomputing();
         for (std::size_t i = 0; i < Objects.size(); i++) {
             App::DocumentObject* obj = Objects[i];
             Part::Feature* feat = static_cast<Part::Feature*>(obj);
             const Part::TopoShape& toposhape = feat->Shape.getShape();
-            if (!toposhape._Shape.IsNull()) {
-                sh = toposhape.getSubShape(SubElements[i].c_str());
+            if (!toposhape.getShape().IsNull()) {
+                sh = toposhape.getSubShape(SubElements[i].c_str(), !execute);
 
-                if (sh.ShapeType() == TopAbs_FACE) {
+                if (!sh.IsNull() && sh.ShapeType() == TopAbs_FACE) {
                     // Get face normal in center point
                     TopoDS_Face face = TopoDS::Face(sh);
                     BRepGProp_Face props(face);
@@ -133,8 +149,7 @@ void Constraint::onChanged(const App::Property* prop)
                     normal.Normalize();
                     NormalDirection.setValue(normal.X(), normal.Y(), normal.Z());
                     // One face is enough...
-                    App::DocumentObject::onChanged(prop);
-                    return;
+                    break;
                 }
             }
         }
@@ -150,7 +165,7 @@ void Constraint::onDocumentRestored()
     App::DocumentObject::onDocumentRestored();
 }
 
-const bool Constraint::getPoints(std::vector<Base::Vector3d> &points, std::vector<Base::Vector3d> &normals, int * scale) const
+bool Constraint::getPoints(std::vector<Base::Vector3d> &points, std::vector<Base::Vector3d> &normals, int * scale) const
 {
     std::vector<App::DocumentObject*> Objects = References.getValues();
     std::vector<std::string> SubElements = References.getSubValues();
@@ -164,19 +179,23 @@ const bool Constraint::getPoints(std::vector<Base::Vector3d> &points, std::vecto
         const Part::TopoShape& toposhape = feat->Shape.getShape();
         if (toposhape.isNull())
             return false;
-        sh = toposhape.getSubShape(SubElements[i].c_str());
+
+        sh = toposhape.getSubShape(SubElements[i].c_str(), true);
+        if (sh.IsNull())
+            return false;
 
         if (sh.ShapeType() == TopAbs_VERTEX) {
             const TopoDS_Vertex& vertex = TopoDS::Vertex(sh);
             gp_Pnt p = BRep_Tool::Pnt(vertex);
-            points.push_back(Base::Vector3d(p.X(), p.Y(), p.Z()));
+            points.emplace_back(p.X(), p.Y(), p.Z());
             normals.push_back(NormalDirection.getValue());
             //OvG: Scale by whole object mass in case of a vertex
             GProp_GProps props;
-            BRepGProp::VolumeProperties(toposhape._Shape, props);
+            BRepGProp::VolumeProperties(toposhape.getShape(), props);
             double lx = props.Mass();
             *scale = this->calcDrawScaleFactor(sqrt(lx)*0.5); //OvG: setup draw scale for constraint
-        } else if (sh.ShapeType() == TopAbs_EDGE) {
+        }
+        else if (sh.ShapeType() == TopAbs_EDGE) {
             BRepAdaptor_Curve curve(TopoDS::Edge(sh));
             double fp = curve.FirstParameter();
             double lp = curve.LastParameter();
@@ -201,36 +220,78 @@ const bool Constraint::getPoints(std::vector<Base::Vector3d> &points, std::vecto
                 steps = 1;
                 *scale = this->calcDrawScaleFactor(); //OvG: setup draw scale for constraint
             }
+
             steps = steps>CONSTRAINTSTEPLIMIT?CONSTRAINTSTEPLIMIT:steps; //OvG: Place upper limit on number of steps
             double step = (lp - fp) / steps;
             for (int i = 0; i < steps + 1; i++) {
-                gp_Pnt p = curve.Value(i * step);
-                points.push_back(Base::Vector3d(p.X(), p.Y(), p.Z()));
+                // Parameter values must be in the range [fp, lp] (#0003683)
+                gp_Pnt p = curve.Value(fp + i * step);
+                points.emplace_back(p.X(), p.Y(), p.Z());
                 normals.push_back(NormalDirection.getValue());
             }
-        } else if (sh.ShapeType() == TopAbs_FACE) {
+        }
+        else if (sh.ShapeType() == TopAbs_FACE) {
             TopoDS_Face face = TopoDS::Face(sh);
+
             // Surface boundaries
             BRepAdaptor_Surface surface(face);
             double ufp = surface.FirstUParameter();
             double ulp = surface.LastUParameter();
             double vfp = surface.FirstVParameter();
             double vlp = surface.LastVParameter();
+            double l;
+            double lv, lu;
+
             // Surface normals
             BRepGProp_Face props(face);
             gp_Vec normal;
             gp_Pnt center;
+
             // Get an estimate for the number of arrows by finding the average length of curves
             Handle(Adaptor3d_HSurface) hsurf;
             hsurf = new BRepAdaptor_HSurface(surface);
-            Adaptor3d_IsoCurve isoc(hsurf, GeomAbs_IsoU, vfp);
-            double l = GCPnts_AbscissaPoint::Length(isoc, Precision::Confusion());
-            isoc.Load(GeomAbs_IsoU, vlp);
-            double lv = (l + GCPnts_AbscissaPoint::Length(isoc, Precision::Confusion()))/2.0;
-            isoc.Load(GeomAbs_IsoV, ufp);
-            l = GCPnts_AbscissaPoint::Length(isoc, Precision::Confusion());
-            isoc.Load(GeomAbs_IsoV, ulp);
-            double lu = (l + GCPnts_AbscissaPoint::Length(isoc, Precision::Confusion()))/2.0;
+
+            Adaptor3d_IsoCurve isoc(hsurf);
+            try {
+                isoc.Load(GeomAbs_IsoU, ufp);
+                l = GCPnts_AbscissaPoint::Length(isoc, Precision::Confusion());
+            }
+            catch (const Standard_Failure&) {
+                gp_Pnt p1 = hsurf->Value(ufp, vfp);
+                gp_Pnt p2 = hsurf->Value(ufp, vlp);
+                l = p1.Distance(p2);
+            }
+
+            try {
+                isoc.Load(GeomAbs_IsoU, ulp);
+                lv = (l + GCPnts_AbscissaPoint::Length(isoc, Precision::Confusion()))/2.0;
+            }
+            catch (const Standard_Failure&) {
+                gp_Pnt p1 = hsurf->Value(ulp, vfp);
+                gp_Pnt p2 = hsurf->Value(ulp, vlp);
+                lv = (l + p1.Distance(p2))/2.0;
+            }
+
+            try {
+                isoc.Load(GeomAbs_IsoV, vfp);
+                l = GCPnts_AbscissaPoint::Length(isoc, Precision::Confusion());
+            }
+            catch (const Standard_Failure&) {
+                gp_Pnt p1 = hsurf->Value(ufp, vfp);
+                gp_Pnt p2 = hsurf->Value(ulp, vfp);
+                l = p1.Distance(p2);
+            }
+
+            try {
+                isoc.Load(GeomAbs_IsoV, vlp);
+                lu = (l + GCPnts_AbscissaPoint::Length(isoc, Precision::Confusion()))/2.0;
+            }
+            catch (const Standard_Failure&) {
+                gp_Pnt p1 = hsurf->Value(ufp, vlp);
+                gp_Pnt p2 = hsurf->Value(ulp, vlp);
+                lu = (l + p1.Distance(p2))/2.0;
+            }
+
             int stepsv;
             if (lv >= 30) //OvG: Increase 10 units distance proportionately to lv for larger objects.
             {
@@ -248,6 +309,7 @@ const bool Constraint::getPoints(std::vector<Base::Vector3d> &points, std::vecto
                 stepsv = 2; // Minimum of three arrows to ensure (as much as possible) that at least one is displayed
                 *scale = this->calcDrawScaleFactor(); //OvG: setup draw scale for constraint
             }
+
             stepsv = stepsv>CONSTRAINTSTEPLIMIT?CONSTRAINTSTEPLIMIT:stepsv; //OvG: Place upper limit on number of steps
             int stepsu;
             if (lu >= 30) //OvG: Increase 10 units distance proportionately to lu for larger objects.
@@ -266,6 +328,7 @@ const bool Constraint::getPoints(std::vector<Base::Vector3d> &points, std::vecto
                 stepsu = 2;
                 *scale = this->calcDrawScaleFactor(); //OvG: setup draw scale for constraint
             }
+
             stepsu = stepsu>CONSTRAINTSTEPLIMIT?CONSTRAINTSTEPLIMIT:stepsu; //OvG: Place upper limit on number of steps
             double stepv = (vlp - vfp) / stepsv;
             double stepu = (ulp - ufp) / stepsu;
@@ -277,10 +340,10 @@ const bool Constraint::getPoints(std::vector<Base::Vector3d> &points, std::vecto
                     gp_Pnt p = surface.Value(u, v);
                     BRepClass_FaceClassifier classifier(face, p, Precision::Confusion());
                     if (classifier.State() != TopAbs_OUT) {
-                        points.push_back(Base::Vector3d(p.X(), p.Y(), p.Z()));
+                        points.emplace_back(p.X(), p.Y(), p.Z());
                         props.Normal(u, v,center,normal);
                         normal.Normalize();
-                        normals.push_back(Base::Vector3d(normal.X(), normal.Y(), normal.Z()));
+                        normals.emplace_back(normal.X(), normal.Y(), normal.Z());
                     }
                 }
             }
@@ -290,7 +353,7 @@ const bool Constraint::getPoints(std::vector<Base::Vector3d> &points, std::vecto
     return true;
 }
 
-const bool Constraint::getCylinder(double &radius, double &height, Base::Vector3d& base, Base::Vector3d& axis) const
+bool Constraint::getCylinder(double &radius, double &height, Base::Vector3d& base, Base::Vector3d& axis) const
 {
     std::vector<App::DocumentObject*> Objects = References.getValues();
     std::vector<std::string> SubElements = References.getSubValues();
@@ -298,7 +361,7 @@ const bool Constraint::getCylinder(double &radius, double &height, Base::Vector3
         return false;
     App::DocumentObject* obj = Objects[0];
     Part::Feature* feat = static_cast<Part::Feature*>(obj);
-    Part::TopoShape toposhape = feat->Shape.getShape();
+    const Part::TopoShape& toposhape = feat->Shape.getShape();
     if (toposhape.isNull())
         return false;
     TopoDS_Shape sh = toposhape.getSubShape(SubElements[0].c_str());
@@ -346,7 +409,7 @@ Base::Vector3d Constraint::getBasePoint(const Base::Vector3d& base, const Base::
     }
 
     // Translate the plane in direction of the cylinder (for positive values of Distance)
-    Handle_Geom_Plane pln = new Geom_Plane(plane);
+    Handle(Geom_Plane) pln = new Geom_Plane(plane);
     gp_Pnt cylbase(base.x, base.y, base.z);
     GeomAPI_ProjectPointOnSurf proj(cylbase, pln);
     if (!proj.IsDone())
@@ -355,10 +418,10 @@ Base::Vector3d Constraint::getBasePoint(const Base::Vector3d& base, const Base::
     gp_Pnt projPnt = proj.NearestPoint();
     if ((fabs(dist) > Precision::Confusion()) && (projPnt.IsEqual(cylbase, Precision::Confusion()) == Standard_False))
         plane.Translate(gp_Vec(projPnt, cylbase).Normalized().Multiplied(dist));
-    Handle_Geom_Plane plnt = new Geom_Plane(plane);
+    Handle(Geom_Plane) plnt = new Geom_Plane(plane);
 
     // Intersect translated plane with cylinder axis
-    Handle_Geom_Curve crv = new Geom_Line(cylbase, cylaxis);
+    Handle(Geom_Curve) crv = new Geom_Line(cylbase, cylaxis);
     GeomAPI_IntCS intersector(crv, plnt);
     if (!intersector.IsDone())
         return Base::Vector3d(0,0,0);
@@ -369,6 +432,28 @@ Base::Vector3d Constraint::getBasePoint(const Base::Vector3d& base, const Base::
 const Base::Vector3d Constraint::getDirection(const App::PropertyLinkSub &direction)
 {
     App::DocumentObject* obj = direction.getValue();
+    if (!obj) {
+        return Base::Vector3d(0,0,0);
+    }
+
+    if (obj->getTypeId().isDerivedFrom(App::Line::getClassTypeId())) {
+        Base::Vector3d vec(1.0, 0.0, 0.0);
+        static_cast<App::Line*>(obj)->Placement.getValue().multVec(vec, vec);
+        return vec;
+    }
+
+    if (obj->getTypeId().isDerivedFrom(App::Plane::getClassTypeId())) {
+        Base::Vector3d vec(0.0, 0.0, 1.0);
+        static_cast<App::Plane*>(obj)->Placement.getValue().multVec(vec, vec);
+        return vec;
+    }
+
+    if (!obj->getTypeId().isDerivedFrom(Part::Feature::getClassTypeId())) {
+        std::stringstream str;
+        str << "Type is not a line, plane or Part object";
+        throw Base::TypeError(str.str());
+    }
+
     std::vector<std::string> names = direction.getSubValues();
     if (names.size() == 0)
         return Base::Vector3d(0,0,0);
@@ -381,7 +466,7 @@ const Base::Vector3d Constraint::getDirection(const App::PropertyLinkSub &direct
     try {
         sh = shape.getSubShape(subName.c_str());
     }
-    catch (Standard_Failure) {
+    catch (Standard_Failure&) {
         std::stringstream str;
         str << "No such sub-element '" << subName << "'";
         throw Base::AttributeError(str.str());
@@ -389,3 +474,27 @@ const Base::Vector3d Constraint::getDirection(const App::PropertyLinkSub &direct
 
     return Fem::Tools::getDirectionFromShape(sh);
 }
+
+// Python feature ---------------------------------------------------------
+
+namespace App {
+/// @cond DOXERR
+PROPERTY_SOURCE_TEMPLATE(Fem::ConstraintPython, Fem::Constraint)
+template<> const char* Fem::ConstraintPython::getViewProviderName(void) const {
+    return "FemGui::ViewProviderFemConstraintPython";
+}
+
+template<> PyObject* Fem::ConstraintPython::getPyObject(void) {
+    if (PythonObject.is(Py::_None())) {
+        // ref counter is set to 1
+        PythonObject = Py::Object(new App::FeaturePythonPyT<App::DocumentObjectPy>(this),true);
+    }
+    return Py::new_reference_to(PythonObject);
+}
+
+// explicit template instantiation
+template class AppFemExport FeaturePythonT<Fem::Constraint>;
+
+/// @endcond
+
+}
