@@ -1,6 +1,7 @@
 /***************************************************************************
  *   Copyright (c) 2013 Jan Rheinländer                                    *
- *                          <jrheinlaender[at]users.sourceforge.net>       *
+ *                                   <jrheinlaender@users.sourceforge.net> *
+ *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
  *   This library is free software; you can redistribute it and/or         *
@@ -40,7 +41,7 @@
 
 using namespace Fem;
 
-PROPERTY_SOURCE(Fem::ConstraintBearing, Fem::Constraint);
+PROPERTY_SOURCE(Fem::ConstraintBearing, Fem::Constraint)
 
 ConstraintBearing::ConstraintBearing()
 {
