@@ -24,6 +24,9 @@
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
+# include <Python.h>
+# include <vtkFieldData.h>
+# include <vtkPointData.h>
 #endif
 
 #include "FemPostFilter.h"
@@ -31,8 +34,7 @@
 #include <Base/Console.h>
 #include <App/Document.h>
 #include <App/DocumentObjectPy.h>
-#include <vtkFieldData.h>
-#include <vtkPointData.h>
+
 
 using namespace Fem;
 using namespace App;
@@ -69,7 +71,7 @@ DocumentObjectExecReturn* FemPostFilter::execute(void) {
 
     if(!m_pipelines.empty() && !m_activePipeline.empty()) {
         FemPostFilter::FilterPipeline& pipe = m_pipelines[m_activePipeline];
-        if ((m_activePipeline.length() >= 13) || (m_activePipeline.length() >= 11)) {
+        if (m_activePipeline.length() >= 11) {
             std::string LineClip = m_activePipeline.substr(0,13);
             std::string PointClip = m_activePipeline.substr(0,11);
             if ((LineClip == "DataAlongLine") || (PointClip == "DataAtPoint")) {
@@ -621,5 +623,3 @@ DocumentObjectExecReturn* FemPostCutFilter::execute(void) {
 
     return Fem::FemPostFilter::execute();
 }
-
-
