@@ -38,7 +38,7 @@
 #include <QObject>
 #include <Base/Console.h>
 #include <App/DocumentObject.h>
-#include <QListWidgetItem>
+#include <QKeyEvent>
 
 class Ui_TaskFemConstraintDisplacement;
 
@@ -48,7 +48,7 @@ class TaskFemConstraintDisplacement : public TaskFemConstraint
     Q_OBJECT
 
 public:
-    TaskFemConstraintDisplacement(ViewProviderFemConstraintDisplacement *ConstraintView,QWidget *parent = 0);
+    TaskFemConstraintDisplacement(ViewProviderFemConstraintDisplacement *ConstraintView, QWidget *parent = 0);
     ~TaskFemConstraintDisplacement();
     const std::string getReferences() const;
     double get_spinxDisplacement()const;
@@ -93,13 +93,12 @@ private Q_SLOTS:
 
     void addToSelection();
     void removeFromSelection();
-    void setSelection(QListWidgetItem* item);
 
 protected:
+    bool event(QEvent *e); 
     void changeEvent(QEvent *e);
 
 private:
-    //void onSelectionChanged(const Gui::SelectionChanges& msg);
     void updateUI();
     Ui_TaskFemConstraintDisplacement* ui;
 
