@@ -31,14 +31,17 @@
 # include <Geom_Line.hxx>
 # include <Geom_Plane.hxx>
 # include <Precision.hxx>
-# include <QMessageBox>
-# include <QAction>
-# include <QRegExp>
-# include <QTextStream>
 # include <TopoDS.hxx>
 # include <gp_Ax1.hxx>
 # include <gp_Lin.hxx>
 # include <gp_Pln.hxx>
+
+# include <QAction>
+# include <QKeyEvent>
+# include <QMessageBox>
+# include <QRegExp>
+# include <QTextStream>
+
 # include <sstream>
 #endif
 
@@ -46,7 +49,9 @@
 #include "TaskFemConstraintHeatflux.h"
 #include "ui_TaskFemConstraintHeatflux.h"
 #include <App/Application.h>
+#include <Base/Tools.h>
 #include <Gui/Command.h>
+#include <Mod/Part/App/PartFeature.h>
 
 using namespace FemGui;
 using namespace Gui;
@@ -54,17 +59,16 @@ using namespace Gui;
 /* TRANSLATOR FemGui::TaskFemConstraintHeatflux */
 
 TaskFemConstraintHeatflux::TaskFemConstraintHeatflux(ViewProviderFemConstraintHeatflux *ConstraintView,QWidget *parent)
-  : TaskFemConstraint(ConstraintView, parent, "fem-constraint-heatflux")
+  : TaskFemConstraint(ConstraintView, parent, "FEM_ConstraintHeatflux")
 {
     proxy = new QWidget(this);
     ui = new Ui_TaskFemConstraintHeatflux();
     ui->setupUi(proxy);
     QMetaObject::connectSlotsByName(this);
 
-    QAction* action = new QAction(tr("Delete"), ui->lw_references);
-    action->connect(action, SIGNAL(triggered()), this, SLOT(onReferenceDeleted()));
-    ui->lw_references->addAction(action);
-    ui->lw_references->setContextMenuPolicy(Qt::ActionsContextMenu);
+    // create a context menu for the listview of the references
+    createDeleteAction(ui->lw_references);
+    deleteAction->connect(deleteAction, SIGNAL(triggered()), this, SLOT(onReferenceDeleted()));
 
     connect(ui->rb_convection, SIGNAL(clicked(bool)),  this, SLOT(Conv()));
     connect(ui->rb_dflux, SIGNAL(clicked(bool)),  this, SLOT(Flux()));
@@ -77,6 +81,8 @@ TaskFemConstraintHeatflux::TaskFemConstraintHeatflux(ViewProviderFemConstraintHe
     //        this, SLOT(onFaceTempChanged(double)));
     connect(ui->if_filmcoef, SIGNAL(valueChanged(double)),
             this, SLOT(onFilmCoefChanged(double)));
+    connect(ui->lw_references, SIGNAL(itemClicked(QListWidgetItem*)),
+        this, SLOT(setSelection(QListWidgetItem*)));
 
     this->groupLayout()->addWidget(proxy);
 
@@ -134,8 +140,6 @@ TaskFemConstraintHeatflux::TaskFemConstraintHeatflux(ViewProviderFemConstraintHe
     ui->btnAdd->blockSignals(false);
     ui->btnRemove->blockSignals(false);
 
-
-
     updateUI();
 }
 
@@ -206,27 +210,26 @@ void TaskFemConstraintHeatflux::Flux()
 void TaskFemConstraintHeatflux::addToSelection()
 {
     std::vector<Gui::SelectionObject> selection = Gui::Selection().getSelectionEx(); //gets vector of selected objects of active document
-    if (selection.size()==0){
+    if (selection.size() == 0){
         QMessageBox::warning(this, tr("Selection error"), tr("Nothing selected!"));
         return;
     }
-
     Fem::ConstraintHeatflux* pcConstraint = static_cast<Fem::ConstraintHeatflux*>(ConstraintView->getObject());
     std::vector<App::DocumentObject*> Objects = pcConstraint->References.getValues();
     std::vector<std::string> SubElements = pcConstraint->References.getSubValues();
 
-    for (std::vector<Gui::SelectionObject>::iterator it = selection.begin();  it != selection.end(); ++it){//for every selected object
-        if (static_cast<std::string>(it->getTypeName()).substr(0,4).compare(std::string("Part"))!=0){
-            QMessageBox::warning(this, tr("Selection error"),tr("Selected object is not a part!"));
+    for (std::vector<Gui::SelectionObject>::iterator it = selection.begin(); it != selection.end(); ++it){//for every selected object
+        if (!it->isObjectTypeOf(Part::Feature::getClassTypeId())) {
+            QMessageBox::warning(this, tr("Selection error"), tr("Selected object is not a part!"));
             return;
         }
+        const std::vector<std::string>& subNames = it->getSubNames();
+        App::DocumentObject* obj = it->getObject();
 
-        std::vector<std::string> subNames=it->getSubNames();
-
-        if (subNames.size()>0){
-            for (unsigned int subIt=0;subIt<(subNames.size());++subIt){
-                if (subNames[subIt].substr(0,4).compare(std::string("Face"))!=0){
-                    QMessageBox::warning(this, tr("Selection error"),tr("Selection must only consist of faces!"));
+        if (subNames.size() > 0){
+            for (size_t subIt = 0; subIt < (subNames.size()); ++subIt){
+                if (subNames[subIt].substr(0, 4) != "Face") {
+                    QMessageBox::warning(this, tr("Selection error"), tr("Selection must only consist of faces!"));
                     return;
                 }
             }
@@ -234,38 +237,33 @@ void TaskFemConstraintHeatflux::addToSelection()
         else{
             //fix me, if an object is selected completely, getSelectionEx does not return any SubElements
         }
-
-        App::DocumentObject* obj = ConstraintView->getObject()->getDocument()->getObject(it->getFeatName());
-        for (unsigned int subIt=0;subIt<(subNames.size());++subIt){// for every selected sub element
-            bool addMe=true;
-            for (std::vector<std::string>::iterator itr=std::find(SubElements.begin(),SubElements.end(),subNames[subIt]);
-                   itr!= SubElements.end();
-                   itr =  std::find(++itr,SubElements.end(),subNames[subIt]))
+        for (size_t subIt = 0; subIt < (subNames.size()); ++subIt){// for every selected sub element
+            bool addMe = true;
+            for (std::vector<std::string>::iterator itr=std::find(SubElements.begin(), SubElements.end(), subNames[subIt]);
+                   itr != SubElements.end();
+                   itr = std::find(++itr, SubElements.end(), subNames[subIt]))
             {// for every sub element in selection that matches one in old list
-                if (obj==Objects[std::distance(SubElements.begin(),itr)]){//if selected sub element's object equals the one in old list then it was added before so don't add
+                if (obj==Objects[std::distance(SubElements.begin(), itr)]){//if selected sub element's object equals the one in old list then it was added before so don't add
                     addMe=false;
                 }
             }
             if (addMe){
-                disconnect(ui->lw_references, SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)),
-                    this, SLOT(setSelection(QListWidgetItem*)));
+                QSignalBlocker block(ui->lw_references);
                 Objects.push_back(obj);
                 SubElements.push_back(subNames[subIt]);
                 ui->lw_references->addItem(makeRefText(obj, subNames[subIt]));
-                connect(ui->lw_references, SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)),
-                    this, SLOT(setSelection(QListWidgetItem*)));
             }
         }
     }
     //Update UI
-    pcConstraint->References.setValues(Objects,SubElements);
+    pcConstraint->References.setValues(Objects, SubElements);
     updateUI();
 }
 
 void TaskFemConstraintHeatflux::removeFromSelection()
 {
     std::vector<Gui::SelectionObject> selection = Gui::Selection().getSelectionEx(); //gets vector of selected objects of active document
-    if (selection.size()==0){
+    if (selection.size() == 0){
         QMessageBox::warning(this, tr("Selection error"), tr("Nothing selected!"));
         return;
     }
@@ -273,19 +271,19 @@ void TaskFemConstraintHeatflux::removeFromSelection()
     Fem::ConstraintHeatflux* pcConstraint = static_cast<Fem::ConstraintHeatflux*>(ConstraintView->getObject());
     std::vector<App::DocumentObject*> Objects = pcConstraint->References.getValues();
     std::vector<std::string> SubElements = pcConstraint->References.getSubValues();
-    std::vector<int> itemsToDel;
+    std::vector<size_t> itemsToDel;
     for (std::vector<Gui::SelectionObject>::iterator it = selection.begin();  it != selection.end(); ++it){//for every selected object
-        if (static_cast<std::string>(it->getTypeName()).substr(0,4).compare(std::string("Part"))!=0){
+        if (!it->isObjectTypeOf(Part::Feature::getClassTypeId())) {
             QMessageBox::warning(this, tr("Selection error"),tr("Selected object is not a part!"));
             return;
         }
+        const std::vector<std::string>& subNames = it->getSubNames();
+        App::DocumentObject* obj = it->getObject();
 
-        std::vector<std::string> subNames=it->getSubNames();
-
-        if (subNames.size()>0){
-            for (unsigned int subIt=0;subIt<(subNames.size());++subIt){
-                if (subNames[subIt].substr(0,4).compare(std::string("Face"))!=0){
-                    QMessageBox::warning(this, tr("Selection error"),tr("Selection must only consist of faces!"));
+        if (subNames.size() > 0){
+            for (size_t subIt = 0; subIt < (subNames.size()); ++subIt){
+                if (subNames[subIt].substr(0, 4) != "Face") {
+                    QMessageBox::warning(this, tr("Selection error"), tr("Selection must only consist of faces!"));
                     return;
                 }
             }
@@ -293,61 +291,35 @@ void TaskFemConstraintHeatflux::removeFromSelection()
         else{
             //fix me, if an object is selected completely, getSelectionEx does not return any SubElements
         }
-
-        App::DocumentObject* obj = ConstraintView->getObject()->getDocument()->getObject(it->getFeatName());
-
-        for (unsigned int subIt=0;subIt<(subNames.size());++subIt){// for every selected sub element
-            for (std::vector<std::string>::iterator itr=std::find(SubElements.begin(),SubElements.end(),subNames[subIt]);
-                itr!= SubElements.end();
-                itr =  std::find(++itr,SubElements.end(),subNames[subIt]))
+        for (size_t subIt = 0; subIt < (subNames.size()); ++subIt){// for every selected sub element
+            for (std::vector<std::string>::iterator itr = std::find(SubElements.begin(), SubElements.end(), subNames[subIt]);
+                itr != SubElements.end();
+                itr = std::find(++itr, SubElements.end(), subNames[subIt]))
             {// for every sub element in selection that matches one in old list
-                if (obj==Objects[std::distance(SubElements.begin(),itr)]){//if selected sub element's object equals the one in old list then it was added before so mark for deletion
-                    itemsToDel.push_back(std::distance(SubElements.begin(),itr));
+                if (obj == Objects[std::distance(SubElements.begin(), itr)]){//if selected sub element's object equals the one in old list then it was added before so mark for deletion
+                    itemsToDel.push_back(std::distance(SubElements.begin(), itr));
                 }
             }
         }
     }
-
-    std::sort(itemsToDel.begin(),itemsToDel.end());
-    while (itemsToDel.size()>0){
-        Objects.erase(Objects.begin()+itemsToDel.back());
-        SubElements.erase(SubElements.begin()+itemsToDel.back());
+    std::sort(itemsToDel.begin(), itemsToDel.end());
+    while (itemsToDel.size() > 0){
+        Objects.erase(Objects.begin() + itemsToDel.back());
+        SubElements.erase(SubElements.begin() + itemsToDel.back());
         itemsToDel.pop_back();
     }
     //Update UI
-    disconnect(ui->lw_references, SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)),
-        this, SLOT(setSelection(QListWidgetItem*)));
-
-    ui->lw_references->clear();
-    for (unsigned int j=0;j<Objects.size();j++){
-        ui->lw_references->addItem(makeRefText(Objects[j], SubElements[j]));
+    {
+        QSignalBlocker block(ui->lw_references);
+        ui->lw_references->clear();
+        for (unsigned int j = 0; j < Objects.size(); j++) {
+            ui->lw_references->addItem(makeRefText(Objects[j], SubElements[j]));
+        }
     }
-    connect(ui->lw_references, SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)),
-        this, SLOT(setSelection(QListWidgetItem*)));
-
-    pcConstraint->References.setValues(Objects,SubElements);
+    pcConstraint->References.setValues(Objects, SubElements);
     updateUI();
 }
 
-
-void TaskFemConstraintHeatflux::setSelection(QListWidgetItem* item){
-    std::string docName=ConstraintView->getObject()->getDocument()->getName();
-
-    std::string s = item->text().toStdString();
-    std::string delimiter = ":";
-
-    size_t pos = 0;
-    std::string objName;
-    std::string subName;
-    pos = s.find(delimiter);
-    objName = s.substr(0, pos);
-    s.erase(0, pos + delimiter.length());
-    subName=s;
-
-    Gui::Selection().clearSelection();
-    Gui::Selection().addSelection(docName.c_str(),objName.c_str(),subName.c_str(),0,0,0);
-}
-
 void TaskFemConstraintHeatflux::onReferenceDeleted() {
     TaskFemConstraintHeatflux::removeFromSelection();
 }
@@ -386,6 +358,11 @@ std::string TaskFemConstraintHeatflux::get_constraint_type(void) const {
     return type;
 }
 
+bool TaskFemConstraintHeatflux::event(QEvent *e)
+{
+    return TaskFemConstraint::KeyEvent(e);
+}
+
 void TaskFemConstraintHeatflux::changeEvent(QEvent *e)
 {
     TaskBox::changeEvent(e);
@@ -406,7 +383,7 @@ TaskDlgFemConstraintHeatflux::TaskDlgFemConstraintHeatflux(ViewProviderFemConstr
 {
     this->ConstraintView = ConstraintView;
     assert(ConstraintView);
-    this->parameter = new TaskFemConstraintHeatflux(ConstraintView);;
+    this->parameter = new TaskFemConstraintHeatflux(ConstraintView);
 
     Content.push_back(parameter);
 }
