@@ -24,6 +24,23 @@
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
+# include <Inventor/events/SoMouseButtonEvent.h>
+# include <Inventor/SoPickedPoint.h>
+# include <Inventor/nodes/SoAnnotation.h>
+# include <Inventor/nodes/SoBaseColor.h>
+# include <Inventor/nodes/SoFontStyle.h>
+# include <Inventor/nodes/SoPickStyle.h>
+# include <Inventor/nodes/SoText2.h>
+# include <Inventor/nodes/SoTranslation.h>
+# include <Inventor/nodes/SoCoordinate3.h>
+# include <Inventor/nodes/SoIndexedLineSet.h>
+# include <Inventor/nodes/SoMarkerSet.h>
+# include <Inventor/nodes/SoDrawStyle.h>
+
+# include <sstream>
+
+# include <QApplication>
+# include <QMessageBox>
 #endif
 
 #include "ui_TaskPostDisplay.h"
@@ -37,6 +54,7 @@
 #include "ViewProviderFemPostObject.h"
 #include "ViewProviderFemPostFunction.h"
 #include "ViewProviderFemPostFilter.h"
+
 #include <Mod/Fem/App/FemPostObject.h>
 #include <Mod/Fem/App/FemPostFilter.h>
 #include <Mod/Fem/App/FemPostPipeline.h>
@@ -46,25 +64,9 @@
 #include <Gui/Command.h>
 #include <Gui/MainWindow.h>
 #include <Gui/Action.h>
-#include <QMessageBox>
-#include <QPushButton>
 #include <Gui/View3DInventor.h>
 #include <Gui/View3DInventorViewer.h>
-# include <Inventor/events/SoMouseButtonEvent.h>
 
-# include <sstream>
-# include <QApplication>
-# include <Inventor/SoPickedPoint.h>
-# include <Inventor/nodes/SoAnnotation.h>
-# include <Inventor/nodes/SoBaseColor.h>
-# include <Inventor/nodes/SoFontStyle.h>
-# include <Inventor/nodes/SoPickStyle.h>
-# include <Inventor/nodes/SoText2.h>
-# include <Inventor/nodes/SoTranslation.h>
-# include <Inventor/nodes/SoCoordinate3.h>
-# include <Inventor/nodes/SoIndexedLineSet.h>
-# include <Inventor/nodes/SoMarkerSet.h>
-# include <Inventor/nodes/SoDrawStyle.h>
 #include <Gui/View3DInventorViewer.h>
 #include <Gui/Inventor/MarkerBitmaps.h>
 #include <Base/Console.h>
@@ -76,7 +78,7 @@
 using namespace FemGui;
 using namespace Gui;
 
-// ----------------------------------------------------------------------------
+// ***************************************************************************
 
 PointMarker::PointMarker(Gui::View3DInventorViewer* iv, std::string ObjName) : view(iv),
     vp(new ViewProviderPointMarker)
@@ -143,7 +145,7 @@ ViewProviderPointMarker::~ViewProviderPointMarker()
     pCoords->unref();
 }
 
-// ----------------------------------------------------------------------------
+// ***************************************************************************
 
 DataMarker::DataMarker(Gui::View3DInventorViewer* iv, std::string ObjName) : view(iv),
     vp(new ViewProviderDataMarker)
@@ -216,10 +218,10 @@ ViewProviderDataMarker::~ViewProviderDataMarker()
     pMarker->unref();
 }
 
-//**************************************************************************
-//**************************************************************************
+// ***************************************************************************
+// ***************************************************************************
 // TaskDialog
-//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+// ***************************************************************************
 
 TaskDlgPost::TaskDlgPost(Gui::ViewProviderDocumentObject *view)
     : TaskDialog(), m_view(view)
@@ -297,7 +299,7 @@ void TaskDlgPost::modifyStandardButtons(QDialogButtonBox* box) {
         box->button(QDialogButtonBox::Apply)->setDefault(true);
 }
 
-//############################################################################################
+// ***************************************************************************
 // some task box methods
 TaskPostBox::TaskPostBox(Gui::ViewProviderDocumentObject* view, const QPixmap &icon, const QString &title, QWidget* parent)
     : TaskBox(icon, title, true, parent) {
@@ -339,10 +341,10 @@ void TaskPostBox::updateEnumerationList(App::PropertyEnumeration& prop, QComboBo
     box->setCurrentIndex(index);
 }
 
-//###########################################################################################################
+// ***************************************************************************
 // post pipeline results
 TaskPostDisplay::TaskPostDisplay(Gui::ViewProviderDocumentObject* view, QWidget *parent)
-    : TaskPostBox(view, Gui::BitmapFactory().pixmap("fem-post-result-show"), tr("Result display options"), parent)
+    : TaskPostBox(view, Gui::BitmapFactory().pixmap("FEM_ResultShow"), tr("Result display options"), parent)
 {
     //we need a separate container widget to add all controls to
     proxy = new QWidget(this);
@@ -396,7 +398,7 @@ void TaskPostDisplay::applyPythonCode() {
 
 }
 
-//############################################################################################
+// ***************************************************************************
 // ?
 // the icon fem-post-geo-plane might be wrong but I do not know any better since the plane is one of the implicit functions
 TaskPostFunction::TaskPostFunction(ViewProviderDocumentObject* view, QWidget* parent): TaskPostBox(view, Gui::BitmapFactory().pixmap("fem-post-geo-plane"), tr("Implicit function"), parent) {
@@ -419,10 +421,10 @@ void TaskPostFunction::applyPythonCode() {
     //we apply the views widgets python code
 }
 
-//############################################################################################
+// ***************************************************************************
 // region clip filter
 TaskPostClip::TaskPostClip(ViewProviderDocumentObject* view, App::PropertyLink* function, QWidget* parent)
-    : TaskPostBox(view,Gui::BitmapFactory().pixmap("fem-post-filter-clip-region"), tr("Clip region, choose implicit function"), parent) {
+    : TaskPostBox(view,Gui::BitmapFactory().pixmap("FEM_PostFilterClipRegion"), tr("Clip region, choose implicit function"), parent) {
 
     assert(view->isDerivedFrom(ViewProviderFemPostClip::getClassTypeId()));
     assert(function);
@@ -541,10 +543,10 @@ void TaskPostClip::on_InsideOut_toggled(bool val) {
     recompute();
 }
 
-//############################################################################################
+// ***************************************************************************
 // data along a line
 TaskPostDataAlongLine::TaskPostDataAlongLine(ViewProviderDocumentObject* view, QWidget* parent)
-    : TaskPostBox(view,Gui::BitmapFactory().pixmap("fem-post-filter-data-along-line"), tr("Data along a line options"), parent) {
+    : TaskPostBox(view,Gui::BitmapFactory().pixmap("FEM_PostFilterDataAlongLine"), tr("Data along a line options"), parent) {
 
     assert(view->isDerivedFrom(ViewProviderFemPostDataAlongLine::getClassTypeId()));
 
@@ -758,10 +760,10 @@ plt.show()\n";
 
 }
 
-//############################################################################################
+// ***************************************************************************
 // data at point
 TaskPostDataAtPoint::TaskPostDataAtPoint(ViewProviderDocumentObject* view, QWidget* parent)
-    : TaskPostBox(view,Gui::BitmapFactory().pixmap("fem-post-filter-data-at-point"), tr("Data at point options"), parent) {
+    : TaskPostBox(view,Gui::BitmapFactory().pixmap("FEM_PostFilterDataAtPoint"), tr("Data at point options"), parent) {
 
     assert(view->isDerivedFrom(ViewProviderFemPostDataAtPoint::getClassTypeId()));
 
@@ -922,10 +924,10 @@ void TaskPostDataAtPoint::on_Field_activated(int i) {
     Base::Console().Error(PointData.c_str());
 }
 
-//############################################################################################
+// ***************************************************************************
 // scalar clip filter
 TaskPostScalarClip::TaskPostScalarClip(ViewProviderDocumentObject* view, QWidget* parent) :
-    TaskPostBox(view, Gui::BitmapFactory().pixmap("fem-post-filter-clip-scalar"), tr("Scalar clip options"), parent) {
+    TaskPostBox(view, Gui::BitmapFactory().pixmap("FEM_PostFilterClipScalar"), tr("Scalar clip options"), parent) {
 
     assert(view->isDerivedFrom(ViewProviderFemPostScalarClip::getClassTypeId()));
 
@@ -939,17 +941,27 @@ TaskPostScalarClip::TaskPostScalarClip(ViewProviderDocumentObject* view, QWidget
     //load the default values
     updateEnumerationList(getTypedObject<Fem::FemPostScalarClipFilter>()->Scalars, ui->Scalar);
     ui->InsideOut->setChecked(static_cast<Fem::FemPostScalarClipFilter*>(getObject())->InsideOut.getValue());
+    App::PropertyFloatConstraint& scalar_prop = static_cast<Fem::FemPostScalarClipFilter*>(getObject())->Value;
+    double scalar_factor = scalar_prop.getValue();
 
-    App::PropertyFloatConstraint& value = static_cast<Fem::FemPostScalarClipFilter*>(getObject())->Value;
-    //don't forget to sync the slider
+    // set spinbox scalar_factor, don't forget to sync the slider
     ui->Value->blockSignals(true);
-    ui->Value->setValue( value.getValue());
-    ui->Value->blockSignals(false);
-    //don't forget to sync the slider
-    ui->Value->blockSignals(true);
-    ui->Value->setValue( value.getConstraints()->UpperBound * (1-double(value.getValue())/100.)
-                            + double(value.getValue())/100.*value.getConstraints()->UpperBound);
+    ui->Value->setValue(scalar_factor);
     ui->Value->blockSignals(false);
+
+    // sync the slider
+    // slider min = 0%, slider max = 100%
+    //
+    //                 scalar_factor 
+    // slider_value = --------------- x 100
+    //                      max
+    //
+    double max = scalar_prop.getConstraints()->UpperBound;
+    int slider_value = (scalar_factor / max) * 100.;
+    ui->Slider->blockSignals(true);
+    ui->Slider->setValue(slider_value);
+    ui->Slider->blockSignals(false);
+    Base::Console().Log("init: scalar_factor, slider_value: %f, %i: \n", scalar_factor, slider_value);
 }
 
 TaskPostScalarClip::~TaskPostScalarClip() {
@@ -965,20 +977,25 @@ void TaskPostScalarClip::on_Scalar_currentIndexChanged(int idx) {
     static_cast<Fem::FemPostScalarClipFilter*>(getObject())->Scalars.setValue(idx);
     recompute();
 
-    //update constraints and values
-    App::PropertyFloatConstraint& value = static_cast<Fem::FemPostScalarClipFilter*>(getObject())->Value;
-    ui->Maximum->setText(QString::number(value.getConstraints()->UpperBound));
-    ui->Minimum->setText(QString::number(value.getConstraints()->LowerBound));
+    // update constraints and values
+    App::PropertyFloatConstraint& scalar_prop = static_cast<Fem::FemPostScalarClipFilter*>(getObject())->Value;
+    double scalar_factor = scalar_prop.getValue();
+    double min = scalar_prop.getConstraints()->LowerBound;
+    double max = scalar_prop.getConstraints()->UpperBound;
 
-    //don't forget to sync the slider
+    ui->Maximum->setText(QString::number(min));
+    ui->Minimum->setText(QString::number(max));
+
+    // set scalar_factor, don't forget to sync the slider
     ui->Value->blockSignals(true);
-    ui->Value->setValue( value.getValue());
-    ui->Value->blockSignals(false);
-    //don't forget to sync the slider
-    ui->Value->blockSignals(true);
-    ui->Value->setValue( value.getConstraints()->UpperBound * (1-double(value.getValue())/100.)
-                            + double(value.getValue())/100.*value.getConstraints()->UpperBound);
+    ui->Value->setValue(scalar_factor);
     ui->Value->blockSignals(false);
+
+    // sync the slider
+    ui->Slider->blockSignals(true);
+    int slider_value = (scalar_factor / max) * 100.;
+    ui->Slider->setValue(slider_value);
+    ui->Slider->blockSignals(false);
 }
 
 void TaskPostScalarClip::on_Slider_valueChanged(int v) {
@@ -1013,13 +1030,12 @@ void TaskPostScalarClip::on_InsideOut_toggled(bool val) {
     recompute();
 }
 
-
-//############################################################################################
+// ***************************************************************************
 // warp filter
 // spinbox min, slider, spinbox max
 // spinbox warp factor
 TaskPostWarpVector::TaskPostWarpVector(ViewProviderDocumentObject* view, QWidget* parent) :
-    TaskPostBox(view, Gui::BitmapFactory().pixmap("fem-post-filter-warp"), tr("Warp options"), parent) {
+    TaskPostBox(view, Gui::BitmapFactory().pixmap("FEM_PostFilterWarp"), tr("Warp options"), parent) {
 
     assert(view->isDerivedFrom(ViewProviderFemPostWarpVector::getClassTypeId()));
 
@@ -1157,10 +1173,10 @@ void TaskPostWarpVector::on_Min_valueChanged(double) {
     ui->Slider->blockSignals(false);
 }
 
-//############################################################################################
+// ***************************************************************************
 // function clip filter
 TaskPostCut::TaskPostCut(ViewProviderDocumentObject* view, App::PropertyLink* function, QWidget* parent)
-    : TaskPostBox(view,Gui::BitmapFactory().pixmap("fem-post-filter-cut-function"), tr("Function cut, choose implicit function"), parent) {
+    : TaskPostBox(view,Gui::BitmapFactory().pixmap("FEM_PostFilterCutFunction"), tr("Function cut, choose implicit function"), parent) {
 
     assert(view->isDerivedFrom(ViewProviderFemPostCut::getClassTypeId()));
     assert(function);
