@@ -1,5 +1,6 @@
 /***************************************************************************
- *   Copyright (c) 2013 Jan Rheinländer <jrheinlaender[at]users.sourceforge.net>     *
+ *   Copyright (c) 2013 Jan Rheinländer                                    *
+ *                                <jrheinlaender[at]users.sourceforge.net> *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -25,10 +26,12 @@
 
 #ifndef _PreComp_
 # include <Standard_math.hxx>
+# include <Precision.hxx>
+
 # include <Inventor/nodes/SoSeparator.h>
 # include <Inventor/nodes/SoTranslation.h>
 # include <Inventor/nodes/SoRotation.h>
-# include <Precision.hxx>
+
 # include <QMessageBox>
 #endif
 
@@ -47,7 +50,7 @@ PROPERTY_SOURCE(FemGui::ViewProviderFemConstraintBearing, FemGui::ViewProviderFe
 
 ViewProviderFemConstraintBearing::ViewProviderFemConstraintBearing()
 {
-    sPixmap = "fem-constraint-bearing";
+    sPixmap = "FEM_ConstraintBearing";
 }
 
 ViewProviderFemConstraintBearing::~ViewProviderFemConstraintBearing()
@@ -116,7 +119,7 @@ void ViewProviderFemConstraintBearing::updateData(const App::Property* prop)
 
     if (strcmp(prop->getName(),"BasePoint") == 0) {
         // Remove and recreate the symbol
-        pShapeSep->removeAllChildren();
+        Gui::coinRemoveAllChildren(pShapeSep);
 
         // This should always point outside of the cylinder
         Base::Vector3d normal = pcConstraint->NormalDirection.getValue();
