@@ -24,18 +24,25 @@
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
-#include <Inventor/nodes/SoCoordinate3.h>
-#include <Inventor/nodes/SoIndexedPointSet.h>
-#include <Inventor/nodes/SoIndexedLineSet.h>
-#include <Inventor/nodes/SoIndexedFaceSet.h>
-#include <Inventor/nodes/SoIndexedTriangleStripSet.h>
-#include <Inventor/nodes/SoShapeHints.h>
-#include <Inventor/nodes/SoMaterial.h>
-#include <Inventor/nodes/SoNormal.h>
-#include <Inventor/nodes/SoSeparator.h>
-#include <Inventor/nodes/SoPointSet.h>
-#include <Inventor/nodes/SoPolygonOffset.h>
-#include <Inventor/nodes/SoDrawStyle.h>
+# include <Inventor/nodes/SoCoordinate3.h>
+# include <Inventor/nodes/SoIndexedPointSet.h>
+# include <Inventor/nodes/SoIndexedLineSet.h>
+# include <Inventor/nodes/SoIndexedFaceSet.h>
+# include <Inventor/nodes/SoIndexedTriangleStripSet.h>
+# include <Inventor/nodes/SoShapeHints.h>
+# include <Inventor/nodes/SoMaterial.h>
+# include <Inventor/nodes/SoNormal.h>
+# include <Inventor/nodes/SoSeparator.h>
+# include <Inventor/nodes/SoPointSet.h>
+# include <Inventor/nodes/SoPolygonOffset.h>
+# include <Inventor/nodes/SoDrawStyle.h>
+
+# include <vtkPointData.h>
+# include <vtkCellArray.h>
+# include <vtkCellData.h>
+# include <vtkLookupTable.h>
+
+# include <QMessageBox>
 #endif
 
 #include "ViewProviderFemPostObject.h"
@@ -48,14 +55,13 @@
 #include <Gui/Document.h>
 #include <Gui/SoFCColorBar.h>
 
-#include <vtkPointData.h>
-#include <vtkCellArray.h>
-#include <vtkCellData.h>
-#include <vtkLookupTable.h>
-#include <QMessageBox>
-
 using namespace FemGui;
 
+#ifdef VTK_CELL_ARRAY_V2
+typedef const vtkIdType* vtkIdTypePtr;
+#else
+typedef vtkIdType* vtkIdTypePtr;
+#endif
 
 PROPERTY_SOURCE(FemGui::ViewProviderFemPostObject, Gui::ViewProviderDocumentObject)
 
@@ -181,7 +187,7 @@ void ViewProviderFemPostObject::attach(App::DocumentObject *pcObj)
     addDisplayMaskMode(m_seperator, "Default");
     setDisplayMaskMode("Default");
 
-    setupPipeline();
+    (void)setupPipeline();
 }
 
 SoSeparator* ViewProviderFemPostObject::getFrontRoot(void) const {
@@ -207,7 +213,7 @@ void ViewProviderFemPostObject::setDisplayMode(const char* ModeName)
     else if (strcmp("Nodes (surface only)",ModeName)==0)
         m_currentAlgorithm = m_pointsSurface;
 
-    update();
+    updateVtk();
 
     ViewProviderDocumentObject::setDisplayMode( ModeName );
 }
@@ -225,7 +231,7 @@ std::vector<std::string> ViewProviderFemPostObject::getDisplayModes(void) const
     return StrList;
 }
 
-void ViewProviderFemPostObject::update() {
+void ViewProviderFemPostObject::updateVtk() {
 
     if(!setupPipeline())
         return;
@@ -316,7 +322,7 @@ void ViewProviderFemPostObject::update3D() {
     vtkDataArray *tcoords = NULL;
     vtkCellArray *cells;
     vtkIdType npts = 0;
-    vtkIdType *indx = 0;
+    vtkIdTypePtr indx = 0;
 
     points = pd->GetPoints();
     pntData = pd->GetPointData();
@@ -504,7 +510,7 @@ void ViewProviderFemPostObject::WriteTransparency() {
 void ViewProviderFemPostObject::updateData(const App::Property* p) {
 
     if( strcmp(p->getName(), "Data") == 0 ) {
-        update();
+        updateVtk();
     }
 }
 
