@@ -1,8 +1,9 @@
 # ***************************************************************************
+# *   Copyright (c) 2013 Joachim Zettler                                    *
+# *   Copyright (c) 2013 Juergen Riegel <FreeCAD@juergen-riegel.net>        *
+# *   Copyright (c) 2016 Bernd Hahnebach <bernd@bimstatik.org>              *
 # *                                                                         *
-# *   Copyright (c) 2013 - Joachim Zettler                                  *
-# *   Copyright (c) 2013 - Juergen Riegel <FreeCAD@juergen-riegel.net>      *
-# *   Copyright (c) 2016 - Bernd Hahnebach <bernd@bimstatik.org>            *
+# *   This file is part of the FreeCAD CAx development system.              *
 # *                                                                         *
 # *   This program is free software; you can redistribute it and/or modify  *
 # *   it under the terms of the GNU Lesser General Public License (LGPL)    *
@@ -22,23 +23,25 @@
 # *                                                                         *
 # ***************************************************************************
 
-__title__ = "FreeCAD Calculix library"
+__title__ = "Result import for Calculix frd file format"
 __author__ = "Juergen Riegel , Michael Hindley, Bernd Hahnebach"
-__url__ = "http://www.freecadweb.org"
+__url__ = "https://www.freecadweb.org"
 
 ## @package importCcxFrdResults
 #  \ingroup FEM
 #  \brief FreeCAD Calculix FRD Reader for FEM workbench
 
-import FreeCAD
 import os
 
+import FreeCAD
+from FreeCAD import Console
+
 
 # ********* generic FreeCAD import and export methods *********
-if open.__module__ == '__builtin__':
+if open.__module__ == "__builtin__":
     # because we'll redefine open below (Python2)
     pyopen = open
-elif open.__module__ == 'io':
+elif open.__module__ == "io":
     # because we'll redefine open below (Python3)
     pyopen = open
 
@@ -49,7 +52,10 @@ def open(filename):
     insert(filename, docname)
 
 
-def insert(filename, docname):
+def insert(
+    filename,
+    docname
+):
     "called when freecad wants to import a file"
     try:
         doc = FreeCAD.getDocument(docname)
@@ -60,85 +66,192 @@ def insert(filename, docname):
 
 
 # ********* module specific methods *********
-def importFrd(filename, analysis=None, result_name_prefix=None):
-    from . import importToolsFem
+def importFrd(
+    filename,
+    analysis=None,
+    result_name_prefix=""
+):
     import ObjectsFem
-    if result_name_prefix is None:
-        result_name_prefix = ''
+    from . import importToolsFem
+
+    if analysis:
+        doc = analysis.Document
+    else:
+        doc = FreeCAD.ActiveDocument
+
     m = read_frd_result(filename)
     result_mesh_object = None
-    if len(m['Nodes']) > 0:
-        if analysis:
-            analysis_object = analysis
+    res_obj = None
 
+    if len(m["Nodes"]) > 0:
         mesh = importToolsFem.make_femmesh(m)
-        result_mesh_object = ObjectsFem.makeMeshResult(FreeCAD.ActiveDocument, 'Result_mesh')
+        result_mesh_object = ObjectsFem.makeMeshResult(
+            doc,
+            "ResultMesh"
+        )
         result_mesh_object.FemMesh = mesh
+        res_mesh_is_compacted = False
+        nodenumbers_for_compacted_mesh = []
 
-        number_of_increments = len(m['Results'])
-        FreeCAD.Console.PrintLog('Increments: ' + str(number_of_increments) + '\n')
-        if len(m['Results']) > 0:
-            for result_set in m['Results']:
-                if 'number' in result_set:
-                    eigenmode_number = result_set['number']
+        number_of_increments = len(m["Results"])
+        Console.PrintLog(
+            "Increments: " + str(number_of_increments) + "\n"
+        )
+        if len(m["Results"]) > 0:
+            for result_set in m["Results"]:
+                if "number" in result_set:
+                    eigenmode_number = result_set["number"]
                 else:
                     eigenmode_number = 0
-                step_time = result_set['time']
+                step_time = result_set["time"]
                 step_time = round(step_time, 2)
                 if eigenmode_number > 0:
-                    results_name = result_name_prefix + 'mode_' + str(eigenmode_number) + '_results'
+                    results_name = (
+                        "{}Mode{}_Results"
+                        .format(result_name_prefix, eigenmode_number)
+                    )
                 elif number_of_increments > 1:
-                    results_name = result_name_prefix + 'time_' + str(step_time) + '_results'
+                    results_name = (
+                        "{}Time{}_Results"
+                        .format(result_name_prefix, step_time)
+                    )
                 else:
-                    results_name = result_name_prefix + 'results'
+                    results_name = (
+                        "{}Results"
+                        .format(result_name_prefix)
+                    )
 
-                res_obj = ObjectsFem.makeResultMechanical(FreeCAD.ActiveDocument, results_name)
+                res_obj = ObjectsFem.makeResultMechanical(doc, results_name)
                 res_obj.Mesh = result_mesh_object
                 res_obj = importToolsFem.fill_femresult_mechanical(res_obj, result_set)
                 if analysis:
-                    analysis_object.addObject(res_obj)
-                # complementary result object calculations
-                import femresult.resulttools as restools
+                    # need to be here, becasause later on, the analysis objs are needed
+                    # see fill of principal stresses
+                    analysis.addObject(res_obj)
+
+                # more result object calculations
+                from femresult import resulttools
+                from femtools import femutils
                 if not res_obj.MassFlowRate:
+                    # information 1:
                     # only compact result if not Flow 1D results
-                    # compact result object, workaround for bug 2873, https://www.freecadweb.org/tracker/view.php?id=2873
-                    res_obj = restools.compact_result(res_obj)
-                res_obj = restools.add_disp_apps(res_obj)  # fill DisplacementLengths
-                res_obj = restools.fill_femresult_stats(res_obj)  # fill Stats
+                    # compact result object, workaround for bug 2873
+                    # https://www.freecadweb.org/tracker/view.php?id=2873
+                    # information 2:
+                    # if the result data has multiple result sets there will be multiple result objs
+                    # they all will use one mesh obj
+                    # on the first res obj fill: the mesh obj will be compacted, thus
+                    # it does not need to be compacted on further result sets
+                    # but NodeNumbers need to be compacted for every result set (res object fill)
+                    # example frd file: https://forum.freecadweb.org/viewtopic.php?t=32649#p274291
+                    if res_mesh_is_compacted is False:
+                        # first result set, compact FemMesh and NodeNumbers
+                        res_obj = resulttools.compact_result(res_obj)
+                        res_mesh_is_compacted = True
+                        nodenumbers_for_compacted_mesh = res_obj.NodeNumbers
+                    else:
+                        # all other result sets, do not compact FemMesh, only set NodeNumbers
+                        res_obj.NodeNumbers = nodenumbers_for_compacted_mesh
+
+                # fill DisplacementLengths
+                res_obj = resulttools.add_disp_apps(res_obj)
+                # fill vonMises
+                res_obj = resulttools.add_von_mises(res_obj)
+                # fill principal stress
+                # if material reinforced object use add additional values to the res_obj
+                if res_obj.getParentGroup():
+                    has_reinforced_mat = False
+                    for obj in res_obj.getParentGroup().Group:
+                        if femutils.is_of_type(obj, "Fem::MaterialReinforced"):
+                            has_reinforced_mat = True
+                            Console.PrintLog(
+                                "Reinfoced material object detected, "
+                                "reinforced principal stresses and standard principal "
+                                " stresses will be added.\n"
+                            )
+                            resulttools.add_principal_stress_reinforced(res_obj)
+                            break
+                    if has_reinforced_mat is False:
+                        Console.PrintLog(
+                            "No einfoced material object detected, "
+                            "standard principal stresses will be added.\n"
+                        )
+                        # fill PrincipalMax, PrincipalMed, PrincipalMin, MaxShear
+                        res_obj = resulttools.add_principal_stress_std(res_obj)
+                else:
+                    Console.PrintLog(
+                        "No Analysis detected, standard principal stresses will be added.\n"
+                    )
+                    # if a pure frd file was opened no analysis and thus no parent group
+                    # fill PrincipalMax, PrincipalMed, PrincipalMin, MaxShear
+                    res_obj = resulttools.add_principal_stress_std(res_obj)
+                # fill Stats
+                res_obj = resulttools.fill_femresult_stats(res_obj)
+
         else:
             error_message = (
-                "We have nodes but no results in frd file, which means we only have a mesh in frd file. "
-                "Usually this happens for analysis type 'NOANALYSIS' or if CalculiX returned no results because "
-                "of nonpositive jacobian determinant in at least one element.\n"
+                "Nodes, but no results found in frd file. "
+                "It means there only is a mesh but no results in frd file. "
+                "Usually this happens for: \n"
+                "- analysis type 'NOANALYSIS'\n"
+                "- if CalculiX returned no results "
+                "(happens on nonpositive jacobian determinant in at least one element)\n"
+                "- just no frd results where requestet in input file "
+                "(neither 'node file' nor 'el file' in output section')\n"
             )
-            FreeCAD.Console.PrintMessage(error_message)
+            Console.PrintWarning(error_message)
+
+        # create a result obj, even if we have no results but a result mesh in frd file
+        # see error message above for more information
+        if not res_obj:
+            if result_name_prefix:
+                results_name = ("{}_Results".format(result_name_prefix))
+            else:
+                results_name = ("Results".format(result_name_prefix))
+            res_obj = ObjectsFem.makeResultMechanical(doc, results_name)
+            res_obj.Mesh = result_mesh_object
+            # TODO, node numbers in result obj could be set
             if analysis:
-                analysis_object.addObject(result_mesh_object)
+                analysis.addObject(res_obj)
 
         if FreeCAD.GuiUp:
             if analysis:
                 import FemGui
-                FemGui.setActiveAnalysis(analysis_object)
-            FreeCAD.ActiveDocument.recompute()
+                FemGui.setActiveAnalysis(analysis)
+            doc.recompute()
 
     else:
-        FreeCAD.Console.PrintError('Problem on frd file import. No nodes found in frd file.\n')
+        Console.PrintError(
+            "Problem on frd file import. No nodes found in frd file.\n"
+        )
+        # None will be returned
+        # or would it be better to raise an exception if there are not even nodes in frd file?
+
+    return res_obj
 
 
-# read a calculix result file and extract the nodes, displacement vectors and stress values.
-def read_frd_result(frd_input):
-    print('Read ccx results from frd file: ' + frd_input)
+# read a calculix result file and extract the nodes
+# displacement vectors and stress values.
+def read_frd_result(
+    frd_input
+):
+    Console.PrintMessage(
+        "Read ccx results from frd file: {}\n"
+        .format(frd_input)
+    )
     inout_nodes = []
-    inout_nodes_file = frd_input.rsplit('.', 1)[0] + '_inout_nodes.txt'
+    inout_nodes_file = frd_input.rsplit(".", 1)[0] + "_inout_nodes.txt"
     if os.path.exists(inout_nodes_file):
-        print('Read special 1DFlow nodes data form: ' + inout_nodes_file)
+        Console.PrintMessage(
+            "Read special 1DFlow nodes data form: {}\n".format(inout_nodes_file)
+        )
         f = pyopen(inout_nodes_file, "r")
         lines = f.readlines()
         for line in lines:
-            a = line.split(',')
+            a = line.split(",")
             inout_nodes.append(a)
         f.close()
-        print(inout_nodes)
+        Console.PrintMessage("{}\n".format(inout_nodes))
     frd_file = pyopen(frd_input, "r")
     nodes = {}
     elements_hexa8 = {}
@@ -155,8 +268,8 @@ def read_frd_result(frd_input):
     elements_seg3 = {}
     results = []
     mode_results = {}
-    mode_results['number'] = float('NaN')
-    mode_results['time'] = float('NaN')
+    mode_results["number"] = float("NaN")
+    mode_results["time"] = float("NaN")
     mode_disp = {}
     mode_stress = {}
     mode_strain = {}
@@ -244,7 +357,8 @@ def read_frd_result(frd_input):
             elif elemType == 4 and input_continues is False:
                 # first line
                 # C3D20 Calculix --> hexa20 FreeCAD
-                # N6, N7, N8, N5, N2, N3, N4, N1, N14, N15, N16, N13, N10, N11, N12, N9, N18, N19, N20, N17
+                # N6, N7, N8, N5, N2, N3, N4, N1, N14, N15
+                # N16, N13, N10, N11, N12, N9, N18, N19, N20, N17
                 nd1 = int(line[3:13])
                 nd2 = int(line[13:23])
                 nd3 = int(line[23:33])
@@ -269,19 +383,31 @@ def read_frd_result(frd_input):
                 nd19 = int(line[83:93])
                 nd20 = int(line[93:103])
                 input_continues = False
-                # CalculiX uses a different node order in input file *.inp and result file *.frd for hexa20 (C3D20)
-                # according to Guido (the developer of ccx), see note in in first line of cgx manuel part element types
-                # ccx (and thus the *.inp) follows the ABAQUS convention (documented in the ccx-documentation)
-                # cgx (and thus the *.frd) follows the FAM2 convention (documented in the cgx-documentation)
-                # FAM32 is from the company FEGS limited, maybe this company does not exist any more)
-                # elements_hexa20[elem] = (nd6, nd7, nd8, nd5, nd2, nd3, nd4, nd1, nd14, nd15,
-                #                          nd16, nd13, nd10, nd11, nd12, nd9, nd18, nd19, nd20, nd17)
-                # elements_hexa20[elem] = (nd6, nd7, nd8, nd5, nd2, nd3, nd4, nd1, nd14, nd15,
-                #                          nd16, nd13, nd18, nd19, nd20, nd17, nd10, nd11, nd12, nd9)
-                # hexa20 import works with the following frd file node assignment
-                elements_hexa20[elem] = (nd8, nd5, nd6, nd7, nd4, nd1, nd2, nd3, nd20, nd17,
-                                         nd18, nd19, nd12, nd9, nd10, nd11, nd16, nd13, nd14, nd15)
-                # print(elements_hexa20[elem])
+                """
+                CalculiX uses a different node order in
+                input file *.inp and result file *.frd for hexa20 (C3D20)
+                according to Guido (the developer of ccx):
+                see note in in first line of cgx manuel part element types
+                ccx (and thus the *.inp) follows the ABAQUS convention
+                documented in the ccx-documentation
+                cgx (and thus the *.frd) follows the FAM2 convention
+                documented in the cgx-documentation
+                FAM32 is from the company FEGS limited
+                maybe this company does not exist any more
+                elements_hexa20[elem] = (
+                    nd6, nd7, nd8, nd5, nd2, nd3, nd4, nd1, nd14, nd15,
+                    nd16, nd13, nd10, nd11, nd12, nd9, nd18, nd19, nd20, nd17
+                )
+                elements_hexa20[elem] = (
+                    nd6, nd7, nd8, nd5, nd2, nd3, nd4, nd1, nd14, nd15,
+                    nd16, nd13, nd18, nd19, nd20, nd17, nd10, nd11, nd12, nd9
+                )
+                hexa20 import works with the following frd file node assignment
+                """
+                elements_hexa20[elem] = (
+                    nd8, nd5, nd6, nd7, nd4, nd1, nd2, nd3, nd20, nd17,
+                    nd18, nd19, nd12, nd9, nd10, nd11, nd16, nd13, nd14, nd15
+                )
             elif elemType == 5 and input_continues is False:
                 # first line
                 # C3D15 Calculix --> penta15 FreeCAD
@@ -305,11 +431,19 @@ def read_frd_result(frd_input):
                 nd14 = int(line[33:43])
                 nd15 = int(line[43:53])
                 input_continues = False
-                # CalculiX uses a different node order in input file *.inp and result file *.frd for penta15 (C3D15), see notes at hexa20
-                # elements_penta15[elem] = (nd5, nd6, nd4, nd2, nd3, nd1, nd11, nd12, nd10, nd8,
-                #                           nd9, nd7, nd14, nd15, nd13)  # order of the *.inp file
-                elements_penta15[elem] = (nd5, nd6, nd4, nd2, nd3, nd1, nd14, nd15, nd13, nd8,
-                                          nd9, nd7, nd11, nd12, nd10)
+                """
+                CalculiX uses a different node order in
+                input file *.inp and result file *.frd for penta15 (C3D15)
+                see notes at hexa20
+                elements_penta15[elem] = (
+                    nd5, nd6, nd4, nd2, nd3, nd1, nd11, nd12, nd10, nd8,
+                    nd9, nd7, nd14, nd15, nd13
+                )  # order of the *.inp file
+                """
+                elements_penta15[elem] = (
+                    nd5, nd6, nd4, nd2, nd3, nd1, nd14, nd15, nd13, nd8,
+                    nd9, nd7, nd11, nd12, nd10
+                )
             elif elemType == 6:
                 # C3D10 Calculix --> tetra10 FreeCAD
                 # N2, N1, N3, N4, N5, N7, N6, N9, N8, N10
@@ -370,7 +504,9 @@ def read_frd_result(frd_input):
             elif elemType == 12:
                 # B32 CalculiX --> seg3 FreeCAD
                 # Also D element element number
-                # CalculiX uses a different node order in input file *.inp and result file *.frd for seg3 (B32), see notes at hexa20
+                # CalculiX uses a different node order in
+                # input file *.inp and result file *.frd for seg3 (B32)
+                # see notes at hexa20
                 # N1, N2 ,N3
                 nd1 = int(line[3:13])
                 nd2 = int(line[13:23])
@@ -378,11 +514,14 @@ def read_frd_result(frd_input):
                 if inout_nodes:
                     for i in range(len(inout_nodes)):
                         if nd1 == int(inout_nodes[i][1]):
-                            elements_seg3[elem] = (int(inout_nodes[i][2]), nd3, nd1)  # fluid inlet node numbering
+                            # fluid inlet node numbering
+                            elements_seg3[elem] = (int(inout_nodes[i][2]), nd3, nd1)
                         elif nd3 == int(inout_nodes[i][1]):
-                            elements_seg3[elem] = (nd1, int(inout_nodes[i][2]), nd3)  # fluid outlet node numbering
+                            # fluid outlet node numbering
+                            elements_seg3[elem] = (nd1, int(inout_nodes[i][2]), nd3)
                 else:
-                    elements_seg3[elem] = (nd1, nd2, nd3)  # normal node numbering for D, B32 elements
+                    # normal node numbering for D, B32 elements
+                    elements_seg3[elem] = (nd1, nd2, nd3)
 
         # Check if we found new eigenmode line
         if line[5:10] == "PMODE":
@@ -396,7 +535,8 @@ def read_frd_result(frd_input):
             mode_time_found = True
         if mode_time_found and (line[2:7] == "100CL"):
             # we found the new time step line
-            # !!! be careful here, there is timetemp and timestep! TODO: use more differ names
+            # !!! be careful here, there is timetemp and timestep!
+            # TODO: use more differ names
             timetemp = float(line[13:25])
             if timetemp > timestep:
                 timestep = timetemp
@@ -425,7 +565,10 @@ def read_frd_result(frd_input):
             stress_4 = float(line[49:61])
             stress_5 = float(line[61:73])
             stress_6 = float(line[73:85])
-            mode_stress[elem] = (stress_1, stress_2, stress_3, stress_4, stress_5, stress_6)
+            # CalculiX frd files: (Sxx, Syy, Szz, Sxy, Syz, Szx)
+            # FreeCAD:            (Sxx, Syy, Szz, Sxy, Sxz, Syz)
+            # thus exchange the last two entries
+            mode_stress[elem] = (stress_1, stress_2, stress_3, stress_4, stress_6, stress_5)
 
         # Check if we found strain section
         if line[5:13] == "TOSTRAIN":
@@ -436,10 +579,13 @@ def read_frd_result(frd_input):
             strain_1 = float(line[13:25])
             strain_2 = float(line[25:37])
             strain_3 = float(line[37:49])
-            # strain_4 = float(line[49:61])  # Not used in vector
-            # strain_5 = float(line[61:73])
-            # strain_6 = float(line[73:85])
-            mode_strain[elem] = FreeCAD.Vector(strain_1, strain_2, strain_3)
+            strain_4 = float(line[49:61])
+            strain_5 = float(line[61:73])
+            strain_6 = float(line[73:85])
+            # CalculiX frd files: (Exx, Eyy, Ezz, Exy, Eyz, Ezx)
+            # FreeCAD:            (Exx, Eyy, Ezz, Exy, Exz, Eyz)
+            # thus exchange the last two entries
+            mode_strain[elem] = (strain_1, strain_2, strain_3, strain_4, strain_6, strain_5)
 
         # Check if we found an equivalent plastic strain section
         if line[5:7] == "PE":
@@ -471,7 +617,8 @@ def read_frd_result(frd_input):
                 for i in range(len(inout_nodes)):
                     if elem == int(inout_nodes[i][1]):
                         node = int(inout_nodes[i][2])
-                        mode_massflow[node] = (massflow * 1000)  # convert units to kg/s from t/s
+                        # convert units to kg/s from t/s
+                        mode_massflow[node] = (massflow * 1000)
 
         # Check if we found a network pressure section
         if line[5:11] == "STPRES":
@@ -500,125 +647,134 @@ def read_frd_result(frd_input):
                 node_element_section = True
 
             if mode_disp_found:
-                mode_results['disp'] = mode_disp
+                mode_results["disp"] = mode_disp
                 mode_disp = {}
                 mode_disp_found = False
                 node_element_section = False
 
             if mode_stress_found:
-                mode_results['stress'] = mode_stress
+                mode_results["stress"] = mode_stress
                 mode_stress = {}
                 mode_stress_found = False
                 node_element_section = False
 
             if mode_strain_found:
-                mode_results['strainv'] = mode_strain
+                mode_results["strain"] = mode_strain
+
                 mode_strain = {}
                 mode_strain_found = False
                 node_element_section = False
 
             if mode_peeq_found:
-                mode_results['peeq'] = mode_peeq
+                mode_results["peeq"] = mode_peeq
                 mode_peeq = {}
                 mode_peeq_found = False
                 node_element_section = False
 
             if mode_temp_found:
-                mode_results['temp'] = mode_temp
+                mode_results["temp"] = mode_temp
                 mode_temp = {}
                 mode_temp_found = False
                 node_element_section = False
 
             if mode_massflow_found:
-                mode_results['mflow'] = mode_massflow
+                mode_results["mflow"] = mode_massflow
                 mode_massflow = {}
                 mode_massflow_found = False
                 node_element_section = False
 
             if mode_networkpressure_found:
-                mode_results['npressure'] = mode_networkpressure
+                mode_results["npressure"] = mode_networkpressure
                 mode_networkpressure_found = False
                 mode_networkpressure = {}
                 node_element_section = False
 
-            '''
-            print('---- End of Section --> Mode_Results may be changed ----')
+            """
+            print("---- End of Section --> Mode_Results may be changed ----")
             for key in sorted(mode_results.keys()):
-                if key is 'number' or key is 'time':
-                    print(key + ' --> ' + str(mode_results[key]))
+                if key is "number" or key is "time":
+                    print(key + " --> " + str(mode_results[key]))
                 else:
-                    print(key + ' --> ' + str(len(mode_results[key])))
-            print('----Mode_Results----\n')
-            '''
+                    print(key + " --> " + str(len(mode_results[key])))
+            print("----Mode_Results----\n")
+            """
 
         # Check if we found the end of frd data
         if line[1:5] == "9999":
             end_of_frd_data_found = True
 
-        if (mode_eigen_changed or mode_time_changed or end_of_frd_data_found) and end_of_section_found and not node_element_section:
+        if (mode_eigen_changed or mode_time_changed or end_of_frd_data_found) \
+                and end_of_section_found \
+                and not node_element_section:
 
-            '''
-            print('\n\n----Append mode_results to results')
+            """
+            print("\n\n----Append mode_results to results")
             print(line)
             for key in sorted(mode_results.keys()):
-                if key is 'number' or key is 'time':
-                    print(key + ' --> ' + str(mode_results[key]))
+                if key is "number" or key is "time":
+                    print(key + " --> " + str(mode_results[key]))
                 else:
-                    print(key + ' --> ' + str(len(mode_results[key])))
-            print('----Append Mode_Results----\n')
-            '''
+                    print(key + " --> " + str(len(mode_results[key])))
+            print("----Append Mode_Results----\n")
+            """
 
             # append mode_results to results and reset mode_result
             results.append(mode_results)
             mode_results = {}
-            mode_results['number'] = float('NaN')  # https://forum.freecadweb.org/viewtopic.php?f=18&t=32649&start=10#p274686
-            mode_results['time'] = float('NaN')
+            # https://forum.freecadweb.org/viewtopic.php?f=18&t=32649&start=10#p274686
+            mode_results["number"] = float("NaN")
+            mode_results["time"] = float("NaN")
             end_of_section_found = False
 
-        # on changed --> write changed values in mode_result --> will be the first to do on an empty mode_result
+        # on changed --> write changed values in mode_result
+        # will be the first to do on an empty mode_result
         if mode_eigen_changed:
-            mode_results['number'] = eigenmode
+            mode_results["number"] = eigenmode
             mode_eigen_changed = False
 
         if mode_time_changed:
-            mode_results['time'] = timestep
-            # mode_results['time'] = 0  # Don't return time if static  # WARUM?
+            mode_results["time"] = timestep
+            # mode_results["time"] = 0  # Don't return time if static  # Why?
             mode_time_found = False
             mode_time_changed = False
 
-        # here we are in the indent of loop for every line in frd file, do not add a print here :-)
+        # here we are in the indent of loop for every line in frd file
+        # do not add a print here :-)
 
     # close frd file if loop over all lines is finished
     frd_file.close()
 
-    '''
+    """
     # debug prints and checks with the read data
-    print('\n\n----RESULTS values begin----')
+    print("\n\n----RESULTS values begin----")
     print(len(results))
-    # print('\n')
+    # print("\n")
     # print(results)
-    print('----RESULTS values end----\n\n')
-    '''
+    print("----RESULTS values end----\n\n")
+    """
 
     if not inout_nodes:
         if results:
-            if 'mflow' in results[0] or 'npressure' in results[0]:
-                FreeCAD.Console.PrintError('We have mflow or npressure, but no inout_nodes file.\n')
+            if "mflow" in results[0] or "npressure" in results[0]:
+                Console.PrintError(
+                    "We have mflow or npressure, but no inout_nodes file.\n"
+                )
     if not nodes:
-        FreeCAD.Console.PrintError('FEM: No nodes found in Frd file.\n')
+        Console.PrintError("FEM: No nodes found in Frd file.\n")
+
     return {
-        'Nodes': nodes,
-        'Seg2Elem': elements_seg2,
-        'Seg3Elem': elements_seg3,
-        'Tria3Elem': elements_tria3,
-        'Tria6Elem': elements_tria6,
-        'Quad4Elem': elements_quad4,
-        'Quad8Elem': elements_quad8,
-        'Tetra4Elem': elements_tetra4,
-        'Tetra10Elem': elements_tetra10,
-        'Hexa8Elem': elements_hexa8,
-        'Hexa20Elem': elements_hexa20,
-        'Penta6Elem': elements_penta6,
-        'Penta15Elem': elements_penta15,
-        'Results': results
+        "Nodes": nodes,
+        "Seg2Elem": elements_seg2,
+        "Seg3Elem": elements_seg3,
+        "Tria3Elem": elements_tria3,
+        "Tria6Elem": elements_tria6,
+        "Quad4Elem": elements_quad4,
+        "Quad8Elem": elements_quad8,
+        "Tetra4Elem": elements_tetra4,
+        "Tetra10Elem": elements_tetra10,
+        "Hexa8Elem": elements_hexa8,
+        "Hexa20Elem": elements_hexa20,
+        "Penta6Elem": elements_penta6,
+        "Penta15Elem": elements_penta15,
+        "Results": results
     }
