@@ -59,12 +59,12 @@ IDF_diag_path="/tmp" # path for output of footprint.lst and missing_models.lst
 ########################################################################################
 
 def open(filename):
-	"""called when freecad opens an Emn file"""
-	docname = os.path.splitext(os.path.basename(filename))[0]
-	doc = FreeCAD.newDocument(docname)
-	message='Started with opening of "'+filename+'" file\n'
-	FreeCAD.Console.PrintMessage(message)
-	process_emn(doc,filename)
+    """called when freecad opens an Emn file"""
+    docname = os.path.splitext(os.path.basename(filename))[0]
+    doc = FreeCAD.newDocument(docname)
+    message='Started with opening of "'+filename+'" file\n'
+    FreeCAD.Console.PrintMessage(message)
+    process_emn(doc,filename)
 
 def insert(filename,docname):
     """called when freecad imports an Emn file"""
@@ -76,7 +76,7 @@ def insert(filename,docname):
 def process_emn(doc,filename):
    """process_emn(document, filename)-> adds emn geometry from emn file"""
    emnfile=pythonopen(filename, "r")
-   emn_unit=1.0 #presume milimeter like emn unit
+   emn_unit=1.0 #presume millimeter like emn unit
    emn_version=2 #presume emn_version 2
    board_thickness=0 #presume 0 board height
    board_outline=[] #no outline
