@@ -1,6 +1,19 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="pt-PT" sourcelanguage="en">
+<TS version="2.1" language="pt-PT" sourcelanguage="en">
+  <context>
+    <name>Image_Scaling</name>
+    <message>
+      <location filename="../../../ImageTools/_CommandImageScaling.py" line="63"/>
+      <source>Scale image plane</source>
+      <translation>Redimensionar plano da imagem</translation>
+    </message>
+    <message>
+      <location filename="../../../ImageTools/_CommandImageScaling.py" line="65"/>
+      <source>Scales an image plane by defining a distance between two points</source>
+      <translation>Redimensiona um plano de imagem, definindo uma distância entre dois pontos</translation>
+    </message>
+  </context>
   <context>
     <name>Dialog</name>
     <message>
@@ -10,8 +23,8 @@
     </message>
     <message>
       <location filename="../../../ImageTools/_CommandImageScaling.py" line="135"/>
-      <source>Distance</source>
-      <translation>Distância</translation>
+      <source>Distance [mm]</source>
+      <translation>Distância em [mm]</translation>
     </message>
     <message>
       <location filename="../../../ImageTools/_CommandImageScaling.py" line="136"/>
@@ -26,7 +39,7 @@
     <message>
       <location filename="../../../ImageTools/_CommandImageScaling.py" line="157"/>
       <source>&lt;font color='red'&gt;Select ImagePlane&lt;/font&gt;</source>
-      <translation>&lt;font color='red'&gt;selecione plano da imagem&lt;/font&gt;</translation>
+      <translation>&lt;font color='red'&gt;Selecione plano da imagem&lt;/font&gt;</translation>
     </message>
     <message>
       <location filename="../../../ImageTools/_CommandImageScaling.py" line="182"/>
@@ -39,19 +52,6 @@
       <translation>Selecione o plano de imagem e digite a distância</translation>
     </message>
   </context>
-  <context>
-    <name>Image_Scaling</name>
-    <message>
-      <location filename="../../../ImageTools/_CommandImageScaling.py" line="63"/>
-      <source>Scale image plane</source>
-      <translation>Redimensionar plano da imagem</translation>
-    </message>
-    <message>
-      <location filename="../../../ImageTools/_CommandImageScaling.py" line="65"/>
-      <source>Scales an image plane by defining a distance between two points</source>
-      <translation>Redimensiona um plano de imagem, definindo uma distância entre dois pontos</translation>
-    </message>
-  </context>
   <context>
     <name>CmdCreateImagePlane</name>
     <message>
@@ -67,7 +67,7 @@
     <message>
       <location filename="../../Command.cpp" line="103"/>
       <source>Create a planar image in the 3D space</source>
-      <translation>Criar uma imagem planar no espaço 3D</translation>
+      <translation>Criar uma imagem plana no espaço 3D</translation>
     </message>
   </context>
   <context>
@@ -80,12 +80,12 @@
     <message>
       <location filename="../../Command.cpp" line="54"/>
       <source>Open...</source>
-      <translation>Abrir ...</translation>
+      <translation>Abrir...</translation>
     </message>
     <message>
       <location filename="../../Command.cpp" line="55"/>
       <source>Open image view</source>
-      <translation>Abrir a visualização da imagem</translation>
+      <translation>Abrir visualização de imagens</translation>
     </message>
   </context>
   <context>
@@ -103,7 +103,7 @@
     <message>
       <location filename="../../Command.cpp" line="177"/>
       <source>Image Scaling</source>
-      <translation>Dimensionar a imagem</translation>
+      <translation>Dimensionar imagem</translation>
     </message>
   </context>
   <context>
@@ -169,7 +169,7 @@
     <message>
       <location filename="../../ImageView.cpp" line="113"/>
       <source>Stretch the image to fit the view</source>
-      <translation>Esticar a imagem para ajustar a exibição</translation>
+      <translation>Esticar a imagem para ajustar à vista</translation>
     </message>
     <message>
       <location filename="../../ImageView.cpp" line="117"/>
@@ -208,7 +208,7 @@
       <location filename="../../ImageView.cpp" line="600"/>
       <location filename="../../ImageView.cpp" line="605"/>
       <source>zoom</source>
-      <translation>zoom</translation>
+      <translation>ampliação</translation>
     </message>
     <message>
       <location filename="../../ImageView.cpp" line="543"/>
@@ -217,7 +217,7 @@
       <location filename="../../ImageView.cpp" line="584"/>
       <location filename="../../ImageView.cpp" line="600"/>
       <source>outside image</source>
-      <translation>imagem exterior</translation>
+      <translation>imagem externa</translation>
     </message>
   </context>
   <context>
@@ -248,7 +248,7 @@
     <message>
       <location filename="../../Command.cpp" line="129"/>
       <source>Could not load the chosen image</source>
-      <translation>Não foi possível carregar a imagem escolhida</translation>
+      <translation>Não foi possível carregar a imagem selecionada</translation>
     </message>
   </context>
   <context>
