@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) Juergen Riegel         <juergen.riegel@web.de>          *
+ *   Copyright (c) Jürgen Riegel <juergen.riegel@web.de>                   *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -35,6 +35,7 @@
 #include <Base/Reader.h>
 #include <Base/Interpreter.h>
 #include <Base/Sequencer.h>
+#include <Base/Tools.h>
 #include <Base/ViewProj.h>
 
 #include "Core/Builder.h"
@@ -49,7 +50,9 @@
 #include "Core/SetOperations.h"
 #include "Core/Triangulation.h"
 #include "Core/Trim.h"
+#include "Core/TrimByPlane.h"
 #include "Core/Visitor.h"
+#include "Core/Decimation.h"
 
 #include "Mesh.h"
 #include "MeshPy.h"
@@ -58,7 +61,7 @@ using namespace Mesh;
 
 float MeshObject::Epsilon = 1.0e-5f;
 
-TYPESYSTEM_SOURCE(Mesh::MeshObject, Data::ComplexGeoData);
+TYPESYSTEM_SOURCE(Mesh::MeshObject, Data::ComplexGeoData)
 
 MeshObject::MeshObject()
 {
@@ -80,7 +83,7 @@ MeshObject::MeshObject(const MeshObject& mesh)
   : _Mtrx(mesh._Mtrx),_kernel(mesh._kernel)
 {
     // copy the mesh structure
-    this->_segments = mesh._segments;
+    copySegments(mesh);
 }
 
 MeshObject::~MeshObject()
@@ -106,7 +109,7 @@ unsigned long MeshObject::countSubElements(const char* Type) const
     return 0;
 }
 
-Data::Segment* MeshObject::getSubElement(const char* Type, unsigned long n) const
+Data::Segment* MeshObject::getSubElement(const char* Type, unsigned long /*n*/) const
 {
     //TODO
     std::string element(Type);
@@ -117,9 +120,9 @@ Data::Segment* MeshObject::getSubElement(const char* Type, unsigned long n) cons
     return 0;
 }
 
-void MeshObject::getFacesFromSubelement(const Data::Segment* segm,
+void MeshObject::getFacesFromSubelement(const Data::Segment* /*segm*/,
                                         std::vector<Base::Vector3d> &Points,
-                                        std::vector<Base::Vector3d> &PointNormals,
+                                        std::vector<Base::Vector3d> &/*PointNormals*/,
                                         std::vector<Facet> &faces) const
 {
     //TODO
@@ -158,13 +161,33 @@ Base::BoundBox3d MeshObject::getBoundBox(void)const
     return Bnd2;
 }
 
+void MeshObject::copySegments(const MeshObject& mesh)
+{
+    // After copying the segments the mesh pointers must be adjusted
+    this->_segments = mesh._segments;
+    std::for_each(this->_segments.begin(), this->_segments.end(), [this](Segment& s) {
+        s._mesh = this;
+    });
+}
+
+void MeshObject::swapSegments(MeshObject& mesh)
+{
+    this->_segments.swap(mesh._segments);
+    std::for_each(this->_segments.begin(), this->_segments.end(), [this](Segment& s) {
+        s._mesh = this;
+    });
+    std::for_each(mesh._segments.begin(), mesh._segments.end(), [&mesh](Segment& s) {
+        s._mesh = &mesh;
+    });
+}
+
 void MeshObject::operator = (const MeshObject& mesh)
 {
     if (this != &mesh) {
         // copy the mesh structure
         setTransform(mesh._Mtrx);
         this->_kernel = mesh._kernel;
-        this->_segments = mesh._segments;
+        copySegments(mesh);
     }
 }
 
@@ -185,7 +208,7 @@ void MeshObject::swap(MeshCore::MeshKernel& Kernel)
 void MeshObject::swap(MeshObject& mesh)
 {
     this->_kernel.Swap(mesh._kernel);
-    this->_segments.swap(mesh._segments);
+    swapSegments(mesh);
     Base::Matrix4D tmp=this->_Mtrx;
     this->_Mtrx = mesh._Mtrx;
     mesh._Mtrx = tmp;
@@ -254,7 +277,7 @@ MeshPoint MeshObject::getPoint(unsigned long index) const
 
 void MeshObject::getPoints(std::vector<Base::Vector3d> &Points,
                            std::vector<Base::Vector3d> &Normals,
-                           float Accuracy, uint16_t flags) const
+                           float /*Accuracy*/, uint16_t /*flags*/) const
 {
     Base::Matrix4D mat = _Mtrx;
 
@@ -288,7 +311,7 @@ Mesh::Facet MeshObject::getFacet(unsigned long index) const
 }
 
 void MeshObject::getFaces(std::vector<Base::Vector3d> &Points,std::vector<Facet> &Topo,
-                          float Accuracy, uint16_t flags) const
+                          float /*Accuracy*/, uint16_t /*flags*/) const
 {
     unsigned long ctpoints = _kernel.CountPoints();
     Points.reserve(ctpoints);
@@ -313,7 +336,7 @@ unsigned int MeshObject::getMemSize (void) const
     return _kernel.GetMemSize();
 }
 
-void MeshObject::Save (Base::Writer &writer) const
+void MeshObject::Save (Base::Writer &/*writer*/) const
 {
     // this is handled by the property class
 }
@@ -323,7 +346,7 @@ void MeshObject::SaveDocFile (Base::Writer &writer) const
     _kernel.Write(writer.Stream());
 }
 
-void MeshObject::Restore(Base::XMLReader &reader)
+void MeshObject::Restore(Base::XMLReader &/*reader*/)
 {
     // this is handled by the property class
 }
@@ -340,13 +363,65 @@ void MeshObject::save(const char* file, MeshCore::MeshIO::Format f,
     MeshCore::MeshOutput aWriter(this->_kernel, mat);
     if (objectname)
         aWriter.SetObjectName(objectname);
+
+    // go through the segment list and put them to the exporter when
+    // the "save" flag is set
+    std::vector<MeshCore::Group> groups;
+    for (std::size_t index = 0; index < this->_segments.size(); index++) {
+        if (this->_segments[index].isSaved()) {
+            MeshCore::Group g;
+            g.indices = this->_segments[index].getIndices();
+            g.name = this->_segments[index].getName();
+            groups.push_back(g);
+        }
+    }
+    aWriter.SetGroups(groups);
+    if (mat && mat->library.empty()) {
+        Base::FileInfo fi(file);
+        const_cast<MeshCore::Material*>(mat)->library = fi.fileNamePure() + ".mtl";
+    }
+
     aWriter.Transform(this->_Mtrx);
-    aWriter.SaveAny(file, f);
+    if (aWriter.SaveAny(file, f)) {
+        if (mat && mat->binding == MeshCore::MeshIO::PER_FACE) {
+            if (f == MeshCore::MeshIO::Undefined)
+                f = MeshCore::MeshOutput::GetFormat(file);
+
+            if (f == MeshCore::MeshIO::OBJ) {
+                Base::FileInfo fi(file);
+                std::string fn = fi.dirPath() + "/" + mat->library;
+                fi.setFile(fn);
+                Base::ofstream str(fi, std::ios::out | std::ios::binary);
+                aWriter.SaveMTL(str);
+                str.close();
+            }
+        }
+    }
 }
 
-void MeshObject::save(std::ostream& out) const
+void MeshObject::save(std::ostream& str, MeshCore::MeshIO::Format f,
+                      const MeshCore::Material* mat,
+                      const char* objectname) const
 {
-    _kernel.Write(out);
+    MeshCore::MeshOutput aWriter(this->_kernel, mat);
+    if (objectname)
+        aWriter.SetObjectName(objectname);
+
+    // go through the segment list and put them to the exporter when
+    // the "save" flag is set
+    std::vector<MeshCore::Group> groups;
+    for (std::size_t index = 0; index < this->_segments.size(); index++) {
+        if (this->_segments[index].isSaved()) {
+            MeshCore::Group g;
+            g.indices = this->_segments[index].getIndices();
+            g.name = this->_segments[index].getName();
+            groups.push_back(g);
+        }
+    }
+    aWriter.SetGroups(groups);
+
+    aWriter.Transform(this->_Mtrx);
+    aWriter.SaveFormat(str, f);
 }
 
 bool MeshObject::load(const char* file, MeshCore::Material* mat)
@@ -356,10 +431,42 @@ bool MeshObject::load(const char* file, MeshCore::Material* mat)
     if (!aReader.LoadAny(file))
         return false;
 
+    swapKernel(kernel, aReader.GetGroupNames());
+
+    if (mat && mat->binding == MeshCore::MeshIO::PER_FACE) {
+        MeshCore::MeshIO::Format format = MeshCore::MeshOutput::GetFormat(file);
+
+        if (format == MeshCore::MeshIO::OBJ) {
+            Base::FileInfo fi(file);
+            std::string fn = fi.dirPath() + "/" + mat->library;
+            fi.setFile(fn);
+            Base::ifstream str(fi, std::ios::in | std::ios::binary);
+            aReader.LoadMTL(str);
+            str.close();
+        }
+    }
+
+    return true;
+}
+
+bool MeshObject::load(std::istream& str, MeshCore::MeshIO::Format f, MeshCore::Material* mat)
+{
+    MeshCore::MeshKernel kernel;
+    MeshCore::MeshInput aReader(kernel, mat);
+    if (!aReader.LoadFormat(str, f))
+        return false;
+
+    swapKernel(kernel, aReader.GetGroupNames());
+    return true;
+}
+
+void MeshObject::swapKernel(MeshCore::MeshKernel& kernel,
+                            const std::vector<std::string>& g)
+{
     _kernel.Swap(kernel);
     // Some file formats define several objects per file (e.g. OBJ).
     // Now we mark each object as an own segment so that we can break
-    // the object into its orriginal objects again.
+    // the object into its original objects again.
     this->_segments.clear();
     const MeshCore::MeshFacetArray& faces = _kernel.GetFacets();
     MeshCore::MeshFacetArray::_TConstIterator it;
@@ -371,7 +478,7 @@ bool MeshObject::load(const char* file, MeshCore::Material* mat)
         if (prop < it->_ulProp) {
             prop = it->_ulProp;
             if (!segment.empty()) {
-                this->_segments.push_back(Segment(this,segment,true));
+                this->_segments.emplace_back(this,segment,true);
                 segment.clear();
             }
         }
@@ -381,9 +488,17 @@ bool MeshObject::load(const char* file, MeshCore::Material* mat)
 
     // if the whole mesh is a single object then don't mark as segment
     if (!segment.empty() && (segment.size() < faces.size())) {
-        this->_segments.push_back(Segment(this,segment,true));
+        this->_segments.emplace_back(this,segment,true);
     }
 
+    // apply the group names to the segments
+    if (this->_segments.size() == g.size()) {
+        for (std::size_t index = 0; index < this->_segments.size(); index++) {
+            this->_segments[index].setName(g[index]);
+        }
+    }
+
+#if 0
 #ifndef FC_DEBUG
     try {
         MeshCore::MeshEvalNeighbourhood nb(_kernel);
@@ -403,8 +518,12 @@ bool MeshObject::load(const char* file, MeshCore::Material* mat)
         Base::Console().Log("Check for defects in mesh data structure failed\n");
     }
 #endif
+#endif
+}
 
-    return true;
+void MeshObject::save(std::ostream& out) const
+{
+    _kernel.Write(out);
 }
 
 void MeshObject::load(std::istream& in)
@@ -443,19 +562,22 @@ void MeshObject::addFacets(const std::vector<MeshCore::MeshGeomFacet>& facets)
     _kernel.AddFacets(facets);
 }
 
-void MeshObject::addFacets(const std::vector<MeshCore::MeshFacet> &facets)
+void MeshObject::addFacets(const std::vector<MeshCore::MeshFacet> &facets,
+                           bool checkManifolds)
 {
-    _kernel.AddFacets(facets);
+    _kernel.AddFacets(facets, checkManifolds);
 }
 
 void MeshObject::addFacets(const std::vector<MeshCore::MeshFacet> &facets,
-                           const std::vector<Base::Vector3f>& points)
+                           const std::vector<Base::Vector3f>& points,
+                           bool checkManifolds)
 {
-    _kernel.AddFacets(facets, points);
+    _kernel.AddFacets(facets, points, checkManifolds);
 }
 
 void MeshObject::addFacets(const std::vector<Data::ComplexGeoData::Facet> &facets,
-                           const std::vector<Base::Vector3d>& points)
+                           const std::vector<Base::Vector3d>& points,
+                           bool checkManifolds)
 {
     std::vector<MeshCore::MeshFacet> facet_v;
     facet_v.reserve(facets.size());
@@ -474,7 +596,7 @@ void MeshObject::addFacets(const std::vector<Data::ComplexGeoData::Facet> &facet
         point_v.push_back(p);
     }
 
-    _kernel.AddFacets(facet_v, point_v);
+    _kernel.AddFacets(facet_v, point_v, checkManifolds);
 }
 
 void MeshObject::setFacets(const std::vector<MeshCore::MeshGeomFacet>& facets)
@@ -517,12 +639,16 @@ void MeshObject::addMesh(const MeshCore::MeshKernel& kernel)
 
 void MeshObject::deleteFacets(const std::vector<unsigned long>& removeIndices)
 {
+    if (removeIndices.empty())
+        return;
     _kernel.DeleteFacets(removeIndices);
     deletedFacets(removeIndices);
 }
 
 void MeshObject::deletePoints(const std::vector<unsigned long>& removeIndices)
 {
+    if (removeIndices.empty())
+        return;
     _kernel.DeletePoints(removeIndices);
     this->_segments.clear();
 }
@@ -559,8 +685,9 @@ void MeshObject::deletedFacets(const std::vector<unsigned long>& remFacets)
             // remove the invalid indices
             std::sort(segm.begin(), segm.end());
             std::vector<unsigned long>::iterator ft = std::find_if
-                (segm.begin(), segm.end(), 
-                std::bind2nd(std::equal_to<unsigned long>(), ULONG_MAX));
+                (segm.begin(), segm.end(), [](unsigned long v) {
+                    return v == ULONG_MAX;
+                });
             if (ft != segm.end())
                 segm.erase(ft, segm.end());
             it->_indices = segm;
@@ -713,8 +840,9 @@ unsigned long MeshObject::getPointDegree(const std::vector<unsigned long>& indic
         pointDeg[face._aulPoints[2]]--;
     }
 
-    unsigned long countInvalids = std::count_if(pointDeg.begin(), pointDeg.end(),
-        std::bind2nd(std::equal_to<unsigned long>(), 0));
+    unsigned long countInvalids = std::count_if(pointDeg.begin(), pointDeg.end(), [](unsigned long v) {
+        return v == 0;
+    });
 
     point_degree.swap(pointDeg);
     return countInvalids;
@@ -775,7 +903,7 @@ void MeshObject::offsetSpecial2(float fSize)
             }
         }
         
-        // if there no flipped triangels -> stop
+        // if there are no flipped triangles -> stop
         //int f =fliped.size();
         if (fliped.size() == 0)
             break;
@@ -857,6 +985,18 @@ void MeshObject::smooth(int iterations, float d_max)
     _kernel.Smooth(iterations, d_max);
 }
 
+void MeshObject::decimate(float fTolerance, float fReduction)
+{
+    MeshCore::MeshSimplify dm(this->_kernel);
+    dm.simplify(fTolerance, fReduction);
+}
+
+void MeshObject::decimate(int targetSize)
+{
+    MeshCore::MeshSimplify dm(this->_kernel);
+    dm.simplify(targetSize);
+}
+
 Base::Vector3d MeshObject::getPointNormal(unsigned long index) const
 {
     std::vector<Base::Vector3f> temp = _kernel.CalcVertexNormals();
@@ -894,8 +1034,11 @@ std::vector<Base::Vector3d> MeshObject::getPointNormals() const
 void MeshObject::crossSections(const std::vector<MeshObject::TPlane>& planes, std::vector<MeshObject::TPolylines> &sections,
                                float fMinEps, bool bConnectPolygons) const
 {
-    MeshCore::MeshFacetGrid grid(_kernel);
-    MeshCore::MeshAlgorithm algo(_kernel);
+    MeshCore::MeshKernel kernel(this->_kernel);
+    kernel.Transform(this->_Mtrx);
+
+    MeshCore::MeshFacetGrid grid(kernel);
+    MeshCore::MeshAlgorithm algo(kernel);
     for (std::vector<MeshObject::TPlane>::const_iterator it = planes.begin(); it != planes.end(); ++it) {
         MeshObject::TPolylines polylines;
         algo.CutWithPlane(it->first, it->second, grid, polylines, fMinEps, bConnectPolygons);
@@ -903,7 +1046,7 @@ void MeshObject::crossSections(const std::vector<MeshObject::TPlane>& planes, st
     }
 }
 
-void MeshObject::cut(const Base::Polygon2D& polygon2d,
+void MeshObject::cut(const Base::Polygon2d& polygon2d,
                      const Base::ViewProjMethod& proj, MeshObject::CutType type)
 {
     MeshCore::MeshAlgorithm meshAlg(this->_kernel);
@@ -928,7 +1071,7 @@ void MeshObject::cut(const Base::Polygon2D& polygon2d,
         this->deleteFacets(check);
 }
 
-void MeshObject::trim(const Base::Polygon2D& polygon2d,
+void MeshObject::trim(const Base::Polygon2d& polygon2d,
                       const Base::ViewProjMethod& proj, MeshObject::CutType type)
 {
     MeshCore::MeshTrimming trim(this->_kernel, &proj, polygon2d);
@@ -953,6 +1096,21 @@ void MeshObject::trim(const Base::Polygon2D& polygon2d,
         this->_kernel.AddFacets(triangle);
 }
 
+void MeshObject::trim(const Base::Vector3f& base, const Base::Vector3f& normal)
+{
+    MeshCore::MeshTrimByPlane trim(this->_kernel);
+    std::vector<unsigned long> trimFacets, removeFacets;
+    std::vector<MeshCore::MeshGeomFacet> triangle;
+
+    MeshCore::MeshFacetGrid meshGrid(this->_kernel);
+    trim.CheckFacets(meshGrid, base, normal, trimFacets, removeFacets);
+    trim.TrimFacets(trimFacets, base, normal, triangle);
+    if (!removeFacets.empty())
+        this->deleteFacets(removeFacets);
+    if (!triangle.empty())
+        this->_kernel.AddFacets(triangle);
+}
+
 MeshObject* MeshObject::unite(const MeshObject& mesh) const
 {
     MeshCore::MeshKernel result;
@@ -1023,9 +1181,11 @@ void MeshObject::refine()
     unsigned long cnt = _kernel.CountFacets();
     MeshCore::MeshFacetIterator cF(_kernel);
     MeshCore::MeshTopoAlgorithm topalg(_kernel);
+
+    // x < 30 deg => cos(x) > sqrt(3)/2 or x > 120 deg => cos(x) < -0.5
     for (unsigned long i=0; i<cnt; i++) {
         cF.Set(i);
-        if (!cF->IsDeformed())
+        if (!cF->IsDeformed(0.86f, -0.5f))
             topalg.InsertVertexAndSwapEdge(i, cF->GetGravityPoint(), 0.1f);
     }
 
@@ -1034,6 +1194,21 @@ void MeshObject::refine()
     this->_segments.clear();
 }
 
+void MeshObject::removeNeedles(float length)
+{
+    unsigned long count = _kernel.CountFacets();
+    MeshCore::MeshRemoveNeedles eval(_kernel, length);
+    eval.Fixup();
+    if (_kernel.CountFacets() < count)
+        this->_segments.clear();
+}
+
+void MeshObject::validateCaps(float fMaxAngle, float fSplitFactor)
+{
+    MeshCore::MeshFixCaps eval(_kernel, fMaxAngle, fSplitFactor);
+    eval.Fixup();
+}
+
 void MeshObject::optimizeTopology(float fMaxAngle)
 {
     MeshCore::MeshTopoAlgorithm topalg(_kernel);
@@ -1066,7 +1241,7 @@ void MeshObject::splitEdges()
             if (!pF->IsFlag(MeshCore::MeshFacet::VISIT) && !rFace.IsFlag(MeshCore::MeshFacet::VISIT)) {
                 pF->SetFlag(MeshCore::MeshFacet::VISIT);
                 rFace.SetFlag(MeshCore::MeshFacet::VISIT);
-                adjacentFacet.push_back(std::make_pair(pF-rFacets.begin(), pF->_aulNeighbours[id]));
+                adjacentFacet.emplace_back(pF-rFacets.begin(), pF->_aulNeighbours[id]);
             }
         }
     }
@@ -1178,6 +1353,10 @@ void MeshObject::removeNonManifolds()
         f_fix.Fixup();
         deletedFacets(f_fix.GetDeletedFaces());
     }
+}
+
+void MeshObject::removeNonManifoldPoints()
+{
     MeshCore::MeshEvalPointManifolds p_eval(_kernel);
     if (!p_eval.Evaluate()) {
         std::vector<unsigned long> faces;
@@ -1209,15 +1388,15 @@ void MeshObject::removeSelfIntersections(const std::vector<unsigned long>& indic
     // make sure that the number of indices is even and are in range
     if (indices.size() % 2 != 0)
         return;
-    if (std::find_if(indices.begin(), indices.end(), 
-        std::bind2nd(std::greater_equal<unsigned long>(), _kernel.CountFacets())) < indices.end())
+    unsigned long cntfacets = _kernel.CountFacets();
+    if (std::find_if(indices.begin(), indices.end(), [cntfacets](unsigned long v) { return v >= cntfacets; }) < indices.end())
         return;
     std::vector<std::pair<unsigned long, unsigned long> > selfIntersections;
     std::vector<unsigned long>::const_iterator it;
     for (it = indices.begin(); it != indices.end(); ) {
         unsigned long id1 = *it; ++it;
         unsigned long id2 = *it; ++it;
-        selfIntersections.push_back(std::make_pair(id1,id2));
+        selfIntersections.emplace_back(id1,id2);
     }
 
     if (!selfIntersections.empty()) {
@@ -1278,6 +1457,15 @@ void MeshObject::removeInvalidPoints()
     deletePoints(nan.GetIndices());
 }
 
+void MeshObject::mergeFacets()
+{
+    unsigned long count = _kernel.CountFacets();
+    MeshCore::MeshFixMergeFacets merge(_kernel);
+    merge.Fixup();
+    if (_kernel.CountFacets() < count)
+        this->_segments.clear();
+}
+
 void MeshObject::validateIndices()
 {
     unsigned long count = _kernel.CountFacets();
@@ -1309,19 +1497,46 @@ void MeshObject::validateIndices()
         this->_segments.clear();
 }
 
-void MeshObject::validateDeformations(float fMaxAngle)
+bool MeshObject::hasInvalidNeighbourhood() const
+{
+    MeshCore::MeshEvalNeighbourhood eval(_kernel);
+    return !eval.Evaluate();
+}
+
+bool MeshObject::hasPointsOutOfRange() const
+{
+    MeshCore::MeshEvalRangePoint eval(_kernel);
+    return !eval.Evaluate();
+}
+
+bool MeshObject::hasFacetsOutOfRange() const
+{
+    MeshCore::MeshEvalRangeFacet eval(_kernel);
+    return !eval.Evaluate();
+}
+
+bool MeshObject::hasCorruptedFacets() const
+{
+    MeshCore::MeshEvalCorruptedFacets eval(_kernel);
+    return !eval.Evaluate();
+}
+
+void MeshObject::validateDeformations(float fMaxAngle, float fEps)
 {
     unsigned long count = _kernel.CountFacets();
-    MeshCore::MeshFixDeformedFacets eval(_kernel, fMaxAngle);
+    MeshCore::MeshFixDeformedFacets eval(_kernel,
+                                         Base::toRadians(15.0f),
+                                         Base::toRadians(150.0f),
+                                         fMaxAngle, fEps);
     eval.Fixup();
     if (_kernel.CountFacets() < count)
         this->_segments.clear();
 }
 
-void MeshObject::validateDegenerations()
+void MeshObject::validateDegenerations(float fEps)
 {
     unsigned long count = _kernel.CountFacets();
-    MeshCore::MeshFixDegeneratedFacets eval(_kernel);
+    MeshCore::MeshFixDegeneratedFacets eval(_kernel, fEps);
     eval.Fixup();
     if (_kernel.CountFacets() < count)
         this->_segments.clear();
@@ -1364,7 +1579,7 @@ MeshObject* MeshObject::createMeshFromList(Py::List& list)
     }
 
     Base::EmptySequencer seq;
-    std::auto_ptr<MeshObject> mesh(new MeshObject);
+    std::unique_ptr<MeshObject> mesh(new MeshObject);
     //mesh->addFacets(facets);
     mesh->getKernel() = facets;
     return mesh.release();
@@ -1376,11 +1591,17 @@ MeshObject* MeshObject::createSphere(float radius, int sampling)
     Base::PyGILStateLocker lock;
     try {
         Py::Module module(PyImport_ImportModule("BuildRegularGeoms"),true);
+        if (module.isNull())
+            return 0;
         Py::Dict dict = module.getDict();
         Py::Callable call(dict.getItem("Sphere"));
         Py::Tuple args(2);
         args.setItem(0, Py::Float(radius));
+#if PY_MAJOR_VERSION >= 3
+        args.setItem(1, Py::Long(sampling));
+#else
         args.setItem(1, Py::Int(sampling));
+#endif
         Py::List list(call.apply(args));
         return createMeshFromList(list);
     }
@@ -1397,12 +1618,18 @@ MeshObject* MeshObject::createEllipsoid(float radius1, float radius2, int sampli
     Base::PyGILStateLocker lock;
     try {
         Py::Module module(PyImport_ImportModule("BuildRegularGeoms"),true);
+        if (module.isNull())
+            return 0;
         Py::Dict dict = module.getDict();
         Py::Callable call(dict.getItem("Ellipsoid"));
         Py::Tuple args(3);
         args.setItem(0, Py::Float(radius1));
         args.setItem(1, Py::Float(radius2));
+#if PY_MAJOR_VERSION >= 3
+        args.setItem(2, Py::Long(sampling));
+#else
         args.setItem(2, Py::Int(sampling));
+#endif
         Py::List list(call.apply(args));
         return createMeshFromList(list);
     }
@@ -1419,14 +1646,22 @@ MeshObject* MeshObject::createCylinder(float radius, float length, int closed, f
     Base::PyGILStateLocker lock;
     try {
         Py::Module module(PyImport_ImportModule("BuildRegularGeoms"),true);
+        if (module.isNull())
+            return 0;
         Py::Dict dict = module.getDict();
         Py::Callable call(dict.getItem("Cylinder"));
         Py::Tuple args(5);
         args.setItem(0, Py::Float(radius));
         args.setItem(1, Py::Float(length));
+#if PY_MAJOR_VERSION >= 3
+        args.setItem(2, Py::Long(closed));
+        args.setItem(3, Py::Float(edgelen));
+        args.setItem(4, Py::Long(sampling));
+#else
         args.setItem(2, Py::Int(closed));
         args.setItem(3, Py::Float(edgelen));
         args.setItem(4, Py::Int(sampling));
+#endif
         Py::List list(call.apply(args));
         return createMeshFromList(list);
     }
@@ -1443,15 +1678,23 @@ MeshObject* MeshObject::createCone(float radius1, float radius2, float len, int
     Base::PyGILStateLocker lock;
     try {
         Py::Module module(PyImport_ImportModule("BuildRegularGeoms"),true);
+        if (module.isNull())
+            return 0;
         Py::Dict dict = module.getDict();
         Py::Callable call(dict.getItem("Cone"));
         Py::Tuple args(6);
         args.setItem(0, Py::Float(radius1));
         args.setItem(1, Py::Float(radius2));
         args.setItem(2, Py::Float(len));
+#if PY_MAJOR_VERSION >= 3
+        args.setItem(3, Py::Long(closed));
+        args.setItem(4, Py::Float(edgelen));
+        args.setItem(5, Py::Long(sampling));
+#else
         args.setItem(3, Py::Int(closed));
         args.setItem(4, Py::Float(edgelen));
         args.setItem(5, Py::Int(sampling));
+#endif
         Py::List list(call.apply(args));
         return createMeshFromList(list);
     }
@@ -1468,12 +1711,18 @@ MeshObject* MeshObject::createTorus(float radius1, float radius2, int sampling)
     Base::PyGILStateLocker lock;
     try {
         Py::Module module(PyImport_ImportModule("BuildRegularGeoms"),true);
+        if (module.isNull())
+            return 0;
         Py::Dict dict = module.getDict();
         Py::Callable call(dict.getItem("Toroid"));
         Py::Tuple args(3);
         args.setItem(0, Py::Float(radius1));
         args.setItem(1, Py::Float(radius2));
+#if PY_MAJOR_VERSION >= 3
+        args.setItem(2, Py::Long(sampling));
+#else
         args.setItem(2, Py::Int(sampling));
+#endif
         Py::List list(call.apply(args));
         return createMeshFromList(list);
     }
@@ -1490,6 +1739,8 @@ MeshObject* MeshObject::createCube(float length, float width, float height)
     Base::PyGILStateLocker lock;
     try {
         Py::Module module(PyImport_ImportModule("BuildRegularGeoms"),true);
+        if (module.isNull())
+            return 0;
         Py::Dict dict = module.getDict();
         Py::Callable call(dict.getItem("Cube"));
         Py::Tuple args(3);
@@ -1512,6 +1763,8 @@ MeshObject* MeshObject::createCube(float length, float width, float height, floa
     Base::PyGILStateLocker lock;
     try {
         Py::Module module(PyImport_ImportModule("BuildRegularGeoms"),true);
+        if (module.isNull())
+            return 0;
         Py::Dict dict = module.getDict();
         Py::Callable call(dict.getItem("FineCube"));
         Py::Tuple args(4);
@@ -1532,6 +1785,10 @@ MeshObject* MeshObject::createCube(float length, float width, float height, floa
 void MeshObject::addSegment(const Segment& s)
 {
     addSegment(s.getIndices());
+    this->_segments.back().setName(s.getName());
+    this->_segments.back().setColor(s.getColor());
+    this->_segments.back().save(s.isSaved());
+    this->_segments.back()._modifykernel = s._modifykernel;
 }
 
 void MeshObject::addSegment(const std::vector<unsigned long>& inds)
@@ -1539,10 +1796,10 @@ void MeshObject::addSegment(const std::vector<unsigned long>& inds)
     unsigned long maxIndex = _kernel.CountFacets();
     for (std::vector<unsigned long>::const_iterator it = inds.begin(); it != inds.end(); ++it) {
         if (*it >= maxIndex)
-            throw Base::Exception("Index out of range");
+            throw Base::IndexError("Index out of range");
     }
 
-    this->_segments.push_back(Segment(this,inds,true));
+    this->_segments.emplace_back(this,inds,true);
 }
 
 const Segment& MeshObject::getSegment(unsigned long index) const
@@ -1571,25 +1828,44 @@ MeshObject* MeshObject::meshFromSegment(const std::vector<unsigned long>& indice
     return new MeshObject(kernel, _Mtrx);
 }
 
-std::vector<Segment> MeshObject::getSegmentsFromType(MeshObject::GeometryType type, const Segment& aSegment,
-                                                     float dev, unsigned long minFacets) const
+std::vector<Segment> MeshObject::getSegmentsOfType(MeshObject::GeometryType type,
+                                                   float dev, unsigned long minFacets) const
 {
     std::vector<Segment> segm;
     if (this->_kernel.CountFacets() == 0)
         return segm;
 
     MeshCore::MeshSegmentAlgorithm finder(this->_kernel);
-    MeshCore::MeshDistanceSurfaceSegment* surf;
-    surf = new MeshCore::MeshDistancePlanarSegment(this->_kernel, minFacets, dev);
-    std::vector<MeshCore::MeshSurfaceSegment*> surfaces;
-    surfaces.push_back(surf);
-    finder.FindSegments(surfaces);
-
-    const std::vector<MeshCore::MeshSegment>& data = surf->GetSegments();
-    for (std::vector<MeshCore::MeshSegment>::const_iterator it = data.begin(); it != data.end(); ++it) {
-        segm.push_back(Segment(const_cast<MeshObject*>(this), *it, false));
+    std::shared_ptr<MeshCore::MeshDistanceSurfaceSegment> surf;
+    switch (type) {
+    case PLANE:
+        //surf.reset(new MeshCore::MeshDistancePlanarSegment(this->_kernel, minFacets, dev));
+        surf.reset(new MeshCore::MeshDistanceGenericSurfaceFitSegment(new MeshCore::PlaneSurfaceFit,
+                   this->_kernel, minFacets, dev));
+    break;
+    case CYLINDER:
+        surf.reset(new MeshCore::MeshDistanceGenericSurfaceFitSegment(new MeshCore::CylinderSurfaceFit,
+                   this->_kernel, minFacets, dev));
+        break;
+    case SPHERE:
+        surf.reset(new MeshCore::MeshDistanceGenericSurfaceFitSegment(new MeshCore::SphereSurfaceFit,
+                   this->_kernel, minFacets, dev));
+        break;
+    default:
+        break;
     }
-    delete surf;
+
+    if (surf.get()) {
+        std::vector<MeshCore::MeshSurfaceSegmentPtr> surfaces;
+        surfaces.push_back(surf);
+        finder.FindSegments(surfaces);
+
+        const std::vector<MeshCore::MeshSegment>& data = surf->GetSegments();
+        for (std::vector<MeshCore::MeshSegment>::const_iterator it = data.begin(); it != data.end(); ++it) {
+            segm.emplace_back(const_cast<MeshObject*>(this), *it, false);
+        }
+    }
+
     return segm;
 }
 
