@@ -82,11 +82,14 @@
 // Inventor
 #ifndef __InventorAll__
 # include <Gui/InventorAll.h>
+# include <Inventor/annex/ForeignFiles/SoSTLFileKit.h>
 #endif
 
 #elif defined(FC_OS_WIN32)
+#ifndef NOMINMAX
 #define NOMINMAX
-#include <windows.h>
+#endif
+#include <Windows.h>
 #endif  //_PreComp_
 
 #endif // MESHGUI_PRECOMPILED_H 
