@@ -41,6 +41,7 @@
 #include <Base/Sequencer.h>
 #include <App/Application.h>
 #include <Gui/Selection.h>
+#include <Gui/Inventor/MarkerBitmaps.h>
 
 #include <Mod/Mesh/App/Core/Degeneration.h>
 #include <Mod/Mesh/App/Core/Evaluation.h>
@@ -89,6 +90,11 @@ void ViewProviderMeshDefects::onChanged(const App::Property* prop)
     if (prop == &LineWidth) {
         pcDrawStyle->lineWidth = LineWidth.getValue();
     }
+    // Visibility changes must be handled here because in the base class it changes the attribute of the feature
+    // and thus affects the visibility of the mesh view provider which is undesired behaviour
+    else if (prop == &Visibility) {
+        Visibility.getValue() ? show() : hide();
+    }
     else {
         ViewProviderDocumentObject::onChanged(prop);
     }
@@ -134,7 +140,7 @@ void ViewProviderMeshOrientation::attach(App::DocumentObject* pcFeat)
     SoBaseColor * markcol = new SoBaseColor;
     markcol->rgb.setValue( 1.0f, 1.0f, 0.0f );
     SoMarkerSet* marker = new SoMarkerSet;
-    marker->markerIndex=SoMarkerSet::PLUS_7_7;
+    marker->markerIndex=Gui::Inventor::MarkerBitmaps::getMarkerIndex("PLUS", App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View")->GetInt("MarkerSize", 7));
     linesep->addChild(markcol);
     linesep->addChild(marker);
 
@@ -145,7 +151,7 @@ void ViewProviderMeshOrientation::attach(App::DocumentObject* pcFeat)
 
 void ViewProviderMeshOrientation::showDefects(const std::vector<unsigned long>& inds)
 {
-    Mesh::Feature* f = dynamic_cast<Mesh::Feature*>(pcObject);
+    Mesh::Feature* f = static_cast<Mesh::Feature*>(pcObject);
     const MeshCore::MeshKernel & rMesh = f->Mesh.getValue().getKernel();
 
     pcCoords->point.deleteValues(0);
@@ -201,7 +207,7 @@ void ViewProviderMeshNonManifolds::attach(App::DocumentObject* pcFeat)
     SoBaseColor * markcol = new SoBaseColor;
     markcol->rgb.setValue( 1.0f, 1.0f, 0.0f );
     SoMarkerSet* marker = new SoMarkerSet;
-    marker->markerIndex=SoMarkerSet::PLUS_7_7;
+    marker->markerIndex=Gui::Inventor::MarkerBitmaps::getMarkerIndex("PLUS", App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View")->GetInt("MarkerSize", 7));
     linesep->addChild(markcol);
     linesep->addChild(marker);
 
@@ -212,7 +218,7 @@ void ViewProviderMeshNonManifolds::showDefects(const std::vector<unsigned long>&
 {
     if ((inds.size() % 2) != 0)
         return;
-    Mesh::Feature* f = dynamic_cast<Mesh::Feature*>(pcObject);
+    Mesh::Feature* f = static_cast<Mesh::Feature*>(pcObject);
     const MeshCore::MeshKernel & rMesh = f->Mesh.getValue().getKernel();
 
     pcCoords->point.deleteValues(0);
@@ -266,7 +272,7 @@ void ViewProviderMeshNonManifoldPoints::attach(App::DocumentObject* pcFeat)
     SoBaseColor * markcol = new SoBaseColor;
     markcol->rgb.setValue( 1.0f, 1.0f, 0.0f );
     SoMarkerSet* marker = new SoMarkerSet;
-    marker->markerIndex=SoMarkerSet::PLUS_7_7;
+    marker->markerIndex=Gui::Inventor::MarkerBitmaps::getMarkerIndex("PLUS", App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View")->GetInt("MarkerSize", 7));
     pointsep->addChild(markcol);
     pointsep->addChild(marker);
 
@@ -275,7 +281,7 @@ void ViewProviderMeshNonManifoldPoints::attach(App::DocumentObject* pcFeat)
 
 void ViewProviderMeshNonManifoldPoints::showDefects(const std::vector<unsigned long>& inds)
 {
-    Mesh::Feature* f = dynamic_cast<Mesh::Feature*>(pcObject);
+    Mesh::Feature* f = static_cast<Mesh::Feature*>(pcObject);
     const MeshCore::MeshKernel & rMesh = f->Mesh.getValue().getKernel();
     pcCoords->point.deleteValues(0);
     pcCoords->point.setNum(inds.size());
@@ -330,7 +336,7 @@ void ViewProviderMeshDuplicatedFaces::attach(App::DocumentObject* pcFeat)
     SoBaseColor * markcol = new SoBaseColor;
     markcol->rgb.setValue( 1.0f, 1.0f, 0.0f );
     SoMarkerSet* marker = new SoMarkerSet;
-    marker->markerIndex=SoMarkerSet::PLUS_7_7;
+    marker->markerIndex=Gui::Inventor::MarkerBitmaps::getMarkerIndex("PLUS", App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View")->GetInt("MarkerSize", 7));
     linesep->addChild(markcol);
     linesep->addChild(marker);
 
@@ -339,7 +345,7 @@ void ViewProviderMeshDuplicatedFaces::attach(App::DocumentObject* pcFeat)
 
 void ViewProviderMeshDuplicatedFaces::showDefects(const std::vector<unsigned long>& inds)
 {
-    Mesh::Feature* f = dynamic_cast<Mesh::Feature*>(pcObject);
+    Mesh::Feature* f = static_cast<Mesh::Feature*>(pcObject);
     const MeshCore::MeshKernel & rMesh = f->Mesh.getValue().getKernel();
 
     pcCoords->point.deleteValues(0);
@@ -395,7 +401,7 @@ void ViewProviderMeshDuplicatedPoints::attach(App::DocumentObject* pcFeat)
     SoBaseColor * markcol = new SoBaseColor;
     markcol->rgb.setValue( 1.0f, 1.0f, 0.0f );
     SoMarkerSet* marker = new SoMarkerSet;
-    marker->markerIndex=SoMarkerSet::PLUS_7_7;
+    marker->markerIndex=Gui::Inventor::MarkerBitmaps::getMarkerIndex("PLUS", App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View")->GetInt("MarkerSize", 7));
     pointsep->addChild(markcol);
     pointsep->addChild(marker);
 
@@ -404,7 +410,7 @@ void ViewProviderMeshDuplicatedPoints::attach(App::DocumentObject* pcFeat)
 
 void ViewProviderMeshDuplicatedPoints::showDefects(const std::vector<unsigned long>& inds)
 {
-    Mesh::Feature* f = dynamic_cast<Mesh::Feature*>(pcObject);
+    Mesh::Feature* f = static_cast<Mesh::Feature*>(pcObject);
     const MeshCore::MeshKernel & rMesh = f->Mesh.getValue().getKernel();
     pcCoords->point.deleteValues(0);
     pcCoords->point.setNum(inds.size());
@@ -452,7 +458,7 @@ void ViewProviderMeshDegenerations::attach(App::DocumentObject* pcFeat)
     SoBaseColor * markcol = new SoBaseColor;
     markcol->rgb.setValue( 1.0f, 1.0f, 0.0f );
     SoMarkerSet* marker = new SoMarkerSet;
-    marker->markerIndex=SoMarkerSet::PLUS_7_7;
+    marker->markerIndex=Gui::Inventor::MarkerBitmaps::getMarkerIndex("PLUS", App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View")->GetInt("MarkerSize", 7));
     linesep->addChild(markcol);
     linesep->addChild(marker);
 
@@ -461,7 +467,7 @@ void ViewProviderMeshDegenerations::attach(App::DocumentObject* pcFeat)
 
 void ViewProviderMeshDegenerations::showDefects(const std::vector<unsigned long>& inds)
 {
-    Mesh::Feature* f = dynamic_cast<Mesh::Feature*>(pcObject);
+    Mesh::Feature* f = static_cast<Mesh::Feature*>(pcObject);
     const MeshCore::MeshKernel & rMesh = f->Mesh.getValue().getKernel();
 
     pcCoords->point.deleteValues(0);
@@ -558,7 +564,7 @@ void ViewProviderMeshIndices::attach(App::DocumentObject* pcFeat)
     SoBaseColor * markcol = new SoBaseColor;
     markcol->rgb.setValue( 1.0f, 1.0f, 0.0f );
     SoMarkerSet* marker = new SoMarkerSet;
-    marker->markerIndex=SoMarkerSet::PLUS_7_7;
+    marker->markerIndex=Gui::Inventor::MarkerBitmaps::getMarkerIndex("PLUS", App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View")->GetInt("MarkerSize", 7));
     linesep->addChild(markcol);
     linesep->addChild(marker);
 
@@ -567,7 +573,7 @@ void ViewProviderMeshIndices::attach(App::DocumentObject* pcFeat)
 
 void ViewProviderMeshIndices::showDefects(const std::vector<unsigned long>& inds)
 {
-    Mesh::Feature* f = dynamic_cast<Mesh::Feature*>(pcObject);
+    Mesh::Feature* f = static_cast<Mesh::Feature*>(pcObject);
     const MeshCore::MeshKernel & rMesh = f->Mesh.getValue().getKernel();
 
     if (!inds.empty()) {
@@ -625,7 +631,7 @@ void ViewProviderMeshSelfIntersections::attach(App::DocumentObject* pcFeat)
     SoBaseColor * markcol = new SoBaseColor;
     markcol->rgb.setValue( 1.0f, 1.0f, 0.0f );
     SoMarkerSet* marker = new SoMarkerSet;
-    marker->markerIndex=SoMarkerSet::PLUS_7_7;
+    marker->markerIndex=Gui::Inventor::MarkerBitmaps::getMarkerIndex("PLUS", App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View")->GetInt("MarkerSize", 7));
     linesep->addChild(markcol);
     linesep->addChild(marker);
 
@@ -636,7 +642,7 @@ void ViewProviderMeshSelfIntersections::showDefects(const std::vector<unsigned l
 {
     if (indices.size() % 2 != 0)
         return;
-    Mesh::Feature* f = dynamic_cast<Mesh::Feature*>(pcObject);
+    Mesh::Feature* f = static_cast<Mesh::Feature*>(pcObject);
     const MeshCore::MeshKernel & rMesh = f->Mesh.getValue().getKernel();
     MeshCore::MeshEvalSelfIntersection eval(rMesh);
   
@@ -645,7 +651,7 @@ void ViewProviderMeshSelfIntersections::showDefects(const std::vector<unsigned l
     for (it = indices.begin(); it != indices.end(); ) {
         unsigned long id1 = *it; ++it;
         unsigned long id2 = *it; ++it;
-        intersection.push_back(std::make_pair(id1,id2));
+        intersection.emplace_back(id1,id2);
     }
 
     std::vector<std::pair<Base::Vector3f, Base::Vector3f> > lines;
@@ -705,7 +711,7 @@ void ViewProviderMeshFolds::attach(App::DocumentObject* pcFeat)
     SoBaseColor * markcol = new SoBaseColor;
     markcol->rgb.setValue( 1.0f, 1.0f, 0.0f );
     SoMarkerSet* marker = new SoMarkerSet;
-    marker->markerIndex=SoMarkerSet::PLUS_7_7;
+    marker->markerIndex=Gui::Inventor::MarkerBitmaps::getMarkerIndex("PLUS", App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/View")->GetInt("MarkerSize", 7));
     linesep->addChild(markcol);
     linesep->addChild(marker);
 
@@ -714,7 +720,7 @@ void ViewProviderMeshFolds::attach(App::DocumentObject* pcFeat)
 
 void ViewProviderMeshFolds::showDefects(const std::vector<unsigned long>& inds)
 {
-    Mesh::Feature* f = dynamic_cast<Mesh::Feature*>(pcObject);
+    Mesh::Feature* f = static_cast<Mesh::Feature*>(pcObject);
     const MeshCore::MeshKernel & rMesh = f->Mesh.getValue().getKernel();
 
     pcCoords->point.deleteValues(0);
