@@ -7,9 +7,14 @@ FreeCAD.addImportType("Binary Mesh (*.bms)","Mesh")
 FreeCAD.addImportType("Alias Mesh (*.obj)","Mesh")
 FreeCAD.addImportType("Object File Format Mesh (*.off)","Mesh")
 FreeCAD.addImportType("Stanford Triangle Mesh (*.ply)","Mesh")
+FreeCAD.addImportType("Simple Model Format (*.smf)","Mesh")
 
 FreeCAD.addExportType("STL Mesh (*.stl *.ast)", "Mesh")
 FreeCAD.addExportType("Binary Mesh (*.bms)","Mesh")
 FreeCAD.addExportType("Alias Mesh (*.obj)","Mesh")
 FreeCAD.addExportType("Object File Format Mesh (*.off)","Mesh")
 FreeCAD.addExportType("Stanford Triangle Mesh (*.ply)","Mesh")
+FreeCAD.addExportType("Additive Manufacturing Format (*.amf)","Mesh")
+FreeCAD.addExportType("Simple Model Format (*.smf)","Mesh")
+
+FreeCAD.__unit_test__ += [ "MeshTestsApp" ]
