@@ -1,130 +1,130 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="pl" sourcelanguage="en">
+<TS version="1.1" language="pl" sourcelanguage="en">
   <context>
     <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="14"/>
+      <location filename="openscadprefs-base.ui" line="14"/>
       <source>General settings</source>
       <translation>Ustawienia ogólne</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="26"/>
+      <location filename="openscadprefs-base.ui" line="26"/>
       <source>General OpenSCAD Settings</source>
       <translation>Ogólne ustawienia OpenSCAD</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="34"/>
+      <location filename="openscadprefs-base.ui" line="34"/>
       <source>OpenSCAD executable</source>
       <translation>Plik wykonywalny OpenSCAD</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="65"/>
+      <location filename="openscadprefs-base.ui" line="65"/>
       <source>OpenSCAD import</source>
       <translation>Importuj z OpenSCAD</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="93"/>
+      <location filename="openscadprefs-base.ui" line="93"/>
       <source>Use ViewProvider in Tree View</source>
       <translation>Użyj ViewProvider w widoku drzewa</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="110"/>
+      <location filename="openscadprefs-base.ui" line="110"/>
       <source>If this is checked, Multmatrix Object will be Parametric</source>
       <translation>Jeżeli ta opcja jest zaznaczona, Obiekt matrycy wielokrotnej będzie parametryczny</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="113"/>
+      <location filename="openscadprefs-base.ui" line="113"/>
       <source>Use Multmatrix Feature</source>
       <translation>Użyj funkcji Multmatrix</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="153"/>
+      <location filename="openscadprefs-base.ui" line="153"/>
       <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
       <translation>Maksymalna liczba obszarów wielokąta, graniastosłupa lub graniastosłupa ściętego. Jeśli fn jest większa niż podana wartość, obiekt uważany będzie za okrągły. Ustaw 0 dla braku ograniczenia</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="133"/>
+      <location filename="openscadprefs-base.ui" line="133"/>
       <source>Maximum number of faces for polygons (fn)</source>
-      <translation>Maksymalna liczba obszarów dla wielokątów (fn)</translation>
+      <translation>Maksymalna liczba ścian dla wielokątów</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="177"/>
+      <location filename="openscadprefs-base.ui" line="177"/>
       <source>OpenSCAD export</source>
       <translation>Eksportuj do OpenSCAD</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="185"/>
+      <location filename="openscadprefs-base.ui" line="185"/>
       <source>maximum fragment size</source>
       <translation>maksymalny rozmiar fragmentu</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="208"/>
+      <location filename="openscadprefs-base.ui" line="208"/>
       <source>angular (fa)</source>
       <translation>kątowe (fa)</translation>
     </message>
     <message encoding="UTF-8">
-      <location filename="../ui/openscadprefs-base.ui" line="218"/>
+      <location filename="openscadprefs-base.ui" line="218"/>
       <source>°</source>
       <translation>°</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="250"/>
+      <location filename="openscadprefs-base.ui" line="250"/>
       <source>size (fs)</source>
       <translation>rozmiar (fs)</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="278"/>
+      <location filename="openscadprefs-base.ui" line="278"/>
       <source>mm</source>
       <translation>mm</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="304"/>
+      <location filename="openscadprefs-base.ui" line="304"/>
       <source>convexity</source>
       <translation>wypukłość</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="341"/>
+      <location filename="openscadprefs-base.ui" line="341"/>
       <source>Mesh fallback</source>
       <translation>Siatki wycofane</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="383"/>
+      <location filename="openscadprefs-base.ui" line="383"/>
       <source>Deflection</source>
       <translation>Odkształcenie</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="386"/>
+      <location filename="openscadprefs-base.ui" line="386"/>
       <source>deflection</source>
       <translation>odkształcenie</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="393"/>
+      <location filename="openscadprefs-base.ui" line="393"/>
       <source>Triangulation settings</source>
       <translation>Ustawienia triangulacji</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="90"/>
+      <location filename="openscadprefs-base.ui" line="90"/>
       <source>If this is checked, Features will claim their children in the tree view</source>
       <translation>Jeżeli zaznaczono te opcję, funkcje będą wymagać swoich potomków w widoku drzewa</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="73"/>
+      <location filename="openscadprefs-base.ui" line="73"/>
       <source>Print debug information in the Console</source>
       <translation>Drukuj informacje o debugowaniu w konsoli</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="47"/>
+      <location filename="openscadprefs-base.ui" line="47"/>
       <source>The path to the OpenSCAD executable</source>
       <translation>Ścieżka do plików wykonywalnych OpenSCAD</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="215"/>
+      <location filename="openscadprefs-base.ui" line="215"/>
       <source>Minimum angle for a fragment</source>
       <translation>Minimalny kąt dla fragmentu</translation>
     </message>
     <message>
-      <location filename="../ui/openscadprefs-base.ui" line="272"/>
+      <location filename="openscadprefs-base.ui" line="272"/>
       <source>Minimum size of a fragment</source>
       <translation>Minimalny rozmiar dla fragmentu</translation>
     </message>
@@ -132,62 +132,62 @@
   <context>
     <name>OpenSCAD</name>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="145"/>
+      <location filename="OpenSCADCommands.py" line="149"/>
       <source>Convert Edges to Faces</source>
-      <translation>Konwersja krawędzi do lic</translation>
+      <translation>Konwertuj krawędzie na ściany</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="224"/>
+      <location filename="OpenSCADCommands.py" line="309"/>
       <source>Please select 3 objects first</source>
-      <translation>Proszę wybrać najpierw 3 obiekty</translation>
+      <translation>Najpierw proszę wybrać 3 obiekty</translation>
     </message>
     <message>
-      <location filename="../../importCSG.py" line="1204"/>
+      <location filename="importCSG.py" line="1226"/>
       <source>Unsupported Function</source>
       <translation>Funkcja nieobsługiwana</translation>
     </message>
     <message>
-      <location filename="../../importCSG.py" line="1204"/>
+      <location filename="importCSG.py" line="1226"/>
       <source>Press OK</source>
       <translation>Naciśnij przycisk OK</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="268"/>
+      <location filename="OpenSCADCommands.py" line="347"/>
       <source>Add</source>
       <translation>Dodaj</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="269"/>
+      <location filename="OpenSCADCommands.py" line="348"/>
       <source>Clear</source>
       <translation>Wyczyść</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="270"/>
+      <location filename="OpenSCADCommands.py" line="349"/>
       <source>as Mesh</source>
       <translation>jako Siatka (Mesh)</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="271"/>
+      <location filename="OpenSCADCommands.py" line="350"/>
       <source>Add OpenSCAD Element</source>
       <translation>Dodaj element OpenSCAD</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="344"/>
+      <location filename="OpenSCADCommands.py" line="423"/>
       <source>Perform</source>
       <translation>Wykonaj</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="345"/>
+      <location filename="OpenSCADCommands.py" line="424"/>
       <source>Mesh Boolean</source>
       <translation>Boolean siatki</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADUtils.py" line="585"/>
+      <location filename="OpenSCADUtils.py" line="623"/>
       <source>Error all shapes must be either 2D or both must be 3D</source>
       <translation>Błąd, wszystkie kształty muszą być albo 2d albo 3d</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="95"/>
+      <location filename="OpenSCADCommands.py" line="102"/>
       <source>Unable to explode %s</source>
       <translation>Nie można rozstrzelić %s</translation>
     </message>
@@ -195,12 +195,12 @@
   <context>
     <name>OpenSCAD_AddOpenSCADElement</name>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="386"/>
+      <location filename="OpenSCADCommands.py" line="464"/>
       <source>Add OpenSCAD Element...</source>
-      <translation>Dodaj element OpenSCAD...</translation>
+      <translation>Dodaj element OpenSCAD ...</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="388"/>
+      <location filename="OpenSCADCommands.py" line="468"/>
       <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
       <translation>Dodaj element OpenSCAD wprowadzając i wykonując jego kod</translation>
     </message>
@@ -208,12 +208,12 @@
   <context>
     <name>OpenSCAD_ColorCodeShape</name>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="122"/>
+      <location filename="OpenSCADCommands.py" line="126"/>
       <source>Color Shapes</source>
       <translation>Kolor kształtów</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="124"/>
+      <location filename="OpenSCADCommands.py" line="129"/>
       <source>Color Shapes by validity and type</source>
       <translation>Kolor kształtów poprzez ważność i typ</translation>
     </message>
@@ -221,7 +221,7 @@
   <context>
     <name>OpenSCAD_Edgestofaces</name>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="143"/>
+      <location filename="OpenSCADCommands.py" line="146"/>
       <source>Convert Edges To Faces</source>
       <translation>Konwersja krawędzi do obszarów</translation>
     </message>
@@ -229,12 +229,12 @@
   <context>
     <name>OpenSCAD_ExpandPlacements</name>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="204"/>
+      <location filename="OpenSCADCommands.py" line="291"/>
       <source>Expand Placements</source>
       <translation>Rozwiń położenia</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="206"/>
+      <location filename="OpenSCADCommands.py" line="294"/>
       <source>Expand all placements downwards the FeatureTree</source>
       <translation>Rozwiń wszystkie miejsca docelowe w dół drzewa funkcji</translation>
     </message>
@@ -242,12 +242,12 @@
   <context>
     <name>OpenSCAD_ExplodeGroup</name>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="104"/>
+      <location filename="OpenSCADCommands.py" line="110"/>
       <source>Explode Group</source>
       <translation>Rozstrzel Grupę</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="106"/>
+      <location filename="OpenSCADCommands.py" line="113"/>
       <source>Remove fusion, apply placement to children, and color randomly</source>
       <translation>Usuń połączenie, zastosuj umiejscowienie obiektów-dzieci i kolory losowo</translation>
     </message>
@@ -255,12 +255,12 @@
   <context>
     <name>OpenSCAD_Hull</name>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="421"/>
+      <location filename="OpenSCADCommands.py" line="497"/>
       <source>Hull</source>
       <translation>Powłoka</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="423"/>
+      <location filename="OpenSCADCommands.py" line="500"/>
       <source>Perform Hull</source>
       <translation>Wykonaj kadłub</translation>
     </message>
@@ -268,12 +268,12 @@
   <context>
     <name>OpenSCAD_IncreaseToleranceFeature</name>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="185"/>
+      <location filename="OpenSCADCommands.py" line="274"/>
       <source>Increase Tolerance Feature</source>
       <translation>Funkcja powiększenia tolerancji</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="187"/>
+      <location filename="OpenSCADCommands.py" line="277"/>
       <source>Create Feature that allows to increase the tolerance</source>
       <translation>Tworzy Funkcję, która umożliwia zwiększenie tolerancji</translation>
     </message>
@@ -281,12 +281,12 @@
   <context>
     <name>OpenSCAD_MeshBoolean</name>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="400"/>
+      <location filename="OpenSCADCommands.py" line="477"/>
       <source>Mesh Boolean...</source>
       <translation>Boolean siatki...</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="402"/>
+      <location filename="OpenSCADCommands.py" line="481"/>
       <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
       <translation>Eksportuje obiekty jako siatki i używa OpenSCAD aby wykonać operację boolean</translation>
     </message>
@@ -294,25 +294,38 @@
   <context>
     <name>OpenSCAD_Minkowski</name>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="442"/>
+      <location filename="OpenSCADCommands.py" line="516"/>
       <source>Minkowski</source>
       <translation>Minkowski</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="444"/>
+      <location filename="OpenSCADCommands.py" line="519"/>
       <source>Perform Minkowski</source>
       <translation>Wykonaj Minkowskiego</translation>
     </message>
   </context>
+  <context>
+    <name>OpenSCAD_MirrorMeshFeature</name>
+    <message>
+      <location filename="OpenSCADCommands.py" line="195"/>
+      <source>Mirror Mesh Feature...</source>
+      <translation>Odbij właściwości siatki...</translation>
+    </message>
+    <message>
+      <location filename="OpenSCADCommands.py" line="198"/>
+      <source>Create Mirror Mesh Feature</source>
+      <translation>Twórz właściwości siatki</translation>
+    </message>
+  </context>
   <context>
     <name>OpenSCAD_RefineShapeFeature</name>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="164"/>
+      <location filename="OpenSCADCommands.py" line="165"/>
       <source>Refine Shape Feature</source>
       <translation>Udoskonalenie funkcji kształtu</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="166"/>
+      <location filename="OpenSCADCommands.py" line="168"/>
       <source>Create Refine Shape Feature</source>
       <translation>Stwórz udoskonaloną funkcje kształtu</translation>
     </message>
@@ -320,12 +333,12 @@
   <context>
     <name>OpenSCAD_RemoveSubtree</name>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="243"/>
+      <location filename="OpenSCADCommands.py" line="324"/>
       <source>Remove Objects and their Children</source>
       <translation>Usuń obiekt wraz z jego potomkami</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="245"/>
+      <location filename="OpenSCADCommands.py" line="327"/>
       <source>Removes the selected objects and all children that are not referenced from other objects</source>
       <translation>Usuwa wybrane obiekty wraz ze wszystkimi potomkami, do których nie odnoszą się inne obiekty</translation>
     </message>
@@ -333,20 +346,46 @@
   <context>
     <name>OpenSCAD_ReplaceObject</name>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="228"/>
+      <location filename="OpenSCADCommands.py" line="312"/>
       <source>Replace Object</source>
-      <translation>Zamień obiekt</translation>
+      <translation>Zastąp obiekt</translation>
     </message>
     <message>
-      <location filename="../../OpenSCADCommands.py" line="230"/>
+      <location filename="OpenSCADCommands.py" line="315"/>
       <source>Replace an object in the Feature Tree. Please select old, new, and parent object</source>
       <translation>Zmień obiekt w drzewie elementów. Wybierz stary, nowy i nadrzędny obiekt</translation>
     </message>
   </context>
+  <context>
+    <name>OpenSCAD_ResizeMeshFeature</name>
+    <message>
+      <location filename="OpenSCADCommands.py" line="254"/>
+      <source>Resize Mesh Feature...</source>
+      <translation>Funkcja zmiany rozmiaru siatki...</translation>
+    </message>
+    <message>
+      <location filename="OpenSCADCommands.py" line="258"/>
+      <source>Create Resize Mesh Feature</source>
+      <translation>Utwórz funkcję zmiany rozmiaru siatki</translation>
+    </message>
+  </context>
+  <context>
+    <name>OpenSCAD_ScaleMeshFeature</name>
+    <message>
+      <location filename="OpenSCADCommands.py" line="224"/>
+      <source>Scale Mesh Feature...</source>
+      <translation>Funkcja skalowania siatki...</translation>
+    </message>
+    <message>
+      <location filename="OpenSCADCommands.py" line="228"/>
+      <source>Create Scale Mesh Feature</source>
+      <translation>Utwórz funkcję zmiany rozmiaru siatki</translation>
+    </message>
+  </context>
   <context>
     <name>Workbech</name>
     <message>
-      <location filename="../../InitGui.py" line="80"/>
+      <location filename="InitGui.py" line="83"/>
       <source>OpenSCAD Part tools</source>
       <translation>OpenSCAD narzędzia części</translation>
     </message>
@@ -354,9 +393,9 @@
   <context>
     <name>Workbench</name>
     <message>
-      <location filename="../../InitGui.py" line="78"/>
+      <location filename="InitGui.py" line="81"/>
       <source>OpenSCADTools</source>
-      <translation>OpenSCADNarzędzia</translation>
+      <translation>Narzędzia OpenSCAD</translation>
     </message>
   </context>
 </TS>
