@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) Jürgen Riegel          (juergen.riegel@web.de) 2002     *
+ *   Copyright (c) 2002 Jürgen Riegel <juergen.riegel@web.de>              *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -62,6 +62,7 @@
 # include <Geom_Plane.hxx>
 # include <Geom2d_TrimmedCurve.hxx>
 # include <Interface_Static.hxx>
+# include <Poly_Triangulation.hxx>
 # include <ShapeUpgrade_ShellSewing.hxx>
 # include <Standard_ConstructionError.hxx>
 # include <Standard_DomainError.hxx>
@@ -79,20 +80,22 @@
 # include <TopTools_ListIteratorOfListOfShape.hxx>
 # include <Precision.hxx>
 # include <Standard_Version.hxx>
+# include <BRepOffsetAPI_ThruSections.hxx>
+# include <BSplCLib.hxx>
+# include <GeomFill_AppSurf.hxx>
+# include <GeomFill_Line.hxx>
+# include <GeomFill_Pipe.hxx>
+# include <GeomFill_SectionGenerator.hxx>
+# include <NCollection_List.hxx>
+# include <BRepFill_Filling.hxx>
 #endif
 
+#include <cstdio>
+#include <fstream>
+
 #include <CXX/Extensions.hxx>
 #include <CXX/Objects.hxx>
 
-#include <BRepOffsetAPI_ThruSections.hxx>
-#include <BSplCLib.hxx>
-#include <GeomFill_AppSurf.hxx>
-#include <GeomFill_Line.hxx>
-#include <GeomFill_Pipe.hxx>
-#include <GeomFill_SectionGenerator.hxx>
-#include <NCollection_List.hxx>
-#include <BRepFill_Filling.hxx>
-
 #include <Base/Console.h>
 #include <Base/PyObjectBase.h>
 #include <Base/Interpreter.h>
@@ -127,7 +130,9 @@
 #include "ImportStep.h"
 #include "edgecluster.h"
 #include "FaceMaker.h"
+#include "PartFeature.h"
 #include "PartPyCXX.h"
+#include "modelRefine.h"
 
 #ifdef FCUseFreeType
 #  include "FT2FC.h"
@@ -135,10 +140,6 @@
 
 extern const char* BRepBuilderAPI_FaceErrorText(BRepBuilderAPI_FaceError fe);
 
-namespace Part {
-extern Py::Object shape2pyshape(const TopoDS_Shape &shape);
-}
-
 #ifndef M_PI
 #define M_PI    3.14159265358979323846 /* pi */
 #endif
@@ -148,6 +149,35 @@ extern Py::Object shape2pyshape(const TopoDS_Shape &shape);
 #endif
 
 namespace Part {
+
+PartExport void getPyShapes(PyObject *obj, std::vector<TopoShape> &shapes) {
+    if(!obj)
+        return;
+    if(PyObject_TypeCheck(obj,&Part::TopoShapePy::Type))
+        shapes.push_back(*static_cast<TopoShapePy*>(obj)->getTopoShapePtr());
+    else if (PyObject_TypeCheck(obj, &GeometryPy::Type)) 
+        shapes.emplace_back(static_cast<GeometryPy*>(obj)->getGeometryPtr()->toShape());
+    else if(PySequence_Check(obj)) {
+        Py::Sequence list(obj);
+        for (Py::Sequence::iterator it = list.begin(); it != list.end(); ++it) {
+            if (PyObject_TypeCheck((*it).ptr(), &(Part::TopoShapePy::Type)))
+                shapes.push_back(*static_cast<TopoShapePy*>((*it).ptr())->getTopoShapePtr());
+            else if (PyObject_TypeCheck((*it).ptr(), &GeometryPy::Type)) 
+                shapes.emplace_back(static_cast<GeometryPy*>(
+                                (*it).ptr())->getGeometryPtr()->toShape());
+            else
+                throw Py::TypeError("expect shape in sequence");
+        }
+    }else
+        throw Py::TypeError("expect shape or sequence of shapes");
+}
+
+PartExport std::vector<TopoShape> getPyShapes(PyObject *obj) {
+    std::vector<TopoShape> ret;
+    getPyShapes(obj,ret);
+    return ret;
+}
+
 struct EdgePoints {
     gp_Pnt v1, v2;
     std::list<TopoDS_Edge>::iterator it;
@@ -241,8 +271,68 @@ PartExport std::list<TopoDS_Edge> sort_Edges(double tol3d, std::list<TopoDS_Edge
 }
 
 namespace Part {
+class BRepFeatModule : public Py::ExtensionModule<BRepFeatModule>
+{
+public:
+    BRepFeatModule() : Py::ExtensionModule<BRepFeatModule>("BRepFeat")
+    {
+        initialize("This is a module working with the BRepFeat package."); // register with Python
+    }
+
+    virtual ~BRepFeatModule() {}
+};
+
+class BRepOffsetAPIModule : public Py::ExtensionModule<BRepOffsetAPIModule>
+{
+public:
+    BRepOffsetAPIModule() : Py::ExtensionModule<BRepOffsetAPIModule>("BRepOffsetAPI")
+    {
+        initialize("This is a module working with the BRepOffsetAPI package."); // register with Python
+    }
+
+    virtual ~BRepOffsetAPIModule() {}
+};
+
+class Geom2dModule : public Py::ExtensionModule<Geom2dModule>
+{
+public:
+    Geom2dModule() : Py::ExtensionModule<Geom2dModule>("Geom2d")
+    {
+        initialize("This is a module working with 2d geometries."); // register with Python
+    }
+
+    virtual ~Geom2dModule() {}
+};
+
+class GeomPlateModule : public Py::ExtensionModule<GeomPlateModule>
+{
+public:
+    GeomPlateModule() : Py::ExtensionModule<GeomPlateModule>("GeomPlate")
+    {
+        initialize("This is a module working with the GeomPlate framework."); // register with Python
+    }
+
+    virtual ~GeomPlateModule() {}
+};
+
+class ShapeUpgradeModule : public Py::ExtensionModule<ShapeUpgradeModule>
+{
+public:
+    ShapeUpgradeModule() : Py::ExtensionModule<ShapeUpgradeModule>("ShapeUpgrade")
+    {
+        initialize("This is a module working with the ShapeUpgrade framework."); // register with Python
+    }
+
+    virtual ~ShapeUpgradeModule() {}
+};
+
 class Module : public Py::ExtensionModule<Module>
 {
+    BRepFeatModule brepFeat;
+    BRepOffsetAPIModule brepOffsetApi;
+    Geom2dModule geom2d;
+    GeomPlateModule geomPlate;
+    ShapeUpgradeModule shapeUpgrade;
 public:
     Module() : Py::ExtensionModule<Module>("Part")
     {
@@ -261,6 +351,9 @@ public:
         add_varargs_method("show",&Module::show,
             "show(shape,[string]) -- Add the shape to the active document or create one if no document exists."
         );
+        add_varargs_method("getFacets",&Module::getFacets,
+            "getFacets(shape): simplified mesh generation"
+        );
         add_varargs_method("makeCompound",&Module::makeCompound,
             "makeCompound(list) -- Create a compound out of a list of shapes."
         );
@@ -352,9 +445,9 @@ public:
             "makeThread(pitch,depth,height,radius) -- Make a thread with a given pitch, depth, height and radius"
         );
         add_varargs_method("makeRevolution",&Module::makeRevolution,
-            "makeRevolution(Curve,[vmin,vmax,angle,pnt,dir,shapetype]) -- Make a revolved shape\n"
+            "makeRevolution(Curve or Edge,[vmin,vmax,angle,pnt,dir,shapetype]) -- Make a revolved shape\n"
             "by rotating the curve or a portion of it around an axis given by (pnt,dir).\n"
-            "By default vmin/vmax=bounds of the curve,angle=360,pnt=Vector(0,0,0) and\n"
+            "By default vmin/vmax=bounds of the curve, angle=360, pnt=Vector(0,0,0),\n"
             "dir=Vector(0,0,1) and shapetype=Part.Solid"
         );
         add_varargs_method("makeRuledSurface",&Module::makeRuledSurface,
@@ -396,7 +489,7 @@ public:
             "Part.show(r[1][0])\n"
         );
         add_varargs_method("exportUnits",&Module::exportUnits,
-            "exportUnits([string=MM|M|IN]) -- Set units for exporting STEP/IGES files and returns the units."
+            "exportUnits([string=MM|M|INCH|FT|MI|KM|MIL|UM|CM|UIN]) -- Set units for exporting STEP/IGES files and returns the units."
         );
         add_varargs_method("setStaticValue",&Module::setStaticValue,
             "setStaticValue(string,string|int|float) -- Set a name to a value The value can be a string, int or float."
@@ -408,11 +501,17 @@ public:
             "getSortedClusters(list of edges) -- Helper method to sort and cluster a variety of edges"
         );
         add_varargs_method("__sortEdges__",&Module::sortEdges,
-            "__sortEdges__(list of edges) -- Helper method to sort an unsorted list of edges so that afterwards\n"
-            "two adjacent edges share a common vertex"
+            "__sortEdges__(list of edges) -- list of edges\n"
+            "Helper method to sort an unsorted list of edges so that afterwards\n"
+            "the start and end vertex of two consecutive edges are geometrically coincident.\n"
+            "It returns a single list of edges and the algorithm stops after the first set of\n"
+            "connected edges which means that the output list can be smaller than the input list.\n"
+            "The sorted list can be used to create a Wire."
         );
         add_varargs_method("sortEdges",&Module::sortEdges2,
-            "sortEdges(list of edges) -- Helper method to sort a list of edges into a list of list of connected edges"
+            "sortEdges(list of edges) -- list of lists of edges\n"
+            "It does basically the same as __sortEdges__ but sorts all input edges and thus returns\n"
+            "a list of lists of edges"
         );
         add_varargs_method("__toPythonOCC__",&Module::toPythonOCC,
             "__toPythonOCC__(shape) -- Helper method to convert an internal shape to pythonocc shape"
@@ -420,13 +519,81 @@ public:
         add_varargs_method("__fromPythonOCC__",&Module::fromPythonOCC,
             "__fromPythonOCC__(occ) -- Helper method to convert a pythonocc shape to an internal shape"
         );
+        add_varargs_method("clearShapeCache",&Module::clearShapeCache,
+            "clearShapeCache() -- Clears internal shape cache"
+        );
+        add_keyword_method("getShape",&Module::getShape,
+            "getShape(obj,subname=None,mat=None,needSubElement=False,transform=True,retType=0):\n"
+            "Obtain the the TopoShape of a given object with SubName reference\n\n"
+            "* obj: the input object\n"
+            "* subname: dot separated sub-object reference\n"
+            "* mat: the current transformation matrix\n"
+            "* needSubElement: if False, ignore the sub-element (e.g. Face1, Edge1) reference in 'subname'\n"
+            "* transform: if False, then skip obj's transformation. Use this if mat already include obj's\n"
+            "             transformation matrix\n"
+            "* retType: 0: return TopoShape,\n"
+            "           1: return (shape,subObj,mat), where subObj is the object referenced in 'subname',\n"
+            "              and 'mat' is the accumulated transformation matrix of that sub-object.\n" 
+            "           2: same as 1, but make sure 'subObj' is resolved if it is a link.\n"
+            "* refine: refine the returned shape"
+        );
+        add_varargs_method("splitSubname",&Module::splitSubname,
+            "splitSubname(subname) -> list(sub,mapped,subElement)\n"
+            "Split the given subname into a list\n\n"
+            "sub: subname without any sub-element reference\n"
+            "mapped: mapped element name, or '' if none\n"
+            "subElement: old style element name, or '' if none"
+        );
+        add_varargs_method("joinSubname",&Module::joinSubname,
+            "joinSubname(sub,mapped,subElement) -> subname\n"
+        );
         initialize("This is a module working with shapes."); // register with Python
+
+        PyModule_AddObject(m_module, "BRepFeat", brepFeat.module().ptr());
+        PyModule_AddObject(m_module, "BRepOffsetAPI", brepOffsetApi.module().ptr());
+        PyModule_AddObject(m_module, "Geom2d", geom2d.module().ptr());
+        PyModule_AddObject(m_module, "GeomPlate", geomPlate.module().ptr());
+        PyModule_AddObject(m_module, "ShapeUpgrade", shapeUpgrade.module().ptr());
     }
 
     virtual ~Module() {}
 
 private:
-    virtual Py::Object invoke_method_varargs(void *method_def, const Py::Tuple &args)
+    virtual Py::Object invoke_method_keyword( void *method_def, 
+            const Py::Tuple &args, const Py::Dict &keywords ) override
+    {
+        try {
+            return Py::ExtensionModule<Module>::invoke_method_keyword(method_def, args, keywords);
+        }
+        catch (const Standard_Failure &e) {
+            std::string str;
+            Standard_CString msg = e.GetMessageString();
+            str += typeid(e).name();
+            str += " ";
+            if (msg) {str += msg;}
+            else     {str += "No OCCT Exception Message";}
+            Base::Console().Error("%s\n", str.c_str());
+            throw Py::Exception(Part::PartExceptionOCCError, str);
+        }
+        catch (const Base::Exception &e) {
+            std::string str;
+            str += "FreeCAD exception thrown (";
+            str += e.what();
+            str += ")";
+            e.ReportException();
+            throw Py::RuntimeError(str);
+        }
+        catch (const std::exception &e) {
+            std::string str;
+            str += "C++ exception thrown (";
+            str += e.what();
+            str += ")";
+            Base::Console().Error("%s\n", str.c_str());
+            throw Py::RuntimeError(str);
+        }
+    }
+
+    virtual Py::Object invoke_method_varargs(void *method_def, const Py::Tuple &args) override
     {
         try {
             return Py::ExtensionModule<Module>::invoke_method_varargs(method_def, args);
@@ -482,7 +649,7 @@ private:
 #else
             Part::ImportStep *pcFeature = (Part::ImportStep *)pcDoc->addObject("Part::ImportStep",file.fileNamePure().c_str());
             pcFeature->FileName.setValue(Name);
-#endif 
+#endif
             pcDoc->recompute();
         }
 #if 1
@@ -535,7 +702,7 @@ private:
             // add Import feature
             Part::ImportStep *pcFeature = (Part::ImportStep *)pcDoc->addObject("Part::ImportStep",file.fileNamePure().c_str());
             pcFeature->FileName.setValue(Name);
-#endif 
+#endif
             pcDoc->recompute();
         }
 #if 1
@@ -612,7 +779,7 @@ private:
         if (!PyArg_ParseTuple(args.ptr(), "O!|s", &(TopoShapePy::Type), &pcObj, &name))
             throw Py::Exception();
 
-        App::Document *pcDoc = App::GetApplication().getActiveDocument(); 	 
+        App::Document *pcDoc = App::GetApplication().getActiveDocument();
         if (!pcDoc)
             pcDoc = App::GetApplication().newDocument();
         TopoShapePy* pShape = static_cast<TopoShapePy*>(pcObj);
@@ -623,6 +790,48 @@ private:
 
         return Py::None();
     }
+    Py::Object getFacets(const Py::Tuple& args)
+    {
+        PyObject *shape;
+        Py::List list;
+        if (!PyArg_ParseTuple(args.ptr(), "O", &shape)) 
+            throw Py::Exception();
+        auto theShape = static_cast<Part::TopoShapePy*>(shape)->getTopoShapePtr()->getShape();
+        for (TopExp_Explorer ex(theShape, TopAbs_FACE); ex.More(); ex.Next()) {
+            TopoDS_Face currentFace = TopoDS::Face(ex.Current());
+            TopLoc_Location loc;
+            Handle(Poly_Triangulation) facets = BRep_Tool::Triangulation(currentFace, loc);
+            const TopAbs_Orientation anOrientation = currentFace.Orientation();
+            bool flip = (anOrientation == TopAbs_REVERSED);
+            if (!facets.IsNull()) {
+                const TColgp_Array1OfPnt& nodes = facets->Nodes();
+                const Poly_Array1OfTriangle& triangles = facets->Triangles();
+                for (int i = 1; i <= triangles.Length(); i++) {
+                    Standard_Integer n1,n2,n3;
+                    triangles(i).Get(n1, n2, n3);
+                    gp_Pnt p1 = nodes(n1);
+                    gp_Pnt p2 = nodes(n2);
+                    gp_Pnt p3 = nodes(n3);
+                    p1.Transform(loc.Transformation());
+                    p2.Transform(loc.Transformation());
+                    p3.Transform(loc.Transformation());
+                    // TODO: verify if tolerance should be hard coded
+                    if (!p1.IsEqual(p2, 0.01) && !p2.IsEqual(p3, 0.01) && !p3.IsEqual(p1, 0.01)) {
+                        PyObject *t1 = PyTuple_Pack(3, PyFloat_FromDouble(p1.X()), PyFloat_FromDouble(p1.Y()), PyFloat_FromDouble(p1.Z()));
+                        PyObject *t2 = PyTuple_Pack(3, PyFloat_FromDouble(p2.X()), PyFloat_FromDouble(p2.Y()), PyFloat_FromDouble(p2.Z()));
+                        PyObject *t3 = PyTuple_Pack(3, PyFloat_FromDouble(p3.X()), PyFloat_FromDouble(p3.Y()), PyFloat_FromDouble(p3.Z()));
+                        if (flip) {
+                            list.append(Py::asObject(PyTuple_Pack(3, t2, t1, t3)));
+                        }
+                        else {
+                            list.append(Py::asObject(PyTuple_Pack(3, t1, t2, t3)));
+                        }
+                    }
+                }
+            }
+        }
+        return list;
+    }
     Py::Object makeCompound(const Py::Tuple& args)
     {
         PyObject *pcObj;
@@ -632,22 +841,14 @@ private:
         BRep_Builder builder;
         TopoDS_Compound Comp;
         builder.MakeCompound(Comp);
-        
-        try {
-            Py::Sequence list(pcObj);
-            for (Py::Sequence::iterator it = list.begin(); it != list.end(); ++it) {
-                if (PyObject_TypeCheck((*it).ptr(), &(Part::TopoShapePy::Type))) {
-                    const TopoDS_Shape& sh = static_cast<TopoShapePy*>((*it).ptr())->
-                        getTopoShapePtr()->getShape();
-                    if (!sh.IsNull())
-                        builder.Add(Comp, sh);
-                }
-            }
-        }
-        catch (Standard_Failure& e) {
-            throw Py::Exception(PartExceptionOCCError, e.GetMessageString());
-        }
 
+        PY_TRY {
+            for(auto &s : getPyShapes(pcObj)) {
+                const auto &sh = s.getShape();
+                if (!sh.IsNull())
+                    builder.Add(Comp, sh);
+            }
+        } _PY_CATCH_OCC(throw Py::Exception())
         return Py::asObject(new TopoShapeCompoundPy(new TopoShape(Comp)));
     }
     Py::Object makeShell(const Py::Tuple& args)
@@ -661,7 +862,7 @@ private:
         TopoDS_Shell shell;
         //BRepOffsetAPI_Sewing mkShell;
         builder.MakeShell(shell);
-        
+
         try {
             Py::Sequence list(obj);
             for (Py::Sequence::iterator it = list.begin(); it != list.end(); ++it) {
@@ -721,17 +922,8 @@ private:
 
                 fm->Build();
 
-                if(fm->Shape().IsNull())
-                    return Py::asObject(new TopoShapePy(new TopoShape(fm->Shape())));
-
-                switch(fm->Shape().ShapeType()){
-                case TopAbs_FACE:
-                    return Py::asObject(new TopoShapeFacePy(new TopoShape(fm->Shape())));
-                case TopAbs_COMPOUND:
-                    return Py::asObject(new TopoShapeCompoundPy(new TopoShape(fm->Shape())));
-                default:
-                    return Py::asObject(new TopoShapePy(new TopoShape(fm->Shape())));
-                }
+                TopoShape topo(fm->Shape());
+                return Py::asObject(topo.getPyObject());
             }
 
             throw Py::Exception(Base::BaseExceptionFreeCADError, std::string("Argument type signature not recognized. Should be either (list, string), or (shape, string)"));
@@ -786,7 +978,7 @@ private:
             }
 
             if (numConstraints == 0) {
-                throw Py::Exception(PartExceptionOCCError, "Failed to created face with no constraints");
+                throw Py::Exception(PartExceptionOCCError, "Failed to create face with no constraints");
             }
 
             builder.Build();
@@ -1047,7 +1239,7 @@ private:
             error = "Line through identic points";
             break;
         }
-        // Error 
+        // Error
         if (error) {
             throw Py::Exception(PartExceptionOCCError, error);
         }
@@ -1313,55 +1505,65 @@ private:
         Handle(Geom_Curve) curve;
         union PyType_Object defaultType = {&Part::TopoShapeSolidPy::Type};
         PyObject* type = defaultType.o;
-        if (PyArg_ParseTuple(args.ptr(), "O!|dddO!O!O!", &(GeometryPy::Type), &pCrv,
-                                                   &vmin, &vmax, &angle,
-                                                   &(Base::VectorPy::Type), &pPnt,
-                                                   &(Base::VectorPy::Type), &pDir,
-                                                   &(PyType_Type), &type)) {
-            GeometryPy* pcGeo = static_cast<GeometryPy*>(pCrv);
-            curve = Handle(Geom_Curve)::DownCast
-                (pcGeo->getGeometryPtr()->handle());
-            if (curve.IsNull()) {
-                throw Py::Exception(PyExc_TypeError, "geometry is not a curve");
-            }
-            if (vmin == DBL_MAX)
-                vmin = curve->FirstParameter();
 
-            if (vmax == -DBL_MAX)
-                vmax = curve->LastParameter();
-        }
-        else {
+        do {
+            if (PyArg_ParseTuple(args.ptr(), "O!|dddO!O!O!", &(GeometryPy::Type), &pCrv,
+                                                       &vmin, &vmax, &angle,
+                                                       &(Base::VectorPy::Type), &pPnt,
+                                                       &(Base::VectorPy::Type), &pDir,
+                                                       &(PyType_Type), &type)) {
+                GeometryPy* pcGeo = static_cast<GeometryPy*>(pCrv);
+                curve = Handle(Geom_Curve)::DownCast
+                    (pcGeo->getGeometryPtr()->handle());
+                if (curve.IsNull()) {
+                    throw Py::Exception(PyExc_TypeError, "geometry is not a curve");
+                }
+                if (vmin == DBL_MAX)
+                    vmin = curve->FirstParameter();
+
+                if (vmax == -DBL_MAX)
+                    vmax = curve->LastParameter();
+                break;
+            }
+
             PyErr_Clear();
-            if (!PyArg_ParseTuple(args.ptr(), "O!|dddO!O!", &(TopoShapePy::Type), &pCrv,
-                &vmin, &vmax, &angle, &(Base::VectorPy::Type), &pPnt,
-                &(Base::VectorPy::Type), &pDir)) {
-                throw Py::Exception();
-            }
-            const TopoDS_Shape& shape = static_cast<TopoShapePy*>(pCrv)->getTopoShapePtr()->getShape();
-            if (shape.IsNull()) {
-                throw Py::Exception(PartExceptionOCCError, "shape is empty");
+            if (PyArg_ParseTuple(args.ptr(), "O!|dddO!O!O!", &(TopoShapePy::Type), &pCrv,
+                                                       &vmin, &vmax, &angle,
+                                                       &(Base::VectorPy::Type), &pPnt,
+                                                       &(Base::VectorPy::Type), &pDir,
+                                                       &(PyType_Type), &type)) {
+                const TopoDS_Shape& shape = static_cast<TopoShapePy*>(pCrv)->getTopoShapePtr()->getShape();
+                if (shape.IsNull()) {
+                    throw Py::Exception(PartExceptionOCCError, "shape is empty");
+                }
+
+                if (shape.ShapeType() != TopAbs_EDGE) {
+                    throw Py::Exception(PartExceptionOCCError, "shape is not an edge");
+                }
+
+                const TopoDS_Edge& edge = TopoDS::Edge(shape);
+                BRepAdaptor_Curve adapt(edge);
+
+                const Handle(Geom_Curve)& hCurve = adapt.Curve().Curve();
+                // Apply placement of the shape to the curve
+                TopLoc_Location loc = edge.Location();
+                curve = Handle(Geom_Curve)::DownCast(hCurve->Transformed(loc.Transformation()));
+                if (curve.IsNull()) {
+                    throw Py::Exception(PartExceptionOCCError, "invalid curve in edge");
+                }
+
+                if (vmin == DBL_MAX)
+                    vmin = adapt.FirstParameter();
+                if (vmax == -DBL_MAX)
+                    vmax = adapt.LastParameter();
+                break;
             }
 
-            if (shape.ShapeType() != TopAbs_EDGE) {
-                throw Py::Exception(PartExceptionOCCError, "shape is not an edge");
-            }
-
-            const TopoDS_Edge& edge = TopoDS::Edge(shape);
-            BRepAdaptor_Curve adapt(edge);
-
-            const Handle(Geom_Curve)& hCurve = adapt.Curve().Curve();
-            // Apply placement of the shape to the curve
-            TopLoc_Location loc = edge.Location();
-            curve = Handle(Geom_Curve)::DownCast(hCurve->Transformed(loc.Transformation()));
-            if (curve.IsNull()) {
-                throw Py::Exception(PartExceptionOCCError, "invalid curve in edge");
-            }
-
-            if (vmin == DBL_MAX)
-                vmin = adapt.FirstParameter();
-            if (vmax == -DBL_MAX)
-                vmax = adapt.LastParameter();
+            // invalid arguments
+            throw Py::TypeError("Expected arguments are:\n"
+                                "Curve or Edge, [float, float, float, Vector, Vector, ShapeType]");
         }
+        while(false);
 
         try {
             gp_Pnt p(0,0,0);
@@ -1657,7 +1859,7 @@ private:
         double height;
         double track = 0;
 
-        Py_UNICODE *unichars;
+        Py_UNICODE *unichars = NULL;
         Py_ssize_t pysize;
 
         PyObject *CharList;
@@ -1671,7 +1873,7 @@ private:
         }
         else {
             PyErr_Clear();
-            if (PyArg_ParseTuple(args.ptr(), "Osd|d", &intext, 
+            if (PyArg_ParseTuple(args.ptr(), "Osd|d", &intext,
                                             &fontspec,
                                             &height,
                                             &track)) {
@@ -1693,12 +1895,28 @@ private:
             if (!p) {
                 throw Py::TypeError("** makeWireString can't convert PyString.");
             }
+#if PY_VERSION_HEX >= 0x03030000
+            pysize = PyUnicode_GetLength(p);
+#else
             pysize = PyUnicode_GetSize(p);
+#endif
+#if PY_VERSION_HEX < 0x03090000
             unichars = PyUnicode_AS_UNICODE(p);
+#else
+            unichars = (Py_UNICODE *)PyUnicode_AsUCS4Copy(p);
+#endif
         }
         else if (PyUnicode_Check(intext)) {
+#if PY_VERSION_HEX >= 0x03030000
+            pysize = PyUnicode_GetLength(intext);
+#else
             pysize = PyUnicode_GetSize(intext);
+#endif
+#if PY_VERSION_HEX < 0x03090000
             unichars = PyUnicode_AS_UNICODE(intext);
+#else
+            unichars = (Py_UNICODE *)PyUnicode_AsUCS4Copy(intext);
+#endif
         }
         else {
             throw Py::TypeError("** makeWireString bad text parameter");
@@ -1706,11 +1924,28 @@ private:
 
         try {
             if (useFontSpec) {
+#ifdef FC_OS_WIN32
+//    Windows doesn't do Utf8 by default and FreeType doesn't do wchar. 
+//    this is a hacky work around.
+//    copy fontspec to Ascii temp name
+                std::string tempFile = Base::FileInfo::getTempFileName();   //utf8/ascii
+				Base::FileInfo fiIn(fontspec);
+				fiIn.copyTo(tempFile.c_str());
+                CharList = FT2FC(unichars,pysize,tempFile.c_str(),height,track);
+				Base::FileInfo fiTemp(tempFile);
+				fiTemp.deleteFile();
+#else
                 CharList = FT2FC(unichars,pysize,fontspec,height,track);
+#endif
             }
             else {
                 CharList = FT2FC(unichars,pysize,dir,fontfile,height,track);
             }
+#if PY_VERSION_HEX >= 0x03090000
+            if (unichars) {
+                PyMem_Free(unichars);
+            }
+#endif
         }
         catch (Standard_DomainError&) {                                      // Standard_DomainError is OCC error.
             throw Py::Exception(PartExceptionOCCDomainError, "makeWireString failed - Standard_DomainError");
@@ -1731,16 +1966,11 @@ private:
             throw Py::Exception();
 
         if (unit) {
-            if (strcmp(unit,"M") == 0 || strcmp(unit,"MM") == 0 || strcmp(unit,"IN") == 0) {
-                if (!Interface_Static::SetCVal("write.iges.unit",unit)) {
-                    throw Py::RuntimeError("Failed to set 'write.iges.unit'");
-                }
-                if (!Interface_Static::SetCVal("write.step.unit",unit)) {
-                    throw Py::RuntimeError("Failed to set 'write.step.unit'");
-                }
+            if (!Interface_Static::SetCVal("write.iges.unit",unit)) {
+                throw Py::RuntimeError("Failed to set 'write.iges.unit'");
             }
-            else {
-                throw Py::ValueError("Wrong unit");
+            if (!Interface_Static::SetCVal("write.step.unit",unit)) {
+                throw Py::RuntimeError("Failed to set 'write.step.unit'");
             }
         }
 
@@ -1796,36 +2026,7 @@ private:
         PyObject *object;
         if (PyArg_ParseTuple(args.ptr(),"O!",&(Part::TopoShapePy::Type), &object)) {
             TopoShape* ptr = static_cast<TopoShapePy*>(object)->getTopoShapePtr();
-            TopoDS_Shape shape = ptr->getShape();
-            if (!shape.IsNull()) {
-                TopAbs_ShapeEnum type = shape.ShapeType();
-                switch (type)
-                {
-                case TopAbs_COMPOUND:
-                    return Py::asObject(new TopoShapeCompoundPy(new TopoShape(shape)));
-                case TopAbs_COMPSOLID:
-                    return Py::asObject(new TopoShapeCompSolidPy(new TopoShape(shape)));
-                case TopAbs_SOLID:
-                    return Py::asObject(new TopoShapeSolidPy(new TopoShape(shape)));
-                case TopAbs_SHELL:
-                    return Py::asObject(new TopoShapeShellPy(new TopoShape(shape)));
-                case TopAbs_FACE:
-                    return Py::asObject(new TopoShapeFacePy(new TopoShape(shape)));
-                case TopAbs_WIRE:
-                    return Py::asObject(new TopoShapeWirePy(new TopoShape(shape)));
-                case TopAbs_EDGE:
-                    return Py::asObject(new TopoShapeEdgePy(new TopoShape(shape)));
-                case TopAbs_VERTEX:
-                    return Py::asObject(new TopoShapeVertexPy(new TopoShape(shape)));
-                case TopAbs_SHAPE:
-                    return Py::asObject(new TopoShapePy(new TopoShape(shape)));
-                default:
-                    break;
-                }
-            }
-            else {
-                throw Py::Exception(PartExceptionOCCError, "empty shape");
-            }
+            return Py::asObject(ptr->getPyObject());
         }
 
         throw Py::Exception();
@@ -1970,6 +2171,97 @@ private:
             throw Py::Exception(PartExceptionOCCError, e.what());
         }
     }
+
+    Py::Object getShape(const Py::Tuple& args, const Py::Dict &kwds) {
+        PyObject *pObj;
+        const char *subname = 0;
+        PyObject *pyMat = 0;
+        PyObject *needSubElement = Py_False;
+        PyObject *transform = Py_True;
+        PyObject *noElementMap = Py_False;
+        PyObject *refine = Py_False;
+        short retType = 0;
+        static char* kwd_list[] = {"obj", "subname", "mat", 
+            "needSubElement","transform","retType","noElementMap","refine",0};
+        if(!PyArg_ParseTupleAndKeywords(args.ptr(), kwds.ptr(), "O!|sO!OOhOO", kwd_list,
+                &App::DocumentObjectPy::Type, &pObj, &subname, &Base::MatrixPy::Type, &pyMat, 
+                &needSubElement,&transform,&retType,&noElementMap,&refine))
+            throw Py::Exception();
+
+        App::DocumentObject *obj = 
+            static_cast<App::DocumentObjectPy*>(pObj)->getDocumentObjectPtr();
+        App::DocumentObject *subObj = 0;
+        Base::Matrix4D mat;
+        if(pyMat)
+            mat = *static_cast<Base::MatrixPy*>(pyMat)->getMatrixPtr();
+        auto shape = Feature::getTopoShape(obj,subname,PyObject_IsTrue(needSubElement),
+                &mat,&subObj,retType==2,PyObject_IsTrue(transform),PyObject_IsTrue(noElementMap));
+        if(PyObject_IsTrue(refine)) {
+            // shape = TopoShape(0,shape.Hasher).makERefine(shape);
+            BRepBuilderAPI_RefineModel mkRefine(shape.getShape());
+            shape.setShape(mkRefine.Shape());
+        }
+        Py::Object sret(shape2pyshape(shape));
+        if(retType==0)
+            return sret;
+
+        return Py::TupleN(sret,Py::asObject(new Base::MatrixPy(new Base::Matrix4D(mat))),
+                subObj?Py::Object(subObj->getPyObject(),true):Py::Object());
+    }
+
+    Py::Object clearShapeCache(const Py::Tuple &args) {
+        if (!PyArg_ParseTuple(args.ptr(),""))
+            throw Py::Exception();
+        Part::Feature::clearShapeCache();
+        return Py::Object();
+    }
+
+    Py::Object splitSubname(const Py::Tuple& args) {
+        const char *subname;
+        if (!PyArg_ParseTuple(args.ptr(), "s",&subname))
+            throw Py::Exception();
+        auto element = Data::ComplexGeoData::findElementName(subname);
+        std::string sub(subname,element-subname);
+        Py::List list;
+        list.append(Py::String(sub));
+        const char *dot = strchr(element,'.');
+        if(!dot)
+            dot = element+strlen(element);
+        const char *mapped = Data::ComplexGeoData::isMappedElement(element);
+        if(mapped)
+            list.append(Py::String(std::string(mapped,dot-mapped)));
+        else
+            list.append(Py::String());
+        if(*dot=='.')
+            list.append(Py::String(dot+1));
+        else if(!mapped)
+            list.append(Py::String(element));
+        else
+            list.append(Py::String());
+        return list;
+    }
+
+    Py::Object joinSubname(const Py::Tuple& args) {
+        const char *sub;
+        const char *mapped;
+        const char *element;
+        if (!PyArg_ParseTuple(args.ptr(), "sss",&sub,&mapped,&element))
+            throw Py::Exception();
+        std::string subname(sub);
+        if (subname.size() && subname[subname.size()-1]!='.')
+            subname += '.';
+        if (mapped && mapped[0]) {
+            if (!Data::ComplexGeoData::isMappedElement(mapped))
+                subname += Data::ComplexGeoData::elementMapPrefix();
+            subname += mapped;
+        }
+        if (element && element[0]) {
+            if (subname.size() && subname[subname.size()-1]!='.')
+                subname += '.';
+            subname += element;
+        }
+        return Py::String(subname);
+    }
 };
 
 PyObject* initModule()
