@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) wandererfan       <wandererfan (at) gmail.com> 2013     *
+ *   Copyright (c) 2013 WandererFan <wandererfan (at) gmail.com>           *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -25,36 +25,40 @@
  *  Project (www.freetype.org).  All rights reserved.                      *
  ***************************************************************************/
 
+#include "PreCompiled.h"
 
 #ifdef FCUseFreeType
 
-#include "PreCompiled.h"
+#ifndef _PreComp_
+# include <iostream>
+# include <fstream>
+# include <string>
+# include <sstream>
+# include <cstdio>
+# include <cstdlib>
+# include <stdexcept>
+# include <vector>
 
-#include <iostream>
-#include <fstream>
-#include <string>
-#include <sstream>
-#include <cstdio> 
-#include <cstdlib> 
-#include <stdexcept>
-#include <vector>
-
-#include <BRepLib.hxx>
-#include <BRepBuilderAPI_MakeEdge.hxx>
-#include <BRepBuilderAPI_MakeWire.hxx>
-#include <BRepBuilderAPI_Transform.hxx>
-#include <gp_Pnt.hxx>
-#include <gp_Vec.hxx>
-#include <TopoDS.hxx>
-#include <TopoDS_Edge.hxx>
-#include <TopoDS_Wire.hxx>
-#include <TColgp_Array1OfPnt2d.hxx>
-#include <GCE2d_MakeSegment.hxx>
-#include <Geom2d_TrimmedCurve.hxx>
-#include <Geom_Plane.hxx>
-#include <Geom2d_BezierCurve.hxx>
-#include <gp_Trsf.hxx>
-#include <Precision.hxx>
+# include <BRepLib.hxx>
+# include <BRepBuilderAPI_MakeEdge.hxx>
+# include <BRepBuilderAPI_MakeWire.hxx>
+# include <BRepBuilderAPI_Transform.hxx>
+# include <gp_Pnt.hxx>
+# include <gp_Vec.hxx>
+# include <TopoDS.hxx>
+# include <TopoDS_Edge.hxx>
+# include <TopoDS_Wire.hxx>
+# include <TopExp_Explorer.hxx>
+# include <TColgp_Array1OfPnt2d.hxx>
+# include <GCE2d_MakeSegment.hxx>
+# include <Geom2d_TrimmedCurve.hxx>
+# include <Geom_Plane.hxx>
+# include <Geom2d_BezierCurve.hxx>
+# include <gp_Trsf.hxx>
+# include <Precision.hxx>
+#include <ShapeConstruct_Curve.hxx>
+#include <Geom2d_BSplineCurve.hxx>
+#endif // _PreComp
 
 #include <Base/Console.h>
 #include "TopoShape.h"
@@ -70,6 +74,8 @@
 
 #include "FT2FC.h"
 
+#define CLOCKWISE 0
+#define ANTICLOCKWISE 1
 using namespace Part;
 
 typedef unsigned long UNICHAR;           // ul is FT2's codepoint type <=> Py_UNICODE2/4
@@ -78,6 +84,7 @@ typedef unsigned long UNICHAR;           // ul is FT2's codepoint type <=> Py_UN
 PyObject* getGlyphContours(FT_Face FTFont, UNICHAR currchar, double PenPos, double Scale,int charNum, double tracking);
 FT_Vector getKerning(FT_Face FTFont, UNICHAR lc, UNICHAR rc);
 TopoDS_Wire edgesToWire(std::vector<TopoDS_Edge> Edges);
+int calcClockDir(std::vector<Base::Vector3d> points);
 
 // for compatibility with old version - separate path & filename
 PyObject* FT2FC(const Py_UNICODE *PyUString,
@@ -98,93 +105,108 @@ PyObject* FT2FC(const Py_UNICODE *PyUString,
                 const size_t length,
                 const char *FontSpec,
                 const double stringheight,                 // fc coords
-                const double tracking) {                     // fc coords
-   FT_Library  FTLib;                
-   FT_Face     FTFont; 
-   FT_Error    error;        
-   FT_Long     FaceIndex = 0;                   // some fonts have multiple faces
-   FT_Vector   kern;
-   FT_UInt     FTLoadFlags = FT_LOAD_DEFAULT | FT_LOAD_NO_BITMAP;
+                const double tracking)                     // fc coords
+{
+    FT_Library  FTLib;
+    FT_Face     FTFont;
+    FT_Error    error;
+    FT_Long     FaceIndex = 0;                   // some fonts have multiple faces
+    FT_Vector   kern;
+    FT_UInt     FTLoadFlags = FT_LOAD_DEFAULT | FT_LOAD_NO_BITMAP;
 
-   std::stringstream ErrorMsg;
-   double PenPos = 0, scalefactor;
-   UNICHAR prevchar = 0, currchar = 0;
-   int  cadv;
-   size_t i;
-   PyObject *WireList, *CharList;
-   
-   error = FT_Init_FreeType(&FTLib); 
-   if(error) {
-      ErrorMsg << "FT_Init_FreeType failed: " << error;
-      throw std::runtime_error(ErrorMsg.str());
-      }
-      
-   // FT does not return an error if font file not found? 
-   std::ifstream is;
-   is.open (FontSpec);
-   if (!is) {
-      ErrorMsg << "Font file not found: " << FontSpec;
-      throw std::runtime_error(ErrorMsg.str());
-      }
+    std::stringstream ErrorMsg;
+    double PenPos = 0, scalefactor;
+    UNICHAR prevchar = 0, currchar = 0;
+    int  cadv;
+    size_t i;
+    Py::List CharList;
+
+    error = FT_Init_FreeType(&FTLib);
+    if (error) {
+        ErrorMsg << "FT_Init_FreeType failed: " << error;
+        throw std::runtime_error(ErrorMsg.str());
+    }
+
+#ifdef FC_OS_WIN32
+    Base::FileInfo fi(FontSpec);
+    if (!fi.isReadable()) {
+        ErrorMsg << "Font file not found (Win): " << FontSpec;
+        throw std::runtime_error(ErrorMsg.str());
+    }
+#else
+    // FT does not return an error if font file not found?
+    std::ifstream is;
+    is.open (FontSpec);
+    if (!is) {
+        ErrorMsg << "Font file not found: " << FontSpec;
+        throw std::runtime_error(ErrorMsg.str());
+    }
+#endif
+
+
+    error = FT_New_Face(FTLib,FontSpec,FaceIndex, &FTFont);
+    if (error) {
+        ErrorMsg << "FT_New_Face failed: " << error;
+        throw std::runtime_error(ErrorMsg.str());
+    }
 
-   error = FT_New_Face(FTLib,FontSpec,FaceIndex, &FTFont); 
-   if(error) {
-      ErrorMsg << "FT_New_Face failed: " << error;
-      throw std::runtime_error(ErrorMsg.str());
-      }
-      
 //TODO: check that FTFont is scalable?  only relevant for hinting etc?
- 
-//  FT2 blows up if char size is not set to some non-zero value. 
-//  This sets size to 48 point. Magic. 
-   error = FT_Set_Char_Size(FTFont,         
-                            0,             /* char_width in 1/64th of points */ 
-                            48*64,         /* char_height in 1/64th of points */ 
-                            0,             /* horizontal device resolution */ 
-                            0 );           /* vertical device resolution */ 
-   if(error) {
-      ErrorMsg << "FT_Set_Char_Size failed: " << error;
-      throw std::runtime_error(ErrorMsg.str());
-      }
- 
-   CharList = PyList_New(0);
-   scalefactor = stringheight/float(FTFont->height);
-   for (i=0; i<length; i++) {
-       currchar = PyUString[i];
-       error = FT_Load_Char(FTFont,
-                            currchar,
-                            FTLoadFlags);
-       if(error) {
-           ErrorMsg << "FT_Load_Char failed: " << error;
-           throw std::runtime_error(ErrorMsg.str());
-       }
 
-       cadv = FTFont->glyph->advance.x;
-       kern = getKerning(FTFont,prevchar,currchar);
-       PenPos += kern.x;
-       WireList = getGlyphContours(FTFont,currchar,PenPos, scalefactor,i,tracking);
-       if (!PyList_Size(WireList))                                  // empty ==> whitespace
-           Base::Console().Log("FT2FC char '0x%04x'/'%d' has no Wires!\n", currchar, currchar);
-       else
-           PyList_Append(CharList, WireList);
-       PenPos += cadv;
-       prevchar = currchar;
-   }
+//  FT2 blows up if char size is not set to some non-zero value.
+//  This sets size to 48 point. Magic.
+    error = FT_Set_Char_Size(FTFont,
+                             0,             /* char_width in 1/64th of points */
+                             48*64,         /* char_height in 1/64th of points */
+                             0,             /* horizontal device resolution */
+                             0 );           /* vertical device resolution */
+    if (error) {
+        ErrorMsg << "FT_Set_Char_Size failed: " << error;
+        throw std::runtime_error(ErrorMsg.str());
+    }
 
-   error = FT_Done_FreeType(FTLib);
-   if(error) {
-      ErrorMsg << "FT_Done_FreeType failed: " << error;
-      throw std::runtime_error(ErrorMsg.str());
-      }
+    scalefactor = stringheight/float(FTFont->height);
+    for (i=0; i<length; i++) {
+        currchar = PyUString[i];
+        error = FT_Load_Char(FTFont,
+                             currchar,
+                             FTLoadFlags);
+        if (error) {
+            ErrorMsg << "FT_Load_Char failed: " << error;
+            throw std::runtime_error(ErrorMsg.str());
+        }
+
+        cadv = FTFont->glyph->advance.x;
+        kern = getKerning(FTFont,prevchar,currchar);
+        PenPos += kern.x;
+        try {
+            Py::List WireList(getGlyphContours(FTFont, currchar, PenPos, scalefactor, i, tracking), true);
+            CharList.append(WireList);
+        }
+        catch (Py::Exception& e) {
+            e.clear();
+            Base::Console().Log("FT2FC char '0x%04x'/'%d' has no Wires!\n", currchar, currchar);
+        }
+
+        PenPos += cadv;
+        prevchar = currchar;
+    }
+
+    error = FT_Done_FreeType(FTLib);
+    if (error) {
+        ErrorMsg << "FT_Done_FreeType failed: " << error;
+        throw std::runtime_error(ErrorMsg.str());
+    }
+
+    return Py::new_reference_to(CharList);
+}
 
-   return(CharList);
-   }
-   
 //********** FT Decompose callbacks and data defns
 // FT Decomp Context for 1 char
-struct FTDC_Ctx {               
+struct FTDC_Ctx {
   std::vector<TopoDS_Wire> Wires;
+  std::vector<int> wDir;
   std::vector<TopoDS_Edge> Edges;
+  std::vector<Base::Vector3d> polyPoints;
   UNICHAR currchar;
   FT_Vector LastVert;
   Handle(Geom_Surface) surf;
@@ -194,16 +216,22 @@ struct FTDC_Ctx {
 // p points to the context where we remember what happened previously (last point, etc)
 static int move_cb(const FT_Vector* pt, void* p) {
    FTDC_Ctx* dc = (FTDC_Ctx*) p;
-   if (!dc->Edges.empty()){                    
+   if (!dc->Edges.empty()){
        TopoDS_Wire newwire = edgesToWire(dc->Edges);
        dc->Wires.push_back(newwire);
        dc->Edges.clear();
+       dc->wDir.push_back(calcClockDir(dc->polyPoints));
+       dc->polyPoints.clear();
    }
    dc->LastVert = *pt;
+   if (dc->polyPoints.empty()) {
+        dc->polyPoints.push_back(Base::Vector3d(pt->x, pt->y, 0.0));
+   }
+
    return 0;
 }
 
-// line_cb called for line segment in the current contour: line(LastVert -- pt) 
+// line_cb called for line segment in the current contour: line(LastVert -- pt)
 static int line_cb(const FT_Vector* pt, void* p) {
    FTDC_Ctx* dc = (FTDC_Ctx*) p;
    gp_Pnt2d v1(dc->LastVert.x, dc->LastVert.y);
@@ -213,11 +241,12 @@ static int line_cb(const FT_Vector* pt, void* p) {
        TopoDS_Edge edge = BRepBuilderAPI_MakeEdge(lseg , dc->surf);
        dc->Edges.push_back(edge);
        dc->LastVert = *pt;
+       dc->polyPoints.push_back(Base::Vector3d(pt->x, pt->y, 0.0));
    }
    return 0;
 }
-   
-// quad_cb called for quadratic (conic) BCurve segment in the current contour 
+
+// quad_cb called for quadratic (conic) BCurve segment in the current contour
 // (ie V-C-V in TTF fonts). BCurve(LastVert -- pt0 -- pt1)
 static int quad_cb(const FT_Vector* pt0, const FT_Vector* pt1, void* p) {
    FTDC_Ctx* dc = (FTDC_Ctx*) p;
@@ -229,9 +258,18 @@ static int quad_cb(const FT_Vector* pt0, const FT_Vector* pt1, void* p) {
    Poles.SetValue(2, c1);
    Poles.SetValue(3, v2);
    Handle(Geom2d_BezierCurve) bcseg = new Geom2d_BezierCurve(Poles);
-   TopoDS_Edge edge = BRepBuilderAPI_MakeEdge(bcseg , dc->surf);
+   double u,v;
+   u = bcseg->FirstParameter();
+   v = bcseg->LastParameter();
+   ShapeConstruct_Curve scc;
+   Handle(Geom2d_BSplineCurve) spline = scc.ConvertToBSpline(bcseg, u, v, Precision::Confusion());
+   if (spline.IsNull()) {
+       Base::Console().Message("Conversion to B-spline failed");
+   }
+   TopoDS_Edge edge = BRepBuilderAPI_MakeEdge(spline , dc->surf);
    dc->Edges.push_back(edge);
    dc->LastVert = *pt1;
+   dc->polyPoints.push_back(Base::Vector3d(pt1->x, pt1->y, 0.0));
    return 0;
 }
 
@@ -249,9 +287,18 @@ static int cubic_cb(const FT_Vector* pt0, const FT_Vector* pt1, const FT_Vector*
    Poles.SetValue(3, c2);
    Poles.SetValue(4, v2);
    Handle(Geom2d_BezierCurve) bcseg = new Geom2d_BezierCurve(Poles);
-   TopoDS_Edge edge = BRepBuilderAPI_MakeEdge(bcseg , dc->surf);
+   double u,v;
+   u = bcseg->FirstParameter();
+   v = bcseg->LastParameter();
+   ShapeConstruct_Curve scc;
+   Handle(Geom2d_BSplineCurve) spline = scc.ConvertToBSpline(bcseg, u, v, Precision::Confusion());
+   if (spline.IsNull()) {
+       Base::Console().Message("Conversion to B-spline failed");
+   }
+   TopoDS_Edge edge = BRepBuilderAPI_MakeEdge(spline , dc->surf);
    dc->Edges.push_back(edge);
    dc->LastVert = *pt2;
+   dc->polyPoints.push_back(Base::Vector3d(pt2->x, pt2->y, 0.0));
    return 0;
 }
 
@@ -275,8 +322,8 @@ PyObject* getGlyphContours(FT_Face FTFont, UNICHAR currchar, double PenPos, doub
    ctx.currchar = currchar;
    ctx.surf = new Geom_Plane(origin,gp::DZ());
 
-   error = FT_Outline_Decompose(&FTFont->glyph->outline, 
-                                &FTcbFuncs, 
+   error = FT_Outline_Decompose(&FTFont->glyph->outline,
+                                &FTcbFuncs,
                                 &ctx);
    if(error) {
       ErrorMsg << "FT_Decompose failed: " << error;
@@ -284,11 +331,22 @@ PyObject* getGlyphContours(FT_Face FTFont, UNICHAR currchar, double PenPos, doub
    }
 
 // make the last TopoDS_Wire
-   if (!ctx.Edges.empty()){                    
+   if (!ctx.Edges.empty()){
        ctx.Wires.push_back(edgesToWire(ctx.Edges));
+       ctx.wDir.push_back(calcClockDir(ctx.polyPoints));
    }
-   /*FT_Orientation fontClass =*/ FT_Outline_Get_Orientation(&FTFont->glyph->outline);
-   PyObject* ret = PyList_New(0);
+
+//a ttf outer contour is clockwise with material on the right.
+//an occ outer contour has material on the left, so it must be reversed?
+
+
+   FT_Orientation ftOrient = FT_Outline_Get_Orientation(&FTFont->glyph->outline);
+   bool isTTF = false;
+   if (ftOrient == FT_ORIENTATION_TRUETYPE) {
+        isTTF = true;
+   }
+
+   Py::List list;
 
    gp_Vec pointer = gp_Vec(PenPos * Scale + charNum*tracking,0.0,0.0);
    gp_Trsf xForm;
@@ -297,25 +355,42 @@ PyObject* getGlyphContours(FT_Face FTFont, UNICHAR currchar, double PenPos, doub
    BRepBuilderAPI_Transform BRepScale(xForm);
    bool bCopy = true;                                                           // no effect?
 
-   for(std::vector<TopoDS_Wire>::iterator iWire=ctx.Wires.begin();iWire != ctx.Wires.end();++iWire) {
+
+   int wCount = 0;
+   for(std::vector<TopoDS_Wire>::iterator iWire=ctx.Wires.begin();iWire != ctx.Wires.end(); ++iWire, wCount++) {
+       if ((ctx.wDir[wCount] == CLOCKWISE) && isTTF) {         //ttf outer wire. fill inside / right
+           (*iWire).Orientation(TopAbs_REVERSED);
+       } else if ((ctx.wDir[wCount] == CLOCKWISE) && !isTTF) { //ps inner wire. fill outside / right
+           (*iWire).Orientation(TopAbs_REVERSED);
+       } else if ((ctx.wDir[wCount] == ANTICLOCKWISE) && isTTF) {  //ttf inner wire. fill outside / left
+           (*iWire).Orientation(TopAbs_REVERSED);
+       } else if ((ctx.wDir[wCount] == ANTICLOCKWISE) && !isTTF) {  //ps outer wire. fill inside / left
+           (*iWire).Orientation(TopAbs_REVERSED);
+       } else {
+            //this is likely a poorly constructed font (ex a ttf with outer wires ACW )
+            Base::Console().Message("FT2FC::getGlyphContours - indeterminate wire direction\n");
+       }
+
        BRepScale.Perform(*iWire,bCopy);
        if (!BRepScale.IsDone())  {
           ErrorMsg << "FT2FC OCC BRepScale failed \n";
           throw std::runtime_error(ErrorMsg.str());
        }
-       PyList_Append(ret,new TopoShapeWirePy(new TopoShape(TopoDS::Wire(BRepScale.Shape()))));
-   } 
-   return(ret);
+
+       PyObject* wire = new TopoShapeWirePy(new TopoShape(TopoDS::Wire(BRepScale.Shape())));
+       list.append(Py::asObject(wire));
+   }
+   return Py::new_reference_to(list);
 }
 
 // get kerning values for this char pair
 //TODO: should check FT_HASKERNING flag? returns (0,0) if no kerning?
 FT_Vector getKerning(FT_Face FTFont, UNICHAR lc, UNICHAR rc) {
    FT_Vector retXY;
-   FT_Error error;        
-   std::stringstream ErrorMsg;  
+   FT_Error error;
+   std::stringstream ErrorMsg;
    FT_Vector ftKern;
-   FT_UInt lcx = FT_Get_Char_Index(FTFont, lc);    
+   FT_UInt lcx = FT_Get_Char_Index(FTFont, lc);
    FT_UInt rcx = FT_Get_Char_Index(FTFont, rc);
    error = FT_Get_Kerning(FTFont,lcx,rcx,FT_KERNING_DEFAULT,&ftKern);
    if(error) {
@@ -343,5 +418,25 @@ TopoDS_Wire edgesToWire(std::vector<TopoDS_Edge> Edges) {
     return(occwire);
 }
 
+//is polygon formed by points clockwise (0) or anticlockwise(1)
+int calcClockDir(std::vector<Base::Vector3d> points)
+{
+    int result = CLOCKWISE;
+    int stop = points.size() - 1;
+    int iPoint = 0;
+    double bigArea = 0;
+    for ( ; iPoint < stop; iPoint++) {
+        double area = points[iPoint].x * points[iPoint + 1].y -
+                      points[iPoint + 1].x * points[iPoint].y;
+        bigArea += area;
+    }
+    double area = points.back().x * points.front().y -
+                  points.front().x * points.back().y;
+    bigArea += area;
+    if (bigArea < 0) {
+        result = ANTICLOCKWISE;
+    }
+    return result;
+}
 
 #endif //#ifdef FCUseFreeType
