@@ -24,6 +24,7 @@
 #include "PreCompiled.h"
 #ifndef _PreComp_
 # include <BRepFilletAPI_MakeChamfer.hxx>
+# include <Precision.hxx>
 # include <TopExp.hxx>
 # include <TopExp_Explorer.hxx>
 # include <TopoDS.hxx>
@@ -51,16 +52,14 @@ App::DocumentObjectExecReturn *Chamfer::execute(void)
     App::DocumentObject* link = Base.getValue();
     if (!link)
         return new App::DocumentObjectExecReturn("No object linked");
-    if (!link->getTypeId().isDerivedFrom(Part::Feature::getClassTypeId()))
-        return new App::DocumentObjectExecReturn("Linked object is not a Part object");
-    Part::Feature *base = static_cast<Part::Feature*>(Base.getValue());
 
     try {
-        BRepFilletAPI_MakeChamfer mkChamfer(base->Shape.getValue());
+        auto baseShape = Feature::getShape(link);
+        BRepFilletAPI_MakeChamfer mkChamfer(baseShape);
         TopTools_IndexedMapOfShape mapOfEdges;
         TopTools_IndexedDataMapOfShapeListOfShape mapEdgeFace;
-        TopExp::MapShapesAndAncestors(base->Shape.getValue(), TopAbs_EDGE, TopAbs_FACE, mapEdgeFace);
-        TopExp::MapShapes(base->Shape.getValue(), TopAbs_EDGE, mapOfEdges);
+        TopExp::MapShapesAndAncestors(baseShape, TopAbs_EDGE, TopAbs_FACE, mapEdgeFace);
+        TopExp::MapShapes(baseShape, TopAbs_EDGE, mapOfEdges);
 
         std::vector<FilletElement> values = Edges.getValues();
         for (std::vector<FilletElement>::iterator it = values.begin(); it != values.end(); ++it) {
@@ -75,7 +74,19 @@ App::DocumentObjectExecReturn *Chamfer::execute(void)
         TopoDS_Shape shape = mkChamfer.Shape();
         if (shape.IsNull())
             return new App::DocumentObjectExecReturn("Resulting shape is null");
-        ShapeHistory history = buildHistory(mkChamfer, TopAbs_FACE, shape, base->Shape.getValue());
+
+        //shapefix re #4285
+        //https://www.forum.freecadweb.org/viewtopic.php?f=3&t=43890&sid=dae2fa6fda71670863a103b42739e47f
+        TopoShape* ts = new TopoShape(shape);
+        double minTol = 2.0 * Precision::Confusion();
+        double maxTol = 4.0 * Precision::Confusion();
+        bool rc = ts->fix(Precision::Confusion(), minTol, maxTol);
+        if (rc) {
+            shape = ts->getShape();
+        }
+        delete ts;
+
+        ShapeHistory history = buildHistory(mkChamfer, TopAbs_FACE, shape, baseShape);
         this->Shape.setValue(shape);
 
         // make sure the 'PropertyShapeHistory' is not safed in undo/redo (#0001889)
