@@ -33,9 +33,9 @@
 # include <Geom_Surface.hxx>
 # include <Precision.hxx>
 # include <Standard_Failure.hxx>
-#endif
 
-#include <boost/uuid/uuid_io.hpp>
+# include <boost/uuid/uuid_io.hpp>
+#endif
 
 #include <Base/GeometryPyCXX.h>
 #include <Base/Matrix.h>
@@ -51,6 +51,7 @@
 #include "GeometryPy.h"
 #include "GeometryPy.cpp"
 
+#include "GeometryExtensionPy.h"
 #include "TopoShape.h"
 #include "TopoShapePy.h"
 
@@ -81,8 +82,7 @@ PyObject* GeometryPy::mirror(PyObject *args)
     PyObject* o;
     if (PyArg_ParseTuple(args, "O!", &(Base::VectorPy::Type),&o)) {
         Base::Vector3d vec = static_cast<Base::VectorPy*>(o)->value();
-        gp_Pnt pnt(vec.x, vec.y, vec.z);
-        getGeometryPtr()->handle()->Mirror(pnt);
+        getGeometryPtr()->mirror(vec);
         Py_Return;
     }
 
@@ -92,8 +92,7 @@ PyObject* GeometryPy::mirror(PyObject *args)
                                        &(Base::VectorPy::Type),&axis)) {
         Base::Vector3d pnt = static_cast<Base::VectorPy*>(o)->value();
         Base::Vector3d dir = static_cast<Base::VectorPy*>(axis)->value();
-        gp_Ax1 ax1(gp_Pnt(pnt.x,pnt.y,pnt.z), gp_Dir(dir.x,dir.y,dir.z));
-        getGeometryPtr()->handle()->Mirror(ax1);
+        getGeometryPtr()->mirror(pnt, dir);
         Py_Return;
     }
 
@@ -108,15 +107,7 @@ PyObject* GeometryPy::rotate(PyObject *args)
         return 0;
 
     Base::Placement* plm = static_cast<Base::PlacementPy*>(o)->getPlacementPtr();
-    Base::Rotation rot(plm->getRotation());
-    Base::Vector3d pnt, dir;
-    double angle;
-
-    rot.getValue(dir, angle);
-    pnt = plm->getPosition();
-
-    gp_Ax1 ax1(gp_Pnt(pnt.x,pnt.y,pnt.z), gp_Dir(dir.x,dir.y,dir.z));
-    getGeometryPtr()->handle()->Rotate(ax1, angle);
+    getGeometryPtr()->rotate(*plm);
     Py_Return;
 }
 
@@ -127,16 +118,14 @@ PyObject* GeometryPy::scale(PyObject *args)
     Base::Vector3d vec;
     if (PyArg_ParseTuple(args, "O!d", &(Base::VectorPy::Type),&o, &scale)) {
         vec = static_cast<Base::VectorPy*>(o)->value();
-        gp_Pnt pnt(vec.x, vec.y, vec.z);
-        getGeometryPtr()->handle()->Scale(pnt, scale);
+        getGeometryPtr()->scale(vec, scale);
         Py_Return;
     }
 
     PyErr_Clear();
     if (PyArg_ParseTuple(args, "O!d", &PyTuple_Type,&o, &scale)) {
         vec = Base::getVectorFromTuple<double>(o);
-        gp_Pnt pnt(vec.x, vec.y, vec.z);
-        getGeometryPtr()->handle()->Scale(pnt, scale);
+        getGeometryPtr()->scale(vec, scale);
         Py_Return;
     }
 
@@ -150,15 +139,7 @@ PyObject* GeometryPy::transform(PyObject *args)
     if (!PyArg_ParseTuple(args, "O!", &(Base::MatrixPy::Type),&o))
         return 0;
     Base::Matrix4D mat = static_cast<Base::MatrixPy*>(o)->value();
-    gp_Trsf trf;
-    trf.SetValues(mat[0][0],mat[0][1],mat[0][2],mat[0][3],
-                  mat[1][0],mat[1][1],mat[1][2],mat[1][3],
-                  mat[2][0],mat[2][1],mat[2][2],mat[2][3]
-#if OCC_VERSION_HEX < 0x060800
-                  , 0.00001,0.00001
-#endif
-                ); //precision was removed in OCCT CR0025194
-    getGeometryPtr()->handle()->Transform(trf);
+    getGeometryPtr()->transform(mat);
     Py_Return;
 }
 
@@ -168,16 +149,14 @@ PyObject* GeometryPy::translate(PyObject *args)
     Base::Vector3d vec;
     if (PyArg_ParseTuple(args, "O!", &(Base::VectorPy::Type),&o)) {
         vec = static_cast<Base::VectorPy*>(o)->value();
-        gp_Vec trl(vec.x, vec.y, vec.z);
-        getGeometryPtr()->handle()->Translate(trl);
+        getGeometryPtr()->translate(vec);
         Py_Return;
     }
 
     PyErr_Clear();
     if (PyArg_ParseTuple(args, "O!", &PyTuple_Type,&o)) {
         vec = Base::getVectorFromTuple<double>(o);
-        gp_Vec trl(vec.x, vec.y, vec.z);
-        getGeometryPtr()->handle()->Translate(trl);
+        getGeometryPtr()->translate(vec);
         Py_Return;
     }
 
@@ -239,15 +218,226 @@ PyObject* GeometryPy::clone(PyObject *args)
     return cpy;
 }
 
-Py::Boolean GeometryPy::getConstruction(void) const
+PyObject* GeometryPy::setExtension(PyObject *args)
 {
-    return Py::Boolean(getGeometryPtr()->Construction);
+    PyObject* o;
+    if (PyArg_ParseTuple(args, "O!", &(GeometryExtensionPy::Type),&o)) {
+        Part::GeometryExtension * ext;
+        ext = static_cast<GeometryExtensionPy *>(o)->getGeometryExtensionPtr();
+
+        // make copy of Python managed memory and wrap it in smart pointer
+        auto cpy = ext->copy();
+
+        this->getGeometryPtr()->setExtension(std::move(cpy));
+        Py_Return;
+    }
+
+    PyErr_SetString(PartExceptionOCCError, "A geometry extension object was expected");
+    return 0;
 }
 
-void  GeometryPy::setConstruction(Py::Boolean arg)
+PyObject* GeometryPy::getExtensionOfType(PyObject *args)
 {
-    if (getGeometryPtr()->getTypeId() != Part::GeomPoint::getClassTypeId())
-        getGeometryPtr()->Construction = arg;
+    char* o;
+    if (PyArg_ParseTuple(args, "s", &o)) {
+
+        Base::Type type = Base::Type::fromName(o);
+
+        if(type != Base::Type::badType()) {
+            try {
+                std::shared_ptr<const GeometryExtension> ext(this->getGeometryPtr()->getExtension(type));
+
+                // we create a copy and transfer this copy's memory management responsibility to Python
+                PyObject* cpy = ext->copyPyObject();
+                return cpy;
+            }
+            catch(const Base::ValueError& e) {
+                PyErr_SetString(PartExceptionOCCError, e.what());
+                return 0;
+            }
+            catch(const std::bad_weak_ptr&) {
+                PyErr_SetString(PartExceptionOCCError, "Geometry extension does not exist anymore.");
+                return 0;
+            }
+            catch(Base::NotImplementedError&) {
+                PyErr_SetString(Part::PartExceptionOCCError, "Geometry extension does not implement a Python counterpart.");
+                return 0;
+            }
+        }
+        else
+        {
+            PyErr_SetString(PartExceptionOCCError, "Exception type does not exist");
+            return 0;
+        }
+
+    }
+
+    PyErr_SetString(PartExceptionOCCError, "A string with the name of the geometry extension type was expected");
+    return 0;
+}
+
+PyObject* GeometryPy::getExtensionOfName(PyObject *args)
+{
+    char* o;
+    if (PyArg_ParseTuple(args, "s", &o)) {
+
+        try {
+            std::shared_ptr<const GeometryExtension> ext(this->getGeometryPtr()->getExtension(std::string(o)));
+
+            // we create a copy and transfer this copy's memory management responsibility to Python
+            PyObject* cpy = ext->copyPyObject();
+            return cpy;
+        }
+        catch(const Base::ValueError& e) {
+            PyErr_SetString(PartExceptionOCCError, e.what());
+            return 0;
+        }
+        catch(const std::bad_weak_ptr&) {
+            PyErr_SetString(PartExceptionOCCError, "Geometry extension does not exist anymore.");
+            return 0;
+        }
+        catch(Base::NotImplementedError&) {
+            PyErr_SetString(Part::PartExceptionOCCError, "Geometry extension does not implement a Python counterpart.");
+            return 0;
+        }
+
+    }
+
+    PyErr_SetString(PartExceptionOCCError, "A string with the name of the geometry extension was expected");
+    return 0;
+}
+
+PyObject* GeometryPy::hasExtensionOfType(PyObject *args)
+{
+    char* o;
+    if (PyArg_ParseTuple(args, "s", &o)) {
+
+        Base::Type type = Base::Type::fromName(o);
+
+        if(type != Base::Type::badType()) {
+            try {
+                return Py::new_reference_to(Py::Boolean(this->getGeometryPtr()->hasExtension(type)));
+            }
+            catch(const Base::ValueError& e) {
+                PyErr_SetString(PartExceptionOCCError, e.what());
+                return 0;
+            }
+        }
+        else
+        {
+            PyErr_SetString(PartExceptionOCCError, "Exception type does not exist");
+            return 0;
+        }
+
+    }
+
+    PyErr_SetString(PartExceptionOCCError, "A string with the type of the geometry extension was expected");
+    return 0;
+}
+
+PyObject* GeometryPy::hasExtensionOfName(PyObject *args)
+{
+    char* o;
+    if (PyArg_ParseTuple(args, "s", &o)) {
+
+        try {
+            return Py::new_reference_to(Py::Boolean(this->getGeometryPtr()->hasExtension(std::string(o))));
+        }
+        catch(const Base::ValueError& e) {
+            PyErr_SetString(PartExceptionOCCError, e.what());
+            return 0;
+        }
+
+    }
+
+    PyErr_SetString(PartExceptionOCCError, "A string with the type of the geometry extension was expected");
+    return 0;
+}
+
+PyObject* GeometryPy::deleteExtensionOfType(PyObject *args)
+{
+    char* o;
+    if (PyArg_ParseTuple(args, "s", &o)) {
+
+        Base::Type type = Base::Type::fromName(o);
+
+        if(type != Base::Type::badType()) {
+            try {
+                this->getGeometryPtr()->deleteExtension(type);
+                Py_Return;
+            }
+            catch(const Base::ValueError& e) {
+                PyErr_SetString(PartExceptionOCCError, e.what());
+                return 0;
+            }
+        }
+        else
+        {
+            PyErr_SetString(PartExceptionOCCError, "Type does not exist");
+            return 0;
+        }
+
+    }
+
+    PyErr_SetString(PartExceptionOCCError, "A string with a type object was expected");
+    return 0;
+}
+
+PyObject* GeometryPy::deleteExtensionOfName(PyObject *args)
+{
+    char* o;
+    if (PyArg_ParseTuple(args, "s", &o)) {
+
+        try {
+            this->getGeometryPtr()->deleteExtension(std::string(o));
+            Py_Return;
+        }
+        catch(const Base::ValueError& e) {
+            PyErr_SetString(PartExceptionOCCError, e.what());
+            return 0;
+        }
+    }
+
+    PyErr_SetString(PartExceptionOCCError, "A string with the name of the extension was expected");
+    return 0;
+}
+
+PyObject* GeometryPy::getExtensions(PyObject *args)
+{
+    if (!PyArg_ParseTuple(args, "")){
+        PyErr_SetString(PartExceptionOCCError, "No arguments were expected");
+        return NULL;
+    }
+
+    try {
+        const std::vector<std::weak_ptr<const GeometryExtension>> ext = this->getGeometryPtr()->getExtensions();
+
+        Py::List list;
+
+        for (std::size_t i=0; i<ext.size(); ++i) {
+
+            // const casting only to get the Python object to make a copy
+            std::shared_ptr<GeometryExtension> p = std::const_pointer_cast<GeometryExtension>(ext[i].lock());
+
+            if(p) {
+                // we create a python copy and add it to the list
+
+                try {
+                    list.append(Py::asObject(p->copyPyObject()));
+                }
+                catch(Base::NotImplementedError&) {
+                    // silently ignoring extensions not having a Python object
+                }
+            }
+        }
+
+        return Py::new_reference_to(list);
+    }
+    catch(const Base::ValueError& e) {
+        PyErr_SetString(PartExceptionOCCError, e.what());
+        return 0;
+    }
+
 }
 
 Py::String GeometryPy::getTag(void) const
