@@ -311,9 +311,7 @@ App::DocumentObjectExecReturn *Loft::execute(void)
         const std::vector<App::DocumentObject*>& shapes = Sections.getValues();
         std::vector<App::DocumentObject*>::const_iterator it;
         for (it = shapes.begin(); it != shapes.end(); ++it) {
-            if (!(*it)->isDerivedFrom(Part::Feature::getClassTypeId()))
-                return new App::DocumentObjectExecReturn("Linked object is not a shape.");
-            TopoDS_Shape shape = static_cast<Part::Feature*>(*it)->Shape.getValue();
+            TopoDS_Shape shape = Feature::getShape(*it);
             if (shape.IsNull())
                 return new App::DocumentObjectExecReturn("Linked shape is invalid.");
 
@@ -424,12 +422,12 @@ App::DocumentObjectExecReturn *Sweep::execute(void)
     if (Sections.getSize() == 0)
         return new App::DocumentObjectExecReturn("No sections linked.");
     App::DocumentObject* spine = Spine.getValue();
-    if (!(spine && spine->getTypeId().isDerivedFrom(Part::Feature::getClassTypeId())))
+    if (!spine)
         return new App::DocumentObjectExecReturn("No spine linked.");
     const std::vector<std::string>& subedge = Spine.getSubValues();
 
     TopoDS_Shape path;
-    const Part::TopoShape& shape = static_cast<Part::Feature*>(spine)->Shape.getValue();
+    const Part::TopoShape& shape = Feature::getTopoShape(spine);
     if (!shape.getShape().IsNull()) {
         try {
             if (!subedge.empty()) {
@@ -483,9 +481,7 @@ App::DocumentObjectExecReturn *Sweep::execute(void)
         const std::vector<App::DocumentObject*>& shapes = Sections.getValues();
         std::vector<App::DocumentObject*>::const_iterator it;
         for (it = shapes.begin(); it != shapes.end(); ++it) {
-            if (!(*it)->isDerivedFrom(Part::Feature::getClassTypeId()))
-                return new App::DocumentObjectExecReturn("Linked object is not a shape.");
-            TopoDS_Shape shape = static_cast<Part::Feature*>(*it)->Shape.getValue();
+            TopoDS_Shape shape = Feature::getShape(*it);
             if (shape.IsNull())
                 return new App::DocumentObjectExecReturn("Linked shape is invalid.");
 
@@ -638,9 +634,9 @@ void Thickness::handleChangedPropertyType(Base::XMLReader &reader, const char *T
 App::DocumentObjectExecReturn *Thickness::execute(void)
 {
     App::DocumentObject* source = Faces.getValue();
-    if (!(source && source->getTypeId().isDerivedFrom(Part::Feature::getClassTypeId())))
+    if (!source)
         return new App::DocumentObjectExecReturn("No source shape linked.");
-    const TopoShape& shape = static_cast<Part::Feature*>(source)->Shape.getShape();
+    const TopoShape& shape = Feature::getTopoShape(source);
     if (shape.isNull())
         return new App::DocumentObjectExecReturn("Source shape is empty.");
 
@@ -673,3 +669,55 @@ App::DocumentObjectExecReturn *Thickness::execute(void)
         this->Shape.setValue(shape);
     return App::DocumentObject::StdReturn;
 }
+
+// ----------------------------------------------------------------------------
+
+PROPERTY_SOURCE(Part::Refine, Part::Feature)
+
+Refine::Refine()
+{
+    ADD_PROPERTY_TYPE(Source,(0),"Refine",App::Prop_None,"Source shape");
+}
+
+App::DocumentObjectExecReturn *Refine::execute(void)
+{
+    Part::Feature* source = Source.getValue<Part::Feature*>();
+    if (!source)
+        return new App::DocumentObjectExecReturn("No part object linked.");
+
+    try {
+        TopoShape myShape = source->Shape.getShape();
+        this->Shape.setValue(myShape.removeSplitter());
+        return App::DocumentObject::StdReturn;
+    }
+    catch (Standard_Failure& e) {
+        return new App::DocumentObjectExecReturn(e.GetMessageString());
+    }
+}
+
+// ----------------------------------------------------------------------------
+
+PROPERTY_SOURCE(Part::Reverse, Part::Feature)
+
+Reverse::Reverse()
+{
+    ADD_PROPERTY_TYPE(Source, (0), "Reverse", App::Prop_None, "Source shape");
+}
+
+App::DocumentObjectExecReturn* Reverse::execute(void)
+{
+    Part::Feature* source = Source.getValue<Part::Feature*>();
+    if (!source)
+        return new App::DocumentObjectExecReturn("No part object linked.");
+
+    try {
+        TopoDS_Shape myShape = source->Shape.getValue();
+        if (!myShape.IsNull())
+            this->Shape.setValue(myShape.Reversed());
+        this->Placement.setValue(source->Placement.getValue());
+        return App::DocumentObject::StdReturn;
+    }
+    catch (Standard_Failure & e) {
+        return new App::DocumentObjectExecReturn(e.GetMessageString());
+    }
+}
