@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) Jürgen Riegel          (juergen.riegel@web.de) 2008     *
+ *   Copyright (c) 2008 Jürgen Riegel <juergen.riegel@web.de>              *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -60,17 +60,16 @@
 # include <TColgp_Array1OfPnt2d.hxx>
 # include <TopExp_Explorer.hxx>
 # include <TopTools_IndexedMapOfShape.hxx>
-#endif
-
-#include <BRepTopAdaptor_FClass2d.hxx>
-#include <BRepPrimAPI_MakeHalfSpace.hxx>
-#include <BRepGProp.hxx>
-#include <GProp_GProps.hxx>
-#include <GProp_PrincipalProps.hxx>
-#include <BRepLProp_SurfaceTool.hxx>
-#include <BRepGProp_Face.hxx>
-#include <GeomLProp_SLProps.hxx>
-#include <BRep_Tool.hxx>
+# include <BRepTopAdaptor_FClass2d.hxx>
+# include <BRepPrimAPI_MakeHalfSpace.hxx>
+# include <BRepGProp.hxx>
+# include <GProp_GProps.hxx>
+# include <GProp_PrincipalProps.hxx>
+# include <BRepLProp_SurfaceTool.hxx>
+# include <BRepGProp_Face.hxx>
+# include <GeomLProp_SLProps.hxx>
+# include <BRep_Tool.hxx>
+#endif // _PreComp
 
 #include <Base/VectorPy.h>
 #include <Base/GeometryPyCXX.h>
@@ -111,13 +110,20 @@ std::string TopoShapeFacePy::representation(void) const
 
 PyObject *TopoShapeFacePy::PyMake(struct _typeobject *, PyObject *, PyObject *)  // Python wrapper
 {
-    // create a new instance of TopoShapeFacePy and the Twin object 
+    // create a new instance of TopoShapeFacePy and the Twin object
     return new TopoShapeFacePy(new TopoShape);
 }
 
 // constructor method
 int TopoShapeFacePy::PyInit(PyObject* args, PyObject* /*kwd*/)
 {
+    if (PyArg_ParseTuple(args, "")) {
+        // Undefined Face
+        getTopoShapePtr()->setShape(TopoDS_Face());
+        return 0;
+    }
+
+    PyErr_Clear();
     PyObject *pW;
     if (PyArg_ParseTuple(args, "O!", &(Part::TopoShapePy::Type), &pW)) {
         try {
@@ -375,6 +381,45 @@ int TopoShapeFacePy::PyInit(PyObject* args, PyObject* /*kwd*/)
     return -1;
 }
 
+/*!
+ * \brief TopoShapeFacePy::addWire
+ * \code
+circle = Part.Circle()
+circle.Radius = 10
+wire = Part.Wire(circle.toShape())
+Part.show(wire)
+
+circle2 = Part.Circle()
+circle2.Radius = 4
+wire2 = Part.Wire(circle2.toShape())
+Part.show(wire2)
+
+plane = Part.Plane()
+face = plane.toShape()
+
+face.addWire(wire)
+face.Area
+Part.show(face)
+
+face.addWire(wire2.reversed())
+face.Area
+Part.show(face)
+ * \endcode
+ */
+PyObject* TopoShapeFacePy::addWire(PyObject *args)
+{
+    PyObject* wire;
+    if (!PyArg_ParseTuple(args, "O!", &TopoShapeWirePy::Type, &wire))
+        return nullptr;
+
+    BRep_Builder aBuilder;
+    TopoDS_Face face = TopoDS::Face(getTopoShapePtr()->getShape());
+    const TopoDS_Shape& shape = static_cast<TopoShapeWirePy*>(wire)->getTopoShapePtr()->getShape();
+    aBuilder.Add(face, shape);
+    getTopoShapePtr()->setShape(face);
+    Py_Return;
+}
+
 PyObject* TopoShapeFacePy::makeOffset(PyObject *args)
 {
     double dist;
@@ -389,7 +434,7 @@ PyObject* TopoShapeFacePy::makeOffset(PyObject *args)
 
     BRepOffsetAPI_MakeOffset mkOffset(f);
     mkOffset.Perform(dist);
-    
+
     return new TopoShapePy(new TopoShape(mkOffset.Shape()));
 }
 
@@ -675,7 +720,7 @@ PyObject* TopoShapeFacePy::curveOnSurface(PyObject *args)
 
         Standard_Real first, last;
         Handle(Geom2d_Curve) curve = BRep_Tool::CurveOnSurface(edge, face, first, last);
-        std::unique_ptr<Part::Geom2dCurve> geo2d = getCurve2dFromGeom2d(curve);
+        std::unique_ptr<Part::Geom2dCurve> geo2d = makeFromCurve2d(curve);
         if (!geo2d)
             Py_Return;
 
@@ -691,6 +736,73 @@ PyObject* TopoShapeFacePy::curveOnSurface(PyObject *args)
     }
 }
 
+PyObject* TopoShapeFacePy::cutHoles(PyObject *args)
+{
+    PyObject *holes=0;
+    if (PyArg_ParseTuple(args, "O!", &(PyList_Type), &holes)) {
+        try {
+            std::vector<TopoDS_Wire> wires;
+            Py::List list(holes);
+            for (Py::List::iterator it = list.begin(); it != list.end(); ++it) {
+                PyObject* item = (*it).ptr();
+                if (PyObject_TypeCheck(item, &(Part::TopoShapePy::Type))) {
+                    const TopoDS_Shape& sh = static_cast<Part::TopoShapePy*>(item)->getTopoShapePtr()->getShape();
+                    if (sh.ShapeType() == TopAbs_WIRE)
+                        wires.push_back(TopoDS::Wire(sh));
+                    else
+                        Standard_Failure::Raise("shape is not a wire");
+                }
+                else
+                    Standard_Failure::Raise("argument is not a shape");
+            }
+
+            if (!wires.empty()) {
+                const TopoDS_Face& f = TopoDS::Face(getTopoShapePtr()->getShape());
+                BRepBuilderAPI_MakeFace mkFace(f);
+                for (std::vector<TopoDS_Wire>::iterator it = wires.begin(); it != wires.end(); ++it)
+                    mkFace.Add(*it);
+                if (!mkFace.IsDone()) {
+                    switch (mkFace.Error()) {
+                    case BRepBuilderAPI_NoFace:
+                        Standard_Failure::Raise("No face");
+                        break;
+                    case BRepBuilderAPI_NotPlanar:
+                        Standard_Failure::Raise("Not planar");
+                        break;
+                    case BRepBuilderAPI_CurveProjectionFailed:
+                        Standard_Failure::Raise("Curve projection failed");
+                        break;
+                    case BRepBuilderAPI_ParametersOutOfRange:
+                        Standard_Failure::Raise("Parameters out of range");
+                        break;
+#if OCC_VERSION_HEX < 0x060500
+                    case BRepBuilderAPI_SurfaceNotC2:
+                        Standard_Failure::Raise("Surface not C2");
+                        break;
+#endif
+                    default:
+                        Standard_Failure::Raise("Unknown failure");
+                        break;
+                    }
+                }
+
+                getTopoShapePtr()->setShape(mkFace.Face());
+                Py_Return;
+            }
+            else {
+                Standard_Failure::Raise("empty wire list");
+            }
+        }
+        catch (Standard_Failure& e) {
+            PyErr_SetString(PartExceptionOCCError, e.GetMessageString());
+            return 0;
+        }
+    }
+    PyErr_SetString(PyExc_RuntimeError, "invalid list of wires");
+    return 0;
+}
+
+
 Py::Object TopoShapeFacePy::getSurface() const
 {
     const TopoDS_Face& f = TopoDS::Face(getTopoShapePtr()->getShape());
@@ -865,13 +977,14 @@ Py::Object TopoShapeFacePy::getWire(void) const
 
 Py::Object TopoShapeFacePy::getOuterWire(void) const
 {
-    const TopoDS_Shape& clSh = getTopoShapePtr()->getShape();
-    if (clSh.IsNull())
+    const TopoDS_Shape& shape = getTopoShapePtr()->getShape();
+    if (shape.IsNull())
         throw Py::RuntimeError("Null shape");
-    if (clSh.ShapeType() == TopAbs_FACE) {
-        TopoDS_Face clFace = (TopoDS_Face&)clSh;
-        TopoDS_Wire clWire = ShapeAnalysis::OuterWire(clFace);
-        return Py::Object(new TopoShapeWirePy(new TopoShape(clWire)),true);
+    if (shape.ShapeType() == TopAbs_FACE) {
+        TopoDS_Wire wire = ShapeAnalysis::OuterWire(TopoDS::Face(shape));
+        Base::PyObjectBase* wirepy = new TopoShapeWirePy(new TopoShape(wire));
+        wirepy->setNotTracking();
+        return Py::asObject(wirepy);
     }
     else {
         throw Py::TypeError("Internal error, TopoDS_Shape is not a face!");
@@ -961,5 +1074,5 @@ PyObject *TopoShapeFacePy::getCustomAttributes(const char* ) const
 
 int TopoShapeFacePy::setCustomAttributes(const char* , PyObject *)
 {
-    return 0; 
+    return 0;
 }
