@@ -22,49 +22,60 @@
 
 
 #include "PreCompiled.h"
+
+#ifndef _PreComp_
+# include <algorithm>
+# include <iterator>
+# include <Geom_Surface.hxx>
+# include <Geom_RectangularTrimmedSurface.hxx>
+# include <GeomAdaptor_Surface.hxx>
+# include <Geom_Plane.hxx>
+# include <Geom_CylindricalSurface.hxx>
+# include <gp_Ax3.hxx>
+# include <Geom_BSplineSurface.hxx>
+# include <gp_Pln.hxx>
+# include <gp_Cylinder.hxx>
+# include <TColgp_Array2OfPnt.hxx>
+# include <TColStd_Array1OfReal.hxx>
+# include <TopoDS_Shape.hxx>
+# include <TopoDS_Compound.hxx>
+# include <TopoDS.hxx>
+# include <TopExp.hxx>
+# include <TopExp_Explorer.hxx>
+# include <BRep_Tool.hxx>
+# include <BRepLib_MakeWire.hxx>
+# include <BRepLib_FuseEdges.hxx>
+# include <BRepBuilderAPI_MakeFace.hxx>
+# include <BRepBuilderAPI_MakeSolid.hxx>
+# include <BRepBuilderAPI_Sewing.hxx>
+# include <Geom_Conic.hxx>
+# include <ShapeBuild_ReShape.hxx>
+# include <ShapeFix_Face.hxx>
+# include <TopTools_ListOfShape.hxx>
+# include <TopTools_ListIteratorOfListOfShape.hxx>
+# include <TopTools_DataMapIteratorOfDataMapOfShapeShape.hxx>
+# include <TopTools_DataMapIteratorOfDataMapOfIntegerListOfShape.hxx>
+# include <BRep_Builder.hxx>
+# include <Bnd_Box.hxx>
+# include <BRepBndLib.hxx>
+# include <ShapeAnalysis_Edge.hxx>
+# include <ShapeAnalysis_Curve.hxx>
+# include <BRepAdaptor_Curve.hxx>
+# include <TColgp_SequenceOfPnt.hxx>
+# include <GeomAPI_ProjectPointOnSurf.hxx>
+# include <BRepGProp.hxx>
+# include <GProp_GProps.hxx>
+# include <Standard_Version.hxx>
+#endif // _PreComp_
+
 #include <Base/Tools.h>
-#include <algorithm>
-#include <iterator>
-#include <Geom_Surface.hxx>
-#include <Geom_RectangularTrimmedSurface.hxx>
-#include <GeomAdaptor_Surface.hxx>
-#include <Geom_Plane.hxx>
-#include <Geom_CylindricalSurface.hxx>
-#include <gp_Ax3.hxx>
-#include <Geom_BSplineSurface.hxx>
-#include <gp_Pln.hxx>
-#include <gp_Cylinder.hxx>
-#include <TColgp_Array2OfPnt.hxx>
-#include <TColStd_Array1OfReal.hxx>
-#include <TopoDS_Shape.hxx>
-#include <TopoDS_Compound.hxx>
-#include <TopoDS.hxx>
-#include <TopExp.hxx>
-#include <TopExp_Explorer.hxx>
-#include <BRep_Tool.hxx>
-#include <BRepLib_MakeWire.hxx>
-#include <BRepLib_FuseEdges.hxx>
-#include <BRepBuilderAPI_MakeFace.hxx>
-#include <BRepBuilderAPI_MakeSolid.hxx>
-#include <BRepBuilderAPI_Sewing.hxx>
-#include <Geom_Conic.hxx>
-#include <ShapeBuild_ReShape.hxx>
-#include <ShapeFix_Face.hxx>
-#include <TopTools_ListOfShape.hxx>
-#include <TopTools_ListIteratorOfListOfShape.hxx>
-#include <TopTools_DataMapIteratorOfDataMapOfShapeShape.hxx>
-#include <TopTools_DataMapIteratorOfDataMapOfIntegerListOfShape.hxx>
-#include <BRep_Builder.hxx>
-#include <Bnd_Box.hxx>
-#include <BRepBndLib.hxx>
-#include <ShapeAnalysis_Edge.hxx>
-#include <ShapeAnalysis_Curve.hxx>
-#include <BRepAdaptor_Curve.hxx>
-#include <TColgp_SequenceOfPnt.hxx>
-#include <GeomAPI_ProjectPointOnSurf.hxx>
+
 #include <Base/Console.h>
+#include <Base/Tools.h>
+
 #include "modelRefine.h"
 
+
 using namespace ModelRefine;
 
 
@@ -346,14 +357,14 @@ FaceTypedPlane::FaceTypedPlane() : FaceTypedBase(GeomAbs_Plane)
 
 static Handle(Geom_Plane) getGeomPlane(const TopoDS_Face &faceIn)
 {
-  Handle_Geom_Plane planeSurfaceOut;
-  Handle_Geom_Surface surface = BRep_Tool::Surface(faceIn);
+  Handle(Geom_Plane) planeSurfaceOut;
+  Handle(Geom_Surface) surface = BRep_Tool::Surface(faceIn);
   if (!surface.IsNull())
   {
     planeSurfaceOut = Handle(Geom_Plane)::DownCast(surface);
     if (planeSurfaceOut.IsNull())
     {
-      Handle_Geom_RectangularTrimmedSurface trimmedSurface = Handle(Geom_RectangularTrimmedSurface)::DownCast(surface);
+      Handle(Geom_RectangularTrimmedSurface) trimmedSurface = Handle(Geom_RectangularTrimmedSurface)::DownCast(surface);
       if (!trimmedSurface.IsNull())
         planeSurfaceOut = Handle(Geom_Plane)::DownCast(trimmedSurface->BasisSurface());
     }
@@ -435,16 +446,33 @@ FaceTypedCylinder::FaceTypedCylinder() : FaceTypedBase(GeomAbs_Cylinder)
 {
 }
 
+static Handle(Geom_CylindricalSurface) getGeomCylinder(const TopoDS_Face &faceIn)
+{
+  Handle(Geom_CylindricalSurface) cylinderSurfaceOut;
+  Handle(Geom_Surface) surface = BRep_Tool::Surface(faceIn);
+  if (!surface.IsNull())
+  {
+    cylinderSurfaceOut = Handle(Geom_CylindricalSurface)::DownCast(surface);
+    if (cylinderSurfaceOut.IsNull())
+    {
+      Handle(Geom_RectangularTrimmedSurface) trimmedSurface = Handle(Geom_RectangularTrimmedSurface)::DownCast(surface);
+      if (!trimmedSurface.IsNull())
+        cylinderSurfaceOut = Handle(Geom_CylindricalSurface)::DownCast(trimmedSurface->BasisSurface());
+    }
+  }
+
+  return cylinderSurfaceOut;
+}
+
 bool FaceTypedCylinder::isEqual(const TopoDS_Face &faceOne, const TopoDS_Face &faceTwo) const
 {
-    //check if these handles are valid?
-    Handle(Geom_CylindricalSurface) surfaceOne = Handle(Geom_CylindricalSurface)::DownCast(BRep_Tool::Surface(faceOne));
-    Handle(Geom_CylindricalSurface) surfaceTwo = Handle(Geom_CylindricalSurface)::DownCast(BRep_Tool::Surface(faceTwo));
+    Handle(Geom_CylindricalSurface) surfaceOne = getGeomCylinder(faceOne);
+    Handle(Geom_CylindricalSurface) surfaceTwo = getGeomCylinder(faceTwo);
     if (surfaceOne.IsNull() || surfaceTwo.IsNull())
         return false;//probably need an error
     gp_Cylinder cylinderOne = surfaceOne->Cylinder();
     gp_Cylinder cylinderTwo = surfaceTwo->Cylinder();
-    
+
     if (fabs(cylinderOne.Radius() - cylinderTwo.Radius()) > Precision::Confusion())
         return false;
     if (!cylinderOne.Axis().IsCoaxial(cylinderTwo.Axis(), Precision::Angular(), Precision::Confusion()) &&
@@ -487,7 +515,7 @@ bool wireEncirclesAxis(const TopoDS_Wire& wire, const Handle(Geom_CylindricalSur
     gp_Ax1 cylAxis = cylinder->Axis();
     gp_Vec cv(cylAxis.Location().X(), cylAxis.Location().Y(), cylAxis.Location().Z()); // center of cylinder
     gp_Vec av(cylAxis.Direction().X(), cylAxis.Direction().Y(), cylAxis.Direction().Z()); // axis of cylinder
-    Handle_Geom_Plane plane = new Geom_Plane(gp_Ax3(cylAxis.Location(), cylAxis.Direction()));
+    Handle(Geom_Plane) plane = new Geom_Plane(gp_Ax3(cylAxis.Location(), cylAxis.Direction()));
     double totalArc = 0.0;
     bool firstSegment = false;
     bool secondSegment = false;
@@ -595,7 +623,7 @@ bool wireEncirclesAxis(const TopoDS_Wire& wire, const Handle(Geom_CylindricalSur
 }
 
 TopoDS_Face FaceTypedCylinder::buildFace(const FaceVectorType &faces) const
-{    
+{
     static TopoDS_Face dummy;
     std::vector<EdgeVectorType> boundaries;
     boundarySplit(faces, boundaries);
@@ -623,9 +651,11 @@ TopoDS_Face FaceTypedCylinder::buildFace(const FaceVectorType &faces) const
 
     // Find outer boundary wires that cut the cylinder into segments. This will be the case f we
     // have removed the seam edges of a complete (360 degrees) cylindrical face
-    Handle(Geom_CylindricalSurface) surface = Handle(Geom_CylindricalSurface)::DownCast(BRep_Tool::Surface(faces.at(0)));
+    Handle(Geom_CylindricalSurface) surface = getGeomCylinder(faces.at(0));
+    if (surface.IsNull())
+      return dummy;
     std::vector<TopoDS_Wire> innerWires, encirclingWires;
-    std::vector<TopoDS_Wire>::iterator wireIt;    
+    std::vector<TopoDS_Wire>::iterator wireIt;
     for (wireIt = allWires.begin(); wireIt != allWires.end(); ++wireIt) {
         if (wireEncirclesAxis(*wireIt, surface))
             encirclingWires.push_back(*wireIt);
@@ -765,7 +795,7 @@ void collectConicEdges(const TopoDS_Shell &shell, TopTools_IndexedMapOfShape &ma
 {
   TopTools_IndexedMapOfShape edges;
   TopExp::MapShapes(shell, TopAbs_EDGE, edges);
-  
+
   for (int index = 1; index <= edges.Extent(); ++index)
   {
     const TopoDS_Edge &currentEdge = TopoDS::Edge(edges.FindKey(index));
@@ -773,7 +803,7 @@ void collectConicEdges(const TopoDS_Shell &shell, TopTools_IndexedMapOfShape &ma
       continue;
     TopLoc_Location location;
     Standard_Real first, last;
-    const Handle_Geom_Curve &curve = BRep_Tool::Curve(currentEdge, location, first, last);
+    const Handle(Geom_Curve) &curve = BRep_Tool::Curve(currentEdge, location, first, last);
     if (curve.IsNull())
       continue;
     if (curve->IsKind(STANDARD_TYPE(Geom_Conic)))
@@ -850,11 +880,41 @@ bool FaceTypedBSpline::isEqual(const TopoDS_Face &faceOne, const TopoDS_Face &fa
         if (vKnotsOne.Value(indexV) != vKnotsTwo.Value(indexV))
             return false;
 
+    //Formulas:
+    //Periodic:     knots=poles+2*degree-mult(1)+2
+    //Non-periodic: knots=poles+degree+1
+    auto getUKnotSequenceSize = [](Handle(Geom_BSplineSurface) surface) {
+        int uPoleCount(surface->NbUPoles());
+        int uDegree(surface->UDegree());
+        if (surface->IsUPeriodic()) {
+            int uMult1(surface->UMultiplicity(1));
+            int size = uPoleCount + 2*uDegree - uMult1 + 2;
+            return size;
+        }
+        else {
+            int size = uPoleCount + uDegree + 1;
+            return size;
+        }
+    };
+    auto getVKnotSequenceSize = [](Handle(Geom_BSplineSurface) surface) {
+        int vPoleCount(surface->NbVPoles());
+        int vDegree(surface->VDegree());
+        if (surface->IsVPeriodic()) {
+            int vMult1(surface->VMultiplicity(1));
+            int size = vPoleCount + 2*vDegree - vMult1 + 2;
+            return size;
+        }
+        else {
+            int size = vPoleCount + vDegree + 1;
+            return size;
+        }
+    };
+
     //knot sequence.
-    int uKnotSequenceOneCount(uPoleCountOne + surfaceOne->UDegree() + 1);
-    int vKnotSequenceOneCount(vPoleCountOne + surfaceOne->VDegree() + 1);
-    int uKnotSequenceTwoCount(uPoleCountTwo + surfaceTwo->UDegree() + 1);
-    int vKnotSequenceTwoCount(vPoleCountTwo + surfaceTwo->VDegree() + 1);
+    int uKnotSequenceOneCount(getUKnotSequenceSize(surfaceOne));
+    int vKnotSequenceOneCount(getVKnotSequenceSize(surfaceOne));
+    int uKnotSequenceTwoCount(getUKnotSequenceSize(surfaceTwo));
+    int vKnotSequenceTwoCount(getVKnotSequenceSize(surfaceTwo));
     if (uKnotSequenceOneCount != uKnotSequenceTwoCount || vKnotSequenceOneCount != vKnotSequenceTwoCount)
         return false;
     TColStd_Array1OfReal uKnotSequenceOne(1, uKnotSequenceOneCount);
@@ -873,11 +933,13 @@ bool FaceTypedBSpline::isEqual(const TopoDS_Face &faceOne, const TopoDS_Face &fa
             return false;
     return true;
   }
-  catch (Standard_Failure)
+  catch (Standard_Failure& e)
   {
-    Handle(Standard_Failure) e = Standard_Failure::Caught();
     std::ostringstream stream;
-    stream << "FaceTypedBSpline::isEqual: OCC Error: " << e->GetMessageString() << std::endl;
+    if (e.GetMessageString())
+      stream << "FaceTypedBSpline::isEqual: OCC Error: " << e.GetMessageString() << std::endl;
+    else
+      stream << "FaceTypedBSpline::isEqual: Unknown OCC Error" << std::endl;
     Base::Console().Message(stream.str().c_str());
   }
   catch (...)
@@ -886,7 +948,7 @@ bool FaceTypedBSpline::isEqual(const TopoDS_Face &faceOne, const TopoDS_Face &fa
     stream << "FaceTypedBSpline::isEqual: Unknown Error" << std::endl;
     Base::Console().Message(stream.str().c_str());
   }
-  
+
   return false;
 }
 
@@ -1012,7 +1074,7 @@ bool FaceUniter::process()
                     if (!temp.empty())
                     {
                         for (FaceVectorType::iterator f = temp.begin(); f != temp.end(); ++f)
-                              modifiedShapes.push_back(std::make_pair(*f, newFace));
+                              modifiedShapes.emplace_back(*f, newFace);
                     }
                 }
             }
@@ -1040,7 +1102,7 @@ bool FaceUniter::process()
             sew.Perform();
             try {
                 workShell = TopoDS::Shell(sew.SewedShape());
-            } catch (Standard_Failure) {
+            } catch (Standard_Failure&) {
                 return false;
             }
             // update the list of modifications
@@ -1062,7 +1124,7 @@ bool FaceUniter::process()
             for(sewIt = facesToSew.begin(); sewIt != facesToSew.end(); ++sewIt)
                 builder.Add(workShell, *sewIt);
         }
-        
+
         BRepLib_FuseEdges edgeFuse(workShell);
 // TODO: change this version after occ fix. Freecad Mantis 1450
 #if OCC_VERSION_HEX <= 0x7fffff
@@ -1098,7 +1160,7 @@ bool FaceUniter::process()
                 // Catch faces that were not united but whose boundary was changed (probably because
                 // several adjacent faces were united)
                 // See https://sourceforge.net/apps/mantisbt/free-cad/view.php?id=873
-                modifiedShapes.push_back(std::make_pair(mapIt.Key(), mapIt.Value()));
+                modifiedShapes.emplace_back(mapIt.Key(), mapIt.Value());
             }
         }
         // Handle edges that were fused. See https://sourceforge.net/apps/mantisbt/free-cad/view.php?id=873
@@ -1115,7 +1177,7 @@ bool FaceUniter::process()
             for (edgeIt.Initialize(edges); edgeIt.More(); edgeIt.Next())
             {
                 if (newEdges.IsBound(idx))
-                    modifiedShapes.push_back(std::make_pair(edgeIt.Value(), newEdges(idx)));
+                    modifiedShapes.emplace_back(edgeIt.Value(), newEdges(idx));
             }
             // TODO: Handle vertices that have disappeared in the fusion of the edges
         }
@@ -1160,6 +1222,16 @@ void Part::BRepBuilderAPI_RefineModel::Build()
             }
         }
         myShape = mkSolid.Solid();
+
+#if OCC_VERSION_HEX <= 0x060700
+        // With occ 6.7 and older it can happen that a solid is flipped.
+        // In this case it must be reversed
+        GProp_GProps props;
+        BRepGProp::VolumeProperties(myShape, props);
+        if (props.Mass() < 0) {
+            myShape.Reverse();
+        }
+#endif
     }
     else if (myShape.ShapeType() == TopAbs_SHELL) {
         const TopoDS_Shell& shell = TopoDS::Shell(myShape);
