@@ -27,15 +27,17 @@
 #include <BRepCheck_Analyzer.hxx>
 #include <BRepCheck_Status.hxx>
 #include <Message_ProgressIndicator.hxx>
+#include <Standard_Version.hxx>
 #include <TopTools_MapOfShape.hxx>
 #include <Gui/TaskView/TaskDialog.h>
 #include <Gui/TaskView/TaskView.h>
 #include <QAbstractItemModel>
 #include <QProgressDialog>
-#include <QTime>
+#include <QElapsedTimer>
 
 class SoSeparator;
 class SoSwitch;
+class QCheckBox;
 class QTextEdit;
 
 namespace PartGui {
@@ -101,13 +103,14 @@ public:
     TaskCheckGeometryResults(QWidget *parent = 0);
     ~TaskCheckGeometryResults();
     QString getShapeContentString();
+    void goCheck();
 
 private Q_SLOTS:
     void currentRowChanged (const QModelIndex &current, const QModelIndex &previous);
 
+
 private:
     void setupInterface();
-    void goCheck();
     void recursiveCheck(const BRepCheck_Analyzer &shapeCheck, const TopoDS_Shape &shape,
                         ResultEntry *parent);
     void checkSub(const BRepCheck_Analyzer &shapeCheck, const TopoDS_Shape &shape,
@@ -115,8 +118,13 @@ private:
     void dispatchError(ResultEntry *entry, const BRepCheck_Status &stat);
     bool split(QString &input, QString &doc, QString &object, QString &sub);
     void setupFunctionMap();
+#if OCC_VERSION_HEX < 0x070500
     int goBOPSingleCheck(const TopoDS_Shape &shapeIn, ResultEntry *theRoot, const QString &baseName,
                          const Handle(Message_ProgressIndicator)& theProgress);
+#else
+    int goBOPSingleCheck(const TopoDS_Shape &shapeIn, ResultEntry *theRoot, const QString &baseName,
+                         const Message_ProgressScope& theScope);
+#endif
     void buildShapeContent(const QString &baseName, const TopoDS_Shape &shape);
     ResultModel *model;
     QTreeView *treeView;
@@ -125,6 +133,7 @@ private:
     SoSeparator *currentSeparator;
     std::vector<FunctionMapType> functionMap;
     std::string shapeContentString;
+
 };
 
 class TaskCheckGeometryDialog : public Gui::TaskView::TaskDialog
@@ -135,16 +144,56 @@ public:
     ~TaskCheckGeometryDialog();
 
     virtual QDialogButtonBox::StandardButtons getStandardButtons() const
-        {return QDialogButtonBox::Close;}
+        {return QDialogButtonBox::Ok | QDialogButtonBox::Close;}
     virtual bool isAllowedAlterDocument(void) const
         {return false;}
     virtual bool needsFullSpace() const {return true;}
 
+private Q_SLOTS:
+    void on_runBOPCheckBox_toggled(bool isOn);
+    void on_runSingleThreadedCheckBox_toggled(bool isOn);
+    void on_logErrorsCheckBox_toggled(bool isOn);
+    void on_expandShapeContentCheckBox_toggled(bool isOn);
+    void on_advancedShapeContentCheckBox_toggled(bool isOn);
+    void on_autoRunCheckBox_toggled(bool isOn);
+    void on_argumentTypeModeCheckBox_toggled(bool isOn);
+    void on_selfInterModeCheckBox_toggled(bool isOn);
+    void on_smallEdgeModeCheckBox_toggled(bool isOn);
+    void on_rebuildFaceModeCheckBox_toggled(bool isOn);
+    void on_continuityModeCheckBox_toggled(bool isOn);
+    void on_tangentModeCheckBox_toggled(bool isOn);
+    void on_mergeVertexModeCheckBox_toggled(bool isOn);
+    void on_mergeEdgeModeCheckBox_toggled(bool isOn);
+    void on_curveOnSurfaceModeCheckBox_toggled(bool isOn);
+    void on_clicked(QAbstractButton* btn);
+
 private:
     TaskCheckGeometryResults* widget;
     Gui::TaskView::TaskBox* taskbox;
     Gui::TaskView::TaskBox* shapeContentBox;
+    Gui::TaskView::TaskBox* settingsBox;
     QTextEdit *contentLabel;
+    QCheckBox *autoRunCheckBox;
+    QCheckBox *runBOPCheckBox;
+    QCheckBox *runSingleThreadedCheckBox;
+    QCheckBox *logErrorsCheckBox;
+    QCheckBox *expandShapeContentCheckBox;
+    QCheckBox *advancedShapeContentCheckBox;
+    QCheckBox *argumentTypeModeCheckBox;
+    QCheckBox *selfInterModeCheckBox;
+    QCheckBox *smallEdgeModeCheckBox;
+    QCheckBox *rebuildFaceModeCheckBox;
+    QCheckBox *continuityModeCheckBox;
+    QCheckBox *tangentModeCheckBox;
+    QCheckBox *mergeVertexModeCheckBox;
+    QCheckBox *mergeEdgeModeCheckBox;
+    QCheckBox *curveOnSurfaceModeCheckBox;
+    bool accept();
+    bool reject();
+    virtual void modifyStandardButtons(QDialogButtonBox*);
+    QPushButton *okBtn;
+    QPushButton *settingsBtn;
+    QPushButton *resultsBtn;
 };
 
 class BOPProgressIndicator : public Message_ProgressIndicator
@@ -153,16 +202,21 @@ public:
     BOPProgressIndicator (const QString &title, QWidget* parent);
     virtual ~BOPProgressIndicator ();
 
+#if OCC_VERSION_HEX < 0x070500
     virtual Standard_Boolean Show (const Standard_Boolean theForce = Standard_True);
+#else
+    virtual void Show (const Message_ProgressScope& theScope,
+                       const Standard_Boolean isForce);
+    virtual void Reset();
+#endif
     virtual Standard_Boolean UserBreak();
 
 private:
     int steps;
     bool canceled;
-    QTime time;
+    QElapsedTimer time;
     QProgressDialog* myProgress;
 };
-
 }
 
 #endif // TASKCHECKGEOMETRY_H
