@@ -24,49 +24,52 @@
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
-# include <sstream>
+# include <boost_signals2.hpp>
+# include <boost_bind_bind.hpp>
 # include <BRep_Tool.hxx>
 # include <BRepGProp.hxx>
 # include <GProp_GProps.hxx>
 # include <gp_Pnt.hxx>
-# include <TopExp_Explorer.hxx>
-# include <TopoDS.hxx>
-# include <TopTools_IndexedMapOfShape.hxx>
-# include <QMessageBox>
-# include <QSet>
-# include <Inventor/SoPickedPoint.h>
 # include <Inventor/actions/SoRayPickAction.h>
 # include <Inventor/actions/SoSearchAction.h>
 # include <Inventor/details/SoFaceDetail.h>
 # include <Inventor/events/SoMouseButtonEvent.h>
 # include <Inventor/nodes/SoCamera.h>
 # include <Inventor/nodes/SoSeparator.h>
+# include <Inventor/SoPickedPoint.h>
+# include <Python.h>
+# include <QFontMetrics>
+# include <QMessageBox>
+# include <QPointer>
+# include <QSet>
+# include <sstream>
+# include <TopExp_Explorer.hxx>
+# include <TopoDS.hxx>
+# include <TopTools_IndexedMapOfShape.hxx>
 #endif
 
-#include <boost/signals.hpp>
-#include <boost/bind.hpp>
-
-#include "ui_TaskFaceColors.h"
 #include "TaskFaceColors.h"
-#include "ViewProviderExt.h"
-#include "SoBrepFaceSet.h"
+#include "ui_TaskFaceColors.h"
 
+#include "SoBrepFaceSet.h"
+#include "ViewProviderExt.h"
+
+#include <App/Document.h>
+#include <App/DocumentObject.h>
 #include <Gui/Application.h>
 #include <Gui/Control.h>
 #include <Gui/Document.h>
 #include <Gui/MainWindow.h>
 #include <Gui/Selection.h>
 #include <Gui/SoFCUnifiedSelection.h>
+#include <Gui/Tools.h>
 #include <Gui/Utilities.h>
 #include <Gui/View3DInventor.h>
 #include <Gui/View3DInventorViewer.h>
-
-#include <App/Document.h>
-#include <App/DocumentObject.h>
 #include <Mod/Part/App/PartFeature.h>
 
-
 using namespace PartGui;
+namespace bp = boost::placeholders;
 
 namespace PartGui {
     class FaceSelection : public Gui::SelectionFilterGate
@@ -74,10 +77,10 @@ namespace PartGui {
         const App::DocumentObject* object;
     public:
         FaceSelection(const App::DocumentObject* obj)
-            : Gui::SelectionFilterGate((Gui::SelectionFilter*)0), object(obj)
+            : Gui::SelectionFilterGate(), object(obj)
         {
         }
-        bool allow(App::Document*pDoc, App::DocumentObject*pObj, const char*sSubName)
+        bool allow(App::Document* /*pDoc*/, App::DocumentObject*pObj, const char*sSubName)
         {
             if (pObj != this->object)
                 return false;
@@ -92,16 +95,18 @@ namespace PartGui {
 class FaceColors::Private
 {
 public:
-    typedef boost::signals::connection Connection;
+    typedef boost::signals2::connection Connection;
     Ui_TaskFaceColors* ui;
-    Gui::View3DInventorViewer* view;
+    QPointer<Gui::View3DInventorViewer> view;
     ViewProviderPartExt* vp;
     App::DocumentObject* obj;
     Gui::Document* doc;
-    std::vector<App::Color> current,perface;
+    std::vector<App::Color> perface;
     QSet<int> index;
+    bool boxSelection;
     Connection connectDelDoc;
     Connection connectDelObj;
+    Connection connectUndoDoc;
 
     Private(ViewProviderPartExt* vp) : ui(new Ui_TaskFaceColors()), view(0), vp(vp)
     {
@@ -116,11 +121,13 @@ public:
             xp.Next();
         }
 
-        current = vp->DiffuseColor.getValues();
+        std::vector<App::Color> current = vp->DiffuseColor.getValues();
         if (current.empty())
             current.push_back(vp->ShapeColor.getValue());
         perface = current;
         perface.resize(mapOfShape.Extent(), perface.front());
+
+        boxSelection = false;
     }
     ~Private()
     {
@@ -161,9 +168,9 @@ public:
 
         return false;
     }
-    void addFacesToSelection(Gui::View3DInventorViewer* viewer,
+    void addFacesToSelection(Gui::View3DInventorViewer* /*viewer*/,
                              const Gui::ViewVolumeProjection& proj,
-                             const Base::Polygon2D& polygon,
+                             const Base::Polygon2d& polygon,
                              const TopoDS_Shape& shape)
     {
         try {
@@ -184,7 +191,7 @@ public:
                     gp_Pnt p = BRep_Tool::Pnt(TopoDS::Vertex(xp_vertex.Current()));
                     Base::Vector3d pt2d;
                     pt2d = proj(Base::Vector3d(p.X(), p.Y(), p.Z()));
-                    if (polygon.Contains(Base::Vector2D(pt2d.x, pt2d.y))) {
+                    if (polygon.Contains(Base::Vector2d(pt2d.x, pt2d.y))) {
 #if 0
                         // TODO
                         if (isVisibleFace(k-1, SbVec2f(pt2d.x, pt2d.y), viewer))
@@ -204,7 +211,7 @@ public:
                 //gp_Pnt c = props.CentreOfMass();
                 //Base::Vector3d pt2d;
                 //pt2d = proj(Base::Vector3d(c.X(), c.Y(), c.Z()));
-                //if (polygon.Contains(Base::Vector2D(pt2d.x, pt2d.y))) {
+                //if (polygon.Contains(Base::Vector2d(pt2d.x, pt2d.y))) {
                 //    if (isVisibleFace(k-1, SbVec2f(pt2d.x, pt2d.y), viewer)) {
                 //        std::stringstream str;
                 //        str << "Face" << k;
@@ -227,18 +234,18 @@ public:
         SoCamera* cam = view->getSoRenderManager()->getCamera();
         SbViewVolume vv = cam->getViewVolume();
         Gui::ViewVolumeProjection proj(vv);
-        Base::Polygon2D polygon;
+        Base::Polygon2d polygon;
         if (picked.size() == 2) {
             SbVec2f pt1 = picked[0];
             SbVec2f pt2 = picked[1];
-            polygon.Add(Base::Vector2D(pt1[0], pt1[1]));
-            polygon.Add(Base::Vector2D(pt1[0], pt2[1]));
-            polygon.Add(Base::Vector2D(pt2[0], pt2[1]));
-            polygon.Add(Base::Vector2D(pt2[0], pt1[1]));
+            polygon.Add(Base::Vector2d(pt1[0], pt1[1]));
+            polygon.Add(Base::Vector2d(pt1[0], pt2[1]));
+            polygon.Add(Base::Vector2d(pt2[0], pt2[1]));
+            polygon.Add(Base::Vector2d(pt2[0], pt1[1]));
         }
         else {
             for (std::vector<SbVec2f>::const_iterator it = picked.begin(); it != picked.end(); ++it)
-                polygon.Add(Base::Vector2D((*it)[0],(*it)[1]));
+                polygon.Add(Base::Vector2d((*it)[0],(*it)[1]));
         }
 
         FaceColors* self = reinterpret_cast<FaceColors*>(ud);
@@ -246,7 +253,11 @@ public:
         if (self->d->obj && self->d->obj->getTypeId().isDerivedFrom(Part::Feature::getClassTypeId())) {
             cb->setHandled();
             const TopoDS_Shape& shape = static_cast<Part::Feature*>(self->d->obj)->Shape.getValue();
+            self->d->boxSelection = true;
             self->d->addFacesToSelection(view, proj, polygon, shape);
+            self->d->boxSelection = false;
+            self->d->ui->boxSelection->setChecked(false);
+            self->updatePanel();
             view->redraw();
         }
     }
@@ -257,6 +268,7 @@ public:
 FaceColors::FaceColors(ViewProviderPartExt* vp, QWidget* parent)
   : d(new Private(vp))
 {
+    Q_UNUSED(parent);
     d->ui->setupUi(this);
     d->ui->groupBox->setTitle(QString::fromUtf8(vp->getObject()->Label.getValue()));
     d->ui->colorButton->setDisabled(true);
@@ -265,9 +277,11 @@ FaceColors::FaceColors(ViewProviderPartExt* vp, QWidget* parent)
     Gui::Selection().addSelectionGate(gate);
 
     d->connectDelDoc = Gui::Application::Instance->signalDeleteDocument.connect(boost::bind
-        (&FaceColors::slotDeleteDocument, this, _1));
+        (&FaceColors::slotDeleteDocument, this, bp::_1));
     d->connectDelObj = Gui::Application::Instance->signalDeletedObject.connect(boost::bind
-        (&FaceColors::slotDeleteObject, this, _1));
+        (&FaceColors::slotDeleteObject, this, bp::_1));
+    d->connectUndoDoc = d->doc->signalUndoDocument.connect(boost::bind
+        (&FaceColors::slotUndoDocument, this, bp::_1));
 }
 
 FaceColors::~FaceColors()
@@ -282,9 +296,18 @@ FaceColors::~FaceColors()
     Gui::Selection().rmvSelectionGate();
     d->connectDelDoc.disconnect();
     d->connectDelObj.disconnect();
+    d->connectUndoDoc.disconnect();
     delete d;
 }
 
+void FaceColors::slotUndoDocument(const Gui::Document& Doc)
+{
+    if (d->doc == &Doc) {
+        d->doc->resetEdit();
+        Gui::Control().closeDialog();
+    }
+}
+
 void FaceColors::slotDeleteDocument(const Gui::Document& Doc)
 {
     if (d->doc == &Doc)
@@ -297,10 +320,18 @@ void FaceColors::slotDeleteObject(const Gui::ViewProvider& obj)
         Gui::Control().closeDialog();
 }
 
-void FaceColors::on_boxSelection_clicked()
+void FaceColors::on_boxSelection_toggled(bool checked)
 {
     Gui::View3DInventor* view = qobject_cast<Gui::View3DInventor*>(Gui::getMainWindow()->activeWindow());
-    if (view) {
+    // toggle the button state and feature
+    d->boxSelection = checked;
+    if (!checked) {
+        // end box selection mode
+        if (view)
+            view->getViewer()->stopSelection();
+    }
+
+    if (view && checked) {
         Gui::View3DInventorViewer* viewer = view->getViewer();
         if (!viewer->isSelecting()) {
             viewer->startSelection(Gui::View3DInventorViewer::Rubberband);
@@ -323,9 +354,10 @@ void FaceColors::on_defaultButton_clicked()
 void FaceColors::on_colorButton_changed()
 {
     if (!d->index.isEmpty()) {
+        float alpha = static_cast<float>(d->vp->Transparency.getValue())/100;
         QColor c = d->ui->colorButton->color();
         for (QSet<int>::iterator it = d->index.begin(); it != d->index.end(); ++it) {
-            d->perface[*it].set(c.redF(), c.greenF(), c.blueF());
+            d->perface[*it].set(c.redF(), c.greenF(), c.blueF(), alpha);
         }
         d->vp->DiffuseColor.setValues(d->perface);
     }
@@ -368,40 +400,52 @@ void FaceColors::onSelectionChanged(const Gui::SelectionChanges& msg)
         selection_changed = true;
     }
 
-    if (selection_changed) {
-        QString faces = QString::fromLatin1("[");
-        int size = d->index.size();
-        for (QSet<int>::iterator it = d->index.begin(); it != d->index.end(); ++it) {
-            faces += QString::number(*it + 1);
-            if (--size > 0)
-                faces += QString::fromLatin1(",");
-        }
-        faces += QString::fromLatin1("]");
-        d->ui->labelElement->setText(faces);
-        d->ui->colorButton->setDisabled(d->index.isEmpty());
+    if (selection_changed && !d->boxSelection) {
+        updatePanel();
     }
 }
 
+void FaceColors::updatePanel()
+{
+    QString faces = QString::fromLatin1("[");
+    int size = d->index.size();
+    for (QSet<int>::iterator it = d->index.begin(); it != d->index.end(); ++it) {
+        faces += QString::number(*it + 1);
+        if (--size > 0)
+            faces += QString::fromLatin1(",");
+    }
+    faces += QString::fromLatin1("]");
+
+    int maxWidth = d->ui->labelElement->width();
+    QFontMetrics fm(d->ui->labelElement->font());
+    if (Gui::QtTools::horizontalAdvance(fm, faces) > maxWidth) {
+        faces = fm.elidedText(faces, Qt::ElideMiddle, maxWidth);
+    }
+
+    d->ui->labelElement->setText(faces);
+    d->ui->colorButton->setDisabled(d->index.isEmpty());
+}
+
+void FaceColors::open()
+{
+    Gui::Document* doc = Gui::Application::Instance->getDocument(d->vp->getObject()->getDocument());
+    doc->openCommand(QT_TRANSLATE_NOOP("Command", "Change face colors"));
+}
+
 bool FaceColors::accept()
 {
     Gui::Document* doc = Gui::Application::Instance->getDocument(d->vp->getObject()->getDocument());
+    doc->commitCommand();
     doc->resetEdit();
     return true;
 }
 
 bool FaceColors::reject()
 {
-    int ret = QMessageBox::question(this, tr("Face colors"), tr("Do you really want to cancel?"),
-        QMessageBox::Yes, QMessageBox::No|QMessageBox::Default|QMessageBox::Escape);
-    if (ret == QMessageBox::Yes) {
-        Gui::Document* doc = Gui::Application::Instance->getDocument(d->vp->getObject()->getDocument());
-        doc->resetEdit();
-        d->vp->DiffuseColor.setValues(d->current);
-        return true;
-    }
-    else {
-        return false;
-    }
+    Gui::Document* doc = Gui::Application::Instance->getDocument(d->vp->getObject()->getDocument());
+    doc->abortCommand();
+    doc->resetEdit();
+    return true;
 }
 
 void FaceColors::changeEvent(QEvent *e)
@@ -430,6 +474,7 @@ TaskFaceColors::~TaskFaceColors()
 
 void TaskFaceColors::open()
 {
+    widget->open();
 }
 
 void TaskFaceColors::clicked(int)
