@@ -102,7 +102,7 @@ void ViewProviderCompound::updateData(const App::Property* prop)
 
         int index=0;
         for (std::vector<App::DocumentObject*>::iterator it = sources.begin(); it != sources.end(); ++it, ++index) {
-            Part::Feature* objBase = dynamic_cast<Part::Feature*>(*it);
+            Part::Feature* objBase = dynamic_cast<Part::Feature*>(Part::Feature::getShapeOwner(*it));
             if (!objBase)
                 continue;
 
@@ -111,15 +111,17 @@ void ViewProviderCompound::updateData(const App::Property* prop)
             TopTools_IndexedMapOfShape baseMap;
             TopExp::MapShapes(baseShape, TopAbs_FACE, baseMap);
 
-            Gui::ViewProvider* vpBase = Gui::Application::Instance->getViewProvider(objBase);
-            std::vector<App::Color> baseCol = static_cast<PartGui::ViewProviderPart*>(vpBase)->DiffuseColor.getValues();
-            applyTransparency(static_cast<PartGui::ViewProviderPart*>(vpBase)->Transparency.getValue(),baseCol);
-            if (static_cast<int>(baseCol.size()) == baseMap.Extent()) {
-                applyColor(hist[index], baseCol, compCol);
-            }
-            else if (!baseCol.empty() && baseCol[0] != this->ShapeColor.getValue()) {
-                baseCol.resize(baseMap.Extent(), baseCol[0]);
-                applyColor(hist[index], baseCol, compCol);
+            auto vpBase = dynamic_cast<PartGui::ViewProviderPart*>(Gui::Application::Instance->getViewProvider(objBase));
+            if (vpBase) {
+                std::vector<App::Color> baseCol = vpBase->DiffuseColor.getValues();
+                applyTransparency(vpBase->Transparency.getValue(),baseCol);
+                if (static_cast<int>(baseCol.size()) == baseMap.Extent()) {
+                    applyColor(hist[index], baseCol, compCol);
+                }
+                else if (!baseCol.empty() && baseCol[0] != this->ShapeColor.getValue()) {
+                    baseCol.resize(baseMap.Extent(), baseCol[0]);
+                    applyColor(hist[index], baseCol, compCol);
+                }
             }
         }
 
@@ -174,10 +176,3 @@ void ViewProviderCompound::dropObject(App::DocumentObject* obj)
     pComp->Links.setValues(pShapes);
 }
 
-void ViewProviderCompound::replaceObject(App::DocumentObject* oldValue, App::DocumentObject* newValue)
-{
-    Part::Compound* pBool = static_cast<Part::Compound*>(getObject());
-    std::vector<App::DocumentObject*> pShapes = pBool->Links.getValues();
-    std::replace(pShapes.begin(), pShapes.end(), oldValue, newValue);
-    pBool->Links.setValues(pShapes);
-}
