@@ -27,6 +27,7 @@
 # include <QAction>
 # include <QMenu>
 # include <QTimer>
+# include <Python.h>
 # include <Standard_math.hxx>
 # include <TopExp.hxx>
 # include <TopTools_IndexedMapOfShape.hxx>
@@ -45,6 +46,7 @@
 #include <Mod/Part/App/FeatureFillet.h>
 #include <Mod/Part/App/FeatureChamfer.h>
 #include <Mod/Part/App/FeatureRevolution.h>
+#include <Mod/Part/App/FeatureOffset.h>
 #include <Mod/Part/App/PartFeatures.h>
 #include <Gui/Application.h>
 #include <Gui/Control.h>
@@ -61,7 +63,7 @@ PROPERTY_SOURCE(PartGui::ViewProviderMirror, PartGui::ViewProviderPart)
 
 ViewProviderMirror::ViewProviderMirror()
 {
-    sPixmap = "Part_Mirror.svg";
+    sPixmap = "Part_Mirror";
     pcEditNode = new SoSeparator();
     pcEditNode->ref();
 }
@@ -89,7 +91,7 @@ bool ViewProviderMirror::setEdit(int ModNum)
         Base::Vector3d base = mf->Base.getValue();
         Base::Vector3d norm = mf->Normal.getValue();
         Base::Vector3d cent = bbox.GetCenter();
-        base = cent.ProjToPlane(base, norm);
+        base = cent.ProjectToPlane(base, norm);
 
         // setup the graph for editing the mirror plane
         SoTransform* trans = new SoTransform;
@@ -165,7 +167,7 @@ void ViewProviderMirror::unsetEdit(int ModNum)
         mf->Normal.setValue(norm[0],norm[1],norm[2]);
 
         pcRoot->removeChild(pcEditNode);
-        pcEditNode->removeAllChildren();
+        Gui::coinRemoveAllChildren(pcEditNode);
     }
     else {
         ViewProviderPart::unsetEdit(ModNum);
@@ -191,13 +193,13 @@ bool ViewProviderMirror::onDelete(const std::vector<std::string> &)
     return true;
 }
 
-void ViewProviderMirror::dragStartCallback(void *data, SoDragger *)
+void ViewProviderMirror::dragStartCallback(void *, SoDragger *)
 {
     // This is called when a manipulator is about to manipulating
-    Gui::Application::Instance->activeDocument()->openCommand("Edit Mirror");
+    Gui::Application::Instance->activeDocument()->openCommand(QT_TRANSLATE_NOOP("Command", "Edit Mirror"));
 }
 
-void ViewProviderMirror::dragFinishCallback(void *data, SoDragger *)
+void ViewProviderMirror::dragFinishCallback(void *, SoDragger *)
 {
     // This is called when a manipulator has done manipulating
     Gui::Application::Instance->activeDocument()->commitCommand();
@@ -238,7 +240,10 @@ void ViewProviderFillet::updateData(const App::Property* prop)
         if (hist.size() != 1)
             return;
         Part::Fillet* objFill = dynamic_cast<Part::Fillet*>(getObject());
-        Part::Feature* objBase = dynamic_cast<Part::Feature*>(objFill->Base.getValue());
+        if (!objFill)
+            return;
+        Part::Feature* objBase = dynamic_cast<Part::Feature*>(
+                Part::Feature::getShapeOwner(objFill->Base.getValue()));
         if (objBase) {
             const TopoDS_Shape& baseShape = objBase->Shape.getValue();
             const TopoDS_Shape& fillShape = objFill->Shape.getValue();
@@ -247,23 +252,23 @@ void ViewProviderFillet::updateData(const App::Property* prop)
             TopExp::MapShapes(baseShape, TopAbs_FACE, baseMap);
             TopExp::MapShapes(fillShape, TopAbs_FACE, fillMap);
 
-            Gui::ViewProvider* vpBase = Gui::Application::Instance->getViewProvider(objBase);
-            std::vector<App::Color> colBase = static_cast<PartGui::ViewProviderPart*>(vpBase)->DiffuseColor.getValues();
-            std::vector<App::Color> colFill;
-            colFill.resize(fillMap.Extent(), static_cast<PartGui::ViewProviderPart*>(vpBase)->ShapeColor.getValue());
+            auto vpBase = dynamic_cast<PartGui::ViewProviderPart*>(Gui::Application::Instance->getViewProvider(objBase));
+            if (vpBase) {
+                std::vector<App::Color> colBase = vpBase->DiffuseColor.getValues();
+                std::vector<App::Color> colFill;
+                colFill.resize(fillMap.Extent(), vpBase->ShapeColor.getValue());
+                applyTransparency(vpBase->Transparency.getValue(),colBase);
+
+                if (static_cast<int>(colBase.size()) == baseMap.Extent()) {
+                    applyColor(hist[0], colBase, colFill);
+                }
+                else if (!colBase.empty() && colBase[0] != this->ShapeColor.getValue()) {
+                    colBase.resize(baseMap.Extent(), colBase[0]);
+                    applyColor(hist[0], colBase, colFill);
+                }
 
-            bool setColor=false;
-            if (static_cast<int>(colBase.size()) == baseMap.Extent()) {
-                applyColor(hist[0], colBase, colFill);
-                setColor = true;
-            }
-            else if (!colBase.empty() && colBase[0] != this->ShapeColor.getValue()) {
-                colBase.resize(baseMap.Extent(), colBase[0]);
-                applyColor(hist[0], colBase, colFill);
-                setColor = true;
-            }
-            if (setColor)
                 this->DiffuseColor.setValues(colFill);
+            }
         }
     }
 }
@@ -341,7 +346,10 @@ void ViewProviderChamfer::updateData(const App::Property* prop)
         if (hist.size() != 1)
             return;
         Part::Chamfer* objCham = dynamic_cast<Part::Chamfer*>(getObject());
-        Part::Feature* objBase = dynamic_cast<Part::Feature*>(objCham->Base.getValue());
+        if (!objCham)
+            return;
+        Part::Feature* objBase = dynamic_cast<Part::Feature*>(
+                Part::Feature::getShapeOwner(objCham->Base.getValue()));
         if (objBase) {
             const TopoDS_Shape& baseShape = objBase->Shape.getValue();
             const TopoDS_Shape& chamShape = objCham->Shape.getValue();
@@ -354,19 +362,17 @@ void ViewProviderChamfer::updateData(const App::Property* prop)
             std::vector<App::Color> colBase = static_cast<PartGui::ViewProviderPart*>(vpBase)->DiffuseColor.getValues();
             std::vector<App::Color> colCham;
             colCham.resize(chamMap.Extent(), static_cast<PartGui::ViewProviderPart*>(vpBase)->ShapeColor.getValue());
+            applyTransparency(static_cast<PartGui::ViewProviderPart*>(vpBase)->Transparency.getValue(),colBase);
 
-            bool setColor=false;
             if (static_cast<int>(colBase.size()) == baseMap.Extent()) {
                 applyColor(hist[0], colBase, colCham);
-                setColor = true;
             }
             else if (!colBase.empty() && colBase[0] != this->ShapeColor.getValue()) {
                 colBase.resize(baseMap.Extent(), colBase[0]);
                 applyColor(hist[0], colBase, colCham);
-                setColor = true;
             }
-            if (setColor)
-                this->DiffuseColor.setValues(colCham);
+
+            this->DiffuseColor.setValues(colCham);
         }
     }
 }
@@ -491,7 +497,11 @@ ViewProviderSweep::~ViewProviderSweep()
 
 std::vector<App::DocumentObject*> ViewProviderSweep::claimChildren() const
 {
-    return static_cast<Part::Sweep*>(getObject())->Sections.getValues();
+    auto obj = static_cast<Part::Sweep*>(getObject());
+    auto children = obj->Sections.getValues();
+    if(obj->Spine.getValue())
+        children.push_back(obj->Spine.getValue());
+    return children;
 }
 
 bool ViewProviderSweep::onDelete(const std::vector<std::string> &)
@@ -580,6 +590,11 @@ bool ViewProviderOffset::onDelete(const std::vector<std::string> &)
     return true;
 }
 
+// ---------------------------------------
+
+PROPERTY_SOURCE(PartGui::ViewProviderOffset2D, PartGui::ViewProviderOffset)
+
+
 // ---------------------------------------
 
 PROPERTY_SOURCE(PartGui::ViewProviderThickness, PartGui::ViewProviderPart)
@@ -660,3 +675,30 @@ bool ViewProviderThickness::onDelete(const std::vector<std::string> &)
 
     return true;
 }
+
+// ---------------------------------------
+
+PROPERTY_SOURCE(PartGui::ViewProviderRefine, PartGui::ViewProviderPart)
+
+ViewProviderRefine::ViewProviderRefine()
+{
+    sPixmap = "Part_Refine_Shape";
+}
+
+ViewProviderRefine::~ViewProviderRefine()
+{
+}
+
+// ---------------------------------------
+
+PROPERTY_SOURCE(PartGui::ViewProviderReverse, PartGui::ViewProviderPart)
+
+ViewProviderReverse::ViewProviderReverse()
+{
+    //TODO: Need a specific icon here!
+    //sPixmap = "Part_Reverse_Shape";
+}
+
+ViewProviderReverse::~ViewProviderReverse()
+{
+}
