@@ -33,8 +33,8 @@
 # define MeshExport     __declspec(dllimport)
 #else // for Linux
 # define PartDesignExport
-# define PartExport 
-# define MeshExport   
+# define PartExport
+# define MeshExport
 #endif
 
 #ifdef _MSC_VER
@@ -57,9 +57,62 @@
 #include <set>
 #include <bitset>
 
+#include <cstring>
+
+# include <math.h>
+
+// QT
+#include <QObject>
+#include <QCoreApplication>
+
 // OpenCasCade =====================================================================================
 #include <Mod/Part/App/OpenCascadeAll.h>
 
+// Apart from the Part OpenCascadeAll, I need:
+# include <GProp_GProps.hxx>
+
+# include <BRepAlgo.hxx>
+# include <BRepAlgoAPI_Fuse.hxx>
+# include <BRepAlgoAPI_Cut.hxx>
+# include <BRepBuilderAPI_GTransform.hxx>
+# include <BRepBuilderAPI_Transform.hxx>
+# include <BRepFeat_MakePrism.hxx>
+# include <BRepGProp.hxx>
+# include <BRepGProp_Face.hxx>
+# include <BRepLProp_SLProps.hxx>
+# include <BRepProj_Projection.hxx>
+# include <BRepBuilderAPI_MakeSolid.hxx>
+# include <BRepBuilderAPI_Sewing.hxx>
+# include <BRepBuilderAPI_MakePolygon.hxx>
+# include <BRepBuilderAPI_MakeFace.hxx>
+# include <BRepClass3d_SolidClassifier.hxx>
+# include <BRepExtrema_DistShapeShape.hxx>
+# include <BRepFilletAPI_MakeChamfer.hxx>
+# include <BRepOffsetAPI_DraftAngle.hxx>
+# include <BRepOffsetAPI_ThruSections.hxx>
+# include <BRepPrimAPI_MakeBox.hxx>
+# include <BRepPrimAPI_MakeCylinder.hxx>
+# include <BRepPrimAPI_MakeSphere.hxx>
+# include <BRepPrimAPI_MakeCone.hxx>
+# include <BRepPrimAPI_MakeTorus.hxx>
+# include <BRepPrimAPI_MakePrism.hxx>
+
+# include <ShapeAnalysis_FreeBounds.hxx>
+# include <ShapeFix_Shape.hxx>
+# include <ShapeFix_ShapeTolerance.hxx>
+
+# include <GeomAPI_IntSS.hxx>
+
+# include <TopExp.hxx>
+# include <TopTools_IndexedDataMapOfShapeListOfShape.hxx>
+# include <TopoDS.hxx>
+# include <Precision.hxx>
+
+#if OCC_VERSION_HEX >= 0x060800
+# include <OSD_OpenFile.hxx>
+#endif
+
+
 #include <Python.h>
 
 #endif // _PreComp_
