@@ -1,23 +1,23 @@
 #/******************************************************************************
-# * Copyright (c)2012 Jan Rheinlaender <jrheinlaender@users.sourceforge.net> *
-# * *
-# * This file is part of the FreeCAD CAx development system. *
-# * *
-# * This library is free software; you can redistribute it and/or *
-# * modify it under the terms of the GNU Library General Public *
-# * License as published by the Free Software Foundation; either *
-# * version 2 of the License, or (at your option) any later version. *
-# * *
-# * This library is distributed in the hope that it will be useful, *
-# * but WITHOUT ANY WARRANTY; without even the implied warranty of *
-# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the *
-# * GNU Library General Public License for more details. *
-# * *
-# * You should have received a copy of the GNU Library General Public *
-# * License along with this library; see the file COPYING.LIB. If not, *
-# * write to the Free Software Foundation, Inc., 59 Temple Place, *
-# * Suite 330, Boston, MA 02111-1307, USA *
-# * *
+# *   Copyright (c) 2012 Jan Rheinländer <jrheinlaender@users.sourceforge.net> *
+# *                                                                            *
+# *   This file is part of the FreeCAD CAx development system.                 *
+# *                                                                            *
+# *   This library is free software; you can redistribute it and/or            *
+# *   modify it under the terms of the GNU Library General Public              *
+# *   License as published by the Free Software Foundation; either             *
+# *   version 2 of the License, or (at your option) any later version.         *
+# *                                                                            *
+# *   This library  is distributed in the hope that it will be useful,         *
+# *   but WITHOUT ANY WARRANTY; without even the implied warranty of           *
+# *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
+# *   GNU Library General Public License for more details.                     *
+# *                                                                            *
+# *   You should have received a copy of the GNU Library General Public        *
+# *   License along with this library; see the file COPYING.LIB. If not,       *
+# *   write to the Free Software Foundation, Inc., 59 Temple Place,            *
+# *   Suite 330, Boston, MA  02111-1307, USA                                   *
+# *                                                                            *
 # ******************************************************************************/
 
 import FreeCAD, FreeCADGui
@@ -94,7 +94,7 @@ class TaskHole:
     def setupUi(self):
         mw = self.getMainWindow()
         form = mw.findChild(QtGui.QWidget, "TaskHole")
-        if form == None:
+        if form is None:
             return
         form.tabWidget = form.findChild(QtGui.QTabWidget, "tabWidget")
         # Type
@@ -367,7 +367,7 @@ class TaskHole:
         self.form.spinThreadLength.setValue(self.feature.ThreadLength)
         # Position
         self.form.buttonSupport.setText("Face")
-        if self.feature.Support == None:
+        if self.feature.Support is None:
             # First-time initialization
             selection = FreeCADGui.Selection.getSelectionEx()
             self.feature.Support = (selection[0].Object, selection[0].SubElementNames)
