@@ -37,10 +37,10 @@
 #else // for Linux
 # define PartDesignExport
 # define PartDesignGuiExport
-# define PartExport     
-# define PartGuiExport     
-# define SketcherExport    
-# define SketcherGuiExport 
+# define PartExport
+# define PartGuiExport
+# define SketcherExport
+# define SketcherGuiExport
 #endif
 
 
@@ -57,9 +57,27 @@
 #include <iostream>
 #include <assert.h>
 #include <cmath>
+#include <sstream>
+
+#include <algorithm>
+
+// Boost
+#include <boost/bind/bind.hpp>
 
 // OCC
 #include <Standard_math.hxx>
+#include <Standard_Version.hxx>
+#include <Bnd_Box.hxx>
+#include <BRepBndLib.hxx>
+#include <BRepAdaptor_Curve.hxx>
+#include <BRepMesh_IncrementalMesh.hxx>
+#include <BRep_Tool.hxx>
+#include <GeomLib_IsPlanarSurface.hxx>
+#include <TopoDS.hxx>
+#include <TopExp.hxx>
+#include <TopExp_Explorer.hxx>
+#include <TopTools_IndexedMapOfShape.hxx>
+#include <BRepAdaptor_Surface.hxx>
 
 // STL
 #include <vector>
@@ -82,6 +100,11 @@
 # include <Gui/Qt4All.h>
 #endif
 
+#include <QMessageBox>
+#include <QMenu>
+#include <QAction>
+#include <QMessageBox>
+
 // Inventor
 #ifndef __InventorAll__
 # include <Gui/InventorAll.h>
