@@ -1,5 +1,5 @@
 /******************************************************************************
- *   Copyright (c)2012 Jan Rheinlaender <jrheinlaender@users.sourceforge.net> *
+ *   Copyright (c) 2012 Jan Rheinländer <jrheinlaender@users.sourceforge.net> *
  *                                                                            *
  *   This file is part of the FreeCAD CAx development system.                 *
  *                                                                            *
@@ -76,7 +76,7 @@ private:
     void updateUI();
 
 private:
-    Ui_TaskScaledParameters* ui;
+    std::unique_ptr<Ui_TaskScaledParameters> ui;
 };
 
 
