@@ -1,5 +1,6 @@
+# -*- coding: utf-8 -*-
 #/******************************************************************************
-# *   Copyright (c)2012 Jan Rheinlaender <jrheinlaender@users.sourceforge.net> *
+# *   Copyright (c) 2012 Jan Rheinländer <jrheinlaender@users.sourceforge.net> *
 # *                                                                            *
 # *   This file is part of the FreeCAD CAx development system.                 *
 # *                                                                            *
@@ -372,19 +373,23 @@ class TranslationFunction:
         
         xresult = []
         yresult = []
-        for xval in sorted(xvals):
-            if xval in divs:
-                i = self.intfunc.index(xval)
-                (begin,  length) = self.intfunc.interval(xval)
-                I_i = self.intfunc.value(xval)
-                C_i0 = self.boundaries[2 * i]
-                C_i1 = self.boundaries[2 * i + 1]
-                FreeCAD.Console.PrintMessage("Interval %u: %f to %f, I_i: %f, C_i0: %f, C_i1: %f\n" % (i,  begin, length,  I_i,  C_i0,  C_i1))           
-            
-            xresult.append(xval)
-            # w(xval) = (transfunc(xval) + C_i0 * xval + C_i1) / (E * I_i)
-            value = (self.transfunc.value(xval)  + C_i0 * xval + C_i1) / (E * I_i)
-            yresult.append(value)
+        # Coverity has reported a problem that I_i, C_i0 or C_i1:
+        # Bad use of null-like value (CIDs are 192609, 192611, 192616)
+        # Since this code doesn't seem to be used anywhere the problematic
+        # part will be commented out
+        #for xval in sorted(xvals):
+        #    if xval in divs:
+        #        i = self.intfunc.index(xval)
+        #        (begin,  length) = self.intfunc.interval(xval)
+        #        I_i = self.intfunc.value(xval)
+        #        C_i0 = self.boundaries[2 * i]
+        #        C_i1 = self.boundaries[2 * i + 1]
+        #        FreeCAD.Console.PrintMessage("Interval %u: %f to %f, I_i: %f, C_i0: %f, C_i1: %f\n" % (i,  begin, length,  I_i,  C_i0,  C_i1))
+        #
+        #    xresult.append(xval)
+        #    # w(xval) = (transfunc(xval) + C_i0 * xval + C_i1) / (E * I_i)
+        #    value = (self.transfunc.value(xval)  + C_i0 * xval + C_i1) / (E * I_i)
+        #    yresult.append(value)
             
         return (xresult, yresult)
 
