@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) Yorik van Havre (yorik@uncreated.net) 2014              *
+ *   Copyright (c) 2014 Yorik van Havre <yorik@uncreated.net>              *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -26,6 +26,7 @@
 #endif
 
 #include "DlgSettingsPathColor.h"
+#include "ui_DlgSettingsPathColor.h"
 #include <Gui/PrefWidgets.h>
 #include <Base/Console.h>
 
@@ -39,8 +40,9 @@ using namespace PathGui;
  */
 DlgSettingsPathColor::DlgSettingsPathColor(QWidget* parent)
     : PreferencePage(parent)
+    , ui(new Ui_DlgSettingsPathColor)
 {
-    this->setupUi(this);
+    ui->setupUi(this);
 }
 
 /**
@@ -54,33 +56,33 @@ DlgSettingsPathColor::~DlgSettingsPathColor()
 void DlgSettingsPathColor::saveSettings()
 {
     // Part
-    DefaultNormalPathColor->onSave();
-    DefaultRapidPathColor->onSave();
-    DefaultPathLineWidth->onSave();
-    DefaultPathMarkerColor->onSave();
-    DefaultExtentsColor->onSave();
-    DefaultProbePathColor->onSave();
-    DefaultHighlightPathColor->onSave();
-    DefaultBBoxSelectionColor->onSave();
-    DefaultBBoxNormalColor->onSave();
-	DefaultSelectionStyle->onSave();
-    DefaultTaskPanelLayout->onSave();
+    ui->DefaultNormalPathColor->onSave();
+    ui->DefaultRapidPathColor->onSave();
+    ui->DefaultPathLineWidth->onSave();
+    ui->DefaultPathMarkerColor->onSave();
+    ui->DefaultExtentsColor->onSave();
+    ui->DefaultProbePathColor->onSave();
+    ui->DefaultHighlightPathColor->onSave();
+    ui->DefaultBBoxSelectionColor->onSave();
+    ui->DefaultBBoxNormalColor->onSave();
+    ui->DefaultSelectionStyle->onSave();
+    ui->DefaultTaskPanelLayout->onSave();
 }
 
 void DlgSettingsPathColor::loadSettings()
 {
     // Part
-    DefaultNormalPathColor->onRestore();
-    DefaultRapidPathColor->onRestore();
-    DefaultPathLineWidth->onRestore();
-    DefaultPathMarkerColor->onRestore();
-    DefaultExtentsColor->onRestore();
-    DefaultProbePathColor->onRestore();
-    DefaultHighlightPathColor->onRestore();
-    DefaultBBoxSelectionColor->onRestore();
-    DefaultBBoxNormalColor->onRestore();
-	DefaultSelectionStyle->onRestore();
-    DefaultTaskPanelLayout->onRestore();
+    ui->DefaultNormalPathColor->onRestore();
+    ui->DefaultRapidPathColor->onRestore();
+    ui->DefaultPathLineWidth->onRestore();
+    ui->DefaultPathMarkerColor->onRestore();
+    ui->DefaultExtentsColor->onRestore();
+    ui->DefaultProbePathColor->onRestore();
+    ui->DefaultHighlightPathColor->onRestore();
+    ui->DefaultBBoxSelectionColor->onRestore();
+    ui->DefaultBBoxNormalColor->onRestore();
+    ui->DefaultSelectionStyle->onRestore();
+    ui->DefaultTaskPanelLayout->onRestore();
 }
 
 /**
@@ -89,7 +91,7 @@ void DlgSettingsPathColor::loadSettings()
 void DlgSettingsPathColor::changeEvent(QEvent *e)
 {
     if (e->type() == QEvent::LanguageChange) {
-        retranslateUi(this);
+        ui->retranslateUi(this);
     }
     else {
         QWidget::changeEvent(e);
