@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) Yorik van Havre (yorik@uncreated.net) 2014              *
+ *   Copyright (c) 2014 Yorik van Havre <yorik@uncreated.net>              *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -32,7 +32,7 @@
 #include <Mod/Part/Gui/SoBrepEdgeSet.h>
 
 class SoCoordinate3;
-class SoDrawStyle;  
+class SoDrawStyle;
 class SoMaterial;
 class SoBaseColor;
 class SoMaterialBinding;
@@ -42,8 +42,9 @@ class SoSwitch;
 namespace PathGui
 {
 
+class PathSelectionObserver;
+
 class PathGuiExport ViewProviderPath : public Gui::ViewProviderGeometryObject
-                                     , public Gui::SelectionObserver
 {
     PROPERTY_HEADER(PathGui::ViewProviderPath);
     typedef ViewProviderGeometryObject inherited;
@@ -54,7 +55,7 @@ public:
 
     /// destructor.
     ~ViewProviderPath();
-    
+
     // Display properties
     App::PropertyInteger LineWidth;
     App::PropertyColor   NormalColor;
@@ -78,19 +79,19 @@ public:
     virtual std::string getElement(const SoDetail *) const;
     SoDetail* getDetail(const char* subelement) const;
 
-    virtual void onSelectionChanged(const Gui::SelectionChanges& msg);
-
     void updateShowConstraints();
     void updateVisual(bool rebuild = false);
     void hideSelection();
 
     virtual void showBoundingBox(bool show);
 
+    friend class PathSelectionObserver;
+
 protected:
 
     virtual void onChanged(const App::Property* prop);
     virtual unsigned long getBoundColor() const;
- 
+
     SoCoordinate3         * pcLineCoords;
     SoCoordinate3         * pcMarkerCoords;
     SoDrawStyle           * pcDrawStyle;
@@ -115,7 +116,7 @@ protected:
     int coordEnd;
 
  };
- 
+
  typedef Gui::ViewProviderPythonFeatureT<ViewProviderPath> ViewProviderPathPython;
 
 } //namespace PathGui
