@@ -1,7 +1,5 @@
 #  -*- coding: utf-8 -*-
-
 # ***************************************************************************
-# *                                                                         *
 # *   Copyright (c) 2014 sliptonic <shopinthewoods@gmail.com>               *
 # *                                                                         *
 # *   This program is free software; you can redistribute it and/or modify  *
@@ -24,20 +22,27 @@
 
 from __future__ import print_function
 import FreeCAD
-import FreeCADGui
 import Path
 from PySide import QtCore
 import math
-import DraftVecUtils as D
 import PathScripts.PathUtils as PathUtils
+import PathScripts.PathGui as PathGui
 
-"""Dragknife Dressup object and FreeCAD command"""
+# lazily loaded modules
+from lazy_loader.lazy_loader import LazyLoader
+D = LazyLoader('DraftVecUtils', globals(), 'DraftVecUtils')
+
+__doc__ = """Dragknife Dressup object and FreeCAD command"""
+
+if FreeCAD.GuiUp:
+    import FreeCADGui
 
 
-# Qt tanslation handling
+# Qt translation handling
 def translate(context, text, disambig=None):
     return QtCore.QCoreApplication.translate(context, text, disambig)
 
+
 movecommands = ['G1', 'G01', 'G2', 'G02', 'G3', 'G03']
 rapidcommands = ['G0', 'G00']
 arccommands = ['G2', 'G3', 'G02', 'G03']
@@ -48,8 +53,8 @@ currLocation = {}
 class ObjectDressup:
 
     def __init__(self, obj):
-        obj.addProperty("App::PropertyLink", "Base",  "Path", QtCore.QT_TRANSLATE_NOOP("App::Property", "The base path to modify"))
-        obj.addProperty("App::PropertyAngle", "filterangle", "Path", QtCore.QT_TRANSLATE_NOOP("App::Property", "Angles less than filter angle will not receive corner actions"))
+        obj.addProperty("App::PropertyLink", "Base", "Path", QtCore.QT_TRANSLATE_NOOP("App::Property", "The base path to modify"))
+        obj.addProperty("App::PropertyAngle", "filterAngle", "Path", QtCore.QT_TRANSLATE_NOOP("App::Property", "Angles less than filter angle will not receive corner actions"))
         obj.addProperty("App::PropertyFloat", "offset", "Path", QtCore.QT_TRANSLATE_NOOP("App::Property", "Distance the point trails behind the spindle"))
         obj.addProperty("App::PropertyFloat", "pivotheight", "Path", QtCore.QT_TRANSLATE_NOOP("App::Property", "Height to raise during corner action"))
 
@@ -62,11 +67,10 @@ class ObjectDressup:
         return None
 
     def shortcut(self, queue):
-        '''Determines whether its shorter to twist CW or CCW to align with the next move'''
+        '''Determines whether its shorter to twist CW or CCW to align with
+        the next move'''
         # get the vector of the last move
 
-        global arccommands
-
         if queue[1].Name in arccommands:
             arcLoc = FreeCAD.Vector(queue[2].x + queue[1].I, queue[2].y + queue[1].J, currLocation['Z'])
             radvector = arcLoc.sub(queue[1].Placement.Base)  # .sub(arcLoc)  # vector of chord from center to point
@@ -93,7 +97,6 @@ class ObjectDressup:
         requires the previous command in order to calculate arcs correctly
         if endpos = True, return the angle at the end of the segment.'''
 
-        global arccommands
         if currCommand.Name in arccommands:
             arcLoc = FreeCAD.Vector((prevCommand.x + currCommand.I), (prevCommand.y + currCommand.J), currentZ)
             if endpos is True:
@@ -126,7 +129,7 @@ class ObjectDressup:
 
     def arcExtension(self, obj, queue):
         '''returns gcode for arc extension'''
-        global currLocation
+        global currLocation  # pylint: disable=global-statement
         results = []
 
         offset = obj.offset
@@ -165,7 +168,7 @@ class ObjectDressup:
         '''returns gcode to do an arc move toward an arc to perform
         a corner action twist. Includes lifting and plungeing the knife'''
 
-        global currLocation
+        global currLocation  # pylint: disable=global-statement
         pivotheight = obj.pivotheight
         offset = obj.offset
         results = []
@@ -232,7 +235,7 @@ class ObjectDressup:
 
     def lineExtension(self, obj, queue):
         '''returns gcode for line extension'''
-        global currLocation
+        global currLocation  # pylint: disable=global-statement
 
         offset = float(obj.offset)
         results = []
@@ -258,7 +261,7 @@ class ObjectDressup:
     def lineTwist(self, obj, queue, lastXY, twistCW=False):
         '''returns gcode to do an arc move toward a line to perform
         a corner action twist. Includes lifting and plungeing the knife'''
-        global currLocation
+        global currLocation  # pylint: disable=global-statement
         pivotheight = obj.pivotheight
         offset = obj.offset
 
@@ -309,7 +312,7 @@ class ObjectDressup:
 
     def execute(self, obj):
         newpath = []
-        global currLocation
+        global currLocation  # pylint: disable=global-statement
 
         if not obj.Base:
             return
@@ -383,7 +386,7 @@ class ObjectDressup:
                         # check if the inciden angle incident exceeds the filter
                         incident_angle = self.getIncidentAngle(queue)
 
-                        if abs(incident_angle) >= obj.filterangle:
+                        if abs(incident_angle) >= obj.filterAngle:
                             if self.shortcut(queue) == "CW":
                                 # if incident_angle >= 0:
                                 twistCW = True
@@ -429,10 +432,60 @@ class ObjectDressup:
             obj.Path = path
 
 
+class TaskPanel:
+
+    def __init__(self, obj):
+        self.obj = obj
+        self.form = FreeCADGui.PySideUic.loadUi(":/panels/DragKnifeEdit.ui")
+        self.filterAngle = PathGui.QuantitySpinBox(self.form.filterAngle, obj, 'filterAngle')
+        self.offsetDistance = PathGui.QuantitySpinBox(self.form.offsetDistance, obj, 'offset')
+        self.pivotHeight = PathGui.QuantitySpinBox(self.form.pivotHeight, obj, 'pivotheight')
+
+        FreeCAD.ActiveDocument.openTransaction(translate("Path_DressupDragKnife", "Edit Dragknife Dress-up"))
+
+    def reject(self):
+        FreeCAD.ActiveDocument.abortTransaction()
+        FreeCADGui.Control.closeDialog()
+        FreeCAD.ActiveDocument.recompute()
+
+    def accept(self):
+        self.getFields()
+        FreeCAD.ActiveDocument.commitTransaction()
+        FreeCADGui.ActiveDocument.resetEdit()
+        FreeCADGui.Control.closeDialog()
+        FreeCAD.ActiveDocument.recompute()
+
+    def getFields(self):
+        self.filterAngle.updateProperty()
+        self.offsetDistance.updateProperty()
+        self.pivotHeight.updateProperty()
+        self.updateUI()
+
+        self.obj.Proxy.execute(self.obj)
+
+    def updateUI(self):
+        self.filterAngle.updateSpinBox()
+        self.offsetDistance.updateSpinBox()
+        self.pivotHeight.updateSpinBox()
+
+    def updateModel(self):
+        self.getFields()
+        FreeCAD.ActiveDocument.recompute()
+
+    def setFields(self):
+        self.updateUI()
+
+    def open(self):
+        pass
+
+    def setupUi(self):
+        self.setFields()
+
+
 class ViewProviderDressup:
 
     def __init__(self, vobj):
-        vobj.Proxy = self
+        self.Object = vobj.Object
 
     def attach(self, vobj):
         self.Object = vobj.Object
@@ -448,9 +501,15 @@ class ViewProviderDressup:
             # FreeCADGui.ActiveDocument.getObject(obj.Base.Name).Visibility = False
 
     def unsetEdit(self, vobj, mode=0):
+        # pylint: disable=unused-argument
         return False
 
     def setEdit(self, vobj, mode=0):
+        # pylint: disable=unused-argument
+        FreeCADGui.Control.closeDialog()
+        panel = TaskPanel(vobj.Object)
+        FreeCADGui.Control.showDialog(panel)
+        panel.setupUi()
         return True
 
     def claimChildren(self):
@@ -460,20 +519,25 @@ class ViewProviderDressup:
         return None
 
     def __setstate__(self, state):
+        # pylint: disable=unused-argument
         return None
 
     def onDelete(self, arg1=None, arg2=None):
-        FreeCADGui.ActiveDocument.getObject(arg1.Object.Base.Name).Visibility = True
-        job = PathUtils.findParentJob(arg1.Object.Base)
-        job.Proxy.addOperation(arg1.Object.Base, arg1.Object)
-        arg1.Object.Base = None
+        # pylint: disable=unused-argument
+        if arg1.Object and arg1.Object.Base:
+            FreeCADGui.ActiveDocument.getObject(arg1.Object.Base.Name).Visibility = True
+            job = PathUtils.findParentJob(arg1.Object.Base)
+            if job:
+                job.Proxy.addOperation(arg1.Object.Base, arg1.Object)
+            arg1.Object.Base = None
         return True
 
 
 class CommandDressupDragknife:
+    # pylint: disable=no-init
 
     def GetResources(self):
-        return {'Pixmap': 'Path-Dressup',
+        return {'Pixmap': 'Path_Dressup',
                 'MenuText': QtCore.QT_TRANSLATE_NOOP("Path_DressupDragKnife", "DragKnife Dress-up"),
                 'ToolTip': QtCore.QT_TRANSLATE_NOOP("Path_DressupDragKnife", "Modifies a path to add dragknife corner actions")}
 
@@ -481,7 +545,7 @@ class CommandDressupDragknife:
         if FreeCAD.ActiveDocument is not None:
             for o in FreeCAD.ActiveDocument.Objects:
                 if o.Name[:3] == "Job":
-                        return True
+                    return True
         return False
 
     def Activated(self):
@@ -511,11 +575,12 @@ class CommandDressupDragknife:
         FreeCADGui.doCommand('job = PathScripts.PathUtils.findParentJob(base)')
         FreeCADGui.doCommand('obj.Base = base')
         FreeCADGui.doCommand('job.Proxy.addOperation(obj, base)')
-        FreeCADGui.doCommand('PathScripts.PathDressupDragknife.ViewProviderDressup(obj.ViewObject)')
+        FreeCADGui.doCommand('obj.ViewObject.Proxy = PathScripts.PathDressupDragknife.ViewProviderDressup(obj.ViewObject)')
         FreeCADGui.doCommand('Gui.ActiveDocument.getObject(base.Name).Visibility = False')
-        FreeCADGui.doCommand('obj.filterangle = 20')
+        FreeCADGui.doCommand('obj.filterAngle = 20')
         FreeCADGui.doCommand('obj.offset = 2')
         FreeCADGui.doCommand('obj.pivotheight = 4')
+        FreeCADGui.doCommand('obj.ViewObject.Document.setEdit(obj.ViewObject, 0)')
 
         FreeCAD.ActiveDocument.commitTransaction()
         FreeCAD.ActiveDocument.recompute()
