@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
-
 # ***************************************************************************
-# *                                                                         *
 # *   Copyright (c) 2017 sliptonic <shopinthewoods@gmail.com>               *
 # *                                                                         *
 # *   This program is free software; you can redistribute it and/or modify  *
@@ -21,8 +19,8 @@
 # *   USA                                                                   *
 # *                                                                         *
 # ***************************************************************************
+
 import FreeCAD
-import Part
 import Path
 import PathScripts.PathDressup as PathDressup
 import PathScripts.PathGeom as PathGeom
@@ -31,24 +29,21 @@ import PathScripts.PathUtil as PathUtil
 import PathScripts.PathUtils as PathUtils
 import copy
 import math
-import sys
-import traceback
 
 from PathScripts.PathDressupTagPreferences import HoldingTagPreferences
 from PathScripts.PathUtils import waiting_effects
 from PySide import QtCore
 
-"""Holding Tags Dressup object and FreeCAD command"""
+# lazily loaded modules
+from lazy_loader.lazy_loader import LazyLoader
+Part = LazyLoader('Part', globals(), 'Part')
 
-if False:
-    PathLog.setLevel(PathLog.Level.DEBUG, PathLog.thisModule())
-    PathLog.trackModule()
-else:
-    PathLog.setLevel(PathLog.Level.INFO, PathLog.thisModule())
+PathLog.setLevel(PathLog.Level.INFO, PathLog.thisModule())
+#PathLog.trackModule()
 
 failures = []
 
-# Qt tanslation handling
+# Qt translation handling
 def translate(context, text, disambig=None):
     return QtCore.QCoreApplication.translate(context, text, disambig)
 
@@ -100,9 +95,9 @@ def debugCone(vector, r1, r2, height, label, color=None):
 
 
 class Tag:
-    def __init__(self, id, x, y, width, height, angle, radius, enabled=True):
+    def __init__(self, nr, x, y, width, height, angle, radius, enabled=True):
         PathLog.track("%.2f, %.2f, %.2f, %.2f, %.2f, %.2f, %d" % (x, y, width, height, angle, radius, enabled))
-        self.id = id
+        self.nr = nr
         self.x = x
         self.y = y
         self.width = math.fabs(width)
@@ -113,6 +108,14 @@ class Tag:
         self.enabled = enabled
         self.isSquare = False
 
+        # initialized later
+        self.toolRadius = None
+        self.realRadius = None
+        self.r1 = None
+        self.r2 = None
+        self.solid = None
+        self.z = None
+
     def fullWidth(self):
         return 2 * self.toolRadius + self.width
 
@@ -138,7 +141,7 @@ class Tag:
             self.isSquare = True
             self.solid = Part.makeCylinder(r1, height)
             radius = min(min(self.radius, r1), self.height)
-            PathLog.debug("Part.makeCone(%f, %f)" % (r1, height))
+            PathLog.debug("Part.makeCylinder(%f, %f)" % (r1, height))
         elif self.angle > 0.0 and height > 0.0:
             # cone
             rad = math.radians(self.angle)
@@ -177,13 +180,13 @@ class Tag:
     def filterIntersections(self, pts, face):
         if type(face.Surface) == Part.Cone or type(face.Surface) == Part.Cylinder or type(face.Surface) == Part.Toroid:
             PathLog.track("it's a cone/cylinder, checking z")
-            return list(filter(lambda pt: pt.z >= self.bottom() and pt.z <= self.top(), pts))
+            return list([pt for pt in pts if pt.z >= self.bottom() and pt.z <= self.top()])
         if type(face.Surface) == Part.Plane:
             PathLog.track("it's a plane, checking R")
             c = face.Edges[0].Curve
             if (type(c) == Part.Circle):
-                return list(filter(lambda pt: (pt - c.Center).Length <= c.Radius or PathGeom.isRoughly((pt - c.Center).Length, c.Radius), pts))
-        print("==== we got a %s" % face.Surface)
+                return list([pt for pt in pts if (pt - c.Center).Length <= c.Radius or PathGeom.isRoughly((pt - c.Center).Length, c.Radius)])
+        PathLog.error("==== we got a %s" % face.Surface)
 
     def isPointOnEdge(self, pt, edge):
         param = edge.Curve.parameter(pt)
@@ -201,14 +204,13 @@ class Tag:
         return False
 
     def nextIntersectionClosestTo(self, edge, solid, refPt):
-        # ef = edge.valueAt(edge.FirstParameter)
-        # em = edge.valueAt((edge.FirstParameter+edge.LastParameter)/2)
-        # el = edge.valueAt(edge.LastParameter)
-        # print("-------- intersect %s (%.2f, %.2f, %.2f) - (%.2f, %.2f, %.2f) - (%.2f, %.2f, %.2f)  refp=(%.2f, %.2f, %.2f)" % (type(edge.Curve), ef.x, ef.y, ef.z, em.x, em.y, em.z, el.x, el.y, el.z, refPt.x, refPt.y, refPt.z))
+        # debugEdge(edge, 'intersects_')
 
         vertexes = edge.common(solid).Vertexes
         if vertexes:
-            return sorted(vertexes, key=lambda v: (v.Point - refPt).Length)[0].Point
+            pt = sorted(vertexes, key=lambda v: (v.Point - refPt).Length)[0].Point
+            debugEdge(edge, "intersects (%.2f, %.2f, %.2f) -> (%.2f, %.2f, %.2f)" % (refPt.x, refPt.y, refPt.z, pt.x, pt.y, pt.z))
+            return pt
         return None
 
     def intersects(self, edge, param):
@@ -268,6 +270,18 @@ class MapWireToTag:
         self.complete = False
         self.haveProblem = False
 
+        # initialized later
+        self.edgePoints = None
+        self.edgesCleanup = None
+        self.edgesOrder = None
+        self.entryEdges = None
+        self.exit = None
+        self.exitEdges = None
+        self.finalEdge = None
+        self.offendingEdge = None
+        self.realEntry = None
+        self.realExit = None
+
     def addEdge(self, edge):
         debugEdge(edge, '..........')
         self.edges.append(edge)
@@ -324,16 +338,16 @@ class MapWireToTag:
         # if there are no edges connected to entry/exit, it means the plunge in/out is vertical
         # we need to add in the missing segment and collect the new entry/exit edges.
         if not self.entryEdges:
-            print("fill entryEdges ...")
+            PathLog.debug("fill entryEdges ...")
             self.realEntry = sorted(self.edgePoints, key=lambda p: (p - self.entry).Length)[0]
-            self.entryEdges = list(filter(lambda e: PathGeom.edgeConnectsTo(e, self.realEntry), edges))
+            self.entryEdges = list([e for e in edges if PathGeom.edgeConnectsTo(e, self.realEntry)])
             edges.append(Part.Edge(Part.LineSegment(self.entry, self.realEntry)))
         else:
             self.realEntry = None
         if not self.exitEdges:
-            print("fill exitEdges ...")
+            PathLog.debug("fill exitEdges ...")
             self.realExit = sorted(self.edgePoints, key=lambda p: (p - self.exit).Length)[0]
-            self.exitEdges = list(filter(lambda e: PathGeom.edgeConnectsTo(e, self.realExit), edges))
+            self.exitEdges = list([e for e in edges if PathGeom.edgeConnectsTo(e, self.realExit)])
             edges.append(Part.Edge(Part.LineSegment(self.realExit, self.exit)))
         else:
             self.realExit = None
@@ -407,13 +421,13 @@ class MapWireToTag:
             if lastP == p0:
                 self.edgesOrder.append(outputEdges)
                 self.edgesOrder.append(edges)
-                print('input edges:')
+                PathLog.debug('input edges:')
                 for e in inputEdges:
                     debugEdge(e, '  ', False)
-                print('ordered edges:')
+                PathLog.debug('ordered edges:')
                 for e, flip in outputEdges:
                     debugEdge(e, '  %c ' % ('<' if flip else '>'), False)
-                print('remaining edges:')
+                PathLog.debug('remaining edges:')
                 for e in edges:
                     debugEdge(e, '    ', False)
                 raise ValueError("No connection to %s" % (p0))
@@ -449,13 +463,13 @@ class MapWireToTag:
                 wire.add(edge)
 
         shell = wire.extrude(FreeCAD.Vector(0, 0, self.tag.height + 1))
-        nullFaces = list(filter(lambda f: PathGeom.isRoughly(f.Area, 0), shell.Faces))
+        nullFaces = list([f for f in shell.Faces if PathGeom.isRoughly(f.Area, 0)])
         if nullFaces:
             return shell.removeShape(nullFaces)
         return shell
 
     def commandsForEdges(self):
-        global failures
+        global failures # pylint: disable=global-statement
         if self.edges:
             try:
                 shape = self.shell().common(self.tag.solid)
@@ -476,7 +490,7 @@ class MapWireToTag:
                     commands.append(Path.Command('G0', {'X': rapid.x, 'Y': rapid.y, 'Z': rapid.z}))
                     rapid = None
                 return commands
-            except Exception as e:
+            except Exception as e: # pylint: disable=broad-except
                 PathLog.error("Exception during processing tag @(%.2f, %.2f) (%s) - disabling the tag" % (self.tag.x, self.tag.y, e.args[0]))
                 #if sys.version_info.major < 3:
                 #    traceback.print_exc(e)
@@ -494,6 +508,7 @@ class MapWireToTag:
         self.tail = None
         self.finalEdge = edge
         if self.tag.solid.isInside(edge.valueAt(edge.LastParameter), PathGeom.Tolerance, True):
+            PathLog.track('solid.isInside')
             self.addEdge(edge)
         else:
             i = self.tag.intersects(edge, edge.LastParameter)
@@ -501,11 +516,13 @@ class MapWireToTag:
                 self.offendingEdge = edge
                 debugEdge(edge, 'offending Edge:', False)
                 o = self.tag.originAt(self.tag.z)
-                print('originAt: (%.2f, %.2f, %.2f)' % (o.x, o.y, o.z))
+                PathLog.debug('originAt: (%.2f, %.2f, %.2f)' % (o.x, o.y, o.z))
                 i = edge.valueAt(edge.FirstParameter)
             if PathGeom.pointsCoincide(i, edge.valueAt(edge.FirstParameter)):
+                PathLog.track('tail')
                 self.tail = edge
             else:
+                PathLog.track('split')
                 e, tail = PathGeom.splitEdgeAt(edge, i)
                 self.addEdge(e)
                 self.tail = tail
@@ -539,7 +556,10 @@ class PathData:
         self.obj = obj
         self.wire, rapid = PathGeom.wireForPath(obj.Base.Path)
         self.rapid = _RapidEdges(rapid)
-        self.edges = self.wire.Edges
+        if self.wire:
+            self.edges = self.wire.Edges
+        else:
+            self.edges = []
         self.baseWire = self.findBottomWire(self.edges)
 
     def findBottomWire(self, edges):
@@ -552,7 +572,7 @@ class PathData:
             wire = Part.Wire(bottom)
             if wire.isClosed():
                 return wire
-        except Exception as e:
+        except Exception: # pylint: disable=broad-except
             #if sys.version_info.major < 3:
             #    traceback.print_exc(e)
             #else:
@@ -581,6 +601,7 @@ class PathData:
         return (edges[0], edges[-1])
 
     def generateTags(self, obj, count, width=None, height=None, angle=None, radius=None, spacing=None):
+        # pylint: disable=unused-argument
         PathLog.track(count, width, height, angle, spacing)
         # for e in self.baseWire.Edges:
         #    debugMarker(e.Vertexes[0].Point, 'base', (0.0, 1.0, 1.0), 0.2)
@@ -590,9 +611,9 @@ class PathData:
         else:
             tagDistance = self.baseWire.Length / (count if count else 4)
 
-        W = width if width else self.defaultTagWidth()
+        W = width  if width  else self.defaultTagWidth()
         H = height if height else self.defaultTagHeight()
-        A = angle if angle else self.defaultTagAngle()
+        A = angle  if angle  else self.defaultTagAngle()
         R = radius if radius else self.defaultTagRadius()
 
         # start assigning tags on the longest segment
@@ -644,6 +665,31 @@ class PathData:
 
         return tags
 
+    def copyTags(self, obj, fromObj, width, height, angle, radius):
+        print("copyTags(%s, %s, %.2f, %.2f, %.2f, %.2f" % (obj.Label, fromObj.Label, width, height, angle, radius))
+        W = width  if width  else self.defaultTagWidth()
+        H = height if height else self.defaultTagHeight()
+        A = angle  if angle  else self.defaultTagAngle()
+        R = radius if radius else self.defaultTagRadius()
+
+        tags = []
+        j = 0
+        for i, pos in enumerate(fromObj.Positions):
+            print("tag[%d]" % i)
+            if not i in fromObj.Disabled:
+                dist = self.baseWire.distToShape(Part.Vertex(FreeCAD.Vector(pos.x, pos.y, self.minZ)))
+                if True or dist[0] < W:
+                    print("tag[%d/%d]: (%.2f, %.2f, %.2f)" % (i, j, pos.x, pos.y, self.minZ))
+                    at = dist[1][0][0]
+                    tags.append(Tag(j, at.x, at.y,  W, H, A, R, True))
+                    j += 1
+                else:
+                    PathLog.warning("Tag[%d] (%.2f, %.2f, %.2f) is too far away to copy: %.2f (%.2f)" % (i, pos.x, pos.y, self.minZ, dist[0], W))
+            else:
+                PathLog.info("tag[%d]: not enabled, skipping" % i)
+        print("copied %d tags" % len(tags))
+        return tags
+
     def processEdge(self, index, edge, currentLength, lastTagLength, tagDistance, minLength, edgeDict):
         tagCount = 0
         currentLength += edge.Length
@@ -683,7 +729,7 @@ class PathData:
         ordered = []
         for edge in self.bottomEdges:
             ts = [t for t in tags if PathGeom.isRoughly(0, Part.Vertex(t.originAt(self.minZ)).distToShape(edge)[0], 0.1)]
-            for t in sorted(ts, key=lambda t: (t.originAt(self.minZ) - edge.valueAt(edge.FirstParameter)).Length):
+            for t in sorted(ts, key=lambda t, edge=edge: (t.originAt(self.minZ) - edge.valueAt(edge.FirstParameter)).Length):
                 tags.remove(t)
                 ordered.append(t)
         # disable all tags that are not on the base wire.
@@ -720,26 +766,40 @@ class ObjectTagDressup:
         obj.addProperty("App::PropertyIntegerList", "Disabled", "Tag", QtCore.QT_TRANSLATE_NOOP("Path_DressupTag", "IDs of disabled holding tags"))
         obj.addProperty("App::PropertyInteger", "SegmentationFactor", "Tag", QtCore.QT_TRANSLATE_NOOP("Path_DressupTag", "Factor determining the # of segments used to approximate rounded tags."))
 
-        obj.Proxy = self
-        obj.Base = base
-
+        # for pylint ...
         self.obj = obj
         self.solids = []
+        self.tags = []
+        self.pathData = None
+        self.toolRadius = None
+        self.mappers = []
+
+        obj.Proxy = self
+        obj.Base = base
 
     def __getstate__(self):
         return None
 
     def __setstate__(self, state):
+        self.obj = state
+        self.solids = []
+        self.tags = []
+        self.pathData = None
+        self.toolRadius = None
+        self.mappers = []
         return None
 
+    def onDocumentRestored(self, obj):
+        self.obj = obj
+
     def supportsTagGeneration(self, obj):
-        if not hasattr(self, 'pathData'):
+        if not self.pathData:
             self.setup(obj)
         return self.pathData.supportsTagGeneration()
 
     def generateTags(self, obj, count):
         if self.supportsTagGeneration(obj):
-            if hasattr(self, "pathData"):
+            if self.pathData:
                 self.tags = self.pathData.generateTags(obj, count, obj.Width.Value, obj.Height.Value, obj.Angle, obj.Radius.Value, None)
                 obj.Positions = [tag.originAt(self.pathData.minZ) for tag in self.tags]
                 obj.Disabled = []
@@ -754,6 +814,18 @@ class ObjectTagDressup:
             obj.Disabled = []
             return False
 
+    def copyTags(self, obj, fromObj):
+        obj.Width  = fromObj.Width
+        obj.Height = fromObj.Height
+        obj.Angle  = fromObj.Angle
+        obj.Radius = fromObj.Radius
+        obj.SegmentationFactor = fromObj.SegmentationFactor
+
+        self.tags = self.pathData.copyTags(obj, fromObj, obj.Width.Value, obj.Height.Value, obj.Angle, obj.Radius.Value)
+        obj.Positions = [tag.originAt(self.pathData.minZ) for tag in self.tags]
+        obj.Disabled = []
+        return False
+
     def isValidTagStartIntersection(self, edge, i):
         if PathGeom.pointsCoincide(i, edge.valueAt(edge.LastParameter)):
             return False
@@ -836,7 +908,7 @@ class ObjectTagDressup:
         return Path.Path(commands)
 
     def problems(self):
-        return list(filter(lambda m: m.haveProblem, self.mappers))
+        return list([m for m in self.mappers if m.haveProblem])
 
     def createTagsPositionDisabled(self, obj, positionsIn, disabledIn):
         rawTags = []
@@ -869,7 +941,7 @@ class ObjectTagDressup:
                 PathLog.debug("previousTag = %d [%s]" % (i, prev))
             else:
                 disabled.append(i)
-            tag.id = i  # assigne final id
+            tag.nr = i  # assign final nr
             tags.append(tag)
             positions.append(tag.originAt(self.pathData.minZ))
         return (tags, positions, disabled)
@@ -894,7 +966,7 @@ class ObjectTagDressup:
 
         pathData = self.setup(obj)
         if not pathData:
-            print("execute - no pathData")
+            PathLog.debug("execute - no pathData")
             return
 
         self.tags = []
@@ -906,13 +978,13 @@ class ObjectTagDressup:
                 obj.Disabled = disabled
 
         if not self.tags:
-            print("execute - no tags")
+            PathLog.debug("execute - no tags")
             obj.Path = obj.Base.Path
             return
 
         try:
             self.processTags(obj)
-        except Exception as e:
+        except Exception as e: # pylint: disable=broad-except
             PathLog.error("processing tags failed clearing all tags ... '%s'" % (e.args[0]))
             #if sys.version_info.major < 3:
             #    traceback.print_exc(e)
@@ -925,15 +997,15 @@ class ObjectTagDressup:
         solids = []
         for tag in self.tags:
             solids.append(tag.solid)
-            if not tag.enabled and tag.id not in disabled:
-                disabled.append(tag.id)
+            if not tag.enabled and tag.nr not in disabled:
+                disabled.append(tag.nr)
         self.solids = solids
         if obj.Disabled != disabled:
             obj.Disabled = disabled
 
     @waiting_effects
     def processTags(self, obj):
-        global failures
+        global failures # pylint: disable=global-statement
         failures = []
         tagID = 0
         if PathLog.getLevel(PathLog.thisModule()) == PathLog.Level.DEBUG:
@@ -962,7 +1034,7 @@ class ObjectTagDressup:
             #    traceback.print_exc()
             return None
 
-        self.toolRadius = PathDressup.toolController(obj.Base).Tool.Diameter / 2
+        self.toolRadius = float(PathDressup.toolController(obj.Base).Tool.Diameter) / 2
         self.pathData = pathData
         if generate:
             obj.Height = self.pathData.defaultTagHeight()
@@ -975,7 +1047,7 @@ class ObjectTagDressup:
 
     def setXyEnabled(self, triples):
         PathLog.track()
-        if not hasattr(self, 'pathData'):
+        if not self.pathData:
             self.setup(self.obj)
         positions = []
         disabled = []
@@ -988,12 +1060,12 @@ class ObjectTagDressup:
         self.processTags(self.obj)
 
     def pointIsOnPath(self, obj, point):
-        if not hasattr(self, 'pathData'):
+        if not self.pathData:
             self.setup(obj)
         return self.pathData.pointIsOnPath(point)
 
     def pointAtBottom(self, obj, point):
-        if not hasattr(self, 'pathData'):
+        if not self.pathData:
             self.setup(obj)
         return self.pathData.pointAtBottom(point)
 
@@ -1010,7 +1082,7 @@ def Create(baseObject, name='DressupTag'):
         PathLog.error(translate('Path_DressupTag', 'Please select a Profile object'))
         return None
 
-    obj = FreeCAD.ActiveDocument.addObject("Path::FeaturePython", "TagDressup")
+    obj = FreeCAD.ActiveDocument.addObject("Path::FeaturePython", name)
     dbo = ObjectTagDressup(obj, baseObject)
     job = PathUtils.findParentJob(baseObject)
     job.Proxy.addOperation(obj, baseObject)
