@@ -1,54 +1,54 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="el" sourcelanguage="en">
+<TS version="1.1" language="el" sourcelanguage="en">
   <context>
     <name>Plot</name>
     <message>
-      <location filename="InitGui.py" line="44"/>
+      <location filename="InitGui.py" line="46"/>
       <source>Plot edition tools</source>
-      <translation>Εργαλεία επεξεργασίας σημείου</translation>
+      <translation>Εργαλεία επεξεργασίας γραφήματος</translation>
     </message>
     <message>
-      <location filename="InitGui.py" line="47"/>
+      <location filename="InitGui.py" line="49"/>
       <source>Plot</source>
-      <translation>Σημείωσε</translation>
+      <translation>Γράφημα</translation>
     </message>
   </context>
   <context>
     <name>Plot_Axes</name>
     <message>
-      <location filename="PlotGui.py" line="62"/>
+      <location filename="PlotGui.py" line="65"/>
       <source>Configure axes</source>
-      <translation>Ρύθμιση αξόνων</translation>
+      <translation>Διαμόρφωση αξόνων</translation>
     </message>
     <message>
-      <location filename="PlotGui.py" line="65"/>
+      <location filename="PlotGui.py" line="68"/>
       <source>Configure the axes parameters</source>
-      <translation>Ρυθμίστε τις παραμέτρους των αξόνων</translation>
+      <translation>Διαμόρφωση παραμέτρων των αξόνων</translation>
     </message>
   </context>
   <context>
     <name>Plot_Grid</name>
     <message>
-      <location filename="PlotGui.py" line="110"/>
+      <location filename="PlotGui.py" line="112"/>
       <source>Show/Hide grid</source>
-      <translation>Εμφάνιση/απόκρυψη πλέγματος</translation>
+      <translation>Εμφάνιση/Απόκρυψη κανάβου</translation>
     </message>
     <message>
-      <location filename="PlotGui.py" line="113"/>
+      <location filename="PlotGui.py" line="115"/>
       <source>Show/Hide grid on selected plot</source>
-      <translation type="unfinished">Show/Hide grid on selected plot</translation>
+      <translation>Εμφάνιση/Απόκρυψη κανάβου στο επιλεγμένο γράφημα</translation>
     </message>
   </context>
   <context>
     <name>Plot_Labels</name>
     <message>
-      <location filename="PlotGui.py" line="154"/>
+      <location filename="PlotGui.py" line="155"/>
       <source>Set labels</source>
       <translation>Ορισμός ετικετών</translation>
     </message>
     <message>
-      <location filename="PlotGui.py" line="157"/>
+      <location filename="PlotGui.py" line="158"/>
       <source>Set title and axes labels</source>
       <translation>Ορισμός τίτλου και ετικετών αξόνων</translation>
     </message>
@@ -56,406 +56,406 @@
   <context>
     <name>Plot_Legend</name>
     <message>
-      <location filename="PlotGui.py" line="137"/>
+      <location filename="PlotGui.py" line="138"/>
       <source>Show/Hide legend</source>
-      <translation type="unfinished">Show/Hide legend</translation>
+      <translation>Εμφάνιση/Απόκρυψη υπομνήματος</translation>
     </message>
     <message>
-      <location filename="PlotGui.py" line="140"/>
+      <location filename="PlotGui.py" line="141"/>
       <source>Show/Hide legend on selected plot</source>
-      <translation type="unfinished">Show/Hide legend on selected plot</translation>
+      <translation>Εμφάνιση/Απόκρυψη υπομνήματος στο επιλεγμένο γράφημα</translation>
     </message>
   </context>
   <context>
     <name>Plot_Positions</name>
     <message>
-      <location filename="PlotGui.py" line="171"/>
+      <location filename="PlotGui.py" line="172"/>
       <source>Set positions and sizes</source>
       <translation>Ορισμός θέσεων και μεγεθών</translation>
     </message>
     <message>
-      <location filename="PlotGui.py" line="174"/>
+      <location filename="PlotGui.py" line="175"/>
       <source>Set labels and legend positions and sizes</source>
-      <translation type="unfinished">Set labels and legend positions and sizes</translation>
+      <translation>Ορισμός ετικετών καθώς και θέσεων και μεγεθών των υπομνημάτων</translation>
     </message>
   </context>
   <context>
     <name>Plot_SaveFig</name>
     <message>
-      <location filename="PlotGui.py" line="45"/>
+      <location filename="PlotGui.py" line="48"/>
       <source>Save plot</source>
-      <translation type="unfinished">Save plot</translation>
+      <translation>Αποθήκευση γραφήματος</translation>
     </message>
     <message>
-      <location filename="PlotGui.py" line="48"/>
+      <location filename="PlotGui.py" line="51"/>
       <source>Save the plot as an image file</source>
-      <translation type="unfinished">Save the plot as an image file</translation>
+      <translation>Αποθήκευση γραφήματος ως αρχείο εικόνας</translation>
     </message>
   </context>
   <context>
     <name>Plot_Series</name>
     <message>
-      <location filename="PlotGui.py" line="81"/>
+      <location filename="PlotGui.py" line="84"/>
       <source>Configure series</source>
-      <translation type="unfinished">Configure series</translation>
+      <translation>Διαμόρφωση σειρών</translation>
     </message>
     <message>
-      <location filename="PlotGui.py" line="84"/>
+      <location filename="PlotGui.py" line="87"/>
       <source>Configure series drawing style and label</source>
-      <translation type="unfinished">Configure series drawing style and label</translation>
+      <translation>Διαμόρφωση του τύπου μορφοποίησης σχεδίασης και των ετικετών των σειρών</translation>
     </message>
   </context>
   <context>
     <name>plot_axes</name>
     <message>
-      <location filename="TaskPanel.py" line="175"/>
+      <location filename="TaskPanel.py" line="180"/>
       <source>Configure axes</source>
-      <translation>Ρύθμιση αξόνων</translation>
+      <translation>Διαμόρφωση αξόνων</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="180"/>
+      <location filename="TaskPanel.py" line="184"/>
       <source>Active axes</source>
       <translation>Ενεργοί άξονες</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="220"/>
+      <location filename="TaskPanel.py" line="216"/>
       <source>Apply to all axes</source>
       <translation>Εφαρμογή σε όλους τους άξονες</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="225"/>
+      <location filename="TaskPanel.py" line="220"/>
       <source>Dimensions</source>
       <translation>Διαστάσεις</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="230"/>
+      <location filename="TaskPanel.py" line="224"/>
       <source>X axis position</source>
-      <translation>Θέση άξονα X</translation>
+      <translation>Θέση του άξονα X</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="235"/>
+      <location filename="TaskPanel.py" line="228"/>
       <source>Y axis position</source>
-      <translation>Θέση άξονα Y</translation>
+      <translation>Θέση του άξονα Y</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="205"/>
+      <location filename="TaskPanel.py" line="204"/>
       <source>Scales</source>
       <translation>Κλίμακες</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="210"/>
+      <location filename="TaskPanel.py" line="208"/>
       <source>X auto</source>
-      <translation type="unfinished">X auto</translation>
+      <translation>Αυτόματη επιλογή X</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="215"/>
+      <location filename="TaskPanel.py" line="212"/>
       <source>Y auto</source>
-      <translation type="unfinished">Y auto</translation>
+      <translation>Αυτόματη επιλογή Y</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="240"/>
+      <location filename="TaskPanel.py" line="232"/>
       <source>Index of the active axes</source>
-      <translation type="unfinished">Index of the active axes</translation>
+      <translation>Δείκτης των ενεργών αξόνων</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="245"/>
+      <location filename="TaskPanel.py" line="237"/>
       <source>Add new axes to the plot</source>
-      <translation type="unfinished">Add new axes to the plot</translation>
+      <translation>Προσθήκη νέων αξόνων στο γράφημα</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="251"/>
+      <location filename="TaskPanel.py" line="242"/>
       <source>Remove selected axes</source>
-      <translation>Κατάργηση επιλεγμένων αξόνων</translation>
+      <translation>Αφαίρεση επιλεγμένων αξόνων</translation>
+    </message>
+    <message>
+      <location filename="TaskPanel.py" line="247"/>
+      <source>Check it to apply transformations to all axes</source>
+      <translation>Επιλέξτε το ώστε να εφαρμόσετε μετασχηματισμούς σε όλους τους άξονες</translation>
+    </message>
+    <message>
+      <location filename="TaskPanel.py" line="252"/>
+      <source>Left bound of axes</source>
+      <translation>Αριστερό όριο των αξόνων</translation>
     </message>
     <message>
       <location filename="TaskPanel.py" line="257"/>
-      <source>Check it to apply transformations to all axes</source>
-      <translation type="unfinished">Check it to apply transformations to all axes</translation>
-    </message>
-    <message>
-      <location filename="TaskPanel.py" line="263"/>
-      <source>Left bound of axes</source>
-      <translation type="unfinished">Left bound of axes</translation>
-    </message>
-    <message>
-      <location filename="TaskPanel.py" line="269"/>
       <source>Right bound of axes</source>
-      <translation type="unfinished">Right bound of axes</translation>
+      <translation>Δεξί όριο των αξόνων</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="275"/>
+      <location filename="TaskPanel.py" line="262"/>
       <source>Bottom bound of axes</source>
-      <translation type="unfinished">Bottom bound of axes</translation>
+      <translation>Κάτω όριο των αξόνων</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="281"/>
+      <location filename="TaskPanel.py" line="267"/>
       <source>Top bound of axes</source>
-      <translation type="unfinished">Top bound of axes</translation>
+      <translation>Άνω όριο των αξόνων</translation>
+    </message>
+    <message>
+      <location filename="TaskPanel.py" line="272"/>
+      <source>Outward offset of X axis</source>
+      <translation>Εξωτερική μετατόπιση του άξονα X</translation>
+    </message>
+    <message>
+      <location filename="TaskPanel.py" line="277"/>
+      <source>Outward offset of Y axis</source>
+      <translation>Εξωτερική μετατόπιση του άξονα Y</translation>
+    </message>
+    <message>
+      <location filename="TaskPanel.py" line="282"/>
+      <source>X axis scale autoselection</source>
+      <translation>Αυτόματη επιλογή κλίμακας του άξονα X</translation>
     </message>
     <message>
       <location filename="TaskPanel.py" line="287"/>
-      <source>Outward offset of X axis</source>
-      <translation type="unfinished">Outward offset of X axis</translation>
-    </message>
-    <message>
-      <location filename="TaskPanel.py" line="293"/>
-      <source>Outward offset of Y axis</source>
-      <translation type="unfinished">Outward offset of Y axis</translation>
-    </message>
-    <message>
-      <location filename="TaskPanel.py" line="299"/>
-      <source>X axis scale autoselection</source>
-      <translation type="unfinished">X axis scale autoselection</translation>
-    </message>
-    <message>
-      <location filename="TaskPanel.py" line="305"/>
       <source>Y axis scale autoselection</source>
-      <translation type="unfinished">Y axis scale autoselection</translation>
+      <translation>Αυτόματη επιλογή κλίμακας του άξονα Y</translation>
     </message>
   </context>
   <context>
     <name>plot_console</name>
     <message>
-      <location filename="Plot.py" line="43"/>
+      <location filename="Plot.py" line="47"/>
       <source>matplotlib not found, so Plot module can not be loaded</source>
-      <translation type="unfinished">matplotlib not found, so Plot module can not be loaded</translation>
+      <translation>δεν βρέθηκε η βιβλιοθήκη matplotlib, οπότε δεν είναι δυνατή η φόρτωση της λειτουργικής μονάδας Γραφήματος</translation>
     </message>
     <message>
-      <location filename="InitGui.py" line="54"/>
+      <location filename="InitGui.py" line="58"/>
       <source>matplotlib not found, Plot module will be disabled</source>
-      <translation type="unfinished">matplotlib not found, Plot module will be disabled</translation>
+      <translation>δεν βρέθηκε η βιβλιοθήκη matplotlib, η λειτουργική μονάδα Γραφήματος θα απενεργοποιηθεί</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="42"/>
+      <location filename="TaskPanel.py" line="48"/>
       <source>Plot document must be selected in order to save it</source>
-      <translation type="unfinished">Plot document must be selected in order to save it</translation>
+      <translation>Πρέπει να επιλέξετε ένα έγγραφο γραφήματος προκειμένου να το αποθηκεύσετε</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="365"/>
+      <location filename="TaskPanel.py" line="346"/>
       <source>Axes 0 can not be deleted</source>
-      <translation type="unfinished">Axes 0 can not be deleted</translation>
+      <translation>Ο άξονας 0 δεν μπορεί να διαγραφεί</translation>
     </message>
     <message>
-      <location filename="PlotGui.py" line="97"/>
+      <location filename="PlotGui.py" line="101"/>
       <source>The grid must be activated on top of a plot document</source>
-      <translation type="unfinished">The grid must be activated on top of a plot document</translation>
+      <translation>Ο κάναβος πρέπει να ενεργοποιηθεί πάνω από κάποιο έγγραφο γραφήματος</translation>
     </message>
     <message>
-      <location filename="PlotGui.py" line="126"/>
+      <location filename="PlotGui.py" line="129"/>
       <source>The legend must be activated on top of a plot document</source>
-      <translation type="unfinished">The legend must be activated on top of a plot document</translation>
+      <translation>Το υπόμνημα πρέπει να ενεργοποιηθεί πάνω από κάποιο έγγραφο γραφήματος</translation>
     </message>
   </context>
   <context>
     <name>plot_labels</name>
     <message>
-      <location filename="TaskPanel.py" line="133"/>
+      <location filename="TaskPanel.py" line="138"/>
       <source>Set labels</source>
       <translation>Ορισμός ετικετών</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="138"/>
+      <location filename="TaskPanel.py" line="142"/>
       <source>Active axes</source>
       <translation>Ενεργοί άξονες</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="143"/>
+      <location filename="TaskPanel.py" line="146"/>
       <source>Title</source>
       <translation>Τίτλος</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="148"/>
+      <location filename="TaskPanel.py" line="150"/>
       <source>X label</source>
       <translation>Ετικέτα X</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="153"/>
+      <location filename="TaskPanel.py" line="154"/>
       <source>Y label</source>
       <translation>Ετικέτα Υ</translation>
     </message>
     <message>
       <location filename="TaskPanel.py" line="158"/>
       <source>Index of the active axes</source>
-      <translation type="unfinished">Index of the active axes</translation>
+      <translation>Δείκτης των ενεργών αξόνων</translation>
     </message>
     <message>
       <location filename="TaskPanel.py" line="163"/>
       <source>Title (associated to active axes)</source>
-      <translation type="unfinished">Title (associated to active axes)</translation>
+      <translation>Τίτλος (που σχετίζεται με τους ενεργούς άξονες)</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="169"/>
+      <location filename="TaskPanel.py" line="168"/>
       <source>Title font size</source>
       <translation>Μέγεθος γραμματοσειράς τίτλου</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="175"/>
+      <location filename="TaskPanel.py" line="173"/>
       <source>X axis title</source>
-      <translation>Τίτλος άξονα X</translation>
+      <translation>Τίτλος του άξονα X</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="181"/>
+      <location filename="TaskPanel.py" line="178"/>
       <source>X axis title font size</source>
-      <translation type="unfinished">X axis title font size</translation>
+      <translation>Μέγεθος γραμματοσειράς τίτλου του άξονα X</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="187"/>
+      <location filename="TaskPanel.py" line="183"/>
       <source>Y axis title</source>
-      <translation>Τίτλος άξονα Υ</translation>
+      <translation>Τίτλος του άξονα Υ</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="193"/>
+      <location filename="TaskPanel.py" line="188"/>
       <source>Y axis title font size</source>
-      <translation type="unfinished">Y axis title font size</translation>
+      <translation>Μέγεθος γραμματοσειράς τίτλου του άξονα Y</translation>
     </message>
   </context>
   <context>
     <name>plot_positions</name>
     <message>
-      <location filename="TaskPanel.py" line="121"/>
+      <location filename="TaskPanel.py" line="124"/>
       <source>Set positions and sizes</source>
       <translation>Ορισμός θέσεων και μεγεθών</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="126"/>
+      <location filename="TaskPanel.py" line="129"/>
       <source>Position</source>
       <translation type="unfinished">Position</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="132"/>
+      <location filename="TaskPanel.py" line="134"/>
       <source>Size</source>
       <translation>Μέγεθος</translation>
     </message>
-    <message>
-      <location filename="TaskPanel.py" line="138"/>
-      <source>List of modificable items</source>
-      <translation type="unfinished">List of modificable items</translation>
-    </message>
     <message>
       <location filename="TaskPanel.py" line="144"/>
       <source>X item position</source>
-      <translation type="unfinished">X item position</translation>
+      <translation>Θέση του αντικειμένου στον άξονα X</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="150"/>
+      <location filename="TaskPanel.py" line="149"/>
       <source>Y item position</source>
-      <translation type="unfinished">Y item position</translation>
+      <translation>Θέση του αντικειμένου στον άξονα Y</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="156"/>
+      <location filename="TaskPanel.py" line="154"/>
       <source>Item size</source>
       <translation>Μέγεθος αντικειμένου</translation>
     </message>
+    <message>
+      <location filename="TaskPanel.py" line="139"/>
+      <source>List of modifiable items</source>
+      <translation>Λίστα τροποποιήσιμων αντικειμένων</translation>
+    </message>
   </context>
   <context>
     <name>plot_save</name>
     <message>
-      <location filename="TaskPanel.py" line="128"/>
+      <location filename="TaskPanel.py" line="132"/>
       <source>Save figure</source>
-      <translation type="unfinished">Save figure</translation>
+      <translation>Αποθήκευση σχήματος</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="133"/>
+      <location filename="TaskPanel.py" line="137"/>
       <source>Inches</source>
-      <translation>ίντσες</translation>
+      <translation>Ίντσες</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="139"/>
+      <location filename="TaskPanel.py" line="142"/>
       <source>Dots per Inch</source>
-      <translation>Κουκκίδες ανά ίντσα</translation>
+      <translation>Κουκκίδες ανά Ίντσα</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="145"/>
+      <location filename="TaskPanel.py" line="147"/>
       <source>Output image file path</source>
-      <translation type="unfinished">Output image file path</translation>
+      <translation>Διαδρομή αρχείου εικόνας εξόδου</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="151"/>
+      <location filename="TaskPanel.py" line="152"/>
       <source>Show a file selection dialog</source>
-      <translation type="unfinished">Show a file selection dialog</translation>
+      <translation>Εμφάνιση ενός διαλόγου επιλογής αρχείου</translation>
     </message>
     <message>
       <location filename="TaskPanel.py" line="157"/>
       <source>X image size</source>
-      <translation type="unfinished">X image size</translation>
+      <translation>Μέγεθος εικόνας στον άξονα X</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="163"/>
+      <location filename="TaskPanel.py" line="162"/>
       <source>Y image size</source>
-      <translation type="unfinished">Y image size</translation>
+      <translation>Μέγεθος εικόνας στον άξονα Y</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="169"/>
+      <location filename="TaskPanel.py" line="168"/>
       <source>Dots per point, with size will define output image resolution</source>
-      <translation type="unfinished">Dots per point, with size will define output image resolution</translation>
+      <translation>Κουκκίδες ανά σημείο, καθορίζουν την ανάλυση της εικόνας εξόδου σε συνδυασμό με το μέγεθος</translation>
     </message>
   </context>
   <context>
     <name>plot_series</name>
     <message>
-      <location filename="TaskPanel.py" line="154"/>
+      <location filename="TaskPanel.py" line="157"/>
       <source>No label</source>
-      <translation>Χωρίς ετικέτα</translation>
+      <translation>Καμία ετικέτα</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="160"/>
-      <source>Remove serie</source>
-      <translation type="unfinished">Remove serie</translation>
-    </message>
-    <message>
-      <location filename="TaskPanel.py" line="196"/>
+      <location filename="TaskPanel.py" line="192"/>
       <source>Line style</source>
-      <translation>Στυλ γραμμής</translation>
+      <translation>Τύπος μορφοποίησης γραμμής</translation>
     </message>
     <message>
       <location filename="TaskPanel.py" line="172"/>
       <source>Marker</source>
-      <translation type="unfinished">Marker</translation>
+      <translation>Δείκτης</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="149"/>
+      <location filename="TaskPanel.py" line="152"/>
       <source>Configure series</source>
-      <translation type="unfinished">Configure series</translation>
+      <translation>Διαμόρφωση σειρών</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="178"/>
+      <location filename="TaskPanel.py" line="177"/>
       <source>List of available series</source>
-      <translation type="unfinished">List of available series</translation>
+      <translation>Λίστα διαθέσιμων σειρών</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="184"/>
+      <location filename="TaskPanel.py" line="182"/>
       <source>Line title</source>
-      <translation type="unfinished">Line title</translation>
+      <translation>Τίτλος γραμμής</translation>
+    </message>
+    <message>
+      <location filename="TaskPanel.py" line="197"/>
+      <source>Marker style</source>
+      <translation>Τύπος μορφοποίησης δείκτη</translation>
     </message>
     <message>
       <location filename="TaskPanel.py" line="202"/>
-      <source>Marker style</source>
-      <translation type="unfinished">Marker style</translation>
-    </message>
-    <message>
-      <location filename="TaskPanel.py" line="208"/>
       <source>Line width</source>
-      <translation>Πλάτος Γραμμής</translation>
+      <translation>Πλάτος γραμμής</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="214"/>
+      <location filename="TaskPanel.py" line="207"/>
       <source>Marker size</source>
-      <translation type="unfinished">Marker size</translation>
+      <translation>Μέγεθος δείκτη</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="220"/>
+      <location filename="TaskPanel.py" line="212"/>
       <source>Line and marker color</source>
-      <translation type="unfinished">Line and marker color</translation>
+      <translation>Χρώμα γραμμής και δείκτη</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="226"/>
-      <source>Removes this serie</source>
-      <translation type="unfinished">Removes this serie</translation>
+      <location filename="TaskPanel.py" line="162"/>
+      <source>Remove series</source>
+      <translation>Αφαίρεση σειράς</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="190"/>
-      <source>If checked serie will not be considered for legend</source>
-      <translation type="unfinished">If checked serie will not be considered for legend</translation>
+      <location filename="TaskPanel.py" line="187"/>
+      <source>If checked, series will not be considered for legend</source>
+      <translation>Αν αυτό έχει επιλεχθεί, η σειρά δεν θα ληφθεί υπόψη στην κατασκευή του υπομνήματος</translation>
+    </message>
+    <message>
+      <location filename="TaskPanel.py" line="217"/>
+      <source>Removes this series</source>
+      <translation>Αφαίρεση αυτής της σειράς</translation>
     </message>
   </context>
 </TS>
