@@ -1,15 +1,15 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="hu" sourcelanguage="en">
+<TS version="1.1" language="hu" sourcelanguage="en">
   <context>
     <name>Plot</name>
     <message>
-      <location filename="../../InitGui.py" line="44"/>
+      <location filename="InitGui.py" line="46"/>
       <source>Plot edition tools</source>
       <translation>Tervrajz szerkesztő eszközök</translation>
     </message>
     <message>
-      <location filename="../../InitGui.py" line="47"/>
+      <location filename="InitGui.py" line="49"/>
       <source>Plot</source>
       <translation>Tervrajz</translation>
     </message>
@@ -17,12 +17,12 @@
   <context>
     <name>Plot_Axes</name>
     <message>
-      <location filename="../../PlotGui.py" line="62"/>
+      <location filename="PlotGui.py" line="65"/>
       <source>Configure axes</source>
       <translation>Tengelyek kialakítása</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="65"/>
+      <location filename="PlotGui.py" line="68"/>
       <source>Configure the axes parameters</source>
       <translation>Tengelyek paramétereinek beállítása</translation>
     </message>
@@ -30,12 +30,12 @@
   <context>
     <name>Plot_Grid</name>
     <message>
-      <location filename="../../PlotGui.py" line="109"/>
+      <location filename="PlotGui.py" line="112"/>
       <source>Show/Hide grid</source>
       <translation>Rács mutatása / eltüntetése</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="112"/>
+      <location filename="PlotGui.py" line="115"/>
       <source>Show/Hide grid on selected plot</source>
       <translation>A kiválasztott tervrajzon a rács mutatása / eltüntetése</translation>
     </message>
@@ -43,12 +43,12 @@
   <context>
     <name>Plot_Labels</name>
     <message>
-      <location filename="../../PlotGui.py" line="152"/>
+      <location filename="PlotGui.py" line="155"/>
       <source>Set labels</source>
       <translation>Címkék beállítása</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="155"/>
+      <location filename="PlotGui.py" line="158"/>
       <source>Set title and axes labels</source>
       <translation>Cím és tengely címkék beállítása</translation>
     </message>
@@ -56,12 +56,12 @@
   <context>
     <name>Plot_Legend</name>
     <message>
-      <location filename="../../PlotGui.py" line="135"/>
+      <location filename="PlotGui.py" line="138"/>
       <source>Show/Hide legend</source>
       <translation>Felirat mutatása / eltüntetése</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="138"/>
+      <location filename="PlotGui.py" line="141"/>
       <source>Show/Hide legend on selected plot</source>
       <translation>A kiválasztott tervrajzon a felirat mutatása / eltüntetése</translation>
     </message>
@@ -69,12 +69,12 @@
   <context>
     <name>Plot_Positions</name>
     <message>
-      <location filename="../../PlotGui.py" line="169"/>
+      <location filename="PlotGui.py" line="172"/>
       <source>Set positions and sizes</source>
       <translation>Pozíciók és méretek beállítása</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="172"/>
+      <location filename="PlotGui.py" line="175"/>
       <source>Set labels and legend positions and sizes</source>
       <translation>Címkék és feliratok pozícióinak és méreteinek beállítása</translation>
     </message>
@@ -82,12 +82,12 @@
   <context>
     <name>Plot_SaveFig</name>
     <message>
-      <location filename="../../PlotGui.py" line="45"/>
+      <location filename="PlotGui.py" line="48"/>
       <source>Save plot</source>
       <translation>Tervrajz mentése</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="48"/>
+      <location filename="PlotGui.py" line="51"/>
       <source>Save the plot as an image file</source>
       <translation>Nyomtatás kép fájlba</translation>
     </message>
@@ -95,12 +95,12 @@
   <context>
     <name>Plot_Series</name>
     <message>
-      <location filename="../../PlotGui.py" line="81"/>
+      <location filename="PlotGui.py" line="84"/>
       <source>Configure series</source>
       <translation>Sorozatok beállítása</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="84"/>
+      <location filename="PlotGui.py" line="87"/>
       <source>Configure series drawing style and label</source>
       <translation>Sorozatok rajz stílusa és címke beállítása</translation>
     </message>
@@ -108,107 +108,107 @@
   <context>
     <name>plot_axes</name>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="175"/>
+      <location filename="TaskPanel.py" line="180"/>
       <source>Configure axes</source>
       <translation>Tengelyek kialakítása</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="179"/>
+      <location filename="TaskPanel.py" line="184"/>
       <source>Active axes</source>
       <translation>Aktív tengelyek</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="211"/>
+      <location filename="TaskPanel.py" line="216"/>
       <source>Apply to all axes</source>
       <translation>Minden tengelyre alkalmazza</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="215"/>
+      <location filename="TaskPanel.py" line="220"/>
       <source>Dimensions</source>
       <translation>Méretek</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="219"/>
+      <location filename="TaskPanel.py" line="224"/>
       <source>X axis position</source>
       <translation>X tengely helye</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="223"/>
+      <location filename="TaskPanel.py" line="228"/>
       <source>Y axis position</source>
       <translation>Y tengely helye</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="199"/>
+      <location filename="TaskPanel.py" line="204"/>
       <source>Scales</source>
       <translation>Lépték</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="203"/>
+      <location filename="TaskPanel.py" line="208"/>
       <source>X auto</source>
       <translation>X automatikus</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="207"/>
+      <location filename="TaskPanel.py" line="212"/>
       <source>Y auto</source>
       <translation>Y automatikus</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="227"/>
+      <location filename="TaskPanel.py" line="232"/>
       <source>Index of the active axes</source>
       <translation>Aktív tengelyek jelölése</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="231"/>
+      <location filename="TaskPanel.py" line="237"/>
       <source>Add new axes to the plot</source>
       <translation>Új tengely hozzáadása a tervrajzhoz</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="236"/>
+      <location filename="TaskPanel.py" line="242"/>
       <source>Remove selected axes</source>
       <translation>A kiválasztott tengelyek eltávolítása</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="241"/>
+      <location filename="TaskPanel.py" line="247"/>
       <source>Check it to apply transformations to all axes</source>
       <translation>Átalakítás alkalmazás ellenőrzése minden tengelyre</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="246"/>
+      <location filename="TaskPanel.py" line="252"/>
       <source>Left bound of axes</source>
       <translation>Tengelyek bal oldali határa</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="251"/>
+      <location filename="TaskPanel.py" line="257"/>
       <source>Right bound of axes</source>
       <translation>Tengelyek jobb oldali határa</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="256"/>
+      <location filename="TaskPanel.py" line="262"/>
       <source>Bottom bound of axes</source>
       <translation>Tengelyek alsó határa</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="261"/>
+      <location filename="TaskPanel.py" line="267"/>
       <source>Top bound of axes</source>
       <translation>Tengelyek felső határa</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="266"/>
+      <location filename="TaskPanel.py" line="272"/>
       <source>Outward offset of X axis</source>
       <translation>Az X tengely külső egyenestől mért távolsága</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="271"/>
+      <location filename="TaskPanel.py" line="277"/>
       <source>Outward offset of Y axis</source>
       <translation>Az Y tengely külső egyenestől mért távolsága</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="276"/>
+      <location filename="TaskPanel.py" line="282"/>
       <source>X axis scale autoselection</source>
       <translation>X tengely léptékének automatikus kiválasztása</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="281"/>
+      <location filename="TaskPanel.py" line="287"/>
       <source>Y axis scale autoselection</source>
       <translation>Y tengely lépték automatikus kiválasztása</translation>
     </message>
@@ -216,32 +216,32 @@
   <context>
     <name>plot_console</name>
     <message>
-      <location filename="../../Plot.py" line="43"/>
+      <location filename="Plot.py" line="47"/>
       <source>matplotlib not found, so Plot module can not be loaded</source>
       <translation>matplotlib nem található, így a tervrajz nyomtatási modult nem lehet betölteni</translation>
     </message>
     <message>
-      <location filename="../../InitGui.py" line="54"/>
+      <location filename="InitGui.py" line="58"/>
       <source>matplotlib not found, Plot module will be disabled</source>
       <translation>matplotlib nem található, tervrajz modul letiltja</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="42"/>
+      <location filename="TaskPanel.py" line="48"/>
       <source>Plot document must be selected in order to save it</source>
       <translation>Tervrajz nyomtatási dokumentumot kell kijelölni a mentés érdekében</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="340"/>
+      <location filename="TaskPanel.py" line="346"/>
       <source>Axes 0 can not be deleted</source>
       <translation>A 0 tengelyek nem törölhetőek</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="97"/>
+      <location filename="PlotGui.py" line="101"/>
       <source>The grid must be activated on top of a plot document</source>
       <translation>A rácsot a nyomtatott dokumentum felett kell aktiválni</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="125"/>
+      <location filename="PlotGui.py" line="129"/>
       <source>The legend must be activated on top of a plot document</source>
       <translation>A feliratot a nyomtatott dokumentum felett kell aktiválni</translation>
     </message>
@@ -249,62 +249,62 @@
   <context>
     <name>plot_labels</name>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="133"/>
+      <location filename="TaskPanel.py" line="138"/>
       <source>Set labels</source>
       <translation>Címkék beállítása</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="137"/>
+      <location filename="TaskPanel.py" line="142"/>
       <source>Active axes</source>
       <translation>Aktív tengelyek</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="141"/>
+      <location filename="TaskPanel.py" line="146"/>
       <source>Title</source>
       <translation>Cím</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="145"/>
+      <location filename="TaskPanel.py" line="150"/>
       <source>X label</source>
       <translation>X felirata</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="149"/>
+      <location filename="TaskPanel.py" line="154"/>
       <source>Y label</source>
       <translation>Y felirata</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="153"/>
+      <location filename="TaskPanel.py" line="158"/>
       <source>Index of the active axes</source>
       <translation>Aktív tengelyek jelölése</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="157"/>
+      <location filename="TaskPanel.py" line="163"/>
       <source>Title (associated to active axes)</source>
       <translation>Cím (kapcsolódó az aktív tengelyekhez)</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="162"/>
+      <location filename="TaskPanel.py" line="168"/>
       <source>Title font size</source>
       <translation>Cím betűméret</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="167"/>
+      <location filename="TaskPanel.py" line="173"/>
       <source>X axis title</source>
       <translation>X tengely címe</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="172"/>
+      <location filename="TaskPanel.py" line="178"/>
       <source>X axis title font size</source>
       <translation>X tengely cím betűmérete</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="177"/>
+      <location filename="TaskPanel.py" line="183"/>
       <source>Y axis title</source>
       <translation>Y tengely címe</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="182"/>
+      <location filename="TaskPanel.py" line="188"/>
       <source>Y axis title font size</source>
       <translation>Y tengely cím betűmérete</translation>
     </message>
@@ -312,37 +312,37 @@
   <context>
     <name>plot_positions</name>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="121"/>
+      <location filename="TaskPanel.py" line="124"/>
       <source>Set positions and sizes</source>
       <translation>Pozíciók és méretek beállítása</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="125"/>
+      <location filename="TaskPanel.py" line="129"/>
       <source>Position</source>
       <translation>Pozíció</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="130"/>
+      <location filename="TaskPanel.py" line="134"/>
       <source>Size</source>
       <translation>Méret</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="140"/>
+      <location filename="TaskPanel.py" line="144"/>
       <source>X item position</source>
       <translation>X elem helyzete</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="145"/>
+      <location filename="TaskPanel.py" line="149"/>
       <source>Y item position</source>
       <translation>Y elem helyzete</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="150"/>
+      <location filename="TaskPanel.py" line="154"/>
       <source>Item size</source>
       <translation>Elem méret</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="135"/>
+      <location filename="TaskPanel.py" line="139"/>
       <source>List of modifiable items</source>
       <translation>Módosítható elemek listája</translation>
     </message>
@@ -350,42 +350,42 @@
   <context>
     <name>plot_save</name>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="127"/>
+      <location filename="TaskPanel.py" line="132"/>
       <source>Save figure</source>
       <translation>Alakzat mentése</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="131"/>
+      <location filename="TaskPanel.py" line="137"/>
       <source>Inches</source>
       <translation>Hüvelyk</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="136"/>
+      <location filename="TaskPanel.py" line="142"/>
       <source>Dots per Inch</source>
       <translation>Hüvelykenkénti pontok száma</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="141"/>
+      <location filename="TaskPanel.py" line="147"/>
       <source>Output image file path</source>
       <translation>Kimeneti képfájl elérési útvonala</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="146"/>
+      <location filename="TaskPanel.py" line="152"/>
       <source>Show a file selection dialog</source>
       <translation>Fájl kiválasztás párbeszédpanel mutatása</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="151"/>
+      <location filename="TaskPanel.py" line="157"/>
       <source>X image size</source>
       <translation>X kép mérete</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="156"/>
+      <location filename="TaskPanel.py" line="162"/>
       <source>Y image size</source>
       <translation>Y kép mérete</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="161"/>
+      <location filename="TaskPanel.py" line="168"/>
       <source>Dots per point, with size will define output image resolution</source>
       <translation>Képpont / pont, mérettel fogja megadni a kimeneti kép felbontását</translation>
     </message>
@@ -393,67 +393,67 @@
   <context>
     <name>plot_series</name>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="153"/>
+      <location filename="TaskPanel.py" line="157"/>
       <source>No label</source>
       <translation>Nincs felirat</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="188"/>
+      <location filename="TaskPanel.py" line="192"/>
       <source>Line style</source>
       <translation>Vonalstílus</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="168"/>
+      <location filename="TaskPanel.py" line="172"/>
       <source>Marker</source>
       <translation>Jelölő</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="149"/>
+      <location filename="TaskPanel.py" line="152"/>
       <source>Configure series</source>
       <translation>Sorozatok beállítása</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="173"/>
+      <location filename="TaskPanel.py" line="177"/>
       <source>List of available series</source>
       <translation>Elérhető szériák listája</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="178"/>
+      <location filename="TaskPanel.py" line="182"/>
       <source>Line title</source>
       <translation>Vonal megnevezése</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="193"/>
+      <location filename="TaskPanel.py" line="197"/>
       <source>Marker style</source>
       <translation>Jelölő stílusa</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="198"/>
+      <location filename="TaskPanel.py" line="202"/>
       <source>Line width</source>
       <translation>Vonalvastagság</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="203"/>
+      <location filename="TaskPanel.py" line="207"/>
       <source>Marker size</source>
       <translation>Jelölő mérete</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="208"/>
+      <location filename="TaskPanel.py" line="212"/>
       <source>Line and marker color</source>
       <translation>Vonal és a jelölő színe</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="158"/>
+      <location filename="TaskPanel.py" line="162"/>
       <source>Remove series</source>
       <translation>Sorozat eltávolítása</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="183"/>
+      <location filename="TaskPanel.py" line="187"/>
       <source>If checked, series will not be considered for legend</source>
       <translation>Ha be van jelölve akkor a szériák nem feliratként értelmezettek</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="213"/>
+      <location filename="TaskPanel.py" line="217"/>
       <source>Removes this series</source>
       <translation>Ennek a szériának az eltávolítása</translation>
     </message>
