@@ -1,15 +1,15 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="uk" sourcelanguage="en">
+<TS version="1.1" language="uk" sourcelanguage="en">
   <context>
     <name>Plot</name>
     <message>
-      <location filename="../../InitGui.py" line="44"/>
+      <location filename="InitGui.py" line="46"/>
       <source>Plot edition tools</source>
       <translation>Інструменти для роботи з діаграмами</translation>
     </message>
     <message>
-      <location filename="../../InitGui.py" line="47"/>
+      <location filename="InitGui.py" line="49"/>
       <source>Plot</source>
       <translation>Діаграма</translation>
     </message>
@@ -17,12 +17,12 @@
   <context>
     <name>Plot_Axes</name>
     <message>
-      <location filename="../../PlotGui.py" line="62"/>
+      <location filename="PlotGui.py" line="65"/>
       <source>Configure axes</source>
       <translation>Налаштування осей</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="65"/>
+      <location filename="PlotGui.py" line="68"/>
       <source>Configure the axes parameters</source>
       <translation>Налаштування параметрів осей</translation>
     </message>
@@ -30,12 +30,12 @@
   <context>
     <name>Plot_Grid</name>
     <message>
-      <location filename="../../PlotGui.py" line="109"/>
+      <location filename="PlotGui.py" line="112"/>
       <source>Show/Hide grid</source>
       <translation>Показати/приховати сітку</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="112"/>
+      <location filename="PlotGui.py" line="115"/>
       <source>Show/Hide grid on selected plot</source>
       <translation>Показати/приховати сітку на обраній діаграмі</translation>
     </message>
@@ -43,12 +43,12 @@
   <context>
     <name>Plot_Labels</name>
     <message>
-      <location filename="../../PlotGui.py" line="152"/>
+      <location filename="PlotGui.py" line="155"/>
       <source>Set labels</source>
       <translation>Вказати бирки</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="155"/>
+      <location filename="PlotGui.py" line="158"/>
       <source>Set title and axes labels</source>
       <translation>Вказати заголовок та бирки для осей</translation>
     </message>
@@ -56,12 +56,12 @@
   <context>
     <name>Plot_Legend</name>
     <message>
-      <location filename="../../PlotGui.py" line="135"/>
+      <location filename="PlotGui.py" line="138"/>
       <source>Show/Hide legend</source>
       <translation>Показати/приховати легенду</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="138"/>
+      <location filename="PlotGui.py" line="141"/>
       <source>Show/Hide legend on selected plot</source>
       <translation>Показати/приховати легенду на обраній діаграмі</translation>
     </message>
@@ -69,12 +69,12 @@
   <context>
     <name>Plot_Positions</name>
     <message>
-      <location filename="../../PlotGui.py" line="169"/>
+      <location filename="PlotGui.py" line="172"/>
       <source>Set positions and sizes</source>
       <translation>Встановити розміщення та розміри</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="172"/>
+      <location filename="PlotGui.py" line="175"/>
       <source>Set labels and legend positions and sizes</source>
       <translation>Встановити розміщення та розміри для бирок та легенди</translation>
     </message>
@@ -82,12 +82,12 @@
   <context>
     <name>Plot_SaveFig</name>
     <message>
-      <location filename="../../PlotGui.py" line="45"/>
+      <location filename="PlotGui.py" line="48"/>
       <source>Save plot</source>
       <translation>Зберегти діаграму</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="48"/>
+      <location filename="PlotGui.py" line="51"/>
       <source>Save the plot as an image file</source>
       <translation>Зберегти діаграму як файл зображення</translation>
     </message>
@@ -95,12 +95,12 @@
   <context>
     <name>Plot_Series</name>
     <message>
-      <location filename="../../PlotGui.py" line="81"/>
+      <location filename="PlotGui.py" line="84"/>
       <source>Configure series</source>
       <translation>Налаштування серії</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="84"/>
+      <location filename="PlotGui.py" line="87"/>
       <source>Configure series drawing style and label</source>
       <translation>Налаштування серії, стиль креслення та бирки</translation>
     </message>
@@ -108,107 +108,107 @@
   <context>
     <name>plot_axes</name>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="175"/>
+      <location filename="TaskPanel.py" line="180"/>
       <source>Configure axes</source>
       <translation>Налаштування осей</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="179"/>
+      <location filename="TaskPanel.py" line="184"/>
       <source>Active axes</source>
       <translation>Активні осі</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="211"/>
+      <location filename="TaskPanel.py" line="216"/>
       <source>Apply to all axes</source>
       <translation>Застосувати до всіх осей</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="215"/>
+      <location filename="TaskPanel.py" line="220"/>
       <source>Dimensions</source>
       <translation>Розміри</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="219"/>
+      <location filename="TaskPanel.py" line="224"/>
       <source>X axis position</source>
       <translation>Положення осі X</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="223"/>
+      <location filename="TaskPanel.py" line="228"/>
       <source>Y axis position</source>
       <translation>Положення осі Y</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="199"/>
+      <location filename="TaskPanel.py" line="204"/>
       <source>Scales</source>
       <translation>Шкали</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="203"/>
+      <location filename="TaskPanel.py" line="208"/>
       <source>X auto</source>
       <translation>X авто</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="207"/>
+      <location filename="TaskPanel.py" line="212"/>
       <source>Y auto</source>
       <translation>Y авто</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="227"/>
+      <location filename="TaskPanel.py" line="232"/>
       <source>Index of the active axes</source>
       <translation>Індекс активних осей</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="231"/>
+      <location filename="TaskPanel.py" line="237"/>
       <source>Add new axes to the plot</source>
       <translation>Додати нові осі</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="236"/>
+      <location filename="TaskPanel.py" line="242"/>
       <source>Remove selected axes</source>
       <translation>Вилучити обрані осі</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="241"/>
+      <location filename="TaskPanel.py" line="247"/>
       <source>Check it to apply transformations to all axes</source>
       <translation>Позначте це, щоб застосувати перетворення до всіх осей</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="246"/>
+      <location filename="TaskPanel.py" line="252"/>
       <source>Left bound of axes</source>
       <translation>Ліва межа для осей</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="251"/>
+      <location filename="TaskPanel.py" line="257"/>
       <source>Right bound of axes</source>
       <translation>Права межа для осей</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="256"/>
+      <location filename="TaskPanel.py" line="262"/>
       <source>Bottom bound of axes</source>
       <translation>Нижня межа для осей</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="261"/>
+      <location filename="TaskPanel.py" line="267"/>
       <source>Top bound of axes</source>
       <translation>Верхня межа для осей</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="266"/>
+      <location filename="TaskPanel.py" line="272"/>
       <source>Outward offset of X axis</source>
       <translation>Зовнішнє зміщення осі X</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="271"/>
+      <location filename="TaskPanel.py" line="277"/>
       <source>Outward offset of Y axis</source>
       <translation>Зовнішнє зміщення осі Y</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="276"/>
+      <location filename="TaskPanel.py" line="282"/>
       <source>X axis scale autoselection</source>
       <translation>Автовибір масштабу осі Х</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="281"/>
+      <location filename="TaskPanel.py" line="287"/>
       <source>Y axis scale autoselection</source>
       <translation>Автовибір масштабу осі Y</translation>
     </message>
@@ -216,32 +216,32 @@
   <context>
     <name>plot_console</name>
     <message>
-      <location filename="../../Plot.py" line="43"/>
+      <location filename="Plot.py" line="47"/>
       <source>matplotlib not found, so Plot module can not be loaded</source>
       <translation>matplotlib не знайдено, тому модуль Діаграма не можливо завантажити</translation>
     </message>
     <message>
-      <location filename="../../InitGui.py" line="54"/>
+      <location filename="InitGui.py" line="58"/>
       <source>matplotlib not found, Plot module will be disabled</source>
       <translation>matplotlib не знайдено, модуль Діаграма буде вимкнено</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="42"/>
+      <location filename="TaskPanel.py" line="48"/>
       <source>Plot document must be selected in order to save it</source>
       <translation>Потрібно обрати документ Діаграми для збереження</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="340"/>
+      <location filename="TaskPanel.py" line="346"/>
       <source>Axes 0 can not be deleted</source>
       <translation>Вісь 0 не може бути вилученою</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="97"/>
+      <location filename="PlotGui.py" line="101"/>
       <source>The grid must be activated on top of a plot document</source>
       <translation>Сітка має бути активована поверх діаграми</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="125"/>
+      <location filename="PlotGui.py" line="129"/>
       <source>The legend must be activated on top of a plot document</source>
       <translation>Опис позначок має бути активований поверх діаграми</translation>
     </message>
@@ -249,62 +249,62 @@
   <context>
     <name>plot_labels</name>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="133"/>
+      <location filename="TaskPanel.py" line="138"/>
       <source>Set labels</source>
       <translation>Вказати бирки</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="137"/>
+      <location filename="TaskPanel.py" line="142"/>
       <source>Active axes</source>
       <translation>Активні осі</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="141"/>
+      <location filename="TaskPanel.py" line="146"/>
       <source>Title</source>
       <translation>Назва</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="145"/>
+      <location filename="TaskPanel.py" line="150"/>
       <source>X label</source>
       <translation>X бирка</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="149"/>
+      <location filename="TaskPanel.py" line="154"/>
       <source>Y label</source>
       <translation>Y бирка</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="153"/>
+      <location filename="TaskPanel.py" line="158"/>
       <source>Index of the active axes</source>
       <translation>Індекс активних осей</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="157"/>
+      <location filename="TaskPanel.py" line="163"/>
       <source>Title (associated to active axes)</source>
       <translation>Назва (пов'язана з активною віссю)</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="162"/>
+      <location filename="TaskPanel.py" line="168"/>
       <source>Title font size</source>
       <translation>Розмір шрифту для назви</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="167"/>
+      <location filename="TaskPanel.py" line="173"/>
       <source>X axis title</source>
       <translation>Назва осі X</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="172"/>
+      <location filename="TaskPanel.py" line="178"/>
       <source>X axis title font size</source>
       <translation>Розмір шрифту для назви осі X</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="177"/>
+      <location filename="TaskPanel.py" line="183"/>
       <source>Y axis title</source>
       <translation>Назва осі Y</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="182"/>
+      <location filename="TaskPanel.py" line="188"/>
       <source>Y axis title font size</source>
       <translation>Розмір шрифту для назви осі Y</translation>
     </message>
@@ -312,37 +312,37 @@
   <context>
     <name>plot_positions</name>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="121"/>
+      <location filename="TaskPanel.py" line="124"/>
       <source>Set positions and sizes</source>
       <translation>Встановити розміщення та розміри</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="125"/>
+      <location filename="TaskPanel.py" line="129"/>
       <source>Position</source>
       <translation>Позиція</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="130"/>
+      <location filename="TaskPanel.py" line="134"/>
       <source>Size</source>
       <translation>Розмір</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="140"/>
+      <location filename="TaskPanel.py" line="144"/>
       <source>X item position</source>
       <translation>Положення X елемента</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="145"/>
+      <location filename="TaskPanel.py" line="149"/>
       <source>Y item position</source>
       <translation>Положення Y елемента</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="150"/>
+      <location filename="TaskPanel.py" line="154"/>
       <source>Item size</source>
       <translation>Розмір елемента</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="135"/>
+      <location filename="TaskPanel.py" line="139"/>
       <source>List of modifiable items</source>
       <translation>Список елементів, які можливо змінювати</translation>
     </message>
@@ -350,42 +350,42 @@
   <context>
     <name>plot_save</name>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="127"/>
+      <location filename="TaskPanel.py" line="132"/>
       <source>Save figure</source>
       <translation>Зберегти фігуру</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="131"/>
+      <location filename="TaskPanel.py" line="137"/>
       <source>Inches</source>
       <translation>Дюйми</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="136"/>
+      <location filename="TaskPanel.py" line="142"/>
       <source>Dots per Inch</source>
       <translation>Точок на дюйм</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="141"/>
+      <location filename="TaskPanel.py" line="147"/>
       <source>Output image file path</source>
       <translation>Шлях до вихідного зображення</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="146"/>
+      <location filename="TaskPanel.py" line="152"/>
       <source>Show a file selection dialog</source>
       <translation>Показати діалог вибору файлів</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="151"/>
+      <location filename="TaskPanel.py" line="157"/>
       <source>X image size</source>
       <translation>X розмір зображення</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="156"/>
+      <location filename="TaskPanel.py" line="162"/>
       <source>Y image size</source>
       <translation>Y розмір зображення</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="161"/>
+      <location filename="TaskPanel.py" line="168"/>
       <source>Dots per point, with size will define output image resolution</source>
       <translation>Крапок на одиницю, з розміром буде визначати розширення вихідного зображення</translation>
     </message>
@@ -393,67 +393,67 @@
   <context>
     <name>plot_series</name>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="153"/>
+      <location filename="TaskPanel.py" line="157"/>
       <source>No label</source>
       <translation>Без бирки</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="188"/>
+      <location filename="TaskPanel.py" line="192"/>
       <source>Line style</source>
       <translation>Стиль лінії</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="168"/>
+      <location filename="TaskPanel.py" line="172"/>
       <source>Marker</source>
       <translation>Позначка</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="149"/>
+      <location filename="TaskPanel.py" line="152"/>
       <source>Configure series</source>
       <translation>Налаштування серії</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="173"/>
+      <location filename="TaskPanel.py" line="177"/>
       <source>List of available series</source>
       <translation>Список доступних серій</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="178"/>
+      <location filename="TaskPanel.py" line="182"/>
       <source>Line title</source>
       <translation>Назва лінії</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="193"/>
+      <location filename="TaskPanel.py" line="197"/>
       <source>Marker style</source>
       <translation>Стиль позначки</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="198"/>
+      <location filename="TaskPanel.py" line="202"/>
       <source>Line width</source>
       <translation>Ширина лінії</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="203"/>
+      <location filename="TaskPanel.py" line="207"/>
       <source>Marker size</source>
       <translation>Розмір позначки</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="208"/>
+      <location filename="TaskPanel.py" line="212"/>
       <source>Line and marker color</source>
       <translation>Колір лінії та позначки</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="158"/>
+      <location filename="TaskPanel.py" line="162"/>
       <source>Remove series</source>
       <translation>Видалити послідовність</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="183"/>
+      <location filename="TaskPanel.py" line="187"/>
       <source>If checked, series will not be considered for legend</source>
       <translation>Якщо позначено, то послідовність не буде використовуватися для напису</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="213"/>
+      <location filename="TaskPanel.py" line="217"/>
       <source>Removes this series</source>
       <translation>Вилучити цю послідовність</translation>
     </message>
