@@ -1,15 +1,15 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="zh-TW" sourcelanguage="en">
+<TS version="1.1" language="zh-TW" sourcelanguage="en">
   <context>
     <name>Plot</name>
     <message>
-      <location filename="../../InitGui.py" line="44"/>
+      <location filename="InitGui.py" line="46"/>
       <source>Plot edition tools</source>
       <translation>製圖編輯工具</translation>
     </message>
     <message>
-      <location filename="../../InitGui.py" line="47"/>
+      <location filename="InitGui.py" line="49"/>
       <source>Plot</source>
       <translation>製圖</translation>
     </message>
@@ -17,12 +17,12 @@
   <context>
     <name>Plot_Axes</name>
     <message>
-      <location filename="../../PlotGui.py" line="62"/>
+      <location filename="PlotGui.py" line="65"/>
       <source>Configure axes</source>
       <translation>配置軸</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="65"/>
+      <location filename="PlotGui.py" line="68"/>
       <source>Configure the axes parameters</source>
       <translation>設定軸之參數</translation>
     </message>
@@ -30,12 +30,12 @@
   <context>
     <name>Plot_Grid</name>
     <message>
-      <location filename="../../PlotGui.py" line="109"/>
+      <location filename="PlotGui.py" line="112"/>
       <source>Show/Hide grid</source>
       <translation>顯示/隱藏格線</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="112"/>
+      <location filename="PlotGui.py" line="115"/>
       <source>Show/Hide grid on selected plot</source>
       <translation>於所選圖面上顯示/隱藏格線</translation>
     </message>
@@ -43,12 +43,12 @@
   <context>
     <name>Plot_Labels</name>
     <message>
-      <location filename="../../PlotGui.py" line="152"/>
+      <location filename="PlotGui.py" line="155"/>
       <source>Set labels</source>
       <translation>設定標示</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="155"/>
+      <location filename="PlotGui.py" line="158"/>
       <source>Set title and axes labels</source>
       <translation>設定標題和軸標示</translation>
     </message>
@@ -56,12 +56,12 @@
   <context>
     <name>Plot_Legend</name>
     <message>
-      <location filename="../../PlotGui.py" line="135"/>
+      <location filename="PlotGui.py" line="138"/>
       <source>Show/Hide legend</source>
       <translation>顯示/隱藏圖例</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="138"/>
+      <location filename="PlotGui.py" line="141"/>
       <source>Show/Hide legend on selected plot</source>
       <translation>於所選圖面上顯示/隱藏圖例</translation>
     </message>
@@ -69,12 +69,12 @@
   <context>
     <name>Plot_Positions</name>
     <message>
-      <location filename="../../PlotGui.py" line="169"/>
+      <location filename="PlotGui.py" line="172"/>
       <source>Set positions and sizes</source>
       <translation>設定位置和尺寸</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="172"/>
+      <location filename="PlotGui.py" line="175"/>
       <source>Set labels and legend positions and sizes</source>
       <translation>設定標示和圖例之位置和尺寸</translation>
     </message>
@@ -82,12 +82,12 @@
   <context>
     <name>Plot_SaveFig</name>
     <message>
-      <location filename="../../PlotGui.py" line="45"/>
+      <location filename="PlotGui.py" line="48"/>
       <source>Save plot</source>
       <translation>儲存製圖</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="48"/>
+      <location filename="PlotGui.py" line="51"/>
       <source>Save the plot as an image file</source>
       <translation>儲存圖形為影像檔</translation>
     </message>
@@ -95,12 +95,12 @@
   <context>
     <name>Plot_Series</name>
     <message>
-      <location filename="../../PlotGui.py" line="81"/>
+      <location filename="PlotGui.py" line="84"/>
       <source>Configure series</source>
       <translation>配置組</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="84"/>
+      <location filename="PlotGui.py" line="87"/>
       <source>Configure series drawing style and label</source>
       <translation>配置工程圖型式及圖標組</translation>
     </message>
@@ -108,107 +108,107 @@
   <context>
     <name>plot_axes</name>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="175"/>
+      <location filename="TaskPanel.py" line="180"/>
       <source>Configure axes</source>
       <translation>配置軸</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="179"/>
+      <location filename="TaskPanel.py" line="184"/>
       <source>Active axes</source>
       <translation>選用軸</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="211"/>
+      <location filename="TaskPanel.py" line="216"/>
       <source>Apply to all axes</source>
       <translation>適用所有軸</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="215"/>
+      <location filename="TaskPanel.py" line="220"/>
       <source>Dimensions</source>
       <translation>尺寸</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="219"/>
+      <location filename="TaskPanel.py" line="224"/>
       <source>X axis position</source>
       <translation>X軸位置</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="223"/>
+      <location filename="TaskPanel.py" line="228"/>
       <source>Y axis position</source>
       <translation>Y軸位置</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="199"/>
+      <location filename="TaskPanel.py" line="204"/>
       <source>Scales</source>
       <translation>刻度</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="203"/>
+      <location filename="TaskPanel.py" line="208"/>
       <source>X auto</source>
       <translation>X軸自動</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="207"/>
+      <location filename="TaskPanel.py" line="212"/>
       <source>Y auto</source>
       <translation>Y軸自動</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="227"/>
+      <location filename="TaskPanel.py" line="232"/>
       <source>Index of the active axes</source>
       <translation>選用軸之索引</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="231"/>
+      <location filename="TaskPanel.py" line="237"/>
       <source>Add new axes to the plot</source>
       <translation>於圖面加入新的軸</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="236"/>
+      <location filename="TaskPanel.py" line="242"/>
       <source>Remove selected axes</source>
       <translation>移除所選之軸</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="241"/>
+      <location filename="TaskPanel.py" line="247"/>
       <source>Check it to apply transformations to all axes</source>
       <translation>選擇此項可提供所有軸之轉換</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="246"/>
+      <location filename="TaskPanel.py" line="252"/>
       <source>Left bound of axes</source>
       <translation>軸之左側範圍</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="251"/>
+      <location filename="TaskPanel.py" line="257"/>
       <source>Right bound of axes</source>
       <translation>軸之右側範圍</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="256"/>
+      <location filename="TaskPanel.py" line="262"/>
       <source>Bottom bound of axes</source>
       <translation>軸之底部範圍</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="261"/>
+      <location filename="TaskPanel.py" line="267"/>
       <source>Top bound of axes</source>
       <translation>軸之上部範圍</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="266"/>
+      <location filename="TaskPanel.py" line="272"/>
       <source>Outward offset of X axis</source>
       <translation>X軸之外部偏移</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="271"/>
+      <location filename="TaskPanel.py" line="277"/>
       <source>Outward offset of Y axis</source>
       <translation>Y軸之外部偏移</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="276"/>
+      <location filename="TaskPanel.py" line="282"/>
       <source>X axis scale autoselection</source>
       <translation>X軸自動縮放</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="281"/>
+      <location filename="TaskPanel.py" line="287"/>
       <source>Y axis scale autoselection</source>
       <translation>Y軸自動縮放</translation>
     </message>
@@ -216,32 +216,32 @@
   <context>
     <name>plot_console</name>
     <message>
-      <location filename="../../Plot.py" line="43"/>
+      <location filename="Plot.py" line="47"/>
       <source>matplotlib not found, so Plot module can not be loaded</source>
       <translation>無matplotlib而無法載入製圖模組</translation>
     </message>
     <message>
-      <location filename="../../InitGui.py" line="54"/>
+      <location filename="InitGui.py" line="58"/>
       <source>matplotlib not found, Plot module will be disabled</source>
       <translation>無matplotlib時製圖模組將無法使用</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="42"/>
+      <location filename="TaskPanel.py" line="48"/>
       <source>Plot document must be selected in order to save it</source>
       <translation>為進行儲存必須選擇製圖文件</translation>
     </message>
     <message>
-      <location filename="../../plotAxes/TaskPanel.py" line="340"/>
+      <location filename="TaskPanel.py" line="346"/>
       <source>Axes 0 can not be deleted</source>
       <translation>不能刪除軸 0</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="97"/>
+      <location filename="PlotGui.py" line="101"/>
       <source>The grid must be activated on top of a plot document</source>
       <translation>必須於製圖文件之上方啟動格線</translation>
     </message>
     <message>
-      <location filename="../../PlotGui.py" line="125"/>
+      <location filename="PlotGui.py" line="129"/>
       <source>The legend must be activated on top of a plot document</source>
       <translation>必須於製圖文件之上方啟動圖例</translation>
     </message>
@@ -249,62 +249,62 @@
   <context>
     <name>plot_labels</name>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="133"/>
+      <location filename="TaskPanel.py" line="138"/>
       <source>Set labels</source>
       <translation>設定標示</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="137"/>
+      <location filename="TaskPanel.py" line="142"/>
       <source>Active axes</source>
       <translation>選用軸</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="141"/>
+      <location filename="TaskPanel.py" line="146"/>
       <source>Title</source>
       <translation>標題</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="145"/>
+      <location filename="TaskPanel.py" line="150"/>
       <source>X label</source>
       <translation>X軸標示</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="149"/>
+      <location filename="TaskPanel.py" line="154"/>
       <source>Y label</source>
       <translation>Y軸標示</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="153"/>
+      <location filename="TaskPanel.py" line="158"/>
       <source>Index of the active axes</source>
       <translation>選用軸之索引</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="157"/>
+      <location filename="TaskPanel.py" line="163"/>
       <source>Title (associated to active axes)</source>
       <translation>標題(與選用軸相關聯)</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="162"/>
+      <location filename="TaskPanel.py" line="168"/>
       <source>Title font size</source>
       <translation>標題字體尺寸</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="167"/>
+      <location filename="TaskPanel.py" line="173"/>
       <source>X axis title</source>
       <translation>X軸標題</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="172"/>
+      <location filename="TaskPanel.py" line="178"/>
       <source>X axis title font size</source>
       <translation>X軸標題字體尺寸</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="177"/>
+      <location filename="TaskPanel.py" line="183"/>
       <source>Y axis title</source>
       <translation>Y軸標題</translation>
     </message>
     <message>
-      <location filename="../../plotLabels/TaskPanel.py" line="182"/>
+      <location filename="TaskPanel.py" line="188"/>
       <source>Y axis title font size</source>
       <translation>Y軸標題字體尺寸</translation>
     </message>
@@ -312,80 +312,80 @@
   <context>
     <name>plot_positions</name>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="121"/>
+      <location filename="TaskPanel.py" line="124"/>
       <source>Set positions and sizes</source>
       <translation>設定位置和尺寸</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="125"/>
+      <location filename="TaskPanel.py" line="129"/>
       <source>Position</source>
       <translation>位置</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="130"/>
+      <location filename="TaskPanel.py" line="134"/>
       <source>Size</source>
       <translation>尺寸</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="140"/>
+      <location filename="TaskPanel.py" line="144"/>
       <source>X item position</source>
       <translation>X項位置</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="145"/>
+      <location filename="TaskPanel.py" line="149"/>
       <source>Y item position</source>
       <translation>Y項位置</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="150"/>
+      <location filename="TaskPanel.py" line="154"/>
       <source>Item size</source>
       <translation>項之尺寸</translation>
     </message>
     <message>
-      <location filename="../../plotPositions/TaskPanel.py" line="135"/>
+      <location filename="TaskPanel.py" line="139"/>
       <source>List of modifiable items</source>
-      <translation type="unfinished">List of modifiable items</translation>
+      <translation>可更改項目的清單</translation>
     </message>
   </context>
   <context>
     <name>plot_save</name>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="127"/>
+      <location filename="TaskPanel.py" line="132"/>
       <source>Save figure</source>
       <translation>儲存圖案</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="131"/>
+      <location filename="TaskPanel.py" line="137"/>
       <source>Inches</source>
       <translation>英寸</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="136"/>
+      <location filename="TaskPanel.py" line="142"/>
       <source>Dots per Inch</source>
       <translation>每英寸點數(DPI)</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="141"/>
+      <location filename="TaskPanel.py" line="147"/>
       <source>Output image file path</source>
       <translation>輸出圖像檔路徑</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="146"/>
+      <location filename="TaskPanel.py" line="152"/>
       <source>Show a file selection dialog</source>
       <translation>顯示檔案選擇對話框</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="151"/>
+      <location filename="TaskPanel.py" line="157"/>
       <source>X image size</source>
       <translation>X圖尺寸</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="156"/>
+      <location filename="TaskPanel.py" line="162"/>
       <source>Y image size</source>
       <translation>Y圖尺寸</translation>
     </message>
     <message>
-      <location filename="../../plotSave/TaskPanel.py" line="161"/>
+      <location filename="TaskPanel.py" line="168"/>
       <source>Dots per point, with size will define output image resolution</source>
       <translation>每點內的點數,具有尺寸可以定義輸出影像之解析度</translation>
     </message>
@@ -393,69 +393,69 @@
   <context>
     <name>plot_series</name>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="153"/>
+      <location filename="TaskPanel.py" line="157"/>
       <source>No label</source>
       <translation>無標示</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="188"/>
+      <location filename="TaskPanel.py" line="192"/>
       <source>Line style</source>
       <translation>線型式</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="168"/>
+      <location filename="TaskPanel.py" line="172"/>
       <source>Marker</source>
       <translation>標注</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="149"/>
+      <location filename="TaskPanel.py" line="152"/>
       <source>Configure series</source>
       <translation>配置組</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="173"/>
+      <location filename="TaskPanel.py" line="177"/>
       <source>List of available series</source>
       <translation>可用系列清單</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="178"/>
+      <location filename="TaskPanel.py" line="182"/>
       <source>Line title</source>
       <translation>線標題</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="193"/>
+      <location filename="TaskPanel.py" line="197"/>
       <source>Marker style</source>
       <translation>標注型式</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="198"/>
+      <location filename="TaskPanel.py" line="202"/>
       <source>Line width</source>
       <translation>線寬</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="203"/>
+      <location filename="TaskPanel.py" line="207"/>
       <source>Marker size</source>
       <translation>標注尺寸</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="208"/>
+      <location filename="TaskPanel.py" line="212"/>
       <source>Line and marker color</source>
       <translation>線和標注色彩</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="158"/>
+      <location filename="TaskPanel.py" line="162"/>
       <source>Remove series</source>
-      <translation type="unfinished">Remove series</translation>
+      <translation>刪除系列</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="183"/>
+      <location filename="TaskPanel.py" line="187"/>
       <source>If checked, series will not be considered for legend</source>
-      <translation type="unfinished">If checked, series will not be considered for legend</translation>
+      <translation>如果已選擇，系列不會被認作圖例</translation>
     </message>
     <message>
-      <location filename="../../plotSeries/TaskPanel.py" line="213"/>
+      <location filename="TaskPanel.py" line="217"/>
       <source>Removes this series</source>
-      <translation type="unfinished">Removes this series</translation>
+      <translation>移除此系列</translation>
     </message>
   </context>
 </TS>
