@@ -1,23 +1,23 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="fi" sourcelanguage="en">
+<TS version="2.1" language="fi" sourcelanguage="en">
   <context>
     <name>CmdPointsConvert</name>
     <message>
-      <location filename="../../Command.cpp" line="188"/>
+      <location filename="../../Command.cpp" line="189"/>
       <source>Points</source>
       <translation>Pisteet</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="189"/>
+      <location filename="../../Command.cpp" line="190"/>
       <source>Convert to points...</source>
-      <translation type="unfinished">Convert to points...</translation>
+      <translation>Muunna pisteiksi...</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="190"/>
-      <location filename="../../Command.cpp" line="192"/>
+      <location filename="../../Command.cpp" line="191"/>
+      <location filename="../../Command.cpp" line="193"/>
       <source>Convert to points</source>
-      <translation type="unfinished">Convert to points</translation>
+      <translation>Muunna pisteiksi</translation>
     </message>
   </context>
   <context>
@@ -42,18 +42,18 @@
   <context>
     <name>CmdPointsImport</name>
     <message>
-      <location filename="../../Command.cpp" line="65"/>
+      <location filename="../../Command.cpp" line="67"/>
       <source>Points</source>
       <translation>Pisteet</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="66"/>
+      <location filename="../../Command.cpp" line="68"/>
       <source>Import points...</source>
       <translation>Tuo pisteet...</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="67"/>
       <location filename="../../Command.cpp" line="69"/>
+      <location filename="../../Command.cpp" line="71"/>
       <source>Imports a point cloud</source>
       <translation>Tuo pistepilven</translation>
     </message>
@@ -61,58 +61,101 @@
   <context>
     <name>CmdPointsMerge</name>
     <message>
-      <location filename="../../Command.cpp" line="318"/>
+      <location filename="../../Command.cpp" line="320"/>
       <source>Points</source>
       <translation>Pisteet</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="319"/>
+      <location filename="../../Command.cpp" line="321"/>
       <source>Merge point clouds</source>
-      <translation type="unfinished">Merge point clouds</translation>
+      <translation>Yhdistä pistepilvet</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="320"/>
       <location filename="../../Command.cpp" line="322"/>
+      <location filename="../../Command.cpp" line="324"/>
       <source>Merge several point clouds into one</source>
-      <translation type="unfinished">Merge several point clouds into one</translation>
+      <translation>Yhdistä useita pistepilviä yhdeksi</translation>
     </message>
   </context>
   <context>
     <name>CmdPointsPolyCut</name>
     <message>
-      <location filename="../../Command.cpp" line="273"/>
+      <location filename="../../Command.cpp" line="275"/>
       <source>Points</source>
       <translation>Pisteet</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="274"/>
+      <location filename="../../Command.cpp" line="276"/>
       <source>Cut point cloud</source>
       <translation>Leikkaa pistepilvi</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="275"/>
       <location filename="../../Command.cpp" line="277"/>
+      <location filename="../../Command.cpp" line="279"/>
       <source>Cuts a point cloud with a picked polygon</source>
       <translation>Leikkaa pistepilven valitun monikulmion kanssa</translation>
     </message>
   </context>
   <context>
-    <name>CmdPointsTransform</name>
+    <name>CmdPointsStructure</name>
     <message>
-      <location filename="../../Command.cpp" line="151"/>
+      <location filename="../../Command.cpp" line="363"/>
       <source>Points</source>
       <translation>Pisteet</translation>
     </message>
+    <message>
+      <location filename="../../Command.cpp" line="364"/>
+      <source>Structured point cloud</source>
+      <translation>Strukturoitu pistepilvi</translation>
+    </message>
+    <message>
+      <location filename="../../Command.cpp" line="365"/>
+      <location filename="../../Command.cpp" line="367"/>
+      <source>Convert points to structured point cloud</source>
+      <translation>Muunna pisteet jäsenneltyyn pistepilveen</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdPointsTransform</name>
     <message>
       <location filename="../../Command.cpp" line="152"/>
+      <source>Points</source>
+      <translation>Pisteet</translation>
+    </message>
+    <message>
+      <location filename="../../Command.cpp" line="153"/>
       <source>Transform Points</source>
       <translation>Muunna pisteet</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="153"/>
-      <location filename="../../Command.cpp" line="155"/>
+      <location filename="../../Command.cpp" line="154"/>
+      <location filename="../../Command.cpp" line="156"/>
       <source>Test to transform a point cloud</source>
-      <translation>Testaa muuttaa pistepilvi</translation>
+      <translation>Testaa pistepilveksi muuntamista</translation>
+    </message>
+  </context>
+  <context>
+    <name>Command</name>
+    <message>
+      <location filename="../../Command.cpp" line="88"/>
+      <source>Import points</source>
+      <translation>Tuo pisteet</translation>
+    </message>
+    <message>
+      <location filename="../../Command.cpp" line="168"/>
+      <source>Transform points</source>
+      <translation>Muuta pisteet</translation>
+    </message>
+    <message>
+      <location filename="../../Command.cpp" line="208"/>
+      <source>Convert to points</source>
+      <translation>Muunna pisteiksi</translation>
+    </message>
+    <message>
+      <location filename="../../ViewProvider.cpp" line="468"/>
+      <location filename="../../ViewProvider.cpp" line="627"/>
+      <source>Cut points</source>
+      <translation>Leikkaa pisteet</translation>
     </message>
   </context>
   <context>
@@ -195,12 +238,12 @@
       <location filename="../../DlgPointsRead.ui" line="196"/>
       <location filename="../../DlgPointsRead.ui" line="253"/>
       <source>I (Gray value)</source>
-      <translation>I (Gray arvo)</translation>
+      <translation>I (harmaa arvo)</translation>
     </message>
     <message>
       <location filename="../../DlgPointsRead.ui" line="204"/>
       <source>Number separator:</source>
-      <translation>Numero erotin:</translation>
+      <translation>Numeron erotin:</translation>
     </message>
     <message>
       <location filename="../../DlgPointsRead.ui" line="211"/>
@@ -263,26 +306,26 @@
   <context>
     <name>QObject</name>
     <message>
-      <location filename="../../Command.cpp" line="79"/>
+      <location filename="../../Command.cpp" line="81"/>
       <location filename="../../Command.cpp" line="129"/>
       <source>Point formats</source>
-      <translation type="unfinished">Point formats</translation>
+      <translation>Pisteen muodot</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="79"/>
+      <location filename="../../Command.cpp" line="81"/>
       <location filename="../../Command.cpp" line="129"/>
       <source>All Files</source>
       <translation>Kaikki tiedostot</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="200"/>
+      <location filename="../../Command.cpp" line="202"/>
       <source>Distance</source>
       <translation>Etäisyys</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="201"/>
+      <location filename="../../Command.cpp" line="203"/>
       <source>Enter maximum distance:</source>
-      <translation type="unfinished">Enter maximum distance:</translation>
+      <translation>Syötä enimmäisetäisyys:</translation>
     </message>
   </context>
   <context>
