@@ -1,5 +1,5 @@
  /***************************************************************************
- *   Copyright (c) Jürgen Riegel          (juergen.riegel@web.de) 2002     *
+ *   Copyright (c) 2002 Jürgen Riegel <juergen.riegel@web.de>              *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -63,7 +63,7 @@
 #include <Mod/Raytracing/App/RayProject.h>
 #include <Mod/Raytracing/App/LuxProject.h>
 #include <Mod/Part/App/PartFeature.h>
-  
+
 #include "FreeCADpov.h"
 
 
@@ -73,7 +73,7 @@
 //===========================================================================
 // CmdRaytracingWriteCamera
 //===========================================================================
-DEF_STD_CMD_A(CmdRaytracingWriteCamera);
+DEF_STD_CMD_A(CmdRaytracingWriteCamera)
 
 CmdRaytracingWriteCamera::CmdRaytracingWriteCamera()
   :Command("Raytracing_WriteCamera")
@@ -94,11 +94,11 @@ void CmdRaytracingWriteCamera::activated(int)
     if (ppReturn) {
         std::string str(ppReturn);
         if (str.find("PerspectiveCamera") == std::string::npos) {
-            int ret = QMessageBox::warning(Gui::getMainWindow(), 
+            int ret = QMessageBox::warning(Gui::getMainWindow(),
                 qApp->translate("CmdRaytracingWriteView","No perspective camera"),
                 qApp->translate("CmdRaytracingWriteView","The current view camera is not perspective"
-                                " and thus the result of the POV-Ray image later might look different to"
-                                " what you expect.\nDo you want to continue?"),
+                                " and thus resulting in a POV-Ray image that may look different than"
+                                " what was expected.\nDo you want to continue?"),
                 QMessageBox::Yes|QMessageBox::No);
             if (ret != QMessageBox::Yes)
                 return;
@@ -135,18 +135,18 @@ void CmdRaytracingWriteCamera::activated(int)
         filter << QString::fromLatin1("%1 (*.pov)").arg(QObject::tr("POV-Ray"));
         filter << QString::fromLatin1("%1 (*.*)").arg(QObject::tr("All Files"));
         QString fn = Gui::FileDialog::getSaveFileName(Gui::getMainWindow(), QObject::tr("Export page"), QString(), filter.join(QLatin1String(";;")));
-        if (fn.isEmpty()) 
+        if (fn.isEmpty())
             return;
         std::string cFullName = (const char*)fn.toUtf8();
 
         // building up the python string
         std::stringstream out;
-        out << "Raytracing.writeCameraFile(\"" << strToPython(cFullName) << "\"," 
-            << "(" << pos.getValue()[0]    <<"," << pos.getValue()[1]    <<"," << pos.getValue()[2]    <<")," 
+        out << "Raytracing.writeCameraFile(\"" << strToPython(cFullName) << "\","
+            << "(" << pos.getValue()[0]    <<"," << pos.getValue()[1]    <<"," << pos.getValue()[2]    <<"),"
             << "(" << lookat.getValue()[0] <<"," << lookat.getValue()[1] <<"," << lookat.getValue()[2] <<")," ;
         lookat *= Dist;
         lookat += pos;
-        out << "(" << lookat.getValue()[0] <<"," << lookat.getValue()[1] <<"," << lookat.getValue()[2] <<")," 
+        out << "(" << lookat.getValue()[0] <<"," << lookat.getValue()[1] <<"," << lookat.getValue()[2] <<"),"
             << "(" << upvec.getValue()[0]  <<"," << upvec.getValue()[1]  <<"," << upvec.getValue()[2]  <<") )" ;
 
         doCommand(Doc,"import Raytracing");
@@ -166,7 +166,7 @@ bool CmdRaytracingWriteCamera::isActive(void)
 //===========================================================================
 // CmdRaytracingWritePart
 //===========================================================================
-DEF_STD_CMD_A(CmdRaytracingWritePart);
+DEF_STD_CMD_A(CmdRaytracingWritePart)
 
 CmdRaytracingWritePart::CmdRaytracingWritePart()
   :Command("Raytracing_WritePart")
@@ -186,7 +186,7 @@ void CmdRaytracingWritePart::activated(int)
     filter << QString::fromLatin1("%1 (*.pov)").arg(QObject::tr("POV-Ray"));
     filter << QString::fromLatin1("%1 (*.*)").arg(QObject::tr("All Files"));
     QString fn = Gui::FileDialog::getSaveFileName(Gui::getMainWindow(), QObject::tr("Export page"), QString(), filter.join(QLatin1String(";;")));
-    if (fn.isEmpty()) 
+    if (fn.isEmpty())
         return;
     std::string cFullName = (const char*)fn.toUtf8();
 
@@ -212,7 +212,7 @@ bool CmdRaytracingWritePart::isActive(void)
 //===========================================================================
 // CmdRaytracingWriteView
 //===========================================================================
-DEF_STD_CMD_A(CmdRaytracingWriteView);
+DEF_STD_CMD_A(CmdRaytracingWriteView)
 
 CmdRaytracingWriteView::CmdRaytracingWriteView()
   :Command("Raytracing_WriteView")
@@ -233,11 +233,11 @@ void CmdRaytracingWriteView::activated(int)
     if (ppReturn) {
         std::string str(ppReturn);
         if (str.find("PerspectiveCamera") == std::string::npos) {
-            int ret = QMessageBox::warning(Gui::getMainWindow(), 
+            int ret = QMessageBox::warning(Gui::getMainWindow(),
                 qApp->translate("CmdRaytracingWriteView","No perspective camera"),
                 qApp->translate("CmdRaytracingWriteView","The current view camera is not perspective"
-                                " and thus the result of the POV-Ray image later might look different to"
-                                " what you expect.\nDo you want to continue?"),
+                                " and thus resulting in a POV-Ray image that may look different than"
+                                " what was expected.\nDo you want to continue?"),
                 QMessageBox::Yes|QMessageBox::No);
             if (ret != QMessageBox::Yes)
                 return;
@@ -249,9 +249,10 @@ void CmdRaytracingWriteView::activated(int)
     filter << QString::fromLatin1("%1 (*.*)").arg(QObject::tr("All Files"));
     QString fn = Gui::FileDialog::getSaveFileName(Gui::getMainWindow(),
         QObject::tr("Export page"), QString(), filter.join(QLatin1String(";;")));
-    if (fn.isEmpty()) 
+    if (fn.isEmpty())
         return;
     std::string cFullName = (const char*)fn.toUtf8();
+    cFullName = strToPython(cFullName);
 
 
     // get all objects of the active document
@@ -274,9 +275,11 @@ void CmdRaytracingWriteView::activated(int)
             Gui::ViewProvider* vp = getActiveGuiDocument()->getViewProvider(*it);
             if (vp && vp->isVisible()) {
                 App::PropertyColor *pcColor = dynamic_cast<App::PropertyColor *>(vp->getPropertyByName("ShapeColor"));
-                App::Color col = pcColor->getValue();
-                doCommand(Doc,"content += Raytracing.getPartAsPovray('%s',App.activeDocument().%s.Shape,%f,%f,%f)",
-                         (*it)->getNameInDocument(),(*it)->getNameInDocument(),col.r,col.g,col.b);
+                if (pcColor) {
+                    App::Color col = pcColor->getValue();
+                    doCommand(Doc,"content += Raytracing.getPartAsPovray('%s',App.activeDocument().%s.Shape,%f,%f,%f)",
+                             (*it)->getNameInDocument(),(*it)->getNameInDocument(),col.r,col.g,col.b);
+                }
             }
         }
         doCommand(Doc,"result = result.replace('//RaytracingContent',content)");
@@ -309,7 +312,7 @@ bool CmdRaytracingWriteView::isActive(void)
 // Raytracing_NewPovrayProject
 //===========================================================================
 
-DEF_STD_CMD_AC(CmdRaytracingNewPovrayProject);
+DEF_STD_CMD_AC(CmdRaytracingNewPovrayProject)
 
 CmdRaytracingNewPovrayProject::CmdRaytracingNewPovrayProject()
   : Command("Raytracing_NewPovrayProject")
@@ -330,11 +333,11 @@ void CmdRaytracingNewPovrayProject::activated(int iMsg)
     if (ppReturn) {
         std::string str(ppReturn);
         if (str.find("PerspectiveCamera") == std::string::npos) {
-            int ret = QMessageBox::warning(Gui::getMainWindow(), 
+            int ret = QMessageBox::warning(Gui::getMainWindow(),
                 qApp->translate("CmdRaytracingWriteView","No perspective camera"),
                 qApp->translate("CmdRaytracingWriteView","The current view camera is not perspective"
-                                " and thus the result of the POV-Ray image later might look different to"
-                                " what you expect.\nDo you want to continue?"),
+                                " and thus resulting in a POV-Ray image that may look different than"
+                                " what was expected.\nDo you want to continue?"),
                 QMessageBox::Yes|QMessageBox::No);
             if (ret != QMessageBox::Yes)
                 return;
@@ -426,7 +429,7 @@ bool CmdRaytracingNewPovrayProject::isActive(void)
 // Raytracing_NewPartView
 //===========================================================================
 
-DEF_STD_CMD_A(CmdRaytracingNewPartSegment);
+DEF_STD_CMD_A(CmdRaytracingNewPartSegment)
 
 CmdRaytracingNewPartSegment::CmdRaytracingNewPartSegment()
   : Command("Raytracing_NewPartSegment")
@@ -509,7 +512,7 @@ bool CmdRaytracingNewPartSegment::isActive(void)
 // Raytracing_ExportProject
 //===========================================================================
 
-DEF_STD_CMD_A(CmdRaytracingExportProject);
+DEF_STD_CMD_A(CmdRaytracingExportProject)
 
 CmdRaytracingExportProject::CmdRaytracingExportProject()
   : Command("Raytracing_ExportProject")
@@ -554,6 +557,7 @@ void CmdRaytracingExportProject::activated(int)
 
         doCommand(Doc,"PageFile = open(App.activeDocument().%s.PageResult,'r')",Sel[0].FeatName);
         std::string fname = (const char*)fn.toUtf8();
+        fname = strToPython(fname);
 #if PY_MAJOR_VERSION < 3
         doCommand(Doc,"OutFile = open(unicode('%s','utf-8'),'w')",fname.c_str());
 #else
@@ -576,7 +580,7 @@ bool CmdRaytracingExportProject::isActive(void)
 // Raytracing_Render
 //===========================================================================
 
-DEF_STD_CMD_A(CmdRaytracingRender);
+DEF_STD_CMD_A(CmdRaytracingRender)
 
 CmdRaytracingRender::CmdRaytracingRender()
   : Command("Raytracing_Render")
@@ -607,7 +611,7 @@ void CmdRaytracingRender::activated(int)
     } else {
         renderType = Raytracing::RayProject::getClassTypeId();
     }
-    
+
     // checking if renderer is present
     ParameterGrp::handle hGrp = App::GetApplication().GetParameterGroupByPath("User parameter:BaseApp/Preferences/Mod/Raytracing");
     std::string renderer;
@@ -640,9 +644,9 @@ void CmdRaytracingRender::activated(int)
             }
         }
     }
-    
+
     std::vector<Gui::SelectionObject> Sel = getSelection().getSelectionEx(0, renderType);
-    
+
     if (renderType == Raytracing::RayProject::getClassTypeId()) {
         Raytracing::RayProject* proj = static_cast<Raytracing::RayProject*>(Sel[0].getObject());
         QFileInfo fi(QString::fromUtf8(proj->PageResult.getValue()));
@@ -729,7 +733,7 @@ void CmdRaytracingRender::activated(int)
         doCommand(Doc,"f.write(PageFile.read())");
         doCommand(Doc,"f.close()");
         doCommand(Doc,"subprocess.Popen([\"%s\",TempFile])",renderer.c_str());
-        doCommand(Doc,"del TempFile,PageFile");            
+        doCommand(Doc,"del TempFile,PageFile");
         commitCommand();
     }
 }
@@ -743,7 +747,7 @@ bool CmdRaytracingRender::isActive(void)
 // Raytracing_NewLuxProject
 //===========================================================================
 
-DEF_STD_CMD_AC(CmdRaytracingNewLuxProject);
+DEF_STD_CMD_AC(CmdRaytracingNewLuxProject)
 
 CmdRaytracingNewLuxProject::CmdRaytracingNewLuxProject()
   : Command("Raytracing_NewLuxProject")
@@ -764,11 +768,11 @@ void CmdRaytracingNewLuxProject::activated(int iMsg)
     if (ppReturn) {
         std::string str(ppReturn);
         if (str.find("PerspectiveCamera") == std::string::npos) {
-            int ret = QMessageBox::warning(Gui::getMainWindow(), 
+            int ret = QMessageBox::warning(Gui::getMainWindow(),
                 qApp->translate("CmdRaytracingWriteView","No perspective camera"),
                 qApp->translate("CmdRaytracingWriteView","The current view camera is not perspective"
-                                " and thus the result of the luxrender image later might look different to"
-                                " what you expect.\nDo you want to continue?"),
+                                " and thus resulting in a luxrender image that may look different than"
+                                " what was expected.\nDo you want to continue?"),
                 QMessageBox::Yes|QMessageBox::No);
             if (ret != QMessageBox::Yes)
                 return;
@@ -855,7 +859,7 @@ bool CmdRaytracingNewLuxProject::isActive(void)
 // Raytracing_ResetCamera
 //===========================================================================
 
-DEF_STD_CMD_A(CmdRaytracingResetCamera);
+DEF_STD_CMD_A(CmdRaytracingResetCamera)
 
 CmdRaytracingResetCamera::CmdRaytracingResetCamera()
   : Command("Raytracing_ResetCamera")
