@@ -1,20 +1,20 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="ar" sourcelanguage="en">
+<TS version="2.1" language="ar" sourcelanguage="en">
   <context>
     <name>CmdRaytracingExportProject</name>
     <message>
-      <location filename="../../Command.cpp" line="519"/>
+      <location filename="../../Command.cpp" line="522"/>
       <source>File</source>
       <translation>ملف</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="520"/>
+      <location filename="../../Command.cpp" line="523"/>
       <source>&amp;Export project...</source>
       <translation>&amp; تصدير المشروع...</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="521"/>
+      <location filename="../../Command.cpp" line="524"/>
       <source>Export a Raytracing project to a file</source>
       <translation>تصدير مشروع Raytracing إلى ملف</translation>
     </message>
@@ -22,27 +22,27 @@
   <context>
     <name>CmdRaytracingNewLuxProject</name>
     <message>
-      <location filename="../../Command.cpp" line="752"/>
+      <location filename="../../Command.cpp" line="756"/>
       <source>Raytracing</source>
       <translation>Raytracing</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="753"/>
+      <location filename="../../Command.cpp" line="757"/>
       <source>New Luxrender project</source>
       <translation>مشروع Luxrender جديد</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="754"/>
+      <location filename="../../Command.cpp" line="758"/>
       <source>Insert new Luxrender project into the document</source>
       <translation>إدراج مشروع Luxrender جديد في المستند</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="806"/>
+      <location filename="../../Command.cpp" line="810"/>
       <source>No template</source>
       <translation>لا يوجد قالب</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="807"/>
+      <location filename="../../Command.cpp" line="811"/>
       <source>No template available</source>
       <translation>لا يوجد قالب متاح</translation>
     </message>
@@ -50,17 +50,17 @@
   <context>
     <name>CmdRaytracingNewPartSegment</name>
     <message>
-      <location filename="../../Command.cpp" line="435"/>
+      <location filename="../../Command.cpp" line="438"/>
       <source>Raytracing</source>
       <translation>Raytracing</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="436"/>
+      <location filename="../../Command.cpp" line="439"/>
       <source>Insert part</source>
       <translation>إدراج جزء</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="437"/>
+      <location filename="../../Command.cpp" line="440"/>
       <source>Insert a new part object into a Raytracing project</source>
       <translation>إدراج جزء كائن جديد في مشروع Raytracing</translation>
     </message>
@@ -68,27 +68,27 @@
   <context>
     <name>CmdRaytracingNewPovrayProject</name>
     <message>
-      <location filename="../../Command.cpp" line="318"/>
+      <location filename="../../Command.cpp" line="321"/>
       <source>Raytracing</source>
       <translation>Raytracing</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="319"/>
+      <location filename="../../Command.cpp" line="322"/>
       <source>New POV-Ray project</source>
       <translation>مشروع POV-Ray جديد</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="320"/>
+      <location filename="../../Command.cpp" line="323"/>
       <source>Insert new POV-Ray project into the document</source>
       <translation>إدراج مشروع POV-Ray جديد في المستند</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="372"/>
+      <location filename="../../Command.cpp" line="375"/>
       <source>No template</source>
       <translation>لا يوجد قالب</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="373"/>
+      <location filename="../../Command.cpp" line="376"/>
       <source>No template available</source>
       <translation>لا يوجد قالب متاح</translation>
     </message>
@@ -96,17 +96,17 @@
   <context>
     <name>CmdRaytracingRender</name>
     <message>
-      <location filename="../../Command.cpp" line="585"/>
+      <location filename="../../Command.cpp" line="589"/>
       <source>Raytracing</source>
       <translation>Raytracing</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="586"/>
+      <location filename="../../Command.cpp" line="590"/>
       <source>&amp;Render</source>
       <translation>&amp; تقديم</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="587"/>
+      <location filename="../../Command.cpp" line="591"/>
       <source>Renders the current raytracing project with an external renderer</source>
       <translation>يعرض المشروع raytracing الحالي مع عارض خارجي</translation>
     </message>
@@ -114,17 +114,17 @@
   <context>
     <name>CmdRaytracingResetCamera</name>
     <message>
-      <location filename="../../Command.cpp" line="865"/>
+      <location filename="../../Command.cpp" line="869"/>
       <source>Raytracing</source>
       <translation>Raytracing</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="866"/>
+      <location filename="../../Command.cpp" line="870"/>
       <source>&amp;Reset Camera</source>
       <translation>&amp;إعادة تعيين الكاميرا</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="867"/>
+      <location filename="../../Command.cpp" line="871"/>
       <source>Sets the camera of the selected Raytracing project to match the current view</source>
       <translation>تعيين الكاميرا الخاصة بالمشروع Raytracing المحدد لتتناسب مع طريقة العرض الحالية</translation>
     </message>
@@ -170,19 +170,19 @@
     <message>
       <location filename="../../Command.cpp" line="98"/>
       <location filename="../../Command.cpp" line="237"/>
-      <location filename="../../Command.cpp" line="334"/>
-      <location filename="../../Command.cpp" line="768"/>
+      <location filename="../../Command.cpp" line="337"/>
+      <location filename="../../Command.cpp" line="772"/>
       <source>No perspective camera</source>
       <translation>لا كاميرا منظور</translation>
     </message>
     <message>
       <location filename="../../Command.cpp" line="99"/>
       <location filename="../../Command.cpp" line="238"/>
-      <location filename="../../Command.cpp" line="335"/>
-      <source>The current view camera is not perspective and thus the result of the POV-Ray image later might look different to what you expect.
+      <location filename="../../Command.cpp" line="338"/>
+      <source>The current view camera is not perspective and thus resulting in a POV-Ray image that may look different than what was expected.
 Do you want to continue?</source>
-      <translation>عرض الكاميرا الحالية ليس من المنظور وذلك نتيجة للصورة POV-Ray في وقت لاحق قد تبدو مختلفة لما كنت تتوقع. 
-هل تريد الاستمرار؟</translation>
+      <translation type="unfinished">The current view camera is not perspective and thus resulting in a POV-Ray image that may look different than what was expected.
+Do you want to continue?</translation>
     </message>
     <message>
       <location filename="../../Command.cpp" line="221"/>
@@ -200,23 +200,23 @@ Do you want to continue?</source>
       <translation>اكتب العرض ثلاثي الأبعاد النشط مع الكاميرا وجميع محتوياتها إلى ملف POV-Ray</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="349"/>
-      <location filename="../../Command.cpp" line="783"/>
+      <location filename="../../Command.cpp" line="352"/>
+      <location filename="../../Command.cpp" line="787"/>
       <source>No template</source>
       <translation>لا يوجد قالب</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="350"/>
-      <location filename="../../Command.cpp" line="784"/>
+      <location filename="../../Command.cpp" line="353"/>
+      <location filename="../../Command.cpp" line="788"/>
       <source>Cannot create a project because there is no template installed.</source>
-      <translation type="unfinished">Cannot create a project because there is no template installed.</translation>
+      <translation>لا يمكن عمل مشروع لأنه لم يتم تحميل أي قالب.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="769"/>
-      <source>The current view camera is not perspective and thus the result of the luxrender image later might look different to what you expect.
+      <location filename="../../Command.cpp" line="773"/>
+      <source>The current view camera is not perspective and thus resulting in a luxrender image that may look different than what was expected.
 Do you want to continue?</source>
-      <translation>عرض الكاميرا الحالية ليس من المنظور وذلك نتيجة للصورة luxrender في وقت لاحق قد تبدو مختلفة لما كنت تتوقع.
- هل تريد الاستمرار؟</translation>
+      <translation type="unfinished">The current view camera is not perspective and thus resulting in a luxrender image that may look different than what was expected.
+Do you want to continue?</translation>
     </message>
   </context>
   <context>
@@ -225,7 +225,7 @@ Do you want to continue?</source>
       <location filename="../../Command.cpp" line="135"/>
       <location filename="../../Command.cpp" line="186"/>
       <location filename="../../Command.cpp" line="248"/>
-      <location filename="../../Command.cpp" line="543"/>
+      <location filename="../../Command.cpp" line="546"/>
       <source>POV-Ray</source>
       <translation>POV-Ray</translation>
     </message>
@@ -233,8 +233,8 @@ Do you want to continue?</source>
       <location filename="../../Command.cpp" line="136"/>
       <location filename="../../Command.cpp" line="187"/>
       <location filename="../../Command.cpp" line="249"/>
-      <location filename="../../Command.cpp" line="548"/>
-      <location filename="../../Command.cpp" line="661"/>
+      <location filename="../../Command.cpp" line="551"/>
+      <location filename="../../Command.cpp" line="665"/>
       <source>All Files</source>
       <translation>كل الملفات</translation>
     </message>
@@ -242,107 +242,107 @@ Do you want to continue?</source>
       <location filename="../../Command.cpp" line="137"/>
       <location filename="../../Command.cpp" line="188"/>
       <location filename="../../Command.cpp" line="251"/>
-      <location filename="../../Command.cpp" line="550"/>
+      <location filename="../../Command.cpp" line="553"/>
       <source>Export page</source>
       <translation>تصدير الصفحة</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="447"/>
-      <location filename="../../Command.cpp" line="534"/>
-      <location filename="../../Command.cpp" line="601"/>
-      <location filename="../../Command.cpp" line="879"/>
+      <location filename="../../Command.cpp" line="450"/>
+      <location filename="../../Command.cpp" line="537"/>
+      <location filename="../../Command.cpp" line="605"/>
+      <location filename="../../Command.cpp" line="883"/>
       <source>Wrong selection</source>
       <translation>إختيار خاطئ</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="448"/>
+      <location filename="../../Command.cpp" line="451"/>
       <source>Select a Part object.</source>
       <translation>قم بتحديد عنصر قطعة.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="458"/>
-      <location filename="../../Command.cpp" line="470"/>
+      <location filename="../../Command.cpp" line="461"/>
+      <location filename="../../Command.cpp" line="473"/>
       <source>No Raytracing project to insert</source>
       <translation>لا يوجد مشروع Raytracing لإدراجه</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="459"/>
+      <location filename="../../Command.cpp" line="462"/>
       <source>Create a Raytracing project to insert a view.</source>
       <translation>إنشاء مشروع Raytracing لإدراج طريقة العرض.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="471"/>
+      <location filename="../../Command.cpp" line="474"/>
       <source>Select a Raytracing project to insert the view.</source>
       <translation>حدد مشروع Raytracing لإدراجه في طريقة العرض.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="535"/>
-      <location filename="../../Command.cpp" line="602"/>
-      <location filename="../../Command.cpp" line="880"/>
+      <location filename="../../Command.cpp" line="538"/>
+      <location filename="../../Command.cpp" line="606"/>
+      <location filename="../../Command.cpp" line="884"/>
       <source>Select one Raytracing project object.</source>
       <translation>حدد كائن مشروع Raytracing واحد.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="539"/>
+      <location filename="../../Command.cpp" line="542"/>
       <source>Luxrender</source>
       <translation>Luxrender</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="617"/>
-      <location filename="../../Command.cpp" line="623"/>
+      <location filename="../../Command.cpp" line="621"/>
+      <location filename="../../Command.cpp" line="627"/>
       <source>POV-Ray not found</source>
       <translation>لم يتم العثور على POV-Ray</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="618"/>
+      <location filename="../../Command.cpp" line="622"/>
       <source>Please set the path to the POV-Ray executable in the preferences.</source>
       <translation>الرجاء تعيين المسار إلى الملف التنفيذي POV-Ray في التفضيلات.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="624"/>
+      <location filename="../../Command.cpp" line="628"/>
       <source>Please correct the path to the POV-Ray executable in the preferences.</source>
       <translation>الرجاء تصحيح المسار إلى الملف التنفيذي POV-Ray في التفضيلات.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="631"/>
-      <location filename="../../Command.cpp" line="637"/>
+      <location filename="../../Command.cpp" line="635"/>
+      <location filename="../../Command.cpp" line="641"/>
       <source>Luxrender not found</source>
       <translation>لم يتم العثور على Luxrender</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="632"/>
+      <location filename="../../Command.cpp" line="636"/>
       <source>Please set the path to the luxrender or luxconsole executable in the preferences.</source>
       <translation>الرجاء تعيين المسار إلى luxrender أو luxconsole القابل للتنفيذ في التفضيلات.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="638"/>
+      <location filename="../../Command.cpp" line="642"/>
       <source>Please correct the path to the luxrender or luxconsole executable in the preferences.</source>
       <translation>الرجاء تصحيح المسار إلى luxrender أو luxconsole القابل للتنفيذ في التفضيلات.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="650"/>
+      <location filename="../../Command.cpp" line="654"/>
       <source>POV-Ray file missing</source>
       <translation>ملف POV-Ray مفقود</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="651"/>
+      <location filename="../../Command.cpp" line="655"/>
       <source>The POV-Ray project file doesn't exist.</source>
       <translation>لا يوجد ملف المشروع POV-Ray.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="657"/>
-      <location filename="../../Command.cpp" line="659"/>
-      <location filename="../../Command.cpp" line="662"/>
+      <location filename="../../Command.cpp" line="661"/>
+      <location filename="../../Command.cpp" line="663"/>
+      <location filename="../../Command.cpp" line="666"/>
       <source>Rendered image</source>
       <translation>الصورة المعروضة</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="719"/>
+      <location filename="../../Command.cpp" line="723"/>
       <source>Lux project file missing</source>
       <translation>ملف مشروع لوكس مفقود</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="720"/>
+      <location filename="../../Command.cpp" line="724"/>
       <source>The Lux project file doesn't exist.</source>
       <translation>لا يوجد ملف المشروع لوكس.</translation>
     </message>
@@ -380,98 +380,101 @@ Do you want to continue?</source>
       <translation>تقديم</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="117"/>
-      <source>The path to the POV-Ray executable, if you want to render from FreeCAD</source>
-      <translation>المسار إلى الملف التنفيذي POV-Ray، إذا كنت ترغب في تقديم من فريكاد</translation>
-    </message>
-    <message>
-      <location filename="../../DlgSettingsRay.ui" line="130"/>
+      <location filename="../../DlgSettingsRay.ui" line="127"/>
       <source>POV-Ray executable:</source>
       <translation>POV-Ray الملف القابل للتنفيذ:</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="137"/>
+      <location filename="../../DlgSettingsRay.ui" line="134"/>
       <source>POV-Ray output parameters:</source>
       <translation>معلمات الإخراج POV-Ray:</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="146"/>
+      <location filename="../../DlgSettingsRay.ui" line="143"/>
       <source>The POV-Ray parameters to be passed to the render.</source>
       <translation>لمعلمات POV-Ray لتمريرها إلى التجسيد.</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="149"/>
+      <location filename="../../DlgSettingsRay.ui" line="146"/>
       <source>+P +A</source>
       <translation>+P +A</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="162"/>
+      <location filename="../../DlgSettingsRay.ui" line="159"/>
       <source>+W: </source>
       <translation>+W: </translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="169"/>
+      <location filename="../../DlgSettingsRay.ui" line="166"/>
       <source>The width of the rendered image</source>
       <translation>عرض الصورة المقدمة</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="188"/>
+      <location filename="../../DlgSettingsRay.ui" line="185"/>
       <source> +H : </source>
       <translation> +H : </translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="195"/>
+      <location filename="../../DlgSettingsRay.ui" line="192"/>
       <source>The height of the rendered image</source>
       <translation>ارتفاع الصورة المقدمة</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="216"/>
+      <location filename="../../DlgSettingsRay.ui" line="213"/>
       <source>Luxrender executable:</source>
       <translation>Luxrender الملف القابل للتنفيذ:</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="223"/>
+      <location filename="../../DlgSettingsRay.ui" line="220"/>
       <source>The path to the luxrender (or luxconsole) executable</source>
       <translation>مسار luxrender (أو luxconsole) القابل للتنفيذ</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="241"/>
+      <location filename="../../DlgSettingsRay.ui" line="238"/>
       <source>Directories</source>
       <translation>المسارات</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="261"/>
+      <location filename="../../DlgSettingsRay.ui" line="258"/>
       <source>Part file name:</source>
       <translation>اسم جزء الملف:</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="268"/>
+      <location filename="../../DlgSettingsRay.ui" line="265"/>
       <source>Camera file name:</source>
       <translation>اسم ملف الكاميرا:</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="278"/>
-      <location filename="../../DlgSettingsRay.ui" line="301"/>
-      <location filename="../../DlgSettingsRay.ui" line="317"/>
+      <location filename="../../DlgSettingsRay.ui" line="275"/>
+      <location filename="../../DlgSettingsRay.ui" line="298"/>
+      <location filename="../../DlgSettingsRay.ui" line="314"/>
       <source>Used by utility tools</source>
       <translation>المستخدمة من قبل أدوات الأداة المساعدة</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="294"/>
+      <location filename="../../DlgSettingsRay.ui" line="291"/>
       <source>Default Project dir:</source>
       <translation>دليل المشروع الافتراضي:</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="304"/>
+      <location filename="../../DlgSettingsRay.ui" line="301"/>
       <source>TempCamera.inc</source>
       <translation>TempCamera.inc</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="320"/>
+      <location filename="../../DlgSettingsRay.ui" line="317"/>
       <source>TempPart.inc</source>
       <translation>TempPart.inc</translation>
     </message>
   </context>
+  <context>
+    <name>RaytracingGui::DlgSettingsRayImp</name>
+    <message>
+      <location filename="../../DlgSettingsRayImp.cpp" line="47"/>
+      <source>The path to the POV-Ray executable, if you want to render from %1</source>
+      <translation type="unfinished">The path to the POV-Ray executable, if you want to render from %1</translation>
+    </message>
+  </context>
   <context>
     <name>RaytracingGui::ViewProviderLux</name>
     <message>
@@ -493,17 +496,17 @@ Do you want to continue?</source>
   <context>
     <name>RaytracingGui::ViewProviderPovray</name>
     <message>
-      <location filename="../../ViewProvider.cpp" line="146"/>
+      <location filename="../../ViewProvider.cpp" line="147"/>
       <source>Edit Povray project</source>
       <translation>تحرير المشروع Povray</translation>
     </message>
     <message>
-      <location filename="../../ViewProvider.cpp" line="177"/>
+      <location filename="../../ViewProvider.cpp" line="178"/>
       <source>Povray template</source>
       <translation>قالب Povray</translation>
     </message>
     <message>
-      <location filename="../../ViewProvider.cpp" line="177"/>
+      <location filename="../../ViewProvider.cpp" line="178"/>
       <source>Select a Povray template</source>
       <translation>حدد قالب Povray</translation>
     </message>
