@@ -1,20 +1,20 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="tr" sourcelanguage="en">
+<TS version="2.1" language="tr" sourcelanguage="en">
   <context>
     <name>CmdRaytracingExportProject</name>
     <message>
-      <location filename="../../Command.cpp" line="519"/>
+      <location filename="../../Command.cpp" line="522"/>
       <source>File</source>
       <translation>Dosya</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="520"/>
+      <location filename="../../Command.cpp" line="523"/>
       <source>&amp;Export project...</source>
       <translation>Proje dosyasını &amp;Dışarı aktar...</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="521"/>
+      <location filename="../../Command.cpp" line="524"/>
       <source>Export a Raytracing project to a file</source>
       <translation>Raytracing proje verme</translation>
     </message>
@@ -22,27 +22,27 @@
   <context>
     <name>CmdRaytracingNewLuxProject</name>
     <message>
-      <location filename="../../Command.cpp" line="752"/>
+      <location filename="../../Command.cpp" line="756"/>
       <source>Raytracing</source>
       <translation>Işın izleme</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="753"/>
+      <location filename="../../Command.cpp" line="757"/>
       <source>New Luxrender project</source>
       <translation>Yeni Luxrender projesi</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="754"/>
+      <location filename="../../Command.cpp" line="758"/>
       <source>Insert new Luxrender project into the document</source>
       <translation>Belgeye yeni Luxrender projesi ekleme</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="806"/>
+      <location filename="../../Command.cpp" line="810"/>
       <source>No template</source>
       <translation>Şablon yok</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="807"/>
+      <location filename="../../Command.cpp" line="811"/>
       <source>No template available</source>
       <translation>Mevcut şablon yok</translation>
     </message>
@@ -50,17 +50,17 @@
   <context>
     <name>CmdRaytracingNewPartSegment</name>
     <message>
-      <location filename="../../Command.cpp" line="435"/>
+      <location filename="../../Command.cpp" line="438"/>
       <source>Raytracing</source>
       <translation>Işın izleme</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="436"/>
+      <location filename="../../Command.cpp" line="439"/>
       <source>Insert part</source>
       <translation>Parça yerleştir</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="437"/>
+      <location filename="../../Command.cpp" line="440"/>
       <source>Insert a new part object into a Raytracing project</source>
       <translation>Raytracing projesine yeni bir parça nesnesi ekleme</translation>
     </message>
@@ -68,27 +68,27 @@
   <context>
     <name>CmdRaytracingNewPovrayProject</name>
     <message>
-      <location filename="../../Command.cpp" line="318"/>
+      <location filename="../../Command.cpp" line="321"/>
       <source>Raytracing</source>
       <translation>Işın izleme</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="319"/>
+      <location filename="../../Command.cpp" line="322"/>
       <source>New POV-Ray project</source>
       <translation>Yeni POV-Ray projesi</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="320"/>
+      <location filename="../../Command.cpp" line="323"/>
       <source>Insert new POV-Ray project into the document</source>
       <translation>Belgeye yeni POV-Ray projesi ekleyin</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="372"/>
+      <location filename="../../Command.cpp" line="375"/>
       <source>No template</source>
       <translation>Şablon yok</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="373"/>
+      <location filename="../../Command.cpp" line="376"/>
       <source>No template available</source>
       <translation>Mevcut şablon yok</translation>
     </message>
@@ -96,17 +96,17 @@
   <context>
     <name>CmdRaytracingRender</name>
     <message>
-      <location filename="../../Command.cpp" line="585"/>
+      <location filename="../../Command.cpp" line="589"/>
       <source>Raytracing</source>
       <translation>Işın izleme</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="586"/>
+      <location filename="../../Command.cpp" line="590"/>
       <source>&amp;Render</source>
-      <translation>&amp;Oluşturma</translation>
+      <translation>&amp;Render</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="587"/>
+      <location filename="../../Command.cpp" line="591"/>
       <source>Renders the current raytracing project with an external renderer</source>
       <translation>Geçerli ışın izleme projesini harici bir oluşturucu ile işler</translation>
     </message>
@@ -114,17 +114,17 @@
   <context>
     <name>CmdRaytracingResetCamera</name>
     <message>
-      <location filename="../../Command.cpp" line="865"/>
+      <location filename="../../Command.cpp" line="869"/>
       <source>Raytracing</source>
       <translation>Işın izleme</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="866"/>
+      <location filename="../../Command.cpp" line="870"/>
       <source>&amp;Reset Camera</source>
       <translation>Kamerayı Sıfırla</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="867"/>
+      <location filename="../../Command.cpp" line="871"/>
       <source>Sets the camera of the selected Raytracing project to match the current view</source>
       <translation>Seçilen Raytracing projesinin kamerasını geçerli görünüme uyacak şekilde ayarlar</translation>
     </message>
@@ -157,7 +157,7 @@
     <message>
       <location filename="../../Command.cpp" line="176"/>
       <source>Export part to POV-Ray...</source>
-      <translation>POV-Ray'e parça ver...</translation>
+      <translation>POV-Ray'e parça aktar...</translation>
     </message>
     <message>
       <location filename="../../Command.cpp" line="177"/>
@@ -170,19 +170,18 @@
     <message>
       <location filename="../../Command.cpp" line="98"/>
       <location filename="../../Command.cpp" line="237"/>
-      <location filename="../../Command.cpp" line="334"/>
-      <location filename="../../Command.cpp" line="768"/>
+      <location filename="../../Command.cpp" line="337"/>
+      <location filename="../../Command.cpp" line="772"/>
       <source>No perspective camera</source>
       <translation>Perspektif kamerası yok</translation>
     </message>
     <message>
       <location filename="../../Command.cpp" line="99"/>
       <location filename="../../Command.cpp" line="238"/>
-      <location filename="../../Command.cpp" line="335"/>
-      <source>The current view camera is not perspective and thus the result of the POV-Ray image later might look different to what you expect.
+      <location filename="../../Command.cpp" line="338"/>
+      <source>The current view camera is not perspective and thus resulting in a POV-Ray image that may look different than what was expected.
 Do you want to continue?</source>
-      <translation>Mevcut görüntüleme kamerası perspektif değildir ve bu nedenle POV-Ray görüntüsünün sonucu beklediğinizden farklı olabilir.
-Devam etmek istiyor musun?</translation>
+      <translation>Mevcut görünüm perspektif değildir ve bu durum POV-Ray görüntüsünün beklenenden farklı görünmesine neden olabilir. Devam etmek istiyor musunuz?</translation>
     </message>
     <message>
       <location filename="../../Command.cpp" line="221"/>
@@ -200,23 +199,22 @@ Devam etmek istiyor musun?</translation>
       <translation>Aktif 3B görünümünü kamera ve tüm içeriği ile POV-Ray dosyasına yazın</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="349"/>
-      <location filename="../../Command.cpp" line="783"/>
+      <location filename="../../Command.cpp" line="352"/>
+      <location filename="../../Command.cpp" line="787"/>
       <source>No template</source>
       <translation>Şablon yok</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="350"/>
-      <location filename="../../Command.cpp" line="784"/>
+      <location filename="../../Command.cpp" line="353"/>
+      <location filename="../../Command.cpp" line="788"/>
       <source>Cannot create a project because there is no template installed.</source>
       <translation>Yüklü şablon olmadığından bir proje oluşturulamaz.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="769"/>
-      <source>The current view camera is not perspective and thus the result of the luxrender image later might look different to what you expect.
+      <location filename="../../Command.cpp" line="773"/>
+      <source>The current view camera is not perspective and thus resulting in a luxrender image that may look different than what was expected.
 Do you want to continue?</source>
-      <translation>Mevcut görüntüleme kamerası perspektif değildir ve bu nedenle luxrender imgesinin sonucu beklediğinizden farklı olabilir.
-Devam etmek istiyor musun?</translation>
+      <translation>Mevcut görünüm perspektif değildir ve bu durum Luxrender görüntüsünün beklenenden farklı görünmesine neden olabilir. Devam etmek istiyor musunuz?</translation>
     </message>
   </context>
   <context>
@@ -225,7 +223,7 @@ Devam etmek istiyor musun?</translation>
       <location filename="../../Command.cpp" line="135"/>
       <location filename="../../Command.cpp" line="186"/>
       <location filename="../../Command.cpp" line="248"/>
-      <location filename="../../Command.cpp" line="543"/>
+      <location filename="../../Command.cpp" line="546"/>
       <source>POV-Ray</source>
       <translation>POV-Ray</translation>
     </message>
@@ -233,8 +231,8 @@ Devam etmek istiyor musun?</translation>
       <location filename="../../Command.cpp" line="136"/>
       <location filename="../../Command.cpp" line="187"/>
       <location filename="../../Command.cpp" line="249"/>
-      <location filename="../../Command.cpp" line="548"/>
-      <location filename="../../Command.cpp" line="661"/>
+      <location filename="../../Command.cpp" line="551"/>
+      <location filename="../../Command.cpp" line="665"/>
       <source>All Files</source>
       <translation>Tüm Dosyalar</translation>
     </message>
@@ -242,107 +240,107 @@ Devam etmek istiyor musun?</translation>
       <location filename="../../Command.cpp" line="137"/>
       <location filename="../../Command.cpp" line="188"/>
       <location filename="../../Command.cpp" line="251"/>
-      <location filename="../../Command.cpp" line="550"/>
+      <location filename="../../Command.cpp" line="553"/>
       <source>Export page</source>
       <translation>Sayfayı dışa aktar</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="447"/>
-      <location filename="../../Command.cpp" line="534"/>
-      <location filename="../../Command.cpp" line="601"/>
-      <location filename="../../Command.cpp" line="879"/>
+      <location filename="../../Command.cpp" line="450"/>
+      <location filename="../../Command.cpp" line="537"/>
+      <location filename="../../Command.cpp" line="605"/>
+      <location filename="../../Command.cpp" line="883"/>
       <source>Wrong selection</source>
       <translation>Yanlış seçim</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="448"/>
+      <location filename="../../Command.cpp" line="451"/>
       <source>Select a Part object.</source>
       <translation>Bölüm nesnesini seç</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="458"/>
-      <location filename="../../Command.cpp" line="470"/>
+      <location filename="../../Command.cpp" line="461"/>
+      <location filename="../../Command.cpp" line="473"/>
       <source>No Raytracing project to insert</source>
       <translation>Eklenecek Raytracing projesi yok</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="459"/>
+      <location filename="../../Command.cpp" line="462"/>
       <source>Create a Raytracing project to insert a view.</source>
       <translation>Bir görüntü eklemek için bir Raytracing projesi oluşturun.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="471"/>
+      <location filename="../../Command.cpp" line="474"/>
       <source>Select a Raytracing project to insert the view.</source>
       <translation>Görünümü eklemek için Raytracing projesi seçin.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="535"/>
-      <location filename="../../Command.cpp" line="602"/>
-      <location filename="../../Command.cpp" line="880"/>
+      <location filename="../../Command.cpp" line="538"/>
+      <location filename="../../Command.cpp" line="606"/>
+      <location filename="../../Command.cpp" line="884"/>
       <source>Select one Raytracing project object.</source>
       <translation>Bir Raytracing proje nesnesi seçin.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="539"/>
+      <location filename="../../Command.cpp" line="542"/>
       <source>Luxrender</source>
       <translation>Luxrender</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="617"/>
-      <location filename="../../Command.cpp" line="623"/>
+      <location filename="../../Command.cpp" line="621"/>
+      <location filename="../../Command.cpp" line="627"/>
       <source>POV-Ray not found</source>
       <translation>POV-Ray bulunamadı</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="618"/>
+      <location filename="../../Command.cpp" line="622"/>
       <source>Please set the path to the POV-Ray executable in the preferences.</source>
       <translation>Tercihlerdeki POV-Ray yürütülebilir dosyanın yolunu ayarlayın.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="624"/>
+      <location filename="../../Command.cpp" line="628"/>
       <source>Please correct the path to the POV-Ray executable in the preferences.</source>
       <translation>Lütfen tercihlerinizdeki POV-Ray yürütülebilir dosyanın yolunu düzeltin.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="631"/>
-      <location filename="../../Command.cpp" line="637"/>
+      <location filename="../../Command.cpp" line="635"/>
+      <location filename="../../Command.cpp" line="641"/>
       <source>Luxrender not found</source>
       <translation>Luxrender bulunamadı</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="632"/>
+      <location filename="../../Command.cpp" line="636"/>
       <source>Please set the path to the luxrender or luxconsole executable in the preferences.</source>
       <translation>Lütfen tercihlerde luxrender veya luxconsole yürütülebilir dosyanın yolunu ayarlayın.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="638"/>
+      <location filename="../../Command.cpp" line="642"/>
       <source>Please correct the path to the luxrender or luxconsole executable in the preferences.</source>
       <translation>Tercihlerdeki luxrender veya luxconsole yürütülebilir dosyanın yolunu düzeltin.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="650"/>
+      <location filename="../../Command.cpp" line="654"/>
       <source>POV-Ray file missing</source>
       <translation>POV-Ray dosyası eksik</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="651"/>
+      <location filename="../../Command.cpp" line="655"/>
       <source>The POV-Ray project file doesn't exist.</source>
       <translation>POV-Ray projesi dosyası mevcut değil.</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="657"/>
-      <location filename="../../Command.cpp" line="659"/>
-      <location filename="../../Command.cpp" line="662"/>
+      <location filename="../../Command.cpp" line="661"/>
+      <location filename="../../Command.cpp" line="663"/>
+      <location filename="../../Command.cpp" line="666"/>
       <source>Rendered image</source>
       <translation>Oluşturulan resim</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="719"/>
+      <location filename="../../Command.cpp" line="723"/>
       <source>Lux project file missing</source>
       <translation>Lux proje dosyası eksik</translation>
     </message>
     <message>
-      <location filename="../../Command.cpp" line="720"/>
+      <location filename="../../Command.cpp" line="724"/>
       <source>The Lux project file doesn't exist.</source>
       <translation>Lux proje dosyası mevcut değil.</translation>
     </message>
@@ -377,101 +375,104 @@ Devam etmek istiyor musun?</translation>
     <message>
       <location filename="../../DlgSettingsRay.ui" line="109"/>
       <source>Render</source>
-      <translation>Kılmak (hale getirmek, vermek)</translation>
+      <translation>İşle (Render)</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="117"/>
-      <source>The path to the POV-Ray executable, if you want to render from FreeCAD</source>
-      <translation>FreeCAD'den işlemek istiyorsanız POV-Ray yürütülebilir dosyanın yolu</translation>
-    </message>
-    <message>
-      <location filename="../../DlgSettingsRay.ui" line="130"/>
+      <location filename="../../DlgSettingsRay.ui" line="127"/>
       <source>POV-Ray executable:</source>
       <translation>POV-Ray çalıştırılabilir:</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="137"/>
+      <location filename="../../DlgSettingsRay.ui" line="134"/>
       <source>POV-Ray output parameters:</source>
       <translation>POV-Ray çıktı parametreleri:</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="146"/>
+      <location filename="../../DlgSettingsRay.ui" line="143"/>
       <source>The POV-Ray parameters to be passed to the render.</source>
       <translation>İşlenene aktarılacak POV-Ray parametreleri.</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="149"/>
+      <location filename="../../DlgSettingsRay.ui" line="146"/>
       <source>+P +A</source>
       <translation>+P +A</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="162"/>
+      <location filename="../../DlgSettingsRay.ui" line="159"/>
       <source>+W: </source>
       <translation>+W: </translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="169"/>
+      <location filename="../../DlgSettingsRay.ui" line="166"/>
       <source>The width of the rendered image</source>
       <translation>İşlenen görüntünün genişliği</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="188"/>
+      <location filename="../../DlgSettingsRay.ui" line="185"/>
       <source> +H : </source>
       <translation> +H : </translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="195"/>
+      <location filename="../../DlgSettingsRay.ui" line="192"/>
       <source>The height of the rendered image</source>
       <translation>İşlenen görüntünün yüksekliği</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="216"/>
+      <location filename="../../DlgSettingsRay.ui" line="213"/>
       <source>Luxrender executable:</source>
       <translation>Lüks çalıştırılabilir:</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="223"/>
+      <location filename="../../DlgSettingsRay.ui" line="220"/>
       <source>The path to the luxrender (or luxconsole) executable</source>
       <translation>Luxrender (veya luxconsole) yürütülebilir yolunun yolu</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="241"/>
+      <location filename="../../DlgSettingsRay.ui" line="238"/>
       <source>Directories</source>
       <translation>Dizinler</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="261"/>
+      <location filename="../../DlgSettingsRay.ui" line="258"/>
       <source>Part file name:</source>
       <translation>Parça dosya adı:</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="268"/>
+      <location filename="../../DlgSettingsRay.ui" line="265"/>
       <source>Camera file name:</source>
       <translation>Kamera dosya adı:</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="278"/>
-      <location filename="../../DlgSettingsRay.ui" line="301"/>
-      <location filename="../../DlgSettingsRay.ui" line="317"/>
+      <location filename="../../DlgSettingsRay.ui" line="275"/>
+      <location filename="../../DlgSettingsRay.ui" line="298"/>
+      <location filename="../../DlgSettingsRay.ui" line="314"/>
       <source>Used by utility tools</source>
       <translation>Yardımcı araçlarla kullanılır</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="294"/>
+      <location filename="../../DlgSettingsRay.ui" line="291"/>
       <source>Default Project dir:</source>
       <translation>Varsayılan proje dizini:</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="304"/>
+      <location filename="../../DlgSettingsRay.ui" line="301"/>
       <source>TempCamera.inc</source>
       <translation>TempCamera.inc</translation>
     </message>
     <message>
-      <location filename="../../DlgSettingsRay.ui" line="320"/>
+      <location filename="../../DlgSettingsRay.ui" line="317"/>
       <source>TempPart.inc</source>
       <translation>TempPart.inc</translation>
     </message>
   </context>
+  <context>
+    <name>RaytracingGui::DlgSettingsRayImp</name>
+    <message>
+      <location filename="../../DlgSettingsRayImp.cpp" line="47"/>
+      <source>The path to the POV-Ray executable, if you want to render from %1</source>
+      <translation>%1 'den oluşturmak istiyorsanız, POV-Ray yürütülebilir dosyasının yolu</translation>
+    </message>
+  </context>
   <context>
     <name>RaytracingGui::ViewProviderLux</name>
     <message>
@@ -493,17 +494,17 @@ Devam etmek istiyor musun?</translation>
   <context>
     <name>RaytracingGui::ViewProviderPovray</name>
     <message>
-      <location filename="../../ViewProvider.cpp" line="146"/>
+      <location filename="../../ViewProvider.cpp" line="147"/>
       <source>Edit Povray project</source>
       <translation>Povray projesini düzenle</translation>
     </message>
     <message>
-      <location filename="../../ViewProvider.cpp" line="177"/>
+      <location filename="../../ViewProvider.cpp" line="178"/>
       <source>Povray template</source>
       <translation>Povray şablonu</translation>
     </message>
     <message>
-      <location filename="../../ViewProvider.cpp" line="177"/>
+      <location filename="../../ViewProvider.cpp" line="178"/>
       <source>Select a Povray template</source>
       <translation>Bir Povray şablonu seçin</translation>
     </message>
