@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) 2008 Jürgen Riegel (juergen.riegel@web.de)              *
+ *   Copyright (c) 2008 Jürgen Riegel <juergen.riegel@web.de>              *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -27,6 +27,7 @@
 #endif
 
 #include <Base/Console.h>
+#include <Base/Interpreter.h>
 #include <Gui/Application.h>
 #include <Gui/Language/Translator.h>
 #include "Workbench.h"
@@ -74,6 +75,15 @@ PyMOD_INIT_FUNC(ReverseEngineeringGui)
         PyMOD_Return(0);
     }
 
+    // load dependent module
+    try {
+        Base::Interpreter().loadModule("MeshGui");
+    }
+    catch(const Base::Exception& e) {
+        PyErr_SetString(PyExc_ImportError, e.what());
+        PyMOD_Return(0);
+    }
+
     PyObject* mod = ReverseEngineeringGui::initModule();
     Base::Console().Log("Loading GUI of ReverseEngineering module... done\n");
 
