@@ -98,7 +98,7 @@ bool PoissonWidget::accept()
 
         Gui::WaitCursor wc;
         Gui::Command::addModule(Gui::Command::App, "ReverseEngineering");
-        Gui::Command::openCommand("Poisson reconstruction");
+        Gui::Command::openCommand(QT_TRANSLATE_NOOP("Command", "Poisson reconstruction"));
         Gui::Command::runCommand(Gui::Command::Doc, command.toLatin1());
         Gui::Command::commitCommand();
         Gui::Command::updateActive();
