@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="hu" sourcelanguage="en">
+<TS version="1.1" language="hu" sourcelanguage="en">
   <context>
     <name>Ship</name>
     <message>
@@ -14,17 +14,17 @@
       <translation>Súlyok</translation>
     </message>
     <message>
-      <location filename="Instance.py" line="44"/>
+      <location filename="Instance.py" line="47"/>
       <source>True if it is a valid ship instance, False otherwise</source>
       <translation>Igaz, ha egy érvényes hajó példányra, egyébként hamis</translation>
     </message>
     <message>
-      <location filename="Instance.py" line="54"/>
+      <location filename="Instance.py" line="56"/>
       <source>Ship length [m]</source>
       <translation>Hajó hossza [m]</translation>
     </message>
     <message>
-      <location filename="Instance.py" line="63"/>
+      <location filename="Instance.py" line="64"/>
       <source>Ship breadth [m]</source>
       <translation>Hajó szélessége [m]</translation>
     </message>
@@ -34,22 +34,22 @@
       <translation>Hajó tervezet [m]</translation>
     </message>
     <message>
-      <location filename="Instance.py" line="83"/>
+      <location filename="Instance.py" line="82"/>
       <source>Set of external faces of the ship hull</source>
       <translation>Hajótest külső felületek csoportja</translation>
     </message>
     <message>
-      <location filename="Instance.py" line="92"/>
+      <location filename="Instance.py" line="90"/>
       <source>Set of weight instances</source>
       <translation>Súly példánykészletek</translation>
     </message>
     <message>
-      <location filename="Instance.py" line="101"/>
+      <location filename="Instance.py" line="98"/>
       <source>Set of tank instances</source>
       <translation>Tartály példánykészletek</translation>
     </message>
     <message>
-      <location filename="Instance.py" line="110"/>
+      <location filename="Instance.py" line="106"/>
       <source>Set of load conditions</source>
       <translation>Terhelési feltételek</translation>
     </message>
@@ -57,12 +57,12 @@
   <context>
     <name>Ship_AreasCurve</name>
     <message>
-      <location filename="ShipGui.py" line="94"/>
+      <location filename="ShipGui.py" line="97"/>
       <source>Areas curve</source>
       <translation>Területek görbéi</translation>
     </message>
     <message>
-      <location filename="ShipGui.py" line="97"/>
+      <location filename="ShipGui.py" line="100"/>
       <source>Plot the transversal areas curve</source>
       <translation>A transzverzális területek görbéit nyomtatja</translation>
     </message>
@@ -70,12 +70,12 @@
   <context>
     <name>Ship_CreateShip</name>
     <message>
-      <location filename="ShipGui.py" line="60"/>
+      <location filename="ShipGui.py" line="63"/>
       <source>Create a new ship</source>
       <translation>Új hajó létrehozása</translation>
     </message>
     <message>
-      <location filename="ShipGui.py" line="63"/>
+      <location filename="ShipGui.py" line="66"/>
       <source>Create a new ship instance on top of the hull geometry</source>
       <translation>Létrehoz egy új hajó példányt a hajótest geometria tetején</translation>
     </message>
@@ -83,12 +83,12 @@
   <context>
     <name>Ship_Hydrostatics</name>
     <message>
-      <location filename="ShipGui.py" line="111"/>
+      <location filename="ShipGui.py" line="114"/>
       <source>Hydrostatics</source>
       <translation>Vízszilárdság / hydrostatika</translation>
     </message>
     <message>
-      <location filename="ShipGui.py" line="114"/>
+      <location filename="ShipGui.py" line="117"/>
       <source>Plot the ship hydrostatics</source>
       <translation>A hajó hidrosztatika tételeinek nyomtatása</translation>
     </message>
@@ -96,12 +96,12 @@
   <context>
     <name>Ship_LoadExample</name>
     <message>
-      <location filename="ShipGui.py" line="43"/>
+      <location filename="ShipGui.py" line="46"/>
       <source>Load an example ship geometry</source>
       <translation>Egy hajó geometria példa betöltése</translation>
     </message>
     <message>
-      <location filename="ShipGui.py" line="46"/>
+      <location filename="ShipGui.py" line="49"/>
       <source>Load an example ship hull geometry.</source>
       <translation>Egy példa hajó test geometria betöltése.</translation>
     </message>
@@ -109,12 +109,12 @@
   <context>
     <name>Ship_OutlineDraw</name>
     <message>
-      <location filename="ShipGui.py" line="77"/>
+      <location filename="ShipGui.py" line="80"/>
       <source>Outline draw</source>
-      <translation>Külső vonal rajzolása</translation>
+      <translation>Körvonal rajzolása</translation>
     </message>
     <message>
-      <location filename="ShipGui.py" line="80"/>
+      <location filename="ShipGui.py" line="83"/>
       <source>Plots the ship hull outline draw</source>
       <translation>Hajótest külső szerkezeti rajzot nyomtat</translation>
     </message>
@@ -127,14 +127,14 @@
       <translation>Tervrajz</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="326"/>
+      <location filename="TaskPanel.py" line="323"/>
       <source>Displacement</source>
       <translation>Elmozdulás</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="352"/>
+      <location filename="TaskPanel.py" line="347"/>
       <source>Areas curve tool draft selected [m]</source>
-      <translation>Területek görbéi tervező eszköz kiválasztva [m]</translation>
+      <translation>Területek görbéinek tervező eszköze kiválasztva [m]</translation>
     </message>
     <message>
       <location filename="TaskPanel.py" line="223"/>
@@ -142,22 +142,22 @@
       <translation>A transzverzális területek görbéit nyomtatja</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="368"/>
+      <location filename="TaskPanel.py" line="362"/>
       <source>Areas curve tool trim selected [deg]</source>
-      <translation>Területek görbe vágó eszköz kiválasztva [fok]</translation>
+      <translation>Területek görbe vágó eszközének kiválasztva [fok]</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="234"/>
+      <location filename="TaskPanel.py" line="233"/>
       <source>Trim angle</source>
-      <translation>Vágás szöge</translation>
+      <translation>Szög vágása</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="240"/>
+      <location filename="TaskPanel.py" line="238"/>
       <source>Number of points</source>
       <translation>Pontok száma</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="384"/>
+      <location filename="TaskPanel.py" line="377"/>
       <source>Areas curve tool number of points</source>
       <translation>Területek görbe eszköz pontok száma</translation>
     </message>
@@ -165,12 +165,12 @@
   <context>
     <name>ship_capacity</name>
     <message>
-      <location filename="ShipGui.py" line="162"/>
+      <location filename="ShipGui.py" line="165"/>
       <source>Tank capacity curve</source>
       <translation>Tartály kapacitás görbe</translation>
     </message>
     <message>
-      <location filename="ShipGui.py" line="165"/>
+      <location filename="ShipGui.py" line="168"/>
       <source>Plot the tank capacity curve (level-volume curve)</source>
       <translation>A tartály kapacitás görbe nyomtatása (térfogat-szint görbe)</translation>
     </message>
@@ -188,142 +188,142 @@
   <context>
     <name>ship_console</name>
     <message>
-      <location filename="TaskPanel.py" line="160"/>
+      <location filename="TaskPanel.py" line="162"/>
       <source>Please create or load a ship hull geometry before using this tool</source>
       <translation>Kérjük, hozzon létre, vagy töltsön be egy hajó törzs geometriát mielőtt használná ezt az eszközt</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="153"/>
+      <location filename="TaskPanel.py" line="156"/>
       <source>Ship objects can only be created on top of hull geometry (no solid found at selected objects)</source>
       <translation>Hajó objektumok csak hajótörzs geometriára létrehozhatók (nem található szilárd test a kijelölt objektumokon)</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="95"/>
+      <location filename="TaskPanel.py" line="98"/>
       <source>Computing hydrostatics</source>
-      <translation>Vízszilárdság / hydrostatika kiszámítása</translation>
+      <translation>Vízszilárdság / hidrosztatika kiszámítása</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="500"/>
+      <location filename="TaskPanel.py" line="490"/>
       <source>Computing external faces</source>
       <translation>Külső felületek számítása</translation>
     </message>
     <message>
-      <location filename="Preview.py" line="54"/>
+      <location filename="Preview.py" line="58"/>
       <source>Computing sections</source>
       <translation>Szakaszok számítása</translation>
     </message>
     <message>
-      <location filename="Preview.py" line="128"/>
+      <location filename="Preview.py" line="131"/>
       <source>Any valid ship section found</source>
-      <translation>Bármely megtalálható érvényes hajó rész</translation>
+      <translation>Ennyi érvényes hajó részt talált</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="132"/>
+      <location filename="TaskPanel.py" line="137"/>
       <source>Ship objects can only be created on top of hull geometry (no objects selected)</source>
       <translation>Hajó objektumok csak hajótörzs geometriára létrehozhatók (nincsenek kijelölt objektumok)</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="199"/>
+      <location filename="TaskPanel.py" line="202"/>
       <source>A ship instance must be selected before using this tool (no objects selected)</source>
       <translation>Egy hajó példányt kell kijelölni, mielőtt használja ezt az eszközt (nincsenek kijelölt objektumok)</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="216"/>
+      <location filename="TaskPanel.py" line="218"/>
       <source>More than one ship have been selected (the extra ships will be ignored)</source>
       <translation>Több, mint egy hajót választott ki (az extra hajókat nem veszi figyelembe)</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="227"/>
+      <location filename="TaskPanel.py" line="228"/>
       <source>A ship instance must be selected before using this tool (no valid ship found at the selected objects)</source>
       <translation>Egy hajó példányt ki kell jelölni, mielőtt használja ezt az eszközt (nem található érvényes hajó a kijelölt objektumokon)</translation>
     </message>
     <message>
-      <location filename="PlotAux.py" line="57"/>
+      <location filename="PlotAux.py" line="61"/>
       <source>Plot module is disabled, so I cannot perform the plot</source>
       <translation>Nyomtató modul le van tiltva, ezért nem hajtható végre nyomtatás</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="183"/>
+      <location filename="TaskPanel.py" line="197"/>
       <source>A ship instance must be selected before use this tool (no objects selected)</source>
       <translation>Egy hajó példányt kell kijelölni, mielőtt használja ezt az eszközt (nincsenek kijelölt objektumok)</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="202"/>
+      <location filename="TaskPanel.py" line="215"/>
       <source>More than one ship has been selected (just the first one will be used)</source>
       <translation>Több, mint egy hajó van jelölve (csak az első, aki fogja használni)</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="213"/>
+      <location filename="TaskPanel.py" line="225"/>
       <source>A ship instance must be selected before use this tool (novalid ships found in the selected objects)</source>
       <translation>Egy hajó példányt ki kell jelölni, mielőtt használja ezt az eszközt (nem található érvényes hajó a kijelölt objektumokon)</translation>
     </message>
     <message>
-      <location filename="InitGui.py" line="41"/>
+      <location filename="InitGui.py" line="45"/>
       <source>Plot module is disabled, tools cannot graph output curves</source>
       <translation>Tervrajz nyomtató kiiktatva, az eszköz nem tud kirajzolni görbét</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="85"/>
+      <location filename="TaskPanel.py" line="89"/>
       <source>Failure detecting external faces from the ship object</source>
       <translation>Hiba a hajó tárgy külső felületeinek észlelése közben</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="118"/>
+      <location filename="TaskPanel.py" line="123"/>
       <source>A tank instance must be selected before using this tool (no objects selected)</source>
       <translation>Egy tank példánynyt kell kijelölni, mielőtt használná ezt az eszközt (nincs tárgy kijelölve)</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="135"/>
+      <location filename="TaskPanel.py" line="139"/>
       <source>More than one tank have been selected (the extra tanks will be ignored)</source>
       <translation>Több mint egy tartályt választott (extra tartályokat figyelmen kívül hagyja)</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="145"/>
+      <location filename="TaskPanel.py" line="148"/>
       <source>A tank instance must be selected before using this tool (no valid tank found at the selected objects)</source>
-      <translation>Egy tartáj példányt kell kijelölni, mielőtt használja ezt az eszközt (nem található érvényes tartáj a kijelölt objektumokon)</translation>
+      <translation>Egy tartály példányt kell kijelölni, mielőtt használja ezt az eszközt (nem található érvényes tartáj a kijelölt objektumokon)</translation>
     </message>
     <message>
-      <location filename="TankInstance.py" line="129"/>
+      <location filename="TankInstance.py" line="133"/>
       <source>Tank volume operation failed. The tool is retrying that slightly moving the free surface position</source>
       <translation>Tartály térfogat művelet nem sikerült. Az eszközt újra próbálkozik kissé elmozgatva a szabad felszíni helyzetet</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="133"/>
+      <location filename="TaskPanel.py" line="138"/>
       <source>A loading condition instance must be selected before using this tool (no objects selected)</source>
       <translation>Terhelési feltétel példányt kell kijelölni, mielőtt használja ezt az eszközt (nincs tárgy kijelölve)</translation>
     </message>
     <message>
-      <location filename="Tools.py" line="197"/>
+      <location filename="Tools.py" line="201"/>
       <source>Wrong Ship label! (no instances labeled as'{}' found)</source>
       <translation>Helytelen hajó címke! (nem található "{}" címkével példány)</translation>
     </message>
     <message>
-      <location filename="Tools.py" line="206"/>
+      <location filename="Tools.py" line="209"/>
       <source>Ambiguous Ship label! ({} instances labeled as'{}' found)</source>
       <translation>Kétértelmű hajó címke! ({} példány talált ezzel a "{}" címkével ellátva)</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="185"/>
+      <location filename="TaskPanel.py" line="187"/>
       <source>More than one loading condition have been selected (the extra loading conditions will be ignored)</source>
       <translation>Egynél több terhelési feltételt választott (extra terhelési feltételeket nem veszi figyelembe)</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="196"/>
+      <location filename="TaskPanel.py" line="198"/>
       <source>A loading condition instance must be selected before using this tool (no valid loading condition found at the selected objects)</source>
       <translation>A terhelési feltétel példányt kell kijelölni, mielőtt használja ezt az eszközt (nincs érvényes terhelési feltétel a kijelölt tárgyakon)</translation>
     </message>
     <message>
-      <location filename="Tools.py" line="117"/>
+      <location filename="Tools.py" line="121"/>
       <source>Too much weight! The ship will never displace water enough</source>
       <translation>Túl nagy súlyt! A hajó nem képes ennyi vizet kiszorítani</translation>
     </message>
     <message>
-      <location filename="Tools.py" line="232"/>
+      <location filename="Tools.py" line="234"/>
       <source>Wrong Weight label! (no instances labeled as'{}' found)</source>
       <translation>Helytelen súly címke! (nem található "{}" címkével példány)</translation>
     </message>
     <message>
-      <location filename="Tools.py" line="241"/>
+      <location filename="Tools.py" line="242"/>
       <source>Ambiguous Weight label! ({} instances labeled as'{}' found)</source>
       <translation>Kétértelmű súly címke! ({} példány talált ezzel a "{}" címkével ellátva)</translation>
     </message>
@@ -333,75 +333,75 @@
       <translation>Érvénytelen súly! (a tárgy "{}" címkével nem tömeg)</translation>
     </message>
     <message>
-      <location filename="Tools.py" line="280"/>
+      <location filename="Tools.py" line="279"/>
       <source>Wrong Tank label! (no instances labeled as'{}' found)</source>
       <translation>Helytelen tartály címke! (nem található "{}" címkével példány)</translation>
     </message>
     <message>
-      <location filename="Tools.py" line="289"/>
+      <location filename="Tools.py" line="287"/>
       <source>Ambiguous Tank label! ({} instances labeled as'{}' found)</source>
       <translation>Kétértelmű tartály címke! ({} példány talált ezzel a "{}" címkével ellátva)</translation>
     </message>
     <message>
-      <location filename="Tools.py" line="302"/>
+      <location filename="Tools.py" line="299"/>
       <source>Invalid Tank! (the object labeled as'{}' is not a tank)</source>
       <translation>Érvénytelen tartály! ("{}" címkével ellátott tárgy nem tartály)</translation>
     </message>
     <message>
-      <location filename="Tools.py" line="49"/>
+      <location filename="Tools.py" line="53"/>
       <source>Computing capacity curves</source>
       <translation>Kapacitás görbék számítása</translation>
     </message>
     <message>
-      <location filename="Tools.py" line="122"/>
+      <location filename="Tools.py" line="128"/>
       <source>Boolean operation failed when trying to get the underwater side. The tool is retrying such operation slightly moving the free surface position</source>
       <translation>Logikai művelet nem sikerült a víz alatti oldal elérésénél. Az eszköz újrapróbálkozik a művelettel kissé elmozdítva a szabad felszíni helyzetet</translation>
     </message>
     <message>
-      <location filename="Tools.py" line="198"/>
+      <location filename="Tools.py" line="201"/>
       <source>Part.OCCError: Transversal area computation failed</source>
       <translation>Part.OCCError: Transzverzális terület kiszámítása nem sikerült</translation>
     </message>
     <message>
-      <location filename="Tools.py" line="275"/>
+      <location filename="Tools.py" line="278"/>
       <source>ZeroDivisionError: Null volume found during the displacement computation!</source>
       <translation>ZeroDivisionError: Null térfogat az elhelyezés számítás során!</translation>
     </message>
     <message>
-      <location filename="Tools.py" line="377"/>
+      <location filename="Tools.py" line="378"/>
       <source>Part.OCCError: Floating area cannot be computed</source>
       <translation>Part.OCCError: Úszó terület nem számítható ki</translation>
     </message>
     <message>
-      <location filename="Tools.py" line="390"/>
+      <location filename="Tools.py" line="391"/>
       <source>ZeroDivisionError: Null area found during the floating area computation!</source>
       <translation>ZeroDivisionError: Üres területet talált a lebegő terület kiszámítása során!</translation>
     </message>
     <message>
-      <location filename="Tools.py" line="466"/>
+      <location filename="Tools.py" line="465"/>
       <source>Part.OCCError: Main frame area cannot be computed</source>
       <translation>Part.OCCError: Fő keret terület nem számítható ki</translation>
     </message>
     <message>
-      <location filename="Tools.py" line="480"/>
+      <location filename="Tools.py" line="479"/>
       <source>ZeroDivisionError: Null area found during the main frame area coefficient computation!</source>
-      <translation>ZeroDivisionError: Üres területet tslált a fő keret terület együttható számítása során!</translation>
+      <translation>ZeroDivisionError: Üres területet talált a fő keret terület együttható számítása során!</translation>
     </message>
   </context>
   <context>
     <name>ship_create</name>
     <message>
-      <location filename="Preview.py" line="66"/>
+      <location filename="Preview.py" line="69"/>
       <source>Base line</source>
       <translation>Alap vonal</translation>
     </message>
     <message>
-      <location filename="Preview.py" line="83"/>
+      <location filename="Preview.py" line="85"/>
       <source>Free surface</source>
       <translation>Szabad felület</translation>
     </message>
     <message>
-      <location filename="Preview.py" line="100"/>
+      <location filename="Preview.py" line="101"/>
       <source>Forward perpendicular</source>
       <translation>Merőleges előtt</translation>
     </message>
@@ -411,27 +411,27 @@
       <translation>Merőleges után</translation>
     </message>
     <message>
-      <location filename="Preview.py" line="134"/>
+      <location filename="Preview.py" line="133"/>
       <source>Main frame</source>
       <translation>Fő keret</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="220"/>
+      <location filename="TaskPanel.py" line="219"/>
       <source>Create a new ship</source>
       <translation>Új hajó létrehozása</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="225"/>
+      <location filename="TaskPanel.py" line="224"/>
       <source>Length</source>
       <translation>Hossz</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="231"/>
+      <location filename="TaskPanel.py" line="229"/>
       <source>Breadth</source>
       <translation>Szélesség</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="237"/>
+      <location filename="TaskPanel.py" line="234"/>
       <source>Draft</source>
       <translation>Tervrajz</translation>
     </message>
@@ -439,47 +439,47 @@
   <context>
     <name>ship_gz</name>
     <message>
-      <location filename="ShipGui.py" line="196"/>
+      <location filename="ShipGui.py" line="199"/>
       <source>GZ curve computation</source>
       <translation>GZ görbe kiszámítása</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="244"/>
+      <location filename="TaskPanel.py" line="242"/>
       <source>Plot the GZ curve</source>
       <translation>A GZ-görbe felrajzolása</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="249"/>
+      <location filename="TaskPanel.py" line="247"/>
       <source>Maximum angle</source>
       <translation>Maximális szög</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="255"/>
+      <location filename="TaskPanel.py" line="252"/>
       <source>Number of points</source>
       <translation>Pontok száma</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="261"/>
+      <location filename="TaskPanel.py" line="257"/>
       <source>Variable trim</source>
       <translation>Változó vágás</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="267"/>
+      <location filename="TaskPanel.py" line="264"/>
       <source>The ship will be rotated to the equilibrium trim angle for each roll angle. It will significantly increase the required computing time</source>
       <translation>A hajót minden csavarási szögnél forgatni kell az egyensúlyi vágási szöghöz. Ez jelentősen növelni fogja a szükséges számítási időt</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="294"/>
+      <location filename="TaskPanel.py" line="287"/>
       <source>GZ curve tool angle selected [deg]</source>
       <translation>GZ görbe eszköz szöge választott [fok]</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="310"/>
+      <location filename="TaskPanel.py" line="302"/>
       <source>GZ curve tool number of points selected</source>
       <translation>GZ görbe eszköz pontok száma választott</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="326"/>
+      <location filename="TaskPanel.py" line="317"/>
       <source>GZ curve tool variable trim angle selection</source>
       <translation>GZ görbe eszköz változó vágási szög választás</translation>
     </message>
@@ -487,47 +487,47 @@
   <context>
     <name>ship_hydrostatic</name>
     <message>
-      <location filename="TaskPanel.py" line="279"/>
+      <location filename="TaskPanel.py" line="277"/>
       <source>Plot hydrostatics</source>
-      <translation>Vízszilárdság / hidrostatika nyomtatása</translation>
+      <translation>Vízszilárdság / hidrosztatika nyomtatása</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="284"/>
+      <location filename="TaskPanel.py" line="282"/>
       <source>Trim</source>
       <translation>Vágás</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="290"/>
+      <location filename="TaskPanel.py" line="287"/>
       <source>Minimum draft</source>
       <translation>Minimális merülés</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="296"/>
+      <location filename="TaskPanel.py" line="292"/>
       <source>Maximum draft</source>
       <translation>Maximális merülés</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="302"/>
+      <location filename="TaskPanel.py" line="297"/>
       <source>Number of points</source>
       <translation>Pontok száma</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="420"/>
+      <location filename="TaskPanel.py" line="413"/>
       <source>Hydrostatics tool trim selected</source>
       <translation>Vízszilárdság vágó eszköz kiválasztva</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="434"/>
+      <location filename="TaskPanel.py" line="426"/>
       <source>Hydrostatics tool minimum draft selected [m]</source>
       <translation>Vízszilárdság minimum merülés kiválasztva [m]</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="448"/>
+      <location filename="TaskPanel.py" line="439"/>
       <source>Hydrostatics tool maximum draft selected [m]</source>
       <translation>Vízszilárdság maximum merülés kiválasztva [m]</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="462"/>
+      <location filename="TaskPanel.py" line="452"/>
       <source>Hydrostatics tool number of points selected</source>
       <translation>Vízszilárdság pontok számai eszköz kiválasztva</translation>
     </message>
@@ -535,12 +535,12 @@
   <context>
     <name>ship_load</name>
     <message>
-      <location filename="TaskPanel.py" line="106"/>
+      <location filename="TaskPanel.py" line="109"/>
       <source>Load example ship</source>
-      <translation>Példa hajó betüöltése</translation>
+      <translation>Példa hajó betöltése</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="111"/>
+      <location filename="TaskPanel.py" line="113"/>
       <source>Select ship example geometry</source>
       <translation>Válasszon példa hajó geometriát</translation>
     </message>
@@ -548,12 +548,12 @@
   <context>
     <name>ship_loadcondition</name>
     <message>
-      <location filename="ShipGui.py" line="179"/>
+      <location filename="ShipGui.py" line="182"/>
       <source>Create a new loading condition</source>
       <translation>Létrehoz egy új terhelési feltételt</translation>
     </message>
     <message>
-      <location filename="ShipGui.py" line="182"/>
+      <location filename="ShipGui.py" line="185"/>
       <source>Create a new load condition spreadsheet</source>
       <translation>Létrehoz egy új terhelés feltétel munkafüzetet</translation>
     </message>
@@ -561,52 +561,52 @@
   <context>
     <name>ship_outline</name>
     <message>
-      <location filename="TaskPanel.py" line="227"/>
+      <location filename="TaskPanel.py" line="236"/>
       <source>Outline draw</source>
-      <translation>Külső vonal rajzolása</translation>
+      <translation>Körvonal rajzolása</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="232"/>
+      <location filename="TaskPanel.py" line="241"/>
       <source>Auto create</source>
       <translation>Automatikus létrehozás</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="238"/>
+      <location filename="TaskPanel.py" line="246"/>
       <source>Delete all sections</source>
       <translation>Minden szakasz törlése</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="244"/>
+      <location filename="TaskPanel.py" line="251"/>
       <source>Create sections</source>
       <translation>Szakaszok létrehozása</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="250"/>
+      <location filename="TaskPanel.py" line="257"/>
       <source>Transversal</source>
       <translation>Átlós</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="257"/>
+      <location filename="TaskPanel.py" line="263"/>
       <source>Longitudinal</source>
       <translation>Hosszanti</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="264"/>
+      <location filename="TaskPanel.py" line="269"/>
       <source>Water lines</source>
       <translation>Vízvonalak</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="479"/>
+      <location filename="TaskPanel.py" line="482"/>
       <source>Transversal section positions [m]</source>
       <translation>Átlós szakaszok pozíciója [m]</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="488"/>
+      <location filename="TaskPanel.py" line="490"/>
       <source>Longitudinal section positions [m]</source>
       <translation>Hosszmetszet pozíciója [m]</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="497"/>
+      <location filename="TaskPanel.py" line="498"/>
       <source>Water line positions [m]</source>
       <translation>Víz szint pozíciók [m]</translation>
     </message>
@@ -614,7 +614,7 @@
   <context>
     <name>ship_tank</name>
     <message>
-      <location filename="TankInstance.py" line="50"/>
+      <location filename="TankInstance.py" line="53"/>
       <source>True if it is a valid tank instance, False otherwise</source>
       <translation>Igaz, ha egy érvényes tartály példányra, egyébként hamis</translation>
     </message>
@@ -624,17 +624,17 @@
       <translation>Új tartály létrehozása</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="109"/>
+      <location filename="TaskPanel.py" line="114"/>
       <source>Tanks objects can only be created on top of its geometry (no objects selected)</source>
       <translation>Tartály tárgyakat csak geometria tetején hozhatók létre (nincsenek kijelölt tárgyak)</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="123"/>
+      <location filename="TaskPanel.py" line="126"/>
       <source>No solids found in the selected objects</source>
       <translation>Nem található szilárd testek a kijelölt tárgyon</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="141"/>
+      <location filename="TaskPanel.py" line="143"/>
       <source>There are not ship objects to create weights into them</source>
       <translation>Nincsenek hajó tárgyak, melyekre súlyok tehetők</translation>
     </message>
@@ -647,77 +647,72 @@
   <context>
     <name>ship_weight</name>
     <message>
-      <location filename="ShipGui.py" line="131"/>
+      <location filename="ShipGui.py" line="134"/>
       <source>Create a new ship weight</source>
       <translation>Hozzon létre egy új hajó súlyt</translation>
     </message>
     <message>
-      <location filename="WeightInstance.py" line="46"/>
+      <location filename="WeightInstance.py" line="49"/>
       <source>True if it is a valid weight instance, False otherwise</source>
       <translation>Igaz, ha az érvényes tömeg példányra, egyébként hamis</translation>
     </message>
     <message>
-      <location filename="WeightInstance.py" line="56"/>
+      <location filename="WeightInstance.py" line="58"/>
       <source>Mass [kg]</source>
       <translation>Tömeg [kg]</translation>
     </message>
     <message>
-      <location filename="WeightInstance.py" line="66"/>
+      <location filename="WeightInstance.py" line="67"/>
       <source>Linear density [kg / m]</source>
       <translation>Lineáris sűrűségű [kg / m]</translation>
     </message>
     <message>
-      <location filename="WeightInstance.py" line="86"/>
+      <location filename="WeightInstance.py" line="85"/>
       <source>Density [kg / m^3]</source>
       <translation>Sűrűsége [kg / m ^ 3]</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="113"/>
+      <location filename="TaskPanel.py" line="118"/>
       <source>Weight objects can only be created on top of its geometry (no objects selected)</source>
       <translation>Súly-tárgyak csak a geometriájuk tetején hozhatók létre (nincs kijelölt tárgy)</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="127"/>
+      <location filename="TaskPanel.py" line="130"/>
       <source>No geometrical shapes found in the selected objects</source>
       <translation>Nem találhatók a kijelölt objektumon geometriai alakzatok</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="164"/>
-      <source>Unknow object shapes selected</source>
-      <translation>Ismeretlen alakzatú tárgyakat választott</translation>
-    </message>
-    <message>
-      <location filename="TaskPanel.py" line="182"/>
+      <location filename="TaskPanel.py" line="183"/>
       <source>There are not ship objects to create weights into them</source>
       <translation>Nincsenek hajó tárgyak, melyekre súlyok tehetők</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="217"/>
+      <location filename="TaskPanel.py" line="216"/>
       <source>Create a new weight</source>
       <translation>Hozzon létre egy új súlyt</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="222"/>
+      <location filename="TaskPanel.py" line="221"/>
       <source>Ship</source>
       <translation>Hajó</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="229"/>
+      <location filename="TaskPanel.py" line="227"/>
       <source>Mass</source>
       <translation>Tömeg</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="236"/>
+      <location filename="TaskPanel.py" line="233"/>
       <source>Linear density</source>
       <translation>Lineáris sűrűség</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="243"/>
+      <location filename="TaskPanel.py" line="239"/>
       <source>Area density</source>
       <translation>Terület sűrűség</translation>
     </message>
     <message>
-      <location filename="TaskPanel.py" line="250"/>
+      <location filename="TaskPanel.py" line="245"/>
       <source>Density</source>
       <translation>Sűrűség</translation>
     </message>
@@ -726,5 +721,10 @@
       <source>Area density [kg / m^2]</source>
       <translation>Terület sűrűség [kg / m ^ 2]</translation>
     </message>
+    <message>
+      <location filename="TaskPanel.py" line="166"/>
+      <source>Unknown object shapes selected</source>
+      <translation>Ismeretlen alakzatú tárgyakat választott</translation>
+    </message>
   </context>
 </TS>
