@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) Jürgen Riegel          (juergen.riegel@web.de) 2008     *
+ *   Copyright (c) 2008 Jürgen Riegel <juergen.riegel@web.de>              *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -57,6 +57,7 @@ enum ConstraintType {
     SnellsLaw = 16,
     Block = 17,
     Diameter = 18,
+    Weight = 19,
     NumConstraintTypes // must be the last item!
 };
 
@@ -74,29 +75,45 @@ enum InternalAlignmentType {
     BSplineKnotPoint        = 10,
 };
 
-/// define if you want to use the end or start point
+/*! PointPos lets us refer to different aspects of a piece of geometry.  sketcher::none refers
+ * to an edge itself (eg., for a Perpendicular constraint on two lines). sketcher::start and
+ * sketcher::end denote the endpoints of lines or bounded curves.  sketcher::mid denotes
+ * geometries with geometrical centers (eg., circle, ellipse). Bare points use 'start'.  More
+ * complex geometries like parabola focus or b-spline knots use InternalAlignment constraints
+ * in addition to PointPos.
+ */
 enum PointPos { none, start, end, mid };
 
 class SketcherExport Constraint : public Base::Persistence
 {
-    TYPESYSTEM_HEADER();
+    TYPESYSTEM_HEADER_WITH_OVERRIDE();
 
 public:
     Constraint();
-    Constraint(const Constraint&);
-    virtual ~Constraint();
-    virtual Constraint *clone(void) const; // does copy the tag, it will be treated as a rename by the expression engine.
-    virtual Constraint *copy(void) const; // does not copy the tag, but generates a new one
+    // PVS V690: It is perfectly fine to use copy operator only internally
+
+    // Constraints objects explicitly not copiable with standard methods
+    // Copy constructor is private for internal use only
+    Constraint &operator =(const Constraint &a) = delete;
+
+    // Constraints objects explicitly not movable
+    Constraint(Constraint&&) = delete;
+    Constraint& operator=(Constraint&&) = delete;
+
+    virtual ~Constraint() = default;
+
+    Constraint *clone(void) const; // does copy the tag, it will be treated as a rename by the expression engine.
+    Constraint *copy(void) const; // does not copy the tag, but generates a new one
 
     static const int GeoUndef;
 
     // from base class
-    virtual unsigned int getMemSize(void) const;
-    virtual void Save(Base::Writer &/*writer*/) const;
-    virtual void Restore(Base::XMLReader &/*reader*/);
+    virtual unsigned int getMemSize(void) const override;
+    virtual void Save(Base::Writer &/*writer*/) const override;
+    virtual void Restore(Base::XMLReader &/*reader*/) override;
+
+    virtual PyObject *getPyObject(void) override;
 
-    virtual PyObject *getPyObject(void);
-    
     Base::Quantity getPresentationValue() const;
     inline void setValue(double newValue) {
         Value = newValue;
@@ -107,11 +124,14 @@ public:
 
     inline bool isDimensional() const {
         return Type == Distance || Type == DistanceX || Type == DistanceY ||
-               Type == Radius || Type == Diameter || Type == Angle || Type == SnellsLaw;
+               Type == Radius || Type == Diameter || Type == Angle || Type == SnellsLaw || Type == Weight;
     }
 
     friend class PropertyConstraintList;
 
+private:
+    Constraint(const Constraint&) = default; // only for internal use
+
 private:
     double Value;
 public:
@@ -127,9 +147,11 @@ public:
     float LabelDistance;
     float LabelPosition;
     bool isDriving;
-    int InternalAlignmentIndex; // Note: for InternalAlignment Type this index indexes equal internal geometry elements (e.g. index of pole in a bspline). It is not a GeoId!! 
+    int InternalAlignmentIndex; // Note: for InternalAlignment Type this index indexes equal internal geometry elements (e.g. index of pole in a bspline). It is not a GeoId!!
     bool isInVirtualSpace;
 
+    bool isActive;
+
 protected:
     boost::uuids::uuid tag;
 };
