@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) Jürgen Riegel          (juergen.riegel@web.de) 2010     *
+ *   Copyright (c) 2010 Jürgen Riegel <juergen.riegel@web.de>              *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -24,9 +24,10 @@
 #ifndef _PreComp_
 # include <sstream>
 # include <Geom_TrimmedCurve.hxx>
+# include <boost/shared_ptr.hpp>
 #endif
 
-#include <boost/shared_ptr.hpp>
+#include <Base/StdStlTools.h>
 
 #include <Mod/Sketcher/App/SketchObject.h>
 #include <Mod/Part/App/LinePy.h>
@@ -46,6 +47,8 @@
 #include "SketchObjectPy.cpp"
 // other python types
 #include "ConstraintPy.h"
+#include "GeometryFacade.h"
+#include "GeometryFacadePy.h"
 
 using namespace Sketcher;
 
@@ -213,6 +216,44 @@ PyObject* SketchObjectPy::delGeometry(PyObject *args)
     Py_Return;
 }
 
+PyObject* SketchObjectPy::delGeometries(PyObject *args)
+{
+    PyObject *pcObj;
+
+    if (!PyArg_ParseTuple(args, "O", &pcObj))
+    return 0;
+
+    if (PyObject_TypeCheck(pcObj, &(PyList_Type)) ||
+        PyObject_TypeCheck(pcObj, &(PyTuple_Type)) ) {
+
+        std::vector<int> geoIdList;
+        Py::Sequence list(pcObj);
+        for (Py::Sequence::iterator it = list.begin(); it != list.end(); ++it) {
+#if PY_MAJOR_VERSION >= 3
+            if (PyLong_Check((*it).ptr()))
+                geoIdList.push_back(PyLong_AsLong((*it).ptr()));
+#else
+            if (PyInt_Check((*it).ptr()))
+                geoIdList.push_back(PyInt_AsLong((*it).ptr()));
+#endif
+        }
+
+        if(this->getSketchObjectPtr()->delGeometries(geoIdList)) {
+            std::stringstream str;
+            str << "Not able to delete geometries";
+            PyErr_SetString(PyExc_ValueError, str.str().c_str());
+            return 0;
+        }
+
+        Py_Return;
+
+    }
+
+    std::string error = std::string("type must be list of GeoIds, not ");
+    error += pcObj->ob_type->tp_name;
+    throw Py::TypeError(error);
+}
+
 PyObject* SketchObjectPy::deleteAllGeometry(PyObject *args)
 {
     if (!PyArg_ParseTuple(args, ""))
@@ -277,6 +318,24 @@ PyObject* SketchObjectPy::setConstruction(PyObject *args)
     Py_Return;
 }
 
+PyObject* SketchObjectPy::getConstruction(PyObject *args)
+{
+    int Index;
+    if (!PyArg_ParseTuple(args, "i", &Index))
+        return 0;
+
+    auto gf = this->getSketchObjectPtr()->getGeometryFacade(Index);
+
+    if(gf)
+        return Py::new_reference_to(Py::Boolean(gf->getConstruction()));
+
+    std::stringstream str;
+    str << "Not able to retrieve construction mode of a geometry with the given index: " << Index;
+    PyErr_SetString(PyExc_ValueError, str.str().c_str());
+    return 0;
+
+}
+
 PyObject* SketchObjectPy::addConstraint(PyObject *args)
 {
     PyObject *pcObj;
@@ -396,17 +455,36 @@ PyObject* SketchObjectPy::renameConstraint(PyObject *args)
         }
     }
 
-    // only change the constraint item if the names are different
-    const Constraint* item = this->getSketchObjectPtr()->Constraints[Index];
-    if (item->Name != Name) {
-        Constraint* copy = item->clone();
-        copy->Name = Name;
-        this->getSketchObjectPtr()->Constraints.set1Value(Index, copy);
-        delete copy;
-    }
+    this->getSketchObjectPtr()->renameConstraint(Index, Name);
+
     Py_Return;
 }
 
+PyObject* SketchObjectPy::getIndexByName(PyObject *args)
+{
+    char* utf8Name;
+    if (!PyArg_ParseTuple(args, "et", "utf-8", &utf8Name))
+        return 0;
+
+    std::string Name = utf8Name;
+    PyMem_Free(utf8Name);
+
+    if (Name.empty()) {
+        PyErr_SetString(PyExc_ValueError, "Passed string is empty");
+        return 0;
+    }
+
+    const std::vector< Sketcher::Constraint * > &vals = getSketchObjectPtr()->Constraints.getValues();
+    for (std::size_t i = 0; i < vals.size(); ++i) {
+        if (Name == vals[i]->Name) {
+            return Py_BuildValue("i", i);
+        }
+    }
+
+    PyErr_SetString(PyExc_LookupError, "No such constraint found");
+    return 0;
+}
+
 PyObject* SketchObjectPy::carbonCopy(PyObject *args)
 {
     char *ObjectName;
@@ -844,6 +922,57 @@ PyObject* SketchObjectPy::toggleVirtualSpace(PyObject *args)
     Py_Return;
 }
 
+PyObject* SketchObjectPy::setActive(PyObject *args)
+{
+    PyObject* isactive;
+    int constrid;
+
+    if (!PyArg_ParseTuple(args, "iO!", &constrid, &PyBool_Type, &isactive))
+        return 0;
+
+    if (this->getSketchObjectPtr()->setActive(constrid, PyObject_IsTrue(isactive) ? true : false)) {
+        std::stringstream str;
+        str << "Not able set active/disabled status for constraint with the given index: " << constrid;
+        PyErr_SetString(PyExc_ValueError, str.str().c_str());
+        return 0;
+    }
+
+    Py_Return;
+}
+
+PyObject* SketchObjectPy::getActive(PyObject *args)
+{
+    int constrid;
+    bool isactive;
+
+    if (!PyArg_ParseTuple(args, "i", &constrid))
+        return 0;
+
+    if (this->getSketchObjectPtr()->getActive(constrid, isactive)) {
+        PyErr_SetString(PyExc_ValueError, "Invalid constraint id");
+        return 0;
+    }
+
+    return Py::new_reference_to(Py::Boolean(isactive));
+}
+
+PyObject* SketchObjectPy::toggleActive(PyObject *args)
+{
+    int constrid;
+
+    if (!PyArg_ParseTuple(args, "i", &constrid))
+        return 0;
+
+    if (this->getSketchObjectPtr()->toggleActive(constrid)) {
+        std::stringstream str;
+        str << "Not able toggle on/off constraint with the given index: " << constrid;
+        PyErr_SetString(PyExc_ValueError, str.str().c_str());
+        return 0;
+    }
+
+    Py_Return;
+}
+
 PyObject* SketchObjectPy::movePoint(PyObject *args)
 {
     PyObject *pcObj;
@@ -866,6 +995,22 @@ PyObject* SketchObjectPy::movePoint(PyObject *args)
 
 }
 
+PyObject* SketchObjectPy::getGeoVertexIndex(PyObject *args)
+{
+    int index;
+    if (!PyArg_ParseTuple(args, "i", &index))
+        return 0;
+
+    SketchObject* obj = this->getSketchObjectPtr();
+    int geoId;
+    PointPos posId;
+    obj->getGeoVertexIndex(index, geoId, posId);
+    Py::Tuple tuple(2);
+    tuple.setItem(0, Py::Long(geoId));
+    tuple.setItem(1, Py::Long(posId));
+    return Py::new_reference_to(tuple);
+}
+
 PyObject* SketchObjectPy::getPoint(PyObject *args)
 {
     int GeoId, PointType;
@@ -898,16 +1043,21 @@ PyObject* SketchObjectPy::getAxis(PyObject *args)
 PyObject* SketchObjectPy::fillet(PyObject *args)
 {
     PyObject *pcObj1, *pcObj2;
-    int geoId1, geoId2, posId1, trim=1;
+    int geoId1, geoId2, posId1;
+    int trim=true;
+    PyObject* createCorner = Py_False;
     double radius;
 
     // Two Lines, radius
-    if (PyArg_ParseTuple(args, "iiO!O!d|i", &geoId1, &geoId2, &(Base::VectorPy::Type), &pcObj1, &(Base::VectorPy::Type), &pcObj2, &radius, &trim)) {
+    if (PyArg_ParseTuple(args, "iiO!O!d|iO!", &geoId1, &geoId2, &(Base::VectorPy::Type), &pcObj1, &(Base::VectorPy::Type), &pcObj2,
+          &radius, &trim, &PyBool_Type, &createCorner)) {
+        // The i for &trim should probably have been a bool like &createCorner, but we'll leave it an int for backward
+        // compatibility (and because python will accept a bool there anyway)
 
         Base::Vector3d v1 = static_cast<Base::VectorPy*>(pcObj1)->value();
         Base::Vector3d v2 = static_cast<Base::VectorPy*>(pcObj2)->value();
 
-        if (this->getSketchObjectPtr()->fillet(geoId1, geoId2, v1, v2, radius, trim?true:false)) {
+        if (this->getSketchObjectPtr()->fillet(geoId1, geoId2, v1, v2, radius, trim, PyObject_IsTrue(createCorner))) {
             std::stringstream str;
             str << "Not able to fillet curves with ids : (" << geoId1 << ", " << geoId2 << ") and points (" << v1.x << ", " << v1.y << ", " << v1.z << ") & "
             << "(" << v2.x << ", " << v2.y << ", " << v2.z << ")";
@@ -919,8 +1069,9 @@ PyObject* SketchObjectPy::fillet(PyObject *args)
 
     PyErr_Clear();
     // Point, radius
-    if (PyArg_ParseTuple(args, "iid|i", &geoId1, &posId1, &radius, &trim)) {
-        if (this->getSketchObjectPtr()->fillet(geoId1, (Sketcher::PointPos) posId1, radius, trim?true:false)) {
+    if (PyArg_ParseTuple(args, "iid|iO!", &geoId1, &posId1, &radius, &trim, &PyBool_Type, &createCorner)) {
+        if (this->getSketchObjectPtr()->fillet(geoId1, (Sketcher::PointPos) posId1, radius, trim,
+              PyObject_IsTrue(createCorner))) {
             std::stringstream str;
             str << "Not able to fillet point with ( geoId: " << geoId1 << ", PointPos: " << posId1 << " )";
             PyErr_SetString(PyExc_ValueError, str.str().c_str());
@@ -930,8 +1081,8 @@ PyObject* SketchObjectPy::fillet(PyObject *args)
     }
 
     PyErr_SetString(PyExc_TypeError, "fillet() method accepts:\n"
-    "-- int,int,Vector,Vector,float,[int]\n"
-    "-- int,int,float,[int]\n");
+    "-- int,int,Vector,Vector,float,[bool],[bool]\n"
+    "-- int,int,float,[bool],[bool]\n");
     return 0;
 }
 
@@ -1043,19 +1194,25 @@ PyObject* SketchObjectPy::addCopy(PyObject *args)
 #endif
         }
 
-        int ret = this->getSketchObjectPtr()->addCopy(geoIdList, vect, false, PyObject_IsTrue(clone) ? true : false) + 1;
+        try {
+            int ret = this->getSketchObjectPtr()->addCopy(geoIdList, vect, false, PyObject_IsTrue(clone) ? true : false) + 1;
 
-        if(ret == -1)
-            throw Py::TypeError("Copy operation unsuccessful!");
+            if(ret == -1)
+                throw Py::TypeError("Copy operation unsuccessful!");
 
-        std::size_t numGeo = geoIdList.size();
-        Py::Tuple tuple(numGeo);
-        for (std::size_t i=0; i<numGeo; ++i) {
-            int geoId = ret - int(numGeo - i);
-            tuple.setItem(i, Py::Long(geoId));
+            std::size_t numGeo = geoIdList.size();
+            Py::Tuple tuple(numGeo);
+            for (std::size_t i=0; i<numGeo; ++i) {
+                int geoId = ret - int(numGeo - i);
+                tuple.setItem(i, Py::Long(geoId));
+            }
+
+            return Py::new_reference_to(tuple);
+        }
+        catch(const Base::ValueError & e) {
+            throw Py::ValueError(e.getMessage());
         }
 
-        return Py::new_reference_to(tuple);
     }
 
     std::string error = std::string("type must be list of GeoIds, not ");
@@ -1124,11 +1281,18 @@ PyObject* SketchObjectPy::addRectangularArray(PyObject *args)
 #endif
         }
 
-        int ret = this->getSketchObjectPtr()->addCopy(geoIdList,vect, false, PyObject_IsTrue(clone) ? true : false,
-                                                      rows, cols, PyObject_IsTrue(constraindisplacement) ? true : false, perpscale) + 1;
+        try {
+            int ret = this->getSketchObjectPtr()->addCopy(geoIdList,vect, false, PyObject_IsTrue(clone) ? true : false,
+                                                        rows, cols, PyObject_IsTrue(constraindisplacement) ? true : false, perpscale) + 1;
+
+            if(ret == -1)
+                throw Py::TypeError("Copy operation unsuccessful!");
+
+        }
+        catch(const Base::ValueError & e) {
+            throw Py::ValueError(e.getMessage());
+        }
 
-        if(ret == -1)
-            throw Py::TypeError("Copy operation unsuccessful!");
         Py_Return;
     }
 
@@ -1305,6 +1469,18 @@ PyObject* SketchObjectPy::increaseBSplineDegree(PyObject *args)
     Py_Return;
 }
 
+PyObject* SketchObjectPy::decreaseBSplineDegree(PyObject *args)
+{
+    int GeoId;
+    int decr = 1;
+
+    if (!PyArg_ParseTuple(args, "i|i", &GeoId, &decr))
+        return nullptr;
+
+    bool ok = this->getSketchObjectPtr()->decreaseBSplineDegree(GeoId, decr);
+    return Py_BuildValue("O", (ok ? Py_True : Py_False));
+}
+
 PyObject* SketchObjectPy::modifyBSplineKnotMultiplicity(PyObject *args)
 {
     int GeoId;
@@ -1647,6 +1823,82 @@ Py::Long SketchObjectPy::getAxisCount(void) const
     return Py::Long(this->getSketchObjectPtr()->getAxisCount());
 }
 
+
+Py::List SketchObjectPy::getGeometryFacadeList(void) const
+{
+    Py::List list;
+
+    for (int i = 0; i < getSketchObjectPtr()->Geometry.getSize(); i++) {
+
+        // we create a python copy and add it to the list
+        std::unique_ptr<GeometryFacade> geofacade = GeometryFacade::getFacade(getSketchObjectPtr()->Geometry[i]->clone());
+
+        Py::Object gfp = Py::Object(new GeometryFacadePy(geofacade.release()),true);
+
+        list.append(gfp);
+    }
+    return list;
+}
+
+void SketchObjectPy::setGeometryFacadeList(Py::List value)
+{
+    std::vector<Part::Geometry *> list;
+    list.reserve(value.size());
+
+    for (const auto & ti : value) {
+        if (PyObject_TypeCheck(ti.ptr(), &(GeometryFacadePy::Type))) {
+
+            GeometryFacadePy * gfp = static_cast<GeometryFacadePy *>(ti.ptr());
+
+            GeometryFacade * gf = gfp->getGeometryFacadePtr();
+
+            Part::Geometry * geo = gf->getGeometry()->clone();
+
+            list.push_back(geo);
+        }
+    }
+
+    getSketchObjectPtr()->Geometry.setValues(std::move(list));
+}
+
+PyObject* SketchObjectPy::getGeometryId(PyObject *args)
+{
+    int Index;
+    if (!PyArg_ParseTuple(args, "i", &Index))
+        return 0;
+
+    long Id;
+
+    if (this->getSketchObjectPtr()->getGeometryId(Index, Id)) {
+        std::stringstream str;
+        str << "Not able to get geometry Id of a geometry with the given index: " << Index;
+        PyErr_SetString(PyExc_ValueError, str.str().c_str());
+        Py_Return;
+    }
+
+    return  Py::new_reference_to(Py::Long(Id));
+}
+
+PyObject* SketchObjectPy::setGeometryId(PyObject *args)
+{
+    int Index;
+    long Id;
+    if (!PyArg_ParseTuple(args, "il", &Index, &Id))
+        return 0;
+
+    if (this->getSketchObjectPtr()->setGeometryId(Index, Id)) {
+        std::stringstream str;
+        str << "Not able to set geometry Id of a geometry with the given index: " << Index;
+        PyErr_SetString(PyExc_ValueError, str.str().c_str());
+        return 0;
+    }
+
+    Py_Return;
+}
+
+
+
+
 PyObject *SketchObjectPy::getCustomAttributes(const char* /*attr*/) const
 {
     return 0;
