@@ -26,9 +26,7 @@
 
 #include <Gui/TaskView/TaskView.h>
 #include <Gui/Selection.h>
-#include <boost/signals2.hpp>
-
-class Ui_TaskSketcherGeneral;
+#include <boost_signals2.hpp>
 
 namespace App {
 class Property;
@@ -40,6 +38,7 @@ class ViewProvider;
 
 namespace SketcherGui {
 
+class Ui_TaskSketcherGeneral;
 class ViewProviderSketch;
 
 class SketcherGeneralWidget : public QWidget
@@ -49,36 +48,34 @@ class SketcherGeneralWidget : public QWidget
 public:
     SketcherGeneralWidget(QWidget *parent=0);
     ~SketcherGeneralWidget();
+    
+    bool eventFilter(QObject *object, QEvent *event);
 
     void saveSettings();
+    void saveOrderingOrder();
     void loadSettings();
+    void loadOrderingOrder();
     void setGridSize(double val);
     void checkGridView(bool);
     void checkGridSnap(bool);
     void checkAutoconstraints(bool);
-
-    bool isGridViewChecked() const;
-    void saveGridViewChecked();
+    void checkAvoidRedundant(bool);
+    void enableGridSettings(bool);
+    void enableAvoidRedundant(bool);
 
 Q_SIGNALS:
     void emitToggleGridView(bool);
-    void emitToggleGridSnap(int);
+    void emitToggleGridSnap(bool);
     void emitSetGridSize(double);
-    void emitToggleAutoconstraints(int);
+    void emitToggleAutoconstraints(bool);
+    void emitToggleAvoidRedundant(bool);
     void emitRenderOrderChanged();
 
-private Q_SLOTS:
-    void onToggleGridView(bool on);
-    void onSetGridSize(double val);
-    void onToggleGridSnap(int state);
-    void onRenderOrderChanged();
-    void on_checkBoxRedundantAutoconstraints_stateChanged(int);
-
 protected:
     void changeEvent(QEvent *e);
 
 private:
-    Ui_TaskSketcherGeneral* ui;
+    std::unique_ptr<Ui_TaskSketcherGeneral> ui;
 };
 
 class TaskSketcherGeneral : public Gui::TaskView::TaskBox,
@@ -96,8 +93,9 @@ public:
 public Q_SLOTS:
     void onToggleGridView(bool on);
     void onSetGridSize(double val);
-    void onToggleGridSnap(int state);
-    void onToggleAutoconstraints(int state);
+    void onToggleGridSnap(bool on);
+    void onToggleAutoconstraints(bool on);
+    void onToggleAvoidRedundant(bool);
     void onRenderOrderChanged();
 
 private:
