@@ -24,6 +24,7 @@
 #include "PreCompiled.h"
 
 #ifndef _PreComp_
+# include <boost_bind_bind.hpp>
 #endif
 
 #include "ui_TaskSketcherMessages.h"
@@ -36,7 +37,7 @@
 #include <Gui/Selection.h>
 #include <Gui/Command.h>
 
-#include <boost/bind.hpp>
+
 
 #include <Mod/Sketcher/App/SketchObject.h>
 
@@ -44,21 +45,22 @@
 
 using namespace SketcherGui;
 using namespace Gui::TaskView;
+namespace bp = boost::placeholders;
 
-TaskSketcherMessages::TaskSketcherMessages(ViewProviderSketch *sketchView)
-    : TaskBox(Gui::BitmapFactory().pixmap("document-new"),tr("Solver messages"),true, 0)
-    , sketchView(sketchView)
+TaskSketcherMessages::TaskSketcherMessages(ViewProviderSketch *sketchView) :
+    TaskBox(Gui::BitmapFactory().pixmap("document-new"), tr("Solver messages"), true, 0),
+    sketchView(sketchView),
+    ui(new Ui_TaskSketcherMessages)
 {
     // we need a separate container widget to add all controls to
     proxy = new QWidget(this);
-    ui = new Ui_TaskSketcherMessages();
     ui->setupUi(proxy);
     QMetaObject::connectSlotsByName(this);
 
     this->groupLayout()->addWidget(proxy);
 
-    connectionSetUp = sketchView->signalSetUp.connect(boost::bind(&SketcherGui::TaskSketcherMessages::slotSetUp, this,_1));
-    connectionSolved = sketchView->signalSolved.connect(boost::bind(&SketcherGui::TaskSketcherMessages::slotSolved, this,_1));
+    connectionSetUp = sketchView->signalSetUp.connect(boost::bind(&SketcherGui::TaskSketcherMessages::slotSetUp, this, bp::_1));
+    connectionSolved = sketchView->signalSolved.connect(boost::bind(&SketcherGui::TaskSketcherMessages::slotSolved, this, bp::_1));
 
     ui->labelConstrainStatus->setOpenExternalLinks(false);
 
@@ -81,14 +83,13 @@ TaskSketcherMessages::TaskSketcherMessages(ViewProviderSketch *sketchView)
     QObject::connect(
         ui->manualUpdate, SIGNAL(clicked(bool)),
         this                     , SLOT  (on_manualUpdate_clicked(bool))
-       );*/   
+       );*/
 }
 
 TaskSketcherMessages::~TaskSketcherMessages()
 {
     connectionSetUp.disconnect();
     connectionSolved.disconnect();
-    delete ui;
 }
 
 void TaskSketcherMessages::slotSetUp(QString msg)
@@ -105,13 +106,19 @@ void TaskSketcherMessages::on_labelConstrainStatus_linkActivated(const QString &
 {
     if( str == QString::fromLatin1("#conflicting"))
         Gui::Application::Instance->commandManager().runCommandByName("Sketcher_SelectConflictingConstraints");
-    
+    else
     if( str == QString::fromLatin1("#redundant"))
         Gui::Application::Instance->commandManager().runCommandByName("Sketcher_SelectRedundantConstraints");
-    
+    else
     if( str == QString::fromLatin1("#dofs"))
         Gui::Application::Instance->commandManager().runCommandByName("Sketcher_SelectElementsWithDoFs");
-    
+    else
+    if( str == QString::fromLatin1("#malformed"))
+        Gui::Application::Instance->commandManager().runCommandByName("Sketcher_SelectMalformedConstraints");
+        else
+    if( str == QString::fromLatin1("#partiallyredundant"))
+        Gui::Application::Instance->commandManager().runCommandByName("Sketcher_SelectPartiallyRedundantConstraints");
+
 }
 
 void TaskSketcherMessages::on_autoUpdate_stateChanged(int state)
