@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (c) 2015 Eivind Kvedalen (eivind@kvedalen.name)             *
  *   Copyright (c) 2006 Werner Mayer <wmayer[at]users.sourceforge.net>     *
+ *   Copyright (c) 2015 Eivind Kvedalen <eivind@kvedalen.name>             *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -117,7 +117,7 @@ PyMOD_INIT_FUNC(SpreadsheetGui)
 
     SpreadsheetGui::ViewProviderSheet::init();
     SpreadsheetGui::Workbench::init();
-//    SpreadsheetGui::SheetView::init();
+    SpreadsheetGui::SheetView::init();
 
     // add resources and reloads the translators
     loadSpreadsheetResource();
