@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="hr" sourcelanguage="en">
+<TS version="2.1" language="hr" sourcelanguage="en">
   <context>
     <name>CmdCreateSpreadsheet</name>
     <message>
@@ -147,8 +147,8 @@
       <translation>Spajanje ćelija</translation>
     </message>
     <message>
-      <source>Merge selected cells in spreadsheet</source>
-      <translation>Spoji odabrane ćelije u proračunskoj tablici</translation>
+      <source>Merge selected cells</source>
+      <translation>Spajanja odabranih ćelija</translation>
     </message>
   </context>
   <context>
@@ -163,7 +163,7 @@
     </message>
     <message>
       <source>Set alias for selected cell</source>
-      <translation>Postavite nadimak za odabrane ćelije</translation>
+      <translation>Postavite pseudonim za odabrane ćelije</translation>
     </message>
   </context>
   <context>
@@ -177,8 +177,8 @@
       <translation>Podijeli ćeliju</translation>
     </message>
     <message>
-      <source>Split previously merged cells in spreadsheet</source>
-      <translation>Podjela prethodno spojenih ćelija u proračunskoj tablici</translation>
+      <source>Split previously merged cells</source>
+      <translation>Razdjeli prije spojene ćelije</translation>
     </message>
   </context>
   <context>
@@ -192,8 +192,8 @@
       <translation>Podebljani tekst</translation>
     </message>
     <message>
-      <source>Set bold text in selected cells</source>
-      <translation>Postavljanje podebljanoga teksta u odabranim ćelijama</translation>
+      <source>Set text in selected cells bold</source>
+      <translation>Postavi tekst u odabranim ćelijama podebljano</translation>
     </message>
   </context>
   <context>
@@ -207,8 +207,8 @@
       <translation>Ukošeni tekst</translation>
     </message>
     <message>
-      <source>Set italic text in selected cells</source>
-      <translation>Postavite ukošeni teksta u odabranim ćelijama</translation>
+      <source>Set text in selected cells italic</source>
+      <translation>Postavi tekst u odabranim ćelijama ukošeno</translation>
     </message>
   </context>
   <context>
@@ -233,6 +233,89 @@
       <translation>Prilagođena boja</translation>
     </message>
   </context>
+  <context>
+    <name>Command</name>
+    <message>
+      <source>Merge cells</source>
+      <translation>Spajanje ćelija</translation>
+    </message>
+    <message>
+      <source>Split cell</source>
+      <translation>Podijeli ćeliju</translation>
+    </message>
+    <message>
+      <source>Left-align cell</source>
+      <translation>Ćeliju poravnaj lijevo</translation>
+    </message>
+    <message>
+      <source>Center cell</source>
+      <translation>centriraj ćeliju</translation>
+    </message>
+    <message>
+      <source>Right-align cell</source>
+      <translation>Ćeliju poravnaj desno</translation>
+    </message>
+    <message>
+      <source>Top-align cell</source>
+      <translation>Ćeliju poravnaj  na gore</translation>
+    </message>
+    <message>
+      <source>Bottom-align cell</source>
+      <translation>Ćeliju poravnaj  na dolje</translation>
+    </message>
+    <message>
+      <source>Vertically center cells</source>
+      <translation>Ćeliju centriraj uspravno</translation>
+    </message>
+    <message>
+      <source>Set bold text</source>
+      <translation>Postavi podebljani tekst</translation>
+    </message>
+    <message>
+      <source>Set italic text</source>
+      <translation>Postavi ukošeni tekst</translation>
+    </message>
+    <message>
+      <source>Set underline text</source>
+      <translation>Postavi podcrtani tekst</translation>
+    </message>
+    <message>
+      <source>Create Spreadsheet</source>
+      <translation>Stvori proračunsku tablicu</translation>
+    </message>
+    <message>
+      <source>Set cell properties</source>
+      <translation>Postavi svojstava ćelija</translation>
+    </message>
+    <message>
+      <source>Edit cell</source>
+      <translation>Uredi ćeliju</translation>
+    </message>
+    <message>
+      <source>Insert rows</source>
+      <translation>Umetni redove</translation>
+    </message>
+    <message>
+      <source>Remove rows</source>
+      <translation>Ukloni redove</translation>
+    </message>
+    <message>
+      <source>Insert columns</source>
+      <translation>Umetni stupce</translation>
+    </message>
+    <message>
+      <source>Clear cell(s)</source>
+      <translation>Obriši ćeliju(e)</translation>
+    </message>
+    <message>
+      <source>Set foreground color</source>
+      <translation>Postavi boju prednjeg plana</translation>
+    </message>
+    <message>
+      <source>Set background color</source>
+      <translation>Postavi boju pozadine</translation>
+    </message>
+  </context>
   <context>
     <name>PropertiesDialog</name>
     <message>
@@ -313,7 +396,7 @@
     </message>
     <message>
       <source>Alias for this cell</source>
-      <translation>Nadimak za ovu ćeliju</translation>
+      <translation>Pseudonim za ovu ćeliju</translation>
     </message>
   </context>
   <context>
@@ -330,10 +413,6 @@
       <source>Export file</source>
       <translation>Izvoz datoteke</translation>
     </message>
-    <message>
-      <source>Cell contents</source>
-      <translation>Sadržaj ćelije</translation>
-    </message>
     <message>
       <source>Show spreadsheet</source>
       <translation>Pokaži Proračunsku Tablicu</translation>
@@ -354,6 +433,35 @@
       <source>Sets the Spreadsheet cell(s) background color</source>
       <translation>Postavlja boju pozadine ćelije proračunske tablice</translation>
     </message>
+    <message>
+      <source>Spreadsheet</source>
+      <translation>Proračunska tablica</translation>
+    </message>
+    <message>
+      <source>Spreadsheet does not support range selection when pasting.
+Please select one cell only.</source>
+      <translation>Proračunska tablica ne podržava odabir raspona prilikom umetanja.
+Odaberite samo jednu ćeliju.
+</translation>
+    </message>
+    <message>
+      <source>Copy &amp; Paste failed</source>
+      <translation>Copy &amp; Paste nije uspjelo</translation>
+    </message>
+    <message>
+      <source>Alias contains invalid characters!</source>
+      <translation>Pseudonim sadrži nevažeće znakove!
+
+</translation>
+    </message>
+    <message>
+      <source>Refer to cell by alias, for example
+Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
+      <translation>Referenca na ćeliju sa pseudonimom, na primjer
+Spreadsheet.my_alias_name umjesto Spreadsheet.B1
+
+</translation>
+    </message>
   </context>
   <context>
     <name>QtColorPicker</name>
@@ -426,8 +534,8 @@
       <translation>Svjetlo siva</translation>
     </message>
     <message>
-      <source>Custom</source>
-      <translation>Prilagođeno</translation>
+      <source>Custom Color</source>
+      <translation>Prilagođena boja</translation>
     </message>
   </context>
   <context>
@@ -437,8 +545,20 @@
       <translation>Obrazac</translation>
     </message>
     <message>
-      <source>&amp;Contents</source>
-      <translation>&amp;Sadržaj</translation>
+      <source>&amp;Content:</source>
+      <translation>&amp;Sadržaj:</translation>
+    </message>
+    <message>
+      <source>&amp;Alias:</source>
+      <translation>&amp;Pseudonim:</translation>
+    </message>
+    <message>
+      <source>Refer to cell by alias, for example
+Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
+      <translation>Referenca na ćeliju sa pseudonimom, na primjer
+Spreadsheet.my_alias_name umjesto Spreadsheet.B1
+
+</translation>
     </message>
   </context>
   <context>
