@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="ja" sourcelanguage="en">
+<TS version="2.1" language="ja" sourcelanguage="en">
   <context>
     <name>CmdCreateSpreadsheet</name>
     <message>
@@ -103,7 +103,7 @@
     </message>
     <message>
       <source>Vertically center-align contents of selected cells</source>
-      <translation type="unfinished">Vertically center-align contents of selected cells</translation>
+      <translation>選択したセルの内容を縦方向中央揃えにする</translation>
     </message>
   </context>
   <context>
@@ -147,8 +147,8 @@
       <translation>セルの結合</translation>
     </message>
     <message>
-      <source>Merge selected cells in spreadsheet</source>
-      <translation>スプレッドシートで選択したセルを結合します</translation>
+      <source>Merge selected cells</source>
+      <translation>選択したセルを結合</translation>
     </message>
   </context>
   <context>
@@ -159,11 +159,11 @@
     </message>
     <message>
       <source>Set alias</source>
-      <translation>別名設定</translation>
+      <translation>エイリアスを設定</translation>
     </message>
     <message>
       <source>Set alias for selected cell</source>
-      <translation>選択したセルに別名を設定</translation>
+      <translation>選択したセルのエイリアスを設定</translation>
     </message>
   </context>
   <context>
@@ -177,8 +177,8 @@
       <translation>セルの分割</translation>
     </message>
     <message>
-      <source>Split previously merged cells in spreadsheet</source>
-      <translation>スプレッドシートにある結合セルを分割します</translation>
+      <source>Split previously merged cells</source>
+      <translation>結合されているセルを分割</translation>
     </message>
   </context>
   <context>
@@ -192,8 +192,8 @@
       <translation>太字</translation>
     </message>
     <message>
-      <source>Set bold text in selected cells</source>
-      <translation>選択したセルのテキストを太字に設定します。</translation>
+      <source>Set text in selected cells bold</source>
+      <translation>選択したセルのテキストに太字を設定</translation>
     </message>
   </context>
   <context>
@@ -207,8 +207,8 @@
       <translation>斜体</translation>
     </message>
     <message>
-      <source>Set italic text in selected cells</source>
-      <translation>選択したセルのテキストを斜体に設定します。</translation>
+      <source>Set text in selected cells italic</source>
+      <translation>選択したセルのテキストに斜体を設定</translation>
     </message>
   </context>
   <context>
@@ -223,14 +223,97 @@
     </message>
     <message>
       <source>Underline text in selected cells</source>
-      <translation type="unfinished">Underline text in selected cells</translation>
+      <translation>選択したセルに下線を設定</translation>
     </message>
   </context>
   <context>
     <name>ColorPickerPopup</name>
     <message>
       <source>Custom Color</source>
-      <translation type="unfinished">Custom Color</translation>
+      <translation>カスタム色</translation>
+    </message>
+  </context>
+  <context>
+    <name>Command</name>
+    <message>
+      <source>Merge cells</source>
+      <translation>セルの結合</translation>
+    </message>
+    <message>
+      <source>Split cell</source>
+      <translation>セルの分割</translation>
+    </message>
+    <message>
+      <source>Left-align cell</source>
+      <translation>セルを左揃え</translation>
+    </message>
+    <message>
+      <source>Center cell</source>
+      <translation>セルを中央揃え</translation>
+    </message>
+    <message>
+      <source>Right-align cell</source>
+      <translation>セルを右揃え</translation>
+    </message>
+    <message>
+      <source>Top-align cell</source>
+      <translation>セルを上揃え</translation>
+    </message>
+    <message>
+      <source>Bottom-align cell</source>
+      <translation>セルを下揃え</translation>
+    </message>
+    <message>
+      <source>Vertically center cells</source>
+      <translation>セルを上下中央揃え</translation>
+    </message>
+    <message>
+      <source>Set bold text</source>
+      <translation>太字にする</translation>
+    </message>
+    <message>
+      <source>Set italic text</source>
+      <translation>斜体にする</translation>
+    </message>
+    <message>
+      <source>Set underline text</source>
+      <translation>下線</translation>
+    </message>
+    <message>
+      <source>Create Spreadsheet</source>
+      <translation>スプレッドシートを作成</translation>
+    </message>
+    <message>
+      <source>Set cell properties</source>
+      <translation>セルのプロパティ</translation>
+    </message>
+    <message>
+      <source>Edit cell</source>
+      <translation>セルを編集</translation>
+    </message>
+    <message>
+      <source>Insert rows</source>
+      <translation>行を挿入</translation>
+    </message>
+    <message>
+      <source>Remove rows</source>
+      <translation>行を削除</translation>
+    </message>
+    <message>
+      <source>Insert columns</source>
+      <translation>列を挿入</translation>
+    </message>
+    <message>
+      <source>Clear cell(s)</source>
+      <translation>セルをクリア</translation>
+    </message>
+    <message>
+      <source>Set foreground color</source>
+      <translation>文字色を設定</translation>
+    </message>
+    <message>
+      <source>Set background color</source>
+      <translation>背景色を設定</translation>
     </message>
   </context>
   <context>
@@ -293,7 +376,7 @@
     </message>
     <message>
       <source>Italic</source>
-      <translation>斜体字</translation>
+      <translation>斜体</translation>
     </message>
     <message>
       <source>Underline</source>
@@ -313,14 +396,14 @@
     </message>
     <message>
       <source>Alias for this cell</source>
-      <translation>このセルのエイリアス</translation>
+      <translation>エイリアス名</translation>
     </message>
   </context>
   <context>
     <name>QObject</name>
     <message>
       <source>All (*)</source>
-      <translation>全て (*)</translation>
+      <translation>すべてのファイル (*.*)</translation>
     </message>
     <message>
       <source>Import file</source>
@@ -330,10 +413,6 @@
       <source>Export file</source>
       <translation>ファイルのエクスポート</translation>
     </message>
-    <message>
-      <source>Cell contents</source>
-      <translation>セルの内容</translation>
-    </message>
     <message>
       <source>Show spreadsheet</source>
       <translation>スプレッドシートを表示</translation>
@@ -354,6 +433,30 @@
       <source>Sets the Spreadsheet cell(s) background color</source>
       <translation>スプレッドシートのセルの背景色を設定</translation>
     </message>
+    <message>
+      <source>Spreadsheet</source>
+      <translation>スプレッドシート</translation>
+    </message>
+    <message>
+      <source>Spreadsheet does not support range selection when pasting.
+Please select one cell only.</source>
+      <translation>スプレッドシートは、貼り付けるときに選択範囲をサポートしていません。
+セルを一つだけ選択してください。</translation>
+    </message>
+    <message>
+      <source>Copy &amp; Paste failed</source>
+      <translation>コピー＆ペーストに失敗しました</translation>
+    </message>
+    <message>
+      <source>Alias contains invalid characters!</source>
+      <translation>エイリアスに無効な文字が含まれています！</translation>
+    </message>
+    <message>
+      <source>Refer to cell by alias, for example
+Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
+      <translation>Spreadsheet.B1 の代わりに
+Spreadsheet.my_alias_name のように、エイリアスでセルを参照してください。</translation>
+    </message>
   </context>
   <context>
     <name>QtColorPicker</name>
@@ -426,8 +529,8 @@
       <translation>明るい灰色</translation>
     </message>
     <message>
-      <source>Custom</source>
-      <translation>色の編集</translation>
+      <source>Custom Color</source>
+      <translation>カスタム色</translation>
     </message>
   </context>
   <context>
@@ -437,9 +540,19 @@
       <translation>フォーム</translation>
     </message>
     <message>
-      <source>&amp;Contents</source>
+      <source>&amp;Content:</source>
       <translation>内容 (&amp;C)</translation>
     </message>
+    <message>
+      <source>&amp;Alias:</source>
+      <translation>エイリアス (&amp;A):</translation>
+    </message>
+    <message>
+      <source>Refer to cell by alias, for example
+Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
+      <translation>Spreadsheet.B1 の代わりに
+Spreadsheet.my_alias_name のように、エイリアスでセルを参照してください。</translation>
+    </message>
   </context>
   <context>
     <name>SpreadsheetGui::Module</name>
