@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="nl" sourcelanguage="en">
+<TS version="2.1" language="nl" sourcelanguage="en">
   <context>
     <name>CmdCreateSpreadsheet</name>
     <message>
@@ -147,8 +147,8 @@
       <translation>Cellen samenvoegen</translation>
     </message>
     <message>
-      <source>Merge selected cells in spreadsheet</source>
-      <translation>De geselecteerde cellen in rekenblad samenvoegen</translation>
+      <source>Merge selected cells</source>
+      <translation>Geselecteerde cellen samenvoegen</translation>
     </message>
   </context>
   <context>
@@ -177,8 +177,8 @@
       <translation>Cel splitsen</translation>
     </message>
     <message>
-      <source>Split previously merged cells in spreadsheet</source>
-      <translation>Eerder samengevoegde cellen in werkblad splitsen</translation>
+      <source>Split previously merged cells</source>
+      <translation>Eerder samengevoegde cellen splitsen</translation>
     </message>
   </context>
   <context>
@@ -192,8 +192,8 @@
       <translation>Vette tekst</translation>
     </message>
     <message>
-      <source>Set bold text in selected cells</source>
-      <translation>Vette tekst instellen in geselecteerde cellen</translation>
+      <source>Set text in selected cells bold</source>
+      <translation>Tekst in geselecteerde cellen vet instellen</translation>
     </message>
   </context>
   <context>
@@ -207,8 +207,8 @@
       <translation>Cursieve tekst</translation>
     </message>
     <message>
-      <source>Set italic text in selected cells</source>
-      <translation>Cursieve tekst in geselecteerde cellen instellen</translation>
+      <source>Set text in selected cells italic</source>
+      <translation>Tekst in geselecteerde cellen cursief instellen</translation>
     </message>
   </context>
   <context>
@@ -233,6 +233,89 @@
       <translation>Aangepaste kleur</translation>
     </message>
   </context>
+  <context>
+    <name>Command</name>
+    <message>
+      <source>Merge cells</source>
+      <translation>Cellen samenvoegen</translation>
+    </message>
+    <message>
+      <source>Split cell</source>
+      <translation>Cel splitsen</translation>
+    </message>
+    <message>
+      <source>Left-align cell</source>
+      <translation type="unfinished">Left-align cell</translation>
+    </message>
+    <message>
+      <source>Center cell</source>
+      <translation type="unfinished">Center cell</translation>
+    </message>
+    <message>
+      <source>Right-align cell</source>
+      <translation type="unfinished">Right-align cell</translation>
+    </message>
+    <message>
+      <source>Top-align cell</source>
+      <translation type="unfinished">Top-align cell</translation>
+    </message>
+    <message>
+      <source>Bottom-align cell</source>
+      <translation type="unfinished">Bottom-align cell</translation>
+    </message>
+    <message>
+      <source>Vertically center cells</source>
+      <translation>Cellen verticaal centreren</translation>
+    </message>
+    <message>
+      <source>Set bold text</source>
+      <translation type="unfinished">Set bold text</translation>
+    </message>
+    <message>
+      <source>Set italic text</source>
+      <translation>Cursieve tekst instellen</translation>
+    </message>
+    <message>
+      <source>Set underline text</source>
+      <translation type="unfinished">Set underline text</translation>
+    </message>
+    <message>
+      <source>Create Spreadsheet</source>
+      <translation type="unfinished">Create Spreadsheet</translation>
+    </message>
+    <message>
+      <source>Set cell properties</source>
+      <translation>Celeigenschappen instellen</translation>
+    </message>
+    <message>
+      <source>Edit cell</source>
+      <translation>Cel bewerken</translation>
+    </message>
+    <message>
+      <source>Insert rows</source>
+      <translation>Rijen invoegen</translation>
+    </message>
+    <message>
+      <source>Remove rows</source>
+      <translation>Rijen verwijderen</translation>
+    </message>
+    <message>
+      <source>Insert columns</source>
+      <translation>Kolommen invoegen</translation>
+    </message>
+    <message>
+      <source>Clear cell(s)</source>
+      <translation type="unfinished">Clear cell(s)</translation>
+    </message>
+    <message>
+      <source>Set foreground color</source>
+      <translation>Voorgrondkleur instellen</translation>
+    </message>
+    <message>
+      <source>Set background color</source>
+      <translation>Achtergrondkleur instellen</translation>
+    </message>
+  </context>
   <context>
     <name>PropertiesDialog</name>
     <message>
@@ -330,10 +413,6 @@
       <source>Export file</source>
       <translation>Bestand exporteren</translation>
     </message>
-    <message>
-      <source>Cell contents</source>
-      <translation>Celinhoud</translation>
-    </message>
     <message>
       <source>Show spreadsheet</source>
       <translation>Rekenblad tonen</translation>
@@ -354,6 +433,30 @@
       <source>Sets the Spreadsheet cell(s) background color</source>
       <translation>Stelt de achtergrondkleur van de Spreadsheet-cel(len) op</translation>
     </message>
+    <message>
+      <source>Spreadsheet</source>
+      <translation>Rekenblad</translation>
+    </message>
+    <message>
+      <source>Spreadsheet does not support range selection when pasting.
+Please select one cell only.</source>
+      <translation>Rekenblad ondersteunt geen bereikselectie bij het plakken.
+Gelieve slechts één cel te kiezen.</translation>
+    </message>
+    <message>
+      <source>Copy &amp; Paste failed</source>
+      <translation>Kopiëren en plakken mislukt</translation>
+    </message>
+    <message>
+      <source>Alias contains invalid characters!</source>
+      <translation>Alias bevat ongeldige tekens!</translation>
+    </message>
+    <message>
+      <source>Refer to cell by alias, for example
+Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
+      <translation>Verwijs naar cel met een alias, bijvoorbeeld
+Spreadsheet.mijn_alias_naam in plaats van Spreadsheet.B1</translation>
+    </message>
   </context>
   <context>
     <name>QtColorPicker</name>
@@ -426,8 +529,8 @@
       <translation>Lichtgrijs</translation>
     </message>
     <message>
-      <source>Custom</source>
-      <translation>Eigen</translation>
+      <source>Custom Color</source>
+      <translation>Aangepaste kleur</translation>
     </message>
   </context>
   <context>
@@ -437,8 +540,18 @@
       <translation>Vorm</translation>
     </message>
     <message>
-      <source>&amp;Contents</source>
-      <translation>&amp;Inhoud</translation>
+      <source>&amp;Content:</source>
+      <translation>&amp;Inhoud:</translation>
+    </message>
+    <message>
+      <source>&amp;Alias:</source>
+      <translation>&amp;Alias:</translation>
+    </message>
+    <message>
+      <source>Refer to cell by alias, for example
+Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
+      <translation>Verwijs naar cel met een alias, bijvoorbeeld
+Spreadsheet.mijn_alias_naam in plaats van Spreadsheet.B1</translation>
     </message>
   </context>
   <context>
