@@ -1,26 +1,26 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="sv-SE" sourcelanguage="en">
+<TS version="2.1" language="sv-SE" sourcelanguage="en">
   <context>
     <name>CmdCreateSpreadsheet</name>
     <message>
       <source>Spreadsheet</source>
-      <translation>Kalkylblad</translation>
+      <translation>Kalkylark</translation>
     </message>
     <message>
       <source>Create spreadsheet</source>
-      <translation>Skapa kalkylblad</translation>
+      <translation>Skapa kalkylark</translation>
     </message>
     <message>
       <source>Create a new spreadsheet</source>
-      <translation>Skapa ett nytt kalkylblad</translation>
+      <translation>Skapa ett nytt kalkylark</translation>
     </message>
   </context>
   <context>
     <name>CmdSpreadsheetAlignBottom</name>
     <message>
       <source>Spreadsheet</source>
-      <translation>Kalkylblad</translation>
+      <translation>Kalkylark</translation>
     </message>
     <message>
       <source>Align bottom</source>
@@ -35,7 +35,7 @@
     <name>CmdSpreadsheetAlignCenter</name>
     <message>
       <source>Spreadsheet</source>
-      <translation>Kalkylblad</translation>
+      <translation>Kalkylark</translation>
     </message>
     <message>
       <source>Align center</source>
@@ -50,7 +50,7 @@
     <name>CmdSpreadsheetAlignLeft</name>
     <message>
       <source>Spreadsheet</source>
-      <translation>Kalkylblad</translation>
+      <translation>Kalkylark</translation>
     </message>
     <message>
       <source>Align left</source>
@@ -65,7 +65,7 @@
     <name>CmdSpreadsheetAlignRight</name>
     <message>
       <source>Spreadsheet</source>
-      <translation>Kalkylblad</translation>
+      <translation>Kalkylark</translation>
     </message>
     <message>
       <source>Align right</source>
@@ -80,7 +80,7 @@
     <name>CmdSpreadsheetAlignTop</name>
     <message>
       <source>Spreadsheet</source>
-      <translation>Kalkylblad</translation>
+      <translation>Kalkylark</translation>
     </message>
     <message>
       <source>Align top</source>
@@ -88,14 +88,14 @@
     </message>
     <message>
       <source>Top-align contents of selected cells</source>
-      <translation>Topjustera innehållet i markerade celler</translation>
+      <translation>Toppjustera innehållet i markerade celler</translation>
     </message>
   </context>
   <context>
     <name>CmdSpreadsheetAlignVCenter</name>
     <message>
       <source>Spreadsheet</source>
-      <translation>Kalkylblad</translation>
+      <translation>Kalkylark</translation>
     </message>
     <message>
       <source>Vertically center-align</source>
@@ -110,52 +110,52 @@
     <name>CmdSpreadsheetExport</name>
     <message>
       <source>Spreadsheet</source>
-      <translation>Kalkylblad</translation>
+      <translation>Kalkylark</translation>
     </message>
     <message>
       <source>Export spreadsheet</source>
-      <translation>Exportera kalkylblad</translation>
+      <translation>Exportera kalkylark</translation>
     </message>
     <message>
       <source>Export spreadsheet to CSV file</source>
-      <translation>Exportera kalkylblad till CSV-fil</translation>
+      <translation>Exportera kalkylark till CSV-fil</translation>
     </message>
   </context>
   <context>
     <name>CmdSpreadsheetImport</name>
     <message>
       <source>Spreadsheet</source>
-      <translation>Kalkylblad</translation>
+      <translation>Kalkylark</translation>
     </message>
     <message>
       <source>Import spreadsheet</source>
-      <translation>Importera kalkylblad</translation>
+      <translation>Importera kalkylark</translation>
     </message>
     <message>
       <source>Import CSV file into spreadsheet</source>
-      <translation>Importera CSV-fil till kalkylblad</translation>
+      <translation>Importera CSV-fil till kalkylark</translation>
     </message>
   </context>
   <context>
     <name>CmdSpreadsheetMergeCells</name>
     <message>
       <source>Spreadsheet</source>
-      <translation>Kalkylblad</translation>
+      <translation>Kalkylark</translation>
     </message>
     <message>
       <source>Merge cells</source>
       <translation>Sammanfoga celler</translation>
     </message>
     <message>
-      <source>Merge selected cells in spreadsheet</source>
-      <translation>Sammanfoga markerade celler i kalkylblad</translation>
+      <source>Merge selected cells</source>
+      <translation>Sammanfoga markerade celler</translation>
     </message>
   </context>
   <context>
     <name>CmdSpreadsheetSetAlias</name>
     <message>
       <source>Spreadsheet</source>
-      <translation>Kalkylblad</translation>
+      <translation>Kalkylark</translation>
     </message>
     <message>
       <source>Set alias</source>
@@ -170,52 +170,52 @@
     <name>CmdSpreadsheetSplitCell</name>
     <message>
       <source>Spreadsheet</source>
-      <translation>Kalkylblad</translation>
+      <translation>Kalkylark</translation>
     </message>
     <message>
       <source>Split cell</source>
-      <translation>Dela upp cell</translation>
+      <translation>Dela cell</translation>
     </message>
     <message>
-      <source>Split previously merged cells in spreadsheet</source>
-      <translation>Dela upp tidigare sammanfogade celler i kalkylblad</translation>
+      <source>Split previously merged cells</source>
+      <translation>Dela sammanslagna celler</translation>
     </message>
   </context>
   <context>
     <name>CmdSpreadsheetStyleBold</name>
     <message>
       <source>Spreadsheet</source>
-      <translation>Kalkylblad</translation>
+      <translation>Kalkylark</translation>
     </message>
     <message>
       <source>Bold text</source>
       <translation>Fet text</translation>
     </message>
     <message>
-      <source>Set bold text in selected cells</source>
-      <translation>Gör texten fet i markerade celler</translation>
+      <source>Set text in selected cells bold</source>
+      <translation>Gör texten i markerade celler fet</translation>
     </message>
   </context>
   <context>
     <name>CmdSpreadsheetStyleItalic</name>
     <message>
       <source>Spreadsheet</source>
-      <translation>Kalkylblad</translation>
+      <translation>Kalkylark</translation>
     </message>
     <message>
       <source>Italic text</source>
       <translation>Kursiv text</translation>
     </message>
     <message>
-      <source>Set italic text in selected cells</source>
-      <translation>Gör texten kursiv i markerade celler</translation>
+      <source>Set text in selected cells italic</source>
+      <translation>Gör texten i markerade celler kursiv</translation>
     </message>
   </context>
   <context>
     <name>CmdSpreadsheetStyleUnderline</name>
     <message>
       <source>Spreadsheet</source>
-      <translation>Kalkylblad</translation>
+      <translation>Kalkylark</translation>
     </message>
     <message>
       <source>Underline text</source>
@@ -223,7 +223,7 @@
     </message>
     <message>
       <source>Underline text in selected cells</source>
-      <translation>Stryk under text i markerade celler</translation>
+      <translation>Gör texten i markerade celler understruken</translation>
     </message>
   </context>
   <context>
@@ -233,6 +233,89 @@
       <translation>Anpassad färg</translation>
     </message>
   </context>
+  <context>
+    <name>Command</name>
+    <message>
+      <source>Merge cells</source>
+      <translation>Sammanfoga celler</translation>
+    </message>
+    <message>
+      <source>Split cell</source>
+      <translation>Dela cell</translation>
+    </message>
+    <message>
+      <source>Left-align cell</source>
+      <translation type="unfinished">Left-align cell</translation>
+    </message>
+    <message>
+      <source>Center cell</source>
+      <translation type="unfinished">Center cell</translation>
+    </message>
+    <message>
+      <source>Right-align cell</source>
+      <translation type="unfinished">Right-align cell</translation>
+    </message>
+    <message>
+      <source>Top-align cell</source>
+      <translation type="unfinished">Top-align cell</translation>
+    </message>
+    <message>
+      <source>Bottom-align cell</source>
+      <translation type="unfinished">Bottom-align cell</translation>
+    </message>
+    <message>
+      <source>Vertically center cells</source>
+      <translation type="unfinished">Vertically center cells</translation>
+    </message>
+    <message>
+      <source>Set bold text</source>
+      <translation type="unfinished">Set bold text</translation>
+    </message>
+    <message>
+      <source>Set italic text</source>
+      <translation type="unfinished">Set italic text</translation>
+    </message>
+    <message>
+      <source>Set underline text</source>
+      <translation type="unfinished">Set underline text</translation>
+    </message>
+    <message>
+      <source>Create Spreadsheet</source>
+      <translation type="unfinished">Create Spreadsheet</translation>
+    </message>
+    <message>
+      <source>Set cell properties</source>
+      <translation type="unfinished">Set cell properties</translation>
+    </message>
+    <message>
+      <source>Edit cell</source>
+      <translation>Redigera cell</translation>
+    </message>
+    <message>
+      <source>Insert rows</source>
+      <translation>Infoga rader</translation>
+    </message>
+    <message>
+      <source>Remove rows</source>
+      <translation>Ta bort rader</translation>
+    </message>
+    <message>
+      <source>Insert columns</source>
+      <translation>Infoga kolumner</translation>
+    </message>
+    <message>
+      <source>Clear cell(s)</source>
+      <translation type="unfinished">Clear cell(s)</translation>
+    </message>
+    <message>
+      <source>Set foreground color</source>
+      <translation type="unfinished">Set foreground color</translation>
+    </message>
+    <message>
+      <source>Set background color</source>
+      <translation type="unfinished">Set background color</translation>
+    </message>
+  </context>
   <context>
     <name>PropertiesDialog</name>
     <message>
@@ -265,7 +348,7 @@
     </message>
     <message>
       <source>Center</source>
-      <translation>Mitten</translation>
+      <translation>Centrum</translation>
     </message>
     <message>
       <source>Right</source>
@@ -301,11 +384,11 @@
     </message>
     <message>
       <source>&amp;Display unit</source>
-      <translation>Displayenhet</translation>
+      <translation>Visningsenhet</translation>
     </message>
     <message>
       <source>Unit string</source>
-      <translation>Enhetssträng</translation>
+      <translation>Enhetstext</translation>
     </message>
     <message>
       <source>A&amp;lias</source>
@@ -330,29 +413,49 @@
       <source>Export file</source>
       <translation>Exportera fil</translation>
     </message>
-    <message>
-      <source>Cell contents</source>
-      <translation>Cellinnehåll</translation>
-    </message>
     <message>
       <source>Show spreadsheet</source>
       <translation>Visa kalkylark</translation>
     </message>
     <message>
       <source>Set cell(s) foreground color</source>
-      <translation>Ange cellens förgrundsfärg</translation>
+      <translation>Ange förgrundsfärg för cell(er)</translation>
     </message>
     <message>
       <source>Sets the Spreadsheet cell(s) foreground color</source>
-      <translation>Ställer in förgrundsfärgen för cellerna i kalkylbladet</translation>
+      <translation>Anger förgrundsfärgen för cellen/cellerna</translation>
     </message>
     <message>
       <source>Set cell(s) background color</source>
-      <translation>Ange cellens bakgrundsfärg</translation>
+      <translation>Ange bakgrundsfärg för cell(er)</translation>
     </message>
     <message>
       <source>Sets the Spreadsheet cell(s) background color</source>
-      <translation>Ställer in bakgrundsfärgen för cellerna i kalkylbladet</translation>
+      <translation>Anger bakgrundsfärgen för cellen/cellerna</translation>
+    </message>
+    <message>
+      <source>Spreadsheet</source>
+      <translation>Kalkylark</translation>
+    </message>
+    <message>
+      <source>Spreadsheet does not support range selection when pasting.
+Please select one cell only.</source>
+      <translation>Kalkylbladet stöder inte markering av intervall när du klistrar in.
+Välj endast en cell.</translation>
+    </message>
+    <message>
+      <source>Copy &amp; Paste failed</source>
+      <translation>Kopiera och klistra in misslyckades</translation>
+    </message>
+    <message>
+      <source>Alias contains invalid characters!</source>
+      <translation>Alias innehåller ogiltiga tecken!</translation>
+    </message>
+    <message>
+      <source>Refer to cell by alias, for example
+Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
+      <translation>Referera till cellen via alias, till exempel
+Spreadsheet.my_alias_name, istället för Spreadsheet.B1</translation>
     </message>
   </context>
   <context>
@@ -403,7 +506,7 @@
     </message>
     <message>
       <source>Dark magenta</source>
-      <translation>Mörk-magenta</translation>
+      <translation>Mörkmagenta</translation>
     </message>
     <message>
       <source>Yellow</source>
@@ -426,8 +529,8 @@
       <translation>Ljusgrå</translation>
     </message>
     <message>
-      <source>Custom</source>
-      <translation>Anpassad</translation>
+      <source>Custom Color</source>
+      <translation>Anpassad färg</translation>
     </message>
   </context>
   <context>
@@ -437,8 +540,18 @@
       <translation>Form</translation>
     </message>
     <message>
-      <source>&amp;Contents</source>
-      <translation>&amp;Innehåll</translation>
+      <source>&amp;Content:</source>
+      <translation>&amp;Innehåll:</translation>
+    </message>
+    <message>
+      <source>&amp;Alias:</source>
+      <translation>Alias ​​</translation>
+    </message>
+    <message>
+      <source>Refer to cell by alias, for example
+Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
+      <translation>Referera till cellen via alias, till exempel
+Spreadsheet.my_alias_name, istället för Spreadsheet.B1</translation>
     </message>
   </context>
   <context>
@@ -464,7 +577,7 @@
     </message>
     <message>
       <source>Remove columns</source>
-      <translation>Radera kolumner</translation>
+      <translation>Ta bort kolumner</translation>
     </message>
     <message>
       <source>Properties...</source>
@@ -475,7 +588,7 @@
     <name>Workbench</name>
     <message>
       <source>Spreadsheet</source>
-      <translation>Kalkylblad</translation>
+      <translation>Kalkylark</translation>
     </message>
   </context>
 </TS>
