@@ -26,11 +26,18 @@
 # include <QAction>
 # include <QApplication>
 # include <QClipboard>
+# include <QMessageBox>
+# include <QMimeData>
 #endif
 
-#include <Gui/Command.h>
-#include <boost/bind.hpp>
+#include <App/Application.h>
+#include <App/AutoTransaction.h>
+#include <App/Document.h>
+#include <Gui/CommandT.h>
+#include <Gui/MainWindow.h>
+#include <boost_bind_bind.hpp>
 #include "../App/Utils.h"
+#include "../App/Cell.h"
 #include <App/Range.h>
 #include "SheetTableView.h"
 #include "LineEdit.h"
@@ -39,6 +46,7 @@
 using namespace SpreadsheetGui;
 using namespace Spreadsheet;
 using namespace App;
+namespace bp = boost::placeholders;
 
 void SheetViewHeader::mouseReleaseEvent(QMouseEvent *event)
 {
@@ -46,6 +54,25 @@ void SheetViewHeader::mouseReleaseEvent(QMouseEvent *event)
     resizeFinished();
 }
 
+bool SheetViewHeader::viewportEvent(QEvent *e) {
+    if(e->type() == QEvent::ContextMenu) {
+        auto *ce = static_cast<QContextMenuEvent*>(e);
+        int section = logicalIndexAt(ce->pos());
+        if(section>=0) {
+            if(orientation() == Qt::Horizontal) {
+                if(!owner->selectionModel()->isColumnSelected(section,owner->rootIndex())) {
+                    owner->clearSelection();
+                    owner->selectColumn(section);
+                }
+            }else if(!owner->selectionModel()->isRowSelected(section,owner->rootIndex())) {
+                owner->clearSelection();
+                owner->selectRow(section);
+            }
+        }
+    }
+    return QHeaderView::viewportEvent(e);
+}
+
 SheetTableView::SheetTableView(QWidget *parent)
     : QTableView(parent)
     , sheet(0)
@@ -55,8 +82,10 @@ SheetTableView::SheetTableView(QWidget *parent)
     QAction * insertColumns = new QAction(tr("Insert columns"), this);
     QAction * removeColumns = new QAction(tr("Remove columns"), this);
 
-    setHorizontalHeader(new SheetViewHeader(Qt::Horizontal));
-    setVerticalHeader(new SheetViewHeader(Qt::Vertical));
+    setHorizontalHeader(new SheetViewHeader(this,Qt::Horizontal));
+    setVerticalHeader(new SheetViewHeader(this,Qt::Vertical));
+    setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
+    setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);
 
     horizontalHeader()->addAction(insertColumns);
     horizontalHeader()->addAction(removeColumns);
@@ -109,8 +138,8 @@ std::vector<Range> SheetTableView::selectedRanges() const
         std::pair<int, int> ul = (*i).first;
         std::pair<int, int> size = (*i).second;
 
-        result.push_back(Range(ul.first, ul.second,
-                                                   ul.first + size.first - 1, ul.second + size.second - 1));
+        result.emplace_back(ul.first, ul.second,
+                                                   ul.first + size.first - 1, ul.second + size.second - 1);
     }
 
     return result;
@@ -129,7 +158,7 @@ void SheetTableView::insertRows()
     std::sort(sortedRows.begin(), sortedRows.end());
 
     /* Insert rows */
-    Gui::Command::openCommand("Insert rows");
+    Gui::Command::openCommand(QT_TRANSLATE_NOOP("Command", "Insert rows"));
     std::vector<int>::const_reverse_iterator it = sortedRows.rbegin();
     while (it != sortedRows.rend()) {
         int prev = *it;
@@ -147,8 +176,7 @@ void SheetTableView::insertRows()
                 break;
         }
 
-        Gui::Command::doCommand(Gui::Command::Doc,"App.ActiveDocument.%s.insertRows('%s', %d)", sheet->getNameInDocument(),
-                                rowName(prev).c_str(), count);
+        Gui::cmdAppObjectArgs(sheet, "insertRows('%s', %d)", rowName(prev).c_str(), count);
     }
     Gui::Command::commitCommand();
     Gui::Command::doCommand(Gui::Command::Doc, "App.ActiveDocument.recompute()");
@@ -167,10 +195,9 @@ void SheetTableView::removeRows()
     std::sort(sortedRows.begin(), sortedRows.end(), std::greater<int>());
 
     /* Remove rows */
-    Gui::Command::openCommand("Remove rows");
+    Gui::Command::openCommand(QT_TRANSLATE_NOOP("Command", "Remove rows"));
     for (std::vector<int>::const_iterator it = sortedRows.begin(); it != sortedRows.end(); ++it) {
-        Gui::Command::doCommand(Gui::Command::Doc,"App.ActiveDocument.%s.removeRows('%s', %d)", sheet->getNameInDocument(),
-                                rowName(*it).c_str(), 1);
+        Gui::cmdAppObjectArgs(sheet, "removeRows('%s', %d)", rowName(*it).c_str(), 1);
     }
     Gui::Command::commitCommand();
     Gui::Command::doCommand(Gui::Command::Doc, "App.ActiveDocument.recompute()");
@@ -189,7 +216,7 @@ void SheetTableView::insertColumns()
     std::sort(sortedColumns.begin(), sortedColumns.end());
 
     /* Insert columns */
-    Gui::Command::openCommand("Insert columns");
+    Gui::Command::openCommand(QT_TRANSLATE_NOOP("Command", "Insert columns"));
     std::vector<int>::const_reverse_iterator it = sortedColumns.rbegin();
     while (it != sortedColumns.rend()) {
         int prev = *it;
@@ -207,8 +234,8 @@ void SheetTableView::insertColumns()
                 break;
         }
 
-        Gui::Command::doCommand(Gui::Command::Doc,"App.ActiveDocument.%s.insertColumns('%s', %d)", sheet->getNameInDocument(),
-                                columnName(prev).c_str(), count);
+        Gui::cmdAppObjectArgs(sheet, "insertColumns('%s', %d)",
+                                     columnName(prev).c_str(), count);
     }
     Gui::Command::commitCommand();
     Gui::Command::doCommand(Gui::Command::Doc, "App.ActiveDocument.recompute()");
@@ -227,10 +254,10 @@ void SheetTableView::removeColumns()
     std::sort(sortedColumns.begin(), sortedColumns.end(), std::greater<int>());
 
     /* Remove columns */
-    Gui::Command::openCommand("Remove rows");
+    Gui::Command::openCommand(QT_TRANSLATE_NOOP("Command", "Remove rows"));
     for (std::vector<int>::const_iterator it = sortedColumns.begin(); it != sortedColumns.end(); ++it)
-        Gui::Command::doCommand(Gui::Command::Doc,"App.ActiveDocument.%s.removeColumns('%s', %d)", sheet->getNameInDocument(),
-                                columnName(*it).c_str(), 1);
+        Gui::cmdAppObjectArgs(sheet, "removeColumns('%s', %d)",
+                                     columnName(*it).c_str(), 1);
     Gui::Command::commitCommand();
     Gui::Command::doCommand(Gui::Command::Doc, "App.ActiveDocument.recompute()");
 }
@@ -253,7 +280,7 @@ void SheetTableView::updateCellSpan(CellAddress address)
 void SheetTableView::setSheet(Sheet * _sheet)
 {
     sheet = _sheet;
-    cellSpanChangedConnection = sheet->cellSpanChanged.connect(bind(&SheetTableView::updateCellSpan, this, _1));
+    cellSpanChangedConnection = sheet->cellSpanChanged.connect(bind(&SheetTableView::updateCellSpan, this, bp::_1));
 
     // Update row and column spans
     std::vector<std::string> usedCells = sheet->getUsedCells();
@@ -392,7 +419,7 @@ void SheetTableView::deleteSelection()
     QModelIndexList selection = selectionModel()->selectedIndexes();
 
     if (selection.size() > 0) {
-        Gui::Command::openCommand("Clear cell(s)");
+        Gui::Command::openCommand(QT_TRANSLATE_NOOP("Command", "Clear cell(s)"));
         std::vector<Range> ranges = selectedRanges();
         std::vector<Range>::const_iterator i = ranges.begin();
 
@@ -405,6 +432,8 @@ void SheetTableView::deleteSelection()
     }
 }
 
+static const QLatin1String _SheetMime("application/x-fc-spreadsheet");
+
 void SheetTableView::copySelection()
 {
     QModelIndexList selection = selectionModel()->selectedIndexes();
@@ -412,7 +441,6 @@ void SheetTableView::copySelection()
     int maxRow = 0;
     int minCol = INT_MAX;
     int maxCol = 0;
-
     for (auto it : selection) {
         int row = it.row();
         int col = it.column();
@@ -434,7 +462,13 @@ void SheetTableView::copySelection()
         if (i < maxRow)
             selectedText.append(QChar::fromLatin1('\n'));
     }
-    QApplication::clipboard()->setText(selectedText);
+
+    Base::StringWriter writer;
+    sheet->getCells()->copyCells(writer,selectedRanges());
+    QMimeData *mime = new QMimeData();
+    mime->setText(selectedText);
+    mime->setData(_SheetMime,QByteArray(writer.getString().c_str()));
+    QApplication::clipboard()->setMimeData(mime);
 }
 
 void SheetTableView::cutSelection()
@@ -445,20 +479,50 @@ void SheetTableView::cutSelection()
 
 void SheetTableView::pasteClipboard()
 {
-    QString text = QApplication::clipboard()->text();
-    QStringList rows = text.split(QLatin1Char('\n'));
+    const QMimeData* mimeData = QApplication::clipboard()->mimeData();
+    if(!mimeData || !mimeData->hasText())
+        return;
+
+    if(selectionModel()->selectedIndexes().size()>1) {
+        QMessageBox::warning(Gui::getMainWindow(), QObject::tr("Spreadsheet"),
+                QObject::tr("Spreadsheet does not support range selection when pasting.\n"
+                            "Please select one cell only."));
+        return;
+    }
 
     QModelIndex current = currentIndex();
-    int i=0;
-    for (auto it : rows) {
-        QStringList cols = it.split(QLatin1Char('\t'));
-        int j=0;
-        for (auto jt : cols) {
-            QModelIndex index = model()->index(current.row()+i, current.column()+j);
-            model()->setData(index, jt);
-            j++;
+
+    App::AutoTransaction committer("Paste cell");
+    try {
+        if (!mimeData->hasFormat(_SheetMime)) {
+            QStringList cells;
+            QString text = mimeData->text();
+            int i=0;
+            for (auto it : text.split(QLatin1Char('\n'))) {
+                QStringList cols = it.split(QLatin1Char('\t'));
+                int j=0;
+                for (auto jt : cols) {
+                    QModelIndex index = model()->index(current.row()+i, current.column()+j);
+                    model()->setData(index, jt);
+                    j++;
+                }
+                i++;
+            }
+        }else{
+            QByteArray res = mimeData->data(_SheetMime);
+            Base::ByteArrayIStreambuf buf(res);
+            std::istream in(0);
+            in.rdbuf(&buf);
+            Base::XMLReader reader("<memory>", in);
+            sheet->getCells()->pasteCells(reader,CellAddress(current.row(),current.column()));
         }
-        i++;
+
+        GetApplication().getActiveDocument()->recompute();
+
+    }catch(Base::Exception &e) {
+        e.ReportException();
+        QMessageBox::critical(Gui::getMainWindow(), QObject::tr("Copy & Paste failed"),
+                QString::fromLatin1(e.what()));
     }
 }
 
