@@ -64,6 +64,10 @@
 #include <QtGui/QMouseEvent>
 #include <math.h>
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+# include <QScreen>
+#endif
+
 #include "qtcolorpicker.h"
 
 /*! \class QtColorPicker
@@ -168,7 +172,7 @@ class ColorPickerItem : public QFrame
     Q_OBJECT
 
 public:
-    ColorPickerItem(const QColor &color = Qt::white, const QString &text = QString::null,
+    ColorPickerItem(const QColor &color = Qt::white, const QString &text = QString(),
               QWidget *parent = 0);
     ~ColorPickerItem();
 
@@ -312,7 +316,11 @@ void QtColorPicker::buttonPressed(bool toggled)
     if (!toggled)
         return;
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+    const QRect desktop = QApplication::primaryScreen()->geometry();
+#else
     const QRect desktop = QApplication::desktop()->geometry();
+#endif
     // Make sure the popup is inside the desktop.
     QPoint pos = mapToGlobal(rect().bottomLeft());
     if (pos.x() < desktop.left())
