@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="eu" sourcelanguage="en">
+<TS version="2.1" language="eu" sourcelanguage="en">
   <context>
     <name>StartPage</name>
     <message>
@@ -154,9 +154,9 @@
       <translation>Ikusi aldaketa guztiak github-en</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="70"/>
-      <source>See all commits on github</source>
-      <translation>Ikusi aldaketa guztiak github-en</translation>
+      <location filename="../../../StartPage/TranslationTexts.py" line="71"/>
+      <source>You can configure a custom folder to display here in menu Edit -&gt; Preferences -&gt; Start -&gt; Show additional folder</source>
+      <translation>Karpeta pertsonalizatu bat konfiguratu daiteke hemen erakutsia izan dadin. Horretarako aukera: 'Editatu -&gt; Hobespenak -&gt; Hasiera -&gt; Erakutsi karpeta gehigarria'</translation>
     </message>
     <message>
       <location filename="../../../StartPage/TranslationTexts.py" line="73"/>
@@ -209,9 +209,9 @@
       <translation>Oharrak</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="81"/>
-      <source>Notes</source>
-      <translation>Oharrak</translation>
+      <location filename="../../../StartPage/TranslationTexts.py" line="82"/>
+      <source>Open start page preferences</source>
+      <translation>Ireki hasiera-orriaren hobespenak</translation>
     </message>
   </context>
   <context>
@@ -222,11 +222,6 @@
       <source>Start page</source>
       <translation>Hasierako orria</translation>
     </message>
-    <message>
-      <location filename="../../../StartPage/StartPage.py" line="545"/>
-      <source>Start page</source>
-      <translation>Hasierako orria</translation>
-    </message>
   </context>
   <context>
     <name>CmdStartPage</name>
