@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="hu" sourcelanguage="en">
+<TS version="2.1" language="hu" sourcelanguage="en">
   <context>
     <name>StartPage</name>
     <message>
@@ -154,9 +154,9 @@
       <translation>Tekintse meg az összes github közzétételt</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="70"/>
-      <source>See all commits on github</source>
-      <translation>Tekintse meg az összes github közzétételt</translation>
+      <location filename="../../../StartPage/TranslationTexts.py" line="71"/>
+      <source>You can configure a custom folder to display here in menu Edit -&gt; Preferences -&gt; Start -&gt; Show additional folder</source>
+      <translation>Az ebben a menüben megjelenítendő egyéni mappát beállíthatod a Szerkesztés -&gt; Beállítások -&gt; Start -&gt; További mappa menüpontban</translation>
     </message>
     <message>
       <location filename="../../../StartPage/TranslationTexts.py" line="73"/>
@@ -209,9 +209,9 @@
       <translation>Megjegyzések</translation>
     </message>
     <message>
-      <location filename="../../../StartPage/TranslationTexts.py" line="81"/>
-      <source>Notes</source>
-      <translation>Megjegyzések</translation>
+      <location filename="../../../StartPage/TranslationTexts.py" line="82"/>
+      <source>Open start page preferences</source>
+      <translation>Kezdőlap beállításainak megnyitása</translation>
     </message>
   </context>
   <context>
@@ -222,11 +222,6 @@
       <source>Start page</source>
       <translation>Kezdőlap</translation>
     </message>
-    <message>
-      <location filename="../../../StartPage/StartPage.py" line="545"/>
-      <source>Start page</source>
-      <translation>Kezdőlap</translation>
-    </message>
   </context>
   <context>
     <name>CmdStartPage</name>
