@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) 2016 Wandererfan <wandererfan@gmail.com>                *
+ *   Copyright (c) 2016 WandererFan <wandererfan@gmail.com>                *
  *                                                                         *
  *   This file is part of the FreeCAD CAx development system.              *
  *                                                                         *
@@ -183,11 +183,13 @@ bool EdgeWalker::perform()
     kura_edges_t::iterator ki, ki_end;
     graph_traits<TechDraw::graph>::edge_descriptor e1;
 
+#if 0 // Function declared in block and lacking of implementation
     // Get the index associated with edge
     graph_traits<TechDraw::graph>::edges_size_type
         get(boost::edge_index_t,
             const TechDraw::graph& m_g,
             graph_traits<TechDraw::graph>::edge_descriptor edge);
+#endif
 
     bool isPlanar = boyer_myrvold_planarity_test(boyer_myrvold_params::graph = m_g,
                                  boyer_myrvold_params::embedding = &embedding[0],            // this is "an" embedding but not one for finding
@@ -341,6 +343,7 @@ std::vector<WalkerEdge> EdgeWalker::makeWalkerEdges(std::vector<TopoDS_Edge> edg
         WalkerEdge we;
         we.v1 = v1dx;
         we.v2 = v2dx;
+        we.idx = 0;
         walkerEdges.push_back(we);
     }
 
@@ -370,7 +373,7 @@ std::vector<TopoDS_Wire> EdgeWalker::sortStrip(std::vector<TopoDS_Wire> fw, bool
         if (BRep_Tool::IsClosed(w)) {
             closedWires.push_back(w);
         }
-    }        
+    }
     std::vector<TopoDS_Wire> sortedWires = sortWiresBySize(closedWires,false);           //biggest 1st
     if (!sortedWires.size()) {
         Base::Console().Log("INFO - EW::sortStrip - no sorted Wires!\n");
@@ -380,7 +383,7 @@ std::vector<TopoDS_Wire> EdgeWalker::sortStrip(std::vector<TopoDS_Wire> fw, bool
     if (!includeBiggest) {
         sortedWires.erase(sortedWires.begin());
     }
-    
+
     return sortedWires;
 }
 
