@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="sv-SE" sourcelanguage="en">
+<TS version="2.1" language="sv-SE" sourcelanguage="en">
   <context>
     <name>CmdWebBrowserBack</name>
     <message>
@@ -48,7 +48,21 @@
       <location filename="../../Command.cpp" line="135"/>
       <location filename="../../Command.cpp" line="136"/>
       <source>Refresh web page</source>
-      <translation>Uppdatera websidan</translation>
+      <translation>Uppdatera webbsida</translation>
+    </message>
+  </context>
+  <context>
+    <name>CmdWebBrowserSetURL</name>
+    <message>
+      <location filename="../../Command.cpp" line="250"/>
+      <source>Web</source>
+      <translation>Webb</translation>
+    </message>
+    <message>
+      <location filename="../../Command.cpp" line="251"/>
+      <location filename="../../Command.cpp" line="252"/>
+      <source>Set URL</source>
+      <translation>Ange URL</translation>
     </message>
   </context>
   <context>
@@ -114,13 +128,13 @@
   <context>
     <name>QObject</name>
     <message>
-      <location filename="../../AppWebGui.cpp" line="80"/>
-      <location filename="../../BrowserView.cpp" line="441"/>
+      <location filename="../../AppWebGui.cpp" line="88"/>
+      <location filename="../../BrowserView.cpp" line="748"/>
       <source>Browser</source>
       <translation>Webbläsare</translation>
     </message>
     <message>
-      <location filename="../../BrowserView.cpp" line="338"/>
+      <location filename="../../BrowserView.cpp" line="563"/>
       <source>File does not exist!</source>
       <translation>Filen existerar inte!</translation>
     </message>
@@ -128,18 +142,24 @@
   <context>
     <name>WebGui::BrowserView</name>
     <message>
-      <location filename="../../BrowserView.cpp" line="329"/>
-      <location filename="../../BrowserView.cpp" line="334"/>
+      <location filename="../../BrowserView.cpp" line="551"/>
+      <location filename="../../BrowserView.cpp" line="556"/>
+      <location filename="../../BrowserView.cpp" line="559"/>
       <source>Error</source>
       <translation>Fel</translation>
     </message>
     <message>
-      <location filename="../../BrowserView.cpp" line="334"/>
+      <location filename="../../BrowserView.cpp" line="556"/>
       <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
-      <translation>Det uppstod ett fel under inläsning av filen. Viss data kan ha ändrats eller inte hämtats alls. Titta i rapportvyn för mer specifik information om de inblandade objekten.</translation>
+      <translation>Det uppstod ett fel under inläsning av filen. Viss data kan ha ändrats eller inte återställts alls. Titta i rapportvyn för mer specifik information om de inblandade objekten.</translation>
     </message>
     <message>
-      <location filename="../../BrowserView.cpp" line="412"/>
+      <location filename="../../BrowserView.cpp" line="559"/>
+      <source>There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</source>
+      <translation type="unfinished">There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</translation>
+    </message>
+    <message>
+      <location filename="../../BrowserView.cpp" line="719"/>
       <source>Loading %1...</source>
       <translation>Laddar %1...</translation>
     </message>
@@ -147,14 +167,19 @@
   <context>
     <name>WebGui::WebView</name>
     <message>
-      <location filename="../../BrowserView.cpp" line="185"/>
+      <location filename="../../BrowserView.cpp" line="308"/>
       <source>Open in External Browser</source>
       <translation>Öppna i extern webbläsare</translation>
     </message>
     <message>
-      <location filename="../../BrowserView.cpp" line="189"/>
+      <location filename="../../BrowserView.cpp" line="312"/>
       <source>Open in new window</source>
-      <translation>Öppna i Nytt fönster</translation>
+      <translation>Öppna i nytt fönster</translation>
+    </message>
+    <message>
+      <location filename="../../BrowserView.cpp" line="344"/>
+      <source>View source</source>
+      <translation>Visa källa</translation>
     </message>
   </context>
   <context>
