@@ -1,12 +1,5 @@
-# Web gui init module  
-# (c) 2003 Juergen Riegel
-#
-# Gathering all the information to start FreeCAD
-# This is the second one of three init scripts, the third one
-# runs when the gui is up
-
 #***************************************************************************
-#*   (c) Juergen Riegel (juergen.riegel@web.de) 2002                       *
+#*   Copyright (c) 2002,2003 Jürgen Riegel <juergen.riegel@web.de>         *
 #*                                                                         *
 #*   This file is part of the FreeCAD CAx development system.              *
 #*                                                                         *
@@ -25,10 +18,13 @@
 #*   License along with FreeCAD; if not, write to the Free Software        *
 #*   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  *
 #*   USA                                                                   *
-#*                                                                         *
-#*   Juergen Riegel 2002                                                   *
 #***************************************************************************/
 
+# Web gui init module
+#
+# Gathering all the information to start FreeCAD
+# This is the second one of three init scripts, the third one
+# runs when the gui is up
 
 
 class WebWorkbench ( Workbench ):
@@ -47,4 +43,7 @@ class WebWorkbench ( Workbench ):
 
 Gui.addWorkbench(WebWorkbench())
 
+# Append the open handler
+FreeCAD.addImportType("Web Page (*.html *.xhtml)", "WebGui")
+
 FreeCAD.__unit_test__ += [ "TestWebGui" ]
