@@ -4,5 +4,5 @@
 
 class ModelTemplate:
     def Generate(self):
-        print "Genertate() needs to be implemented in a Template class!"
+        print("Generate() needs to be implemented in a Template class!")
 
